/**
 * @license
 * Copyright 2019 The Emscripten Authors
 * SPDX-License-Identifier: MIT
 */

// wasm2js.js - enough of a polyfill for the WebAssembly object so that we can load
// wasm2js code that way.

// Emit "var WebAssembly" if definitely using wasm2js. Otherwise, in MAYBE_WASM2JS
// mode, we can't use a "var" since it would prevent normal wasm from working.
/** @suppress{duplicate, const} */
var
WebAssembly = {
  // Note that we do not use closure quoting (this['buffer'], etc.) on these
  // functions, as they are just meant for internal use. In other words, this is
  // not a fully general polyfill.
  /** @constructor */
  Memory: function(opts) {
    this.buffer = new ArrayBuffer(opts['initial'] * 65536);
  },

  Module: function(binary) {
    // TODO: use the binary and info somehow - right now the wasm2js output is embedded in
    // the main JS
  },

  /** @constructor */
  Instance: function(module, info) {
    // TODO: use the module and info somehow - right now the wasm2js output is embedded in
    // the main JS
    // This will be replaced by the actual wasm2js code.
    this.exports = (
// EMSCRIPTEN_START_ASM
function instantiate(xb){function c(d){d.set=function(a,b){this[a]=b};d.get=function(a){return this[a]};return d}var e;var f=new ArrayBuffer(16);var g=new Int32Array(f);var h=new Float32Array(f);var i=new Float64Array(f);function j(k){return g[k]}function l(k,m){g[k]=m}function n(){return i[0]}function o(m){i[0]=m}function p(m){h[2]=m}function q(){return h[2]}function vb(wb){var r=wb.a;var s=r.buffer;r.grow=tb;var t=new Int8Array(s);var u=new Int16Array(s);var v=new Int32Array(s);var w=new Uint8Array(s);var x=new Uint16Array(s);var y=new Uint32Array(s);var z=new Float32Array(s);var A=new Float64Array(s);var B=Math.imul;var C=Math.fround;var D=Math.abs;var E=Math.clz32;var F=Math.min;var G=Math.max;var H=Math.floor;var I=Math.ceil;var J=Math.trunc;var K=Math.sqrt;var L=wb.abort;var M=NaN;var N=Infinity;var O=wb.b;var P=wb.c;var Q=wb.d;var R=wb.e;var S=wb.f;var T=wb.g;var U=wb.h;var V=wb.i;var W=wb.j;var X=wb.k;var Y=wb.l;var Z=wb.m;var _=wb.n;var $=wb.o;var aa=wb.p;var ba=wb.q;var ca=wb.r;var da=wb.s;var ea=wb.t;var fa=wb.u;var ga=wb.v;var ha=wb.w;var ia=wb.x;var ja=wb.y;var ka=wb.z;var la=wb.A;var ma=wb.B;var na=wb.C;var oa=wb.D;var pa=wb.E;var qa=wb.F;var ra=wb.G;var sa=wb.H;var ta=wb.I;var ua=wb.J;var va=wb.K;var wa=wb.L;var xa=wb.M;var ya=wb.N;var za=wb.O;var Aa=wb.P;var Ba=wb.Q;var Ca=wb.R;var Da=wb.S;var Ea=wb.T;var Fa=wb.U;var Ga=wb.V;var Ha=wb.W;var Ia=wb.X;var Ja=wb.Y;var Ka=wb.Z;var La=wb._;var Ma=wb.$;var Na=wb.aa;var Oa=wb.ba;var Pa=wb.ca;var Qa=wb.da;var Ra=wb.ea;var Sa=wb.fa;var Ta=wb.ga;var Ua=wb.ha;var Va=wb.ia;var Wa=wb.ja;var Xa=wb.ka;var Ya=wb.la;var Za=wb.ma;var _a=wb.na;var $a=wb.oa;var ab=wb.pa;var bb=wb.qa;var cb=wb.ra;var db=wb.sa;var eb=wb.ta;var fb=wb.ua;var gb=wb.va;var hb=wb.wa;var ib=wb.xa;var jb=5713008;var kb=0;var lb=0;var mb=0;
// EMSCRIPTEN_START_FUNCS
function yJ(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,A=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,Q=0,R=0,S=0,V=0,W=C(0),X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=C(0),Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=C(0),_a=0;da=jb-32|0;jb=da;e=da+24|0;v[e>>2]=49532;v[e>>2]=49432;g=xJ(da+16|0);h=xJ(da+8|0);fa=b;la=c;ma=e;na=v[g>>2];Ea=w[g+4|0];oa=v[h>>2];Fa=w[h+4|0];c=0;M=jb-112|0;jb=M;d=a;pa=a+24604|0;a=pa;a:{if(!v[a+16>>2]){break a}b=v[a+20>>2];if(b>>>0>4|!(1<<b&22)){break a}a=v[a+28>>2];if(a>>>0>4){break a}c=23>>>a&1}if(!c){c=M+96|0;MM(c,9093,12922,220,45);a=jb-48|0;jb=a;b=xc(a+16|0,17718);v[23588]=0;U(5,a|0,1,17381);e=v[23588];v[23588]=0;b:{c:{d:{e:{if((e|0)!=1){v[23588]=0;U(2,a+32|0,b|0,a|0);e=v[23588];v[23588]=0;if((e|0)==1){break e}v[23588]=0;U(843,c|0,1,a+32|0);c=v[23588];v[23588]=0;if((c|0)!=1){break b}c=P()|0;O()|0;zb(a+32|0);break d}c=P()|0;O()|0;break c}c=P()|0;O()|0}zb(a)}zb(b);T(c|0);L()}zb(a+32|0);zb(a);zb(b);jb=a+48|0}qa=d+8204|0;ra=d+397452|0;sa=d+397448|0;aa=d+393352|0;H=d+397456|0;_=d+12|0;Ga=d+1074376|0;Ha=d+1298420|0;Ia=d+1074365|0;while(1){f:{g:{a=v[d+480208>>2];if(!(!fa|a&512)){h:{if(v[d+1074380>>2]){break h}b=a|512;i:{if(a&256){break i}j=jb-48|0;jb=j;F=jb-32|0;jb=F;k=d+1074312|0;e=d+1074992|0;h=d+1298264|0;s=d+1074424|0;o=d+484360|0;n=d+1074448|0;m=d+1074376|0;b=v[d+1074392>>2];r=d+480188|0;A=d+480180|0;q=d+484376|0;p=d+484348|0;G=d+480210|0;E=d+484364|0;j:{k:{l:while(1){m:{a=b+1|0;v[d+1074392>>2]=a;if(il(m)>>>0>a>>>0){break m}bO(F+24|0,v[A>>2],x[r>>1],m,(v[d+480208>>2]&524288)>>>19|0);n:{o:{p:{q:{r:{if(w[d+480208|0]&32){l=v[p>>2];c=v[d+484344>>2];b=x[d+1074446>>1];break r}b=65535;J=v[d+484360>>2];i=w[q|0];a=Vb(J,i);c=v[a>>2];a=Qc(c,v[a+4>>2]);f=x[d+1074448>>1];if(a>>>0>f>>>0){b=x[cc(c,f)>>1]}u[d+1074446>>1]=b;s:{t:{c=v[d+484344>>2];l=v[p>>2];a=b&65535;if(Af(c,l)>>>0<=a>>>0){break t}a=Yb(c,a);if(Ob(v[a>>2],v[a+4>>2])){break t}a=0;break s}a=1}while(1){u:{v:{if(!a){b=65534;u[d+1074446>>1]=65534;break v}w:{x:{y:{a=b&65535;if(Af(c,l)>>>0<=a>>>0){z:{A:{if((a|0)==65535){g=Vb(J,i);break A}g=Vb(J,i);if(Qc(v[g>>2],v[g+4>>2])>>>0>(f&65535)>>>0){break z}}b=x[g+28>>1];if(b){c=v[g>>2];l=Qc(c,v[g+4>>2]);break x}a=f&65535;c=v[g>>2];l=Qc(c,v[g+4>>2]);if(!a|l>>>0<a>>>0){break y}while(1){b=a;a=a-1|0;if(!a){break y}if(x[cc(c,a)>>1]!=65535){continue}break}break x}f=f+1|0;u[n>>1]=f;break w}u[d+1074450>>1]=f;break r}b=0}u[d+1074448>>1]=b;v[d+480208>>2]=v[d+480208>>2]&-524289;while(1){a=b&65535;if(a>>>0>=l>>>0){break q}if(x[cc(c,a)>>1]==65534){b=b+1|0;u[n>>1]=b;continue}break}if(!Gq(g,a)){break q}f=x[d+1074448>>1];J=v[d+484360>>2];i=w[q|0];g=Vb(J,i)}b=65535;a=f&65535;if(Qc(v[g>>2],v[g+4>>2])>>>0>a>>>0){b=x[cc(v[Vb(J,i)>>2],a)>>1]}u[d+1074446>>1]=b;c=v[d+484344>>2];l=v[p>>2];a=b&65535;if(Af(c,l)>>>0<=a>>>0){break v}a=Yb(c,a);if(!Ob(v[a>>2],v[a+4>>2])){break u}}a=1;continue}a=0;continue}}a=b&65535;if(!xe(c,l,a)){break k}b=v[s>>2];if(b>>>0>=y[Yb(c,a)+12>>2]){v[s>>2]=0;b=0}if(v[d+480208>>2]&32?v[d+480272>>2]!=-1:0){break n}if(!st(h,x[n>>1],b,Up(F+16|0,e),w[F+24|0])){break n}a=v[d+480272>>2];if(a){if((a|0)>0){v[d+480272>>2]=a-1}$n(h,1);st(h,x[n>>1],v[s>>2],Up(F+16|0,e),w[F+24|0]);break n}if(!(w[G|0]&64)){break q}b=0;if(nO(h,n,s)){break o}v[d+1074424>>2]=0;v[d+1074428>>2]=0;v[d+1074448>>2]=0;c=rj(v[d+484360>>2],v[E>>2])-1|0;a=w[q|0];if((c|0)>(a|0)){break p}Fj(o,0)}$n(h,1);break k}Fj(o,a+1&255);$n(h,1)}while(1){if((b|0)==256){CM(d);v[d+1074416>>2]=v[d+480196>>2];v[d+1074420>>2]=v[d+480204>>2];v[d+1074456>>2]=v[d+480200>>2];a=x[d+1074448>>1];u[d+1074450>>1]=a;b=v[d+1074424>>2];v[d+1074428>>2]=b;c=Vb(v[d+484360>>2],w[q|0]);g=v[c>>2];if(Qc(g,v[c+4>>2])>>>0>a>>>0){Xa=d,Ya=x[cc(g,a)>>1],u[Xa+1074446>>1]=Ya}st(h,a,b,Up(F+16|0,e),w[F+24|0]);if(!xe(v[d+484344>>2],v[p>>2],x[d+1074446>>1])){break k}}else{eo((B(b,872)+d|0)+1074992|0,d,b&65535,134217728);b=b+1|0;continue}break}}aO(d,m,(v[d+480208>>2]&32)>>>5|0);a=Yb(v[d+484344>>2],x[d+1074446>>1]);a=id(v[a>>2],v[v[a+48>>2]+12>>2],v[d+1074424>>2],0);g=e+B(x[r>>1],872)|0;b=e;while(1){if((b|0)==(g|0)){B:{C:{a=v[d+484344>>2];b=x[d+1074446>>1];if(Qm(a,v[d+484348>>2],b)){a=Yb(a,b);b=v[a+16>>2];a=v[a+20>>2];if(ZN(b,a)){break C}}v[d+1074408>>2]=v[d+480216>>2];a=v[d+480220>>2];break B}v[d+1074408>>2]=b}v[d+1074412>>2]=a;if(!w[F+24|0]){break m}b=v[d+1074416>>2];v[d+1074392>>2]=b;continue l}Cb(F+16|0,k,82);D:{if(!Bb(v[v[F+16>>2]>>2],v[F+20>>2])|w[b+805|0]!=1){break D}c=w[a+3|0];if((c|0)!=2&(c|0)!=3){break D}Xa=b,Ya=eh(d,w[b+800|0],u[b+772>>1],v[b+704>>2]),v[Xa+700>>2]=Ya}Cb(F+16|0,k,91);E:{if(!Bb(v[v[F+16>>2]>>2],v[F+20>>2])){break E}if(_c(w[a|0])){break E}c=w[b+788|0];if(!_c(c)|w[b+791|0]!=19){break E}f=w[b+793|0];if((f&240)!=208|y[d+1074416>>2]>(f&15)>>>0){break E}Xa=b,Ya=eh(d,c,u[b+772>>1],0),v[Xa+700>>2]=Ya}Cb(F+16|0,k,92);F:{if(!Bb(v[v[F+16>>2]>>2],v[F+20>>2])){break F}Cb(F+8|0,k,5);if(Bb(v[v[F+8>>2]>>2],v[F+12>>2])|v[d+1074416>>2]!=1|w[b+791|0]!=17){break F}v[d+1074420>>2]=B(w[b+793|0],1e4)}c=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);t[b+788|0]=c;t[b+789|0]=c>>>8;t[b+790|0]=c>>>16;t[b+791|0]=c>>>24;c=w[a+4|0]|w[a+5|0]<<8;t[b+792|0]=c;t[b+793|0]=c>>>8;c=v[b+676>>2];v[b+20>>2]=v[b+672>>2];v[b+24>>2]=c;v[b+88>>2]=v[b+88>>2]&-393217;Cb(F+16|0,k,21);if(!Bb(v[v[F+16>>2]>>2],v[F+20>>2])){t[b+831|0]=0}v[b+860>>2]=0;t[b+805|0]=0;a=a+6|0;b=b+872|0;continue}}break}a=v[d+1074416>>2];if(!a){v[d+1074416>>2]=1;a=1}b=v[d+480208>>2];e=v[d+1074392>>2];G:{H:{if(e){c=b&-4097;v[d+480208>>2]=c;g=v[d+480180>>2];if(g&1048580|(b&2097152?0:(g|0)==1)){break G}if(il(m)>>>0<=e>>>0){break G}if(!((e>>>0)%(v[d+1074400>>2]+a>>>0)|0)){break H}break G}c=b&-528385}v[d+480208>>2]=c|4096}q=0;i=jb-16|0;jb=i;u[d+1074444>>1]=65535;a=d+1074436|0;v[a>>2]=-1;v[a+4>>2]=-1;A=d+480180|0;$=d+1075809|0;o=d+1074312|0;Z=d+906300|0;G=d+480208|0;I=d+1074376|0;Y=d+480188|0;ba=d+480210|0;V=d+480190|0;Q=d+480192|0;while(1){I:{if(x[Y>>1]<=q>>>0){J:{if(!(w[G+1|0]&16)){break J}if(!SN(d,I,Vb(v[d+484360>>2],w[d+484376|0]),1)){break J}v[G>>2]=v[G>>2]|524288}jb=i+16|0;break I}p=B(q,872)+d|0;k=p+1075785|0;c=w[k|0];l=p+1075784|0;r=w[l|0];R=p+1075781|0;e=w[R|0];a=v[d+1074392>>2];b=v[d+1074400>>2];h=v[d+1074416>>2];X=p+1075782|0;f=w[X|0];s=p+1075783|0;J=w[s|0];g=vm(f,J);n=p+1075843|0;t[n|0]=v[G>>2]>>>12&1|w[n|0]&254;h=(a>>>0)%(b+h>>>0)|0;N=p+1075780|0;a=w[N|0];K:{L:{M:{if((a|0)==252){m=gk(f,r);E=gk(J,c);a=252;b=e-1|0;if((b&255)>>>0>249){break M}b=v[Ld(Z,b)>>2];if(!b){break M}nb[v[v[b>>2]+44>>2]](b,m,C(C(E>>>0)/C(999)));a=w[N|0]}if((a&255)==251){break L}}if(z[p+1075852>>2]==C(0)|J){break K}}m=v[G>>2]&4096;N:{if(!m){b=w[p+1075862|0];break N}b=w[R|0];t[p+1075862|0]=b}if((b-1&255)>>>0>249){break K}E=Ld(Z,(b&255)-1|0);b=v[E>>2];if(!b){break K}O:{if(!m){a=x[p+1075860>>1];break O}a=Vy(w[X|0],w[l|0]);u[p+1075860>>1]=a;W=C(C(Vy(w[s|0],w[k|0])>>>0)/C(999));z[p+1075856>>2]=W;Xa=p+1075852|0,Za=C(C(W-C(nb[v[v[b>>2]+48>>2]](b,a)))/C(il(I)>>>0)),z[Xa>>2]=Za;b=v[E>>2]}k=a;a=(v[d+1074392>>2]+1|0)==(il(I)|0);nb[v[v[b>>2]+(a?44:108)>>2]](b,k,z[(a?p+1075856|0:p+1075852|0)>>2]);a=w[N|0]}k=p+1074992|0;if(HN(a&255)){b=jb-16|0;jb=b;u[b+12>>1]=0;v[b+8>>2]=0;a=tg(b+8|0);c=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);t[k+788|0]=c;t[k+789|0]=c>>>8;t[k+790|0]=c>>>16;t[k+791|0]=c>>>24;a=w[a+4|0]|w[a+5|0]<<8;t[k+792|0]=a;t[k+793|0]=a>>>8;jb=b+16|0;g=0;J=0;r=0;f=0;e=0;c=0}P:{if(!(w[G+1|0]&16)){hN(d,k);break P}if(!e){break P}v[p+1075752>>2]=0}Q:{R:{if((J|0)==33){Cb(i+8|0,o,30);a=c>>>4|0;Gy(d,q&65535,a+(c&15)|0,Bb(v[v[i+8>>2]>>2],v[i+12>>2]));break R}a=0;if((J-19&255)>>>0>1){break R}S:{if(!(!(v[A>>2]&16777250)|c)){c=w[p+1075825|0];break S}t[p+1075825|0]=c}b=c&240;if((b|0)==208){b=c&15;if(!b){b=v[A>>2];if(b&16777248){a=1;break R}if((b|0)==2){break Q}break R}if(b>>>0>=v[d+1074400>>2]+v[d+1074416>>2]>>>0){Cb(i+8|0,o,14);a=b;if(!Bb(v[v[i+8>>2]>>2],v[i+12>>2])){break R}if(!e){break Q}t[p+1075795|0]=e;break Q}a=b;break R}if(!(w[G+1|0]&16)|(b|0)!=224){break R}b=v[A>>2];if(v[d+1074396>>2]?b&16777250:0){break R}m=b&2;b=c&15;if(b?0:m){break R}v[d+1074396>>2]=b+1}b=v[A>>2]==16&(J|0)==19&(c&240)==208;E=b?0:a;T:{if(!E|w[N|0]!=255|w[X|0]!=2){break T}Cb(i+8|0,o,74);if(!Bb(v[v[i+8>>2]>>2],v[i+12>>2])){break T}t[X|0]=0}K=c&15;a=v[d+1074392>>2];Cb(i+8|0,o,72);U:{if(Bb(v[v[i+8>>2]>>2],v[i+12>>2])){s=0;if(E>>>0>=y[d+1074416>>2]){break U}}Cb(i+8|0,o,88);s=(h|0)==(E|0)|(a|0)==(E|0);if(!(!Bb(v[v[i+8>>2]>>2],v[i+12>>2])|!E)){break U}s=(a|0)==(E|0)}Cb(i+8|0,o,44);b=b?K|144:c;V:{if(!Bb(v[v[i+8>>2]>>2],v[i+12>>2])){a=w[n|0];break V}a=w[n|0]&-2|(h|0)==(E|0)}t[n|0]=a&253|(s?2:0);Cb(i+8|0,o,66);g=(!E|Bb(v[v[i+8>>2]>>2],v[i+12>>2])^1)&g;W:{X:{if(!(v[d+1074392>>2]|(!(w[ba|0]&32)|!e))){v[p+1075652>>2]=0;if(s){break X}if(!xi(v[k+8>>2],v[k+12>>2])){break W}t[p+1075795|0]=e;if(x[V>>1]<e>>>0){break W}a=B(e,104)+d|0;v[p+1075680>>2]=x[a+484410>>1];u[p+1075764>>1]=t[a+484417|0];break W}if(!s){break W}}c=w[N|0];if(e){t[p+1075795|0]=e}Y:{Z:{if(!_c(c)){break Z}Cb(i+8|0,o,67);if(!Bb(v[v[i+8>>2]>>2],v[i+12>>2])){break Z}a=u[p+1075762>>1];_:{if(!e|g){break _}h=uq(d,c,e);if(!h){break _}a=t[Gi(d,h)+36|0]}c=(a+c|0)-132>>>0<4294967176?0:c;break Y}if(!(v[A>>2]&25165856)){break Y}l=x[Q>>1];if(!l){break Y}if(c){a=_c(c)}else{a=1}if(!a){break Y}h=e;$:{if(!e){h=w[p+1075796|0];if(!h){break $}}if(v[((h<<2)+d|0)+900380>>2]?h>>>0<=l>>>0:0){break Y}c=0}e=0}if(!((J|0)!=25|b)){Cb(i+8|0,o,55);a=Bb(v[v[i+8>>2]>>2],v[i+12>>2]);e=a?0:e;c=a?0:c}Cb(i+8|0,o,65);a=(e|0)!=0;l=Bb(v[v[i+8>>2]>>2],v[i+12>>2]);ca=!c;S=1;aa:{if(v[A>>2]&16777248){break aa}Cb(i+8|0,o,107);if(Bb(v[v[i+8>>2]>>2],v[i+12>>2])){break aa}Cb(i,o,85);S=0;if(!Bb(v[v[i>>2]>>2],v[i+4>>2])){break aa}if(xi(v[k+8>>2],v[k+12>>2])){break aa}S=1;h=v[p+1075096>>2];if(!h){break aa}S=Zd(v[h>>2],v[h+20>>2])^1}m=a&l;a=a&ca;ba:{ca:{da:{ea:{fa:{ga:{ha:{if(!(v[A>>2]&1048580)){break ha}ia:{if((c|0)!=255){break ia}if(!(!((f|0)==1|e)&(J|0)!=13)){Cb(i+8|0,o,55);if(Bb(v[v[i+8>>2]>>2],v[i+12>>2])){break ia}}h=v[p+1075648>>2];if(t[h+60|0]&1?h:0){break ia}v[p+1075680>>2]=0;a=p+1075080|0;v[a>>2]=v[a>>2]|2097152;ja:{if(!(v[G>>2]&4096)){break ja}Cb(i+8|0,o,86);if(!Bb(v[v[i+8>>2]>>2],v[i+12>>2])){break ja}v[a>>2]=v[a>>2]|4096}e=0;c=0;a=0;h=0;l=1;if(m){break ca}break ba}Cb(i+8|0,o,59);if(!Bb(v[v[i+8>>2]>>2],v[i+12>>2])|v[G>>2]&4096){break ha}if(!c){c=w[p+1075789|0]-w[p+1075762|0]|0;break ga}if(c>>>0>250){S=0;m=1;c=0;break ga}if(!e){Cb(i+8|0,o,98);if(Bb(v[v[i+8>>2]>>2],v[i+12>>2])){break ga}}S=1;m=1;break ga}h=0;if(!a){break ea}break fa}h=c;g=0}Cb(i+8|0,o,65);if(!Bb(v[v[i+8>>2]>>2],v[i+12>>2])){break da}c=h;h=1}a=c;l=1;if(m){break ca}break ba}c=h;h=1;l=m}ka:{la:{if(!x[Q>>1]){if(x[V>>1]<e>>>0){break ka}a=(B(e,104)+d|0)+484380|0;break la}a=v[p+1075096>>2];if(!a){break ka}}ma:{if(u[a+34>>1]<0){break ma}if(v[A>>2]==2){if(!Zd(v[a>>2],v[a+20>>2])){break ma}}v[p+1075680>>2]=x[a+30>>1]}if(!l){break ka}aq(k,x[a+28>>1],d)}a=c}Cb(i+8|0,o,71);if(!(!Bb(v[v[i+8>>2]>>2],v[i+12>>2])|!e)){t[p+1075831|0]=32}na:{if(!x[Q>>1]){break na}Cb(i+8|0,o,100);if(!Bb(v[v[i+8>>2]>>2],v[i+12>>2])|!e){break na}if(_c(a&255)){break na}c=v[G>>2];oa:{if(g){if(c&8){break oa}break na}if(!(c&4)){break na}}tm(k);v[p+1075688>>2]=65536;c=p+1075080|0;v[c>>2]=v[c>>2]|2097152}if(h){Cb(i+8|0,o,11);pa:{qa:{ra:{if(!(Bb(v[v[i+8>>2]>>2],v[i+12>>2])|v[A>>2]==268435456)){c=x[Q>>1];break ra}Cb(i+8|0,o,87);h=0;if(Bb(v[v[i+8>>2]>>2],v[i+12>>2])){h=xi(v[k+8>>2],v[k+12>>2])^1}c=x[Q>>1];sa:{if(c){if(c>>>0<e>>>0){break qa}if(v[p+1075648>>2]!=v[((e<<2)+d|0)+900380>>2]|h){break sa}break qa}if((h^-1)&v[p+1075096>>2]==((B(e,104)+d|0)+484380|0)){break pa}}a=w[p+1075789|0]}if(!(c&65535)){break pa}}if(!(v[A>>2]&1048588)){break pa}tm(k);t[p+1075810|0]=0;v[p+1075748>>2]=0;v[p+1075688>>2]=65536;c=p+1075080|0;v[c>>2]=v[c>>2]&-2101249|2097152;Cb(i+8|0,o,86);if(!Bb(v[v[i+8>>2]>>2],v[i+12>>2])){break pa}v[c>>2]=v[c>>2]&-2049}e=S?e:0}l=a&255;ta:{if(l>>>0<251){break ta}Cb(i+8|0,o,50);ua:{if(!Bb(v[v[i+8>>2]>>2],v[i+12>>2])|!e){break ua}c=uq(d,w[p+1075791|0],e);if(!c){break ua}c=B(c,104)+d|0;if(u[c+484414>>1]<0){break ua}v[p+1075680>>2]=x[c+484410>>1]}Cb(i+8|0,o,100);if(Xa=Bb(v[v[i+8>>2]>>2],v[i+12>>2]),Ya=0,_a=v[G>>2]&4,_a?Xa:Ya){break ta}e=0}c=_c(l);if(c){t[p+1075794|0]=a;t[p+1075791|0]=a;if(!g){iN(d,q&65535,e,l,0)}yP(k)}va:{wa:{xa:{ya:{za:{if(e){h=p+1075096|0;m=v[h>>2];Tp(d,k,e,g,1,1);a=v[h>>2];Aa:{if(!a|!(w[a+35|0]&2)){break Aa}S=v[d+1298300>>2];if(!Ed(S)){break Aa}qz(S,q&65535,a+68|0)}Ba:{Ca:{if(v[A>>2]==1){if(!g){break Ca}Cb(i+8|0,o,85);if(!Bb(v[v[i+8>>2]>>2],v[i+12>>2])){break Ca}break Ba}Cb(i+8|0,o,50);if((c|Bb(v[v[i+8>>2]>>2],v[i+12>>2])^1)!=1){break Ba}}t[p+1075795|0]=0}Cb(i+8|0,o,42);if(Bb(v[v[i+8>>2]>>2],v[i+12>>2])){if(!c|(m|0)==v[h>>2]){break ya}break za}if(v[A>>2]&16777248){a=0;if(c&(m|0)!=v[h>>2]){break xa}}Cb(i+8|0,o,107);Da:{if(!Bb(v[v[i+8>>2]>>2],v[i+12>>2])|((m|0)==v[h>>2]|(c^1|g)!=1)){break Da}a=p+1075068|0;if(y[a>>2]>=y[k+4>>2]){break Da}v[a>>2]=0;break ya}Cb(i+8|0,o,85);if(!Bb(v[v[i+8>>2]>>2],v[i+12>>2])){break ya}if(!xi(v[k+8>>2],v[k+12>>2])){break za}break ya}if(!l){a=g;break va}h=0;m=p+1075795|0;a=w[m|0];if(!(!a|c^1)){Tp(d,k,a,g,!(v[p+1075096>>2]?1:v[p+1075648>>2]),!(v[A>>2]&1048580));t[m|0]=0;h=1}a=g;break wa}v[k>>2]=0;v[k+4>>2]=0}a=g}h=0;if(!l){break va}}c=v[p+1075096>>2];Ea:{if(!c|!(w[c+35|0]&2)){break Ea}g=v[d+1298300>>2];if(!Ed(g)){break Ea}if(!h){if(jN(g,q&65535)){break Ea}}qz(g,q&65535,c+68|0)}c=q&65535;nt(d,k,l,a,!(v[A>>2]&1048580),0,c);XN(v[A>>2],x[Y>>1],I,c);if(!(!a|(!(v[A>>2]&1048580)|!e))){e=p+1075080|0;v[e>>2]=v[e>>2]|2097152;tm(k);t[p+1075810|0]=0;v[p+1075748>>2]=0}if(!(v[p+1075080>>2]&512)){break va}if(!Ed(v[d+1298300>>2])){break va}if(l>>>0<=253){if((l|0)!=253){break va}Cb(i+8|0,o,99);if(Bb(v[v[i+8>>2]>>2],v[i+12>>2])){break va}}Cb(i+8|0,o,110);if(Bb(v[v[i+8>>2]>>2],v[i+12>>2])){rz(v[d+1298300>>2],c,0,1,0)}hk(v[d+1298300>>2],c)}Fa:{Ga:{switch(f-1|0){case 0:r=r>>>0<64?r:64;v[p+1075680>>2]=r<<2;c=p+1075080|0;v[c>>2]=v[c>>2]|2097152;break Fa;case 1:break Ga;default:break Fa}}um(d,k,r,6)}if(x[Q>>1]){gN(d,q&65535)}g=a}Cb(i+8|0,o,77);if(Xa=Bb(v[v[i+8>>2]>>2],v[i+12>>2]),Ya=0,_a=v[((q<<5)+d|0)+480280>>2]&1024,_a?Xa:Ya){break Q}a=v[d+1074392>>2];Cb(i+8|0,o,75);e=a>>>0>=E>>>0;Ha:{Ia:{Ja:{Ka:{if(!Bb(v[v[i+8>>2]>>2],v[i+12>>2])|!E){break Ka}c=v[d+1074392>>2];if(!c){break Ja}e=1;if((c|0)!=(E|0)){break Ka}e=!w[R|0]&(f|0)!=11}a=f;if(!e|a>>>0<3){break Ja}if((a|0)==11){a=i+8|0;Zy(a,d,w[N+3|0],w[N+4|0],E);a=w[Se(a)|0];Fy(d,q&65535,x[i+8>>1]);if(a){break Ia}f=11;break Ja}Cb(i+8|0,o,62);La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{if(!(!Bb(v[v[i+8>>2]>>2],v[i+12>>2])|r)){r=0;f=0;Sa:{switch(a-8|0){case 0:break Ra;case 1:break Sa;default:break Ja}}if(w[G+1|0]&16){break Ja}v[p+1075684>>2]=0;break Ja}Cb(i+8|0,o,41);Ta:{if(Bb(v[v[i+8>>2]>>2],v[i+12>>2])){break Ta}if(r){t[p+1075826|0]=r;break Ta}r=w[p+1075826|0]}Ua:{switch(a-3|0){case 0:case 1:Va:{Wa:{if(r){break Wa}Cb(i+8|0,o,41);if(!Bb(v[v[i+8>>2]>>2],v[i+12>>2])){break Wa}r=w[p+1075826|0];if(r){break Va}r=0;break Ja}t[p+1075826|0]=r}Yn(d,k,((a|0)==3?r<<4:r)&255);break Ja;case 2:if((E|0)!=v[d+1074392>>2]){Cb(i+8|0,o,41);f=5;if(Bb(v[v[i+8>>2]>>2],v[i+12>>2])){break Ja}}Cb(i+8|0,o,41);Xn(d,k,r,Bb(v[v[i+8>>2]>>2],v[i+12>>2]));f=5;break Ja;case 3:if((E|0)!=v[d+1074392>>2]){Cb(i+8|0,o,41);f=6;if(Bb(v[v[i+8>>2]>>2],v[i+12>>2])){break Ja}}Cb(i+8|0,o,41);Wn(d,k,r,Bb(v[v[i+8>>2]>>2],v[i+12>>2]));f=6;break Ja;case 11:break La;case 12:break Ma;case 10:break Na;case 9:break Oa;case 7:break Pa;case 6:break Qa;case 5:break Ra;case 4:break Ua;default:break Ja}}Cb(i+8|0,o,53);if(Bb(v[v[i+8>>2]>>2],v[i+12>>2])){t[p+1075815|0]=r&15;f=7;break Ja}hl(k,r<<4);f=7;break Ja}hl(k,r);f=8;break Ja}Cb(i+8|0,o,62);Ey(d,k,r,Bb(v[v[i+8>>2]>>2],v[i+12>>2])^1);f=9;break Ja}Cb(i+8|0,o,62);Ey(d,k,r<<4&240,Bb(v[v[i+8>>2]>>2],v[i+12>>2])^1);f=10;break Ja}f=12;Cb(i+8|0,o,12);fN(d,q&65535,r<<2&252,Bb(v[v[i+8>>2]>>2],v[i+12>>2]));break Ja}Cb(i+8|0,o,12);eN(d,q&65535,r<<2&252,Bb(v[v[i+8>>2]>>2],v[i+12>>2]));f=13;break Ja}f=15;if(!s){break Ja}a=v[p+1075096>>2];if(!a|r>>>0>9){break Ja}Xa:{if(!r){e=v[p+1075656>>2];break Xa}e=v[Db(a+68|0,r-1|0)>>2];v[p+1075656>>2]=e}Zn(d,k,e);break Ja}f=14;if(r>>>0>1){break Ja}t[n|0]=w[n|0]&247|!r<<3}e=b;Ya:{Za:{_a:{switch(J-1|0){case 12:if(!(w[G+1|0]&16)){break Ia}a=B(q,872)+d|0;v[a+1075680>>2]=b>>>0<64?b<<2:256;a=a+1075080|0;v[a>>2]=v[a>>2]|2097152;break Ia;case 1:if(!b){e=0;if(t[A|0]&1){break Ha}}fN(d,q&65535,b,0);break Ia;case 2:if(!b){e=0;if(t[A|0]&1){break Ha}}eN(d,q&65535,b,0);break Ia;case 10:if(!b){e=0;if(v[A>>2]==1){break Ha}}Yn(d,k,b);break Ia;case 3:Fy(d,q&65535,b);break Ia;case 5:if(!(!b&v[A>>2]==1)){Yn(d,k,b)}Fy(d,q&65535,0);break Ia;case 4:hl(k,b);break Ia;case 6:if(!(!b&v[A>>2]==1)){Yn(d,k,b)}hl(k,0);break Ia;case 15:if(!(w[G+1|0]&16)){break Ia}break Ya;case 16:Cb(i+8|0,o,5);if(Bb(v[v[i+8>>2]>>2],v[i+12>>2])){if(!(w[G+1|0]&16)|!b){break Ia}break Ya}e=Vn(d,x[d+1074446>>1],v[d+1074424>>2],q&65535,0);$a:{if(!(v[d+480180>>2]&16777250)){break $a}if(e){t[(B(q,872)+d|0)+1075827|0]=e;break $a}e=w[(B(q,872)+d|0)+1075827|0]}v[i+8>>2]=B(e,1e4);wc(i+8|0,B(v[v[d+8>>2]+24>>2],1e4));a=jb-16|0;jb=a;c=v[i+8>>2];v[a+8>>2]=c;b=v[d+8>>2];ab:{if(c>>>0>=(v[d+480180>>2]&16393?1e4:32e4)>>>0){c=v[d+480208>>2];Cb(a,d+1074312|0,92);if((Bb(v[v[a>>2]>>2],v[a+4>>2])|0)==((c&4096)>>>12|0)){break ab}v[a>>2]=B(v[b+24>>2],1e4);Xa=d+1074420|0,Ya=v[Jb(a+8|0,a)>>2],v[Xa>>2]=Ya;break ab}if(w[d+480209|0]&16){break ab}g=d+1074420|0;c=(c>>>0)/1e4|0;h=B(c&15,1e4);v[g>>2]=v[g>>2]+((c&240)==16?h:0-h|0);c=v[b+20>>2];b=v[b+24>>2];Cb(a,d+1074312|0,8);Po(g,B(c,1e4),Bb(v[v[a>>2]>>2],v[a+4>>2])?255e4:B(b,1e4))}jb=a+16|0;break Ha;case 9:if(!s|v[A>>2]==4&g){break Ia}WN(d,k,q&65535,v[d+1074424>>2],x[d+1074446>>1]);break Ia;case 43:if(!s){break Ia}c=Lka(v[(B(q,872)+d|0)+1075068>>2],0,b,0);a=mb;f=a>>>8|0;Zn(d,k,Dc((a&255)<<24|c>>>8,f));break Ia;case 0:if(v[d+1074392>>2]){break Ia}a=B(q,872)+d|0;bb:{if(w[a+1075789|0]?v[a+1075692>>2]:0){break bb}a=v[a+1075648>>2];if(a){if(uj(w[a+31|0])){break bb}}Cb(i+8|0,o,13);if(Bb(v[v[i+8>>2]>>2],v[i+12>>2])){break bb}if(v[A>>2]&16777248){break Ia}}if(!b){e=0;if(w[A|0]&5){break Ha}t[(B(q,872)+d|0)+1075797|0]=1;break Ha}a=B(q,872)+d|0;t[a+1075798|0]=b;t[a+1075797|0]=1;break Ia;case 14:if(v[A>>2]&1048580){b=b&240?b:w[(B(q,872)+d|0)+1075799|0]&240|b;if(!(b&15)){b=w[(B(q,872)+d|0)+1075799|0]&15|b}b=b|256}e=b;Cb(i+8|0,o,23);if(Bb(v[v[i+8>>2]>>2],v[i+12>>2])){b=d;c=q&65535;if(e){t[(B(q,872)+d|0)+1075799|0]=e;a=e}else{a=w[(B(q,872)+d|0)+1075799|0]}Dy(b,c,a&255,(f|0)==15?r+1|0:0);break Ha}cb:{if(e){t[(B(q,872)+d|0)+1075799|0]=e;break cb}e=w[(B(q,872)+d|0)+1075799|0]}Dy(d,q&65535,e,(f|0)==15?r+1|0:0);break Ha;case 17:if(!(w[G+1|0]&16)){break Ia}Cb(i+8|0,o,22);db:{eb:{if(Bb(v[v[i+8>>2]>>2],v[i+12>>2])){if(!b){b=0;break eb}if(w[G|0]&4){break eb}a=b&240?b-16|0:b;b=a-((a&15)!=0)|0;t[(B(q,872)+d|0)+1075832|0]=b;break eb}Cb(i+8|0,o,71);if(!Bb(v[v[i+8>>2]>>2],v[i+12>>2])){break db}}a=(B(q,872)+d|0)+1075831|0;t[a|0]=w[a|0]|128}a=B(q,872)+d|0;t[a+1075797|0]=18;if(!b){e=0;break Ha}t[a+1075832|0]=b;break Ia;case 22:if(!(w[G+1|0]&16)){break Ia}a=v[A>>2];e=b<<!(a&59593760);if(e>>>0<=128){v[d+1074456>>2]=e<<1;break Ha}if(a&16777250){break Ha}v[d+1074456>>2]=256;break Ha;case 23:Cb(i+8|0,o,9);if(Bb(v[v[i+8>>2]>>2],v[i+12>>2])){dN(d,b,(B(q,872)+d|0)+1075809|0);break Ia}dN(d,b,$);break Ia;case 8:if(!(w[G+1|0]&16)){break Ia}um(d,k,b,8);break Ia;case 28:Ey(d,k,b,1);break Ia;case 7:ON(k,b);break Ia;case 25:PN(d,k,b);break Ia;case 18:e=jb-16|0;jb=e;h=d+1074376|0;a=q&65535;g=B(a,872);c=(h+g|0)+616|0;f=b&15;fb:{gb:{switch(b>>>4|0){case 0:a=(b&1)<<14;c=x[d+480188>>1];g=0;while(1){if((c|0)==(g|0)){break fb}h=(B(g,872)+d|0)+1075080|0;v[h>>2]=(a|v[h>>2]&-16385)^16384;g=g+1|0;continue};case 1:if(!f){f=0;if(!(v[d+480180>>2]&1048580)){break fb}}Ry(d,c,f);Cb(e+8|0,d+1074312|0,117);if(Bb(v[v[e+8>>2]>>2],v[e+12>>2])){break fb}Pn(d,a,b|240,1);break fb;case 2:if(!f){f=0;if(!(v[d+480180>>2]&1048580)){break fb}}Qy(d,c,f);Cb(e+8|0,d+1074312|0,117);if(Bb(v[v[e+8>>2]>>2],v[e+12>>2])){break fb}Pn(d,a,0-(b|240)|0,1);break fb;case 3:a=(d+g|0)+1075080|0;v[a>>2]=v[a>>2]&-1048577|((f|0)!=0)<<20;break fb;case 4:t[(d+g|0)+1075814|0]=b&7;break fb;case 5:if(!(w[d+480209|0]&16)){break fb}g=v[d+480180>>2];if(g&69206025){c=B(a,872)+d|0;u[c+1075764>>1]=f<<28>>24;g=c+1075692|0;if(!v[g>>2]){break fb}if(!_c(w[c+1075780|0])){break fb}a=B(a,872)+d|0;Xa=g,Ya=eh(d,w[a+1075789|0],f<<28>>24,v[a+1075696>>2]),v[Xa>>2]=Ya;break fb}c=_c(w[(B(a,872)+d|0)+1075780|0]);if((g|0)==16){if(!c){break fb}c=B(a,872)+d|0;g=v[c+1075096>>2];if(!g){break fb}t[g+37|0]=f;u[c+1075764>>1]=f;c=c+1075692|0;if(!v[c>>2]){break fb}a=B(a,872)+d|0;Xa=c,Ya=eh(d,w[a+1075789|0],f,v[a+1075696>>2]),v[Xa>>2]=Ya;break fb}if(!c){break fb}a=B(a,872)+d|0;c=(b<<4^-128)<<24>>24;u[a+1075764>>1]=c;g=a+1075692|0;if(!v[g>>2]){break fb}Xa=g,Ya=eh(d,w[a+1075789|0],c,v[a+1075696>>2]),v[Xa>>2]=Ya;break fb;case 6:if(!(w[d+480209|0]&16)){break fb}Yy(d,h,c,f);break fb;case 7:t[(d+g|0)+1075817|0]=b&7;break fb;case 8:if(!(w[d+480209|0]&16)){break fb}um(d,c,f,4);break fb;case 9:Dy(d,a,f,0);break fb;case 10:if(f){Xn(d,c,f,0);break fb}if(!(v[d+480180>>2]&1048580)){break fb}Xn(d,c,0,0);break fb;case 11:if(f){Wn(d,c,f,0);break fb}if(!(v[d+480180>>2]&1048580)){break fb}Wn(d,c,0,0);break fb;case 12:Gy(d,a,f,0);break fb;case 15:break gb;default:break fb}}if(v[d+480180>>2]==1){t[(B(a,872)+d|0)+1075838|0]=f;if(!(w[d+480209|0]&16)){break fb}hN(d,c);break fb}t[(B(a,872)+d|0)+1075836|0]=f}jb=e+16|0;break Ia;case 19:cN(d,q&65535,b);break Ia;case 24:Cb(i+8|0,o,55);if(Bb(v[v[i+8>>2]>>2],v[i+12>>2])){if(v[d+1074392>>2]!=(b|0)){break Ia}a=v[(B(q,872)+d|0)+1075648>>2];if(t[a+60|0]&1?a:0){break Za}if(!(!(w[X|0]?1:w[R|0])|b)){a=(B(q,872)+d|0)+1075080|0;v[a>>2]=v[a>>2]|4096;break Za}a=B(q,872)+d|0;v[a+1075680>>2]=0;a=a+1075080|0;v[a>>2]=v[a>>2]|2097152;break Za}if(!(w[G+1|0]&16)){break Ia}break Za;case 27:a=(b&240)-16>>>4|0;if(a>>>0>9){break Ia}if(!(1<<a&880)){if(a){if((a|0)!=1){break Ia}Py(d,k,K);Cb(i+8|0,o,117);if(Bb(v[v[i+8>>2]>>2],v[i+12>>2])){break Ia}Pn(d,q&65535,-224-K|0,1);break Ia}Sy(d,k,K);Cb(i+8|0,o,117);if(Bb(v[v[i+8>>2]>>2],v[i+12>>2])){break Ia}Pn(d,q&65535,K|224,1);break Ia}Cb(i+8|0,o,58);if(Bb(v[v[i+8>>2]>>2],v[i+12>>2])){break Ia}cN(d,q&65535,b);break Ia;case 34:case 35:if(!(w[G+1|0]&16)&(J|0)!=36){break Ia}c=q&65535;TN(d,c,I,(J|0)==36);a=Op(d,v[k+88>>2],v[k+656>>2]);if(!a){break Ia}nb[v[v[a>>2]+80>>2]](a,(x[k+774>>1]&65532)>>>2^8192,c);break Ia;case 20:if(!(w[G+1|0]&16)|b>>>0>64){break Ia}a=B(q,872)+d|0;v[a+1075740>>2]=b;a=a+1075080|0;v[a>>2]=v[a>>2]|2097152;break Ia;case 21:f=v[A>>2];e=v[G>>2];a=b;hb:{if(a){t[k+816|0]=a;break hb}a=w[k+816|0]}g=a&255;h=a&240;c=a&15;ib:{jb:{if(!(!h|(c|0)!=15)){if(!(e&4096)){break ib}a=g>>>4|0;break jb}e=e&4096;if(!(!c|(h|0)!=240)){if(!e){break ib}a=0-c|0;break jb}if(e){break ib}if(c){a=0-c|0;if(!(f&25690144)|!h){break jb}break ib}if((a&255)>>>0<16){break ib}a=g>>>4|0}Xa=k,Ya=Xb(a+v[k+748>>2]|0,0,64),v[Xa+748>>2]=Ya}break Ia;case 26:MN(k,b);break Ia;case 29:if(!(w[G+1|0]&16)){break Ia}a=B(q,872)+d|0;v[a+1075716>>2]=b;Cb(i+8|0,o,60);if(Xa=0,Ya=Bb(v[v[i+8>>2]>>2],v[i+12>>2]),_a=w[a+1075722|0]&4,_a?Xa:Ya){break Ia}a=B(q,872)+d|0;v[a+1075732>>2]=b;v[a+1075724>>2]=b;break Ia;case 11:RN(d,I,q&65535);break Ia;case 13:a=QN(d,I,q&65535,b);if((a|0)==-1){break Ia}v[d+1074436>>2]=a;if(!(w[d+480208|0]&32)){break Ia}u[d+1074444>>1]=x[d+1074448>>1];break Ia;case 37:case 38:case 39:case 40:DN(d,k,b,(J|0)==38|(J|0)==40,(J&254)==40);break Ia;case 41:VN(k,b);break Ia;case 42:if(v[d+1074392>>2]|K>>>0>1|b>>>0>47){break Ia}a=(b&240)==16;g=a?x[d+480188>>1]-1|0:q;e=a?0:q;a=((K|0)==1)<<26;while(1){c=e&65535;if(c>>>0>(g&65535)>>>0){break Ia}h=((c<<5)+d|0)+480280|0;v[h>>2]=a|v[h>>2]&-67108865;c=(B(c,872)+d|0)+1075080|0;v[c>>2]=a|v[c>>2]&-67108865;e=e+1|0;continue};case 44:break _a;default:break Ha}}UN(k,b);break Ia}Un(d,k);break Ia}_N(d,I,b)}e=b}Cb(i+8|0,o,78);if(!(!Bb(v[v[i+8>>2]>>2],v[i+12>>2])|!e)){JN(k,e&255)}a=w[R|0];if(!a){break Q}t[p+1075796|0]=a}q=q+1|0;continue}break}a=1;break j}a=0}jb=F+32|0;N=!v[d+1074420>>2]|a^1;kb:{if(N){break kb}a=YN(d,d+1074376|0);v[d+1074380>>2]=a;v[d+1074404>>2]=a;b=Cd(x[d+480188>>1],1,31);lb:{if(Pd(w[d+1074366|0])){a=v[d+24628>>2];if((a|0)>=129){a=((B(a-128|0,b+4|0)|0)/16|0)+128|0}s=((B(v[d+480228>>2],a)<<1&-128)>>>0)/w[(b>>>1|0)+32160|0]|0;break lb}s=v[d+480228>>2]}u[d+480212>>1]=0;o=d+1074312|0;S=d+1074365|0;F=d+480180|0;I=d+480210|0;K=d+480209|0;R=d+1074366|0;X=d+1074364|0;Z=d+1074360|0;q=0;while(1){if((q|0)==256){b=v[d+24608>>2];g=x[d+480212>>1];if(b>>>0>g>>>0){break kb}e=jb-16|0;jb=e;v[e+8>>2]=d;a=d+1074478|0;c=a;g=a+(g<<1)|0;mb:{a=a+(b<<1)|0;if((c|0)==(a|0)){break mb}nb:{b=a-c|0;if((b|0)<3){break nb}h=b>>1;b=(h-2|0)/2|0;while(1){if((b|0)<0){break nb}ky(c,v[e+8>>2],h,c+(b<<1)|0);b=b-1|0;continue}}h=a-c>>1;b=a;while(1){if((b|0)==(g|0)){b=a-c>>1;while(1){if((b|0)>1){a=a-2|0;ly(c,a);b=b-1|0;ky(c,v[e+8>>2],b,c);continue}break}break mb}if(Jp(v[e+8>>2],x[b>>1],x[c>>1])){ly(b,c);ky(c,v[e+8>>2],h,c)}b=b+2|0;continue}}jb=e+16|0}else{m=B(q,872)+d|0;p=m+1075080|0;ob:{if(!(v[p>>2]&4096)|(v[m+1075016>>2]|(v[m+1075012>>2]|v[m+1075688>>2]))){break ob}Cb(j+16|0,o,64);if(Bb(v[v[j+16>>2]>>2],v[j+20>>2])){break ob}v[m+1075068>>2]=0;a=m+1075084|0;v[a>>2]=0;v[a+4>>2]=0}a=x[d+480188>>1];b=v[p>>2];pb:{if(v[m+1075068>>2]|a>>>0>q>>>0?b&1024:1){if(a>>>0>q>>>0){sM(d,q&65535)}u[m+1075834>>1]=0;break pb}c=0;Q=m+1075712|0;v[Q>>2]=0;G=m+1075672|0;v[G>>2]=0;A=m+1075e3|0;e=A;v[e>>2]=0;v[e+4>>2]=0;v[m+1075092>>2]=0;v[j+44>>2]=1065353216;u[j+42>>1]=0;J=m+1075648|0;E=v[J>>2];v[j+36>>2]=0;f=0;l=m+1075692|0;f=v[l>>2]?v[m+1075068>>2]!=0:f;g=m+1074992|0;qb:{rb:{sb:{if(a>>>0<=q>>>0){break sb}if(w[((q<<5)+d|0)+480288|0]){break rb}if(!E){break sb}c=w[E+34|0]!=0}if((c|f)!=1){break qb}}v[j+8>>2]=v[m+1075680>>2];v[j+32>>2]=v[m+1075744>>2];Cb(j+16|0,o,28);b=j+8|0;a=Bb(v[v[j+16>>2]>>2],v[j+20>>2])?j+32|0:b;c=jb-16|0;jb=c;e=d+1074312|0;Cb(c+8|0,e,28);tb:{if(Bb(v[v[c+8>>2]>>2],v[c+12>>2])){v[a>>2]=v[a>>2]+u[g+776>>1];oe(a,0,64);break tb}Cb(c+8|0,e,1);e=u[g+776>>1];if(Bb(v[v[c+8>>2]>>2],v[c+12>>2])){v[a>>2]=e+v[a>>2];oe(a,0,256);break tb}v[g+688>>2]=e+v[g+688>>2];oe(g+688|0,0,256);v[a>>2]=v[g+688>>2];u[g+776>>1]=0}jb=c+16|0;a=jb-16|0;jb=a;c=d+1074312|0;Cb(a+8|0,c,28);ub:{vb:{if(!Bb(v[v[a+8>>2]>>2],v[a+12>>2])){Cb(a,c,1);if(!Bb(v[v[a>>2]>>2],v[a+4>>2])){break vb}}v[g+684>>2]=v[g+692>>2]+u[g+778>>1];oe(g+684|0,0,256);break ub}v[g+692>>2]=v[g+692>>2]+u[g+778>>1];oe(g+692|0,0,256);u[g+778>>1]=0;v[g+684>>2]=v[g+692>>2]}jb=a+16|0;e=jb-16|0;jb=e;wb:{if(!(w[g+90|0]&4)|(v[d+480208>>2]&2101248)==2101248){break wb}xb:{if(v[b>>2]<=0){Cb(e+8|0,d+1074312|0,21);if(!Bb(v[v[e+8>>2]>>2],v[e+12>>2])){break xb}}c=5;if(!(v[d+480180>>2]&5)){Cb(e+8|0,d+1074312|0,21);c=Bb(v[v[e+8>>2]>>2],v[e+12>>2])?5:6}a=oy(d,w[g+825|0],w[g+820|0]);yb:{if((w[g+825|0]&3)!=1){break yb}Cb(e+8|0,d+1074312|0,89);if(!Bb(v[v[e+8>>2]>>2],v[e+12>>2])){break yb}a=w[g+819|0];k=w[g+820|0];h=k<<2&124;a=(!(w[g+90|0]&2)|w[d+480209|0]&16?a:w[g+823|0]+a|0)&32?h^127:h;a=k&32?0-a|0:a}if(v[d+480180>>2]!=131072){a=v[b>>2]+((B(w[g+827|0],a)|0)/(1<<c)|0)|0}else{c=64-a|0;a=v[b>>2];a=((B(w[g+827|0],B(c,a))|0)/-8192|0)+a|0}v[b>>2]=a}a=v[d+480208>>2];if(!(v[d+480180>>2]&16777248)|a&4?a&4096:0){break wb}Cb(e+8|0,d+1074312|0,21);a=w[g+826|0];c=w[g+820|0];h=Bb(v[v[e+8>>2]>>2],v[e+12>>2]);t[g+820|0]=(h?a<<2:c)+(h?c:a)}jb=e+16|0;e=q&65535;h=jb-16|0;jb=h;a=d+1074312|0;Cb(h+8|0,a,71);zb:{if(Bb(v[v[h+8>>2]>>2],v[h+12>>2])){a=(B(e,872)+d|0)+1075831|0;c=t[a|0];if((c|0)>=0){break zb}if(!(w[d+480209|0]&16|w[(B(e,872)+d|0)+1075797|0]!=18)){k=c&-33;t[a|0]=k;Ab:{Bb:{if((k|0)!=-64){c=c&223;if((c|0)!=128){break Bb}c=w[(B(e,872)+d|0)+1075832|0]>>>4|-64;break Ab}c=w[(B(e,872)+d|0)+1075832|0]&15|-128;break Ab}c=c-1|0}t[a|0]=c;a=(B(e,872)+d|0)+1075080|0;v[a>>2]=v[a>>2]|2097152}if((c&224)!=128){break zb}v[b>>2]=0;break zb}if(w[(B(e,872)+d|0)+1075797|0]!=18){break zb}Cb(h+8|0,a,22);Cb:{if(Bb(v[v[h+8>>2]>>2],v[h+12>>2])){n=B(e,872)+d|0;a=n+1075831|0;k=w[a|0];c=k<<24>>24;if(!((c|0)>=0|!v[n+1075068>>2])){Db:{Eb:{if((k|0)!=192){if((k|0)!=128){break Eb}c=w[(B(e,872)+d|0)+1075832|0]>>>4|-64;break Db}c=w[(B(e,872)+d|0)+1075832|0]&15|-128;break Db}c=c-1|0}t[a|0]=c}if((c&192)!=128){break Cb}v[b>>2]=0;break Cb}a=w[(B(e,872)+d|0)+1075832|0];r=a>>>4|0;i=r+(a&15)|0;k=v[d+480180>>2];if(!(w[d+480208|0]&4?0:k&16777248)){r=r+1|0;i=i+2|0}a=(B(e,872)+d|0)+1075831|0;c=w[a|0];if(!(k&4)){c=(c&255)>>>0<i>>>0?c:0;if((c&255)>>>0>=r>>>0){v[b>>2]=0}t[a|0]=c+1;break Cb}Fb:{if(w[d+480209|0]&16){c=c&255?c-1|0:0;break Fb}t[a|0]=c+1}if(((c&255)>>>0)%(i>>>0)>>>0<r>>>0){break Cb}v[b>>2]=0}a=(B(e,872)+d|0)+1075080|0;v[a>>2]=v[a>>2]|2097152}a=B(e,872)+d|0;Gb:{if(w[a+1075797|0]!=18){break Gb}c=v[a+1075648>>2];if(!c){break Gb}a=w[c+34|0];if(!a|w[c+15|0]&2){break Gb}k=B(e,872)+d|0;if(v[k+1075080>>2]&134218752){break Gb}k=k+1075791|0;n=w[k|0];if(!_c(n)){break Gb}a=v[Ld(d+906300|0,a-1|0)>>2];if(!a){break Gb}n=nb[v[v[a>>2]+104>>2]](a,n,e)|0;i=v[b>>2];if(!(!n|i)){nb[v[v[a>>2]+96>>2]](a,c,w[k|0]|256,0,e);break Gb}if(n|!i){break Gb}nb[v[v[a>>2]+96>>2]](a,c,w[k|0],x[(B(e,872)+d|0)+1075680>>1],e)}jb=h+16|0;oe(b,0,256);v[j+8>>2]=v[j+8>>2]<<6;Hb:{if(E){Cb(j+16|0,o,31);if(Bb(v[v[j+16>>2]>>2],v[j+20>>2])){jt(d,g)}c=j+8|0;a=jb-16|0;jb=a;Ib:{if(!my(d,g,0)){break Ib}h=v[g+656>>2];k=d+1074312|0;Cb(a+8|0,k,31);Jb:{if(Bb(v[v[a+8>>2]>>2],v[a+12>>2])){b=v[g+724>>2];if(b){break Jb}break Ib}b=v[g+724>>2]}Cb(a+8|0,k,31);i=b-Bb(v[v[a+8>>2]>>2],v[a+12>>2])|0;b=$p(h+48|0,i,256,64);r=w[h+65|0];Kb:{if((r|0)==255){break Kb}n=u[g+728>>1];if((n|0)==-1){break Kb}r=Db(v[h+48>>2],r);h=w[r+2|0];r=x[r>>1];Cb(a+8|0,k,94);k=h<<2;b=(i|0)==(r|0)?k:b;if(Bb(v[v[a+8>>2]>>2],v[a+12>>2])){b=n+(b-k<<1)|0;break Kb}if(!h){b=0;break Kb}b=(B(b,n)|0)/(k|0)|0}Xa=c,Ya=(B(Xb(b,0,512),v[c>>2])|0)/256|0,v[Xa>>2]=Ya}jb=a+16|0;BN(g,c);a=jb-16|0;jb=a;Lb:{if(!my(d,g,1)){break Lb}c=v[g+656>>2];h=d+1074312|0;Cb(a+8|0,h,31);Mb:{if(Bb(v[v[a+8>>2]>>2],v[a+12>>2])){b=v[g+732>>2];if(b){break Mb}break Lb}b=v[g+732>>2]}Cb(a+8|0,h,31);c=$p(c+68|0,b-Bb(v[v[a+8>>2]>>2],v[a+12>>2])|0,64,64)-32|0;b=v[g+684>>2];Xa=g,Ya=Xb(((B(c,(b|0)>127?256-b|0:b)|0)/32|0)+b|0,0,256),v[Xa+684>>2]=Ya}jb=a+16|0;Cb(j+16|0,o,115);if(Bb(v[v[j+16>>2]>>2],v[j+20>>2])){break Hb}b=w[m+1075789|0];if(!b){break Hb}a=v[J>>2];if(!a|!w[a+26|0]){break Hb}FN(m+1075676|0,b,w[a+26|0],w[a+27|0]);break Hb}if(!(w[p+1|0]&16)){break Hb}v[m+1075688>>2]=0;v[j+8>>2]=0}Nb:{if(w[m+1075843|0]&8){c=0;v[j+8>>2]=0;break Nb}c=v[j+8>>2];if(!c){c=0;break Nb}if(w[p+3|0]&8){v[G>>2]=0;break Nb}if(Pd(w[S|0])){a=B(v[j+32>>2],v[m+1075740>>2]);b=a;h=a>>31;a=c<<8;Xa=G,Ya=Hc(Mka(Lka(b,h,a,a>>31),mb,1048576,0),mb),v[Xa>>2]=Ya;break Nb}a=B(v[j+32>>2],v[m+1075740>>2]);b=a;h=a>>31;a=B(v[d+1074456>>2],c);Xa=G,Ya=Hc(Mka(Lka(b,h,a,a>>31),mb,1048576,0),mb),v[Xa>>2]=Ya}v[Q>>2]=c;Ob:{Pb:{c=v[l>>2];if(!(v[F>>2]==2|(c|0)>=v[d+480260>>2])){if(!nj(d)){break Pb}c=v[l>>2]}if((c|0)<v[d+480264>>2]){break Ob}Cb(j+16|0,o,113);if(!Bb(v[v[j+16>>2]>>2],v[j+20>>2])){break Ob}if(nj(d)){break Ob}v[l>>2]=v[d+480264>>2];break Ob}v[l>>2]=v[d+480260>>2]}Cb(j+16|0,o,73);a=v[l>>2];v[j+36>>2]=a;Qb:{if((v[p>>2]&1572864)!=1572864){break Qb}b=v[d+480208>>2];if(b&2097152){if(!vm(w[m+1075782|0],w[m+1075783|0])|b&4096){break Qb}}b=m+1075704|0;Rb:{if((a|0)==v[b>>2]){c=v[m+1075708>>2];break Rb}v[b>>2]=a;c=a;a=m+1075764|0;b=m+1075696|0;c=eh(d,gt(d,c,u[a>>1],v[b>>2]),u[a>>1],v[b>>2]);v[m+1075708>>2]=c}v[j+36>>2]=c}k=jb-16|0;jb=k;i=B(e,872)+d|0;r=i+1075648|0;a=v[r>>2];Sb:{if(!a){break Sb}b=w[a+34|0];if(v[(B(e,872)+d|0)+1075080>>2]&134218752|(!b|w[a+15|0]&2)){break Sb}if(!v[Ld(d+906300|0,b-1|0)>>2]){break Sb}b=B(e,872)+d|0;h=b+1075780|0;a=w[b+1075793|0];Y=b+1075783|0;n=w[Y|0];Tb:{Ub:{if((n|0)==1){b=a;Vb:{Wb:{switch(((y[d+1074392>>2]%(v[d+1074400>>2]+v[d+1074416>>2]>>>0)>>>0)%3|0)-1|0){case 0:b=a+(w[(B(e,872)+d|0)+1075798|0]>>>4|0)|0;break Vb;case 1:break Wb;default:break Vb}}b=a+(w[(B(e,872)+d|0)+1075798|0]&15)|0}c=B(e,872)+d|0;if(w[c+1075792|0]==(b&255)){break Tb}if(!(t[c+1075843|0]&1)){break Ub}if(!_c(w[h|0])){break Ub}if(vm(w[h+2|0],1)){break Ub}break Tb}if(w[h|0]){b=a;if(!vm(w[h+2|0],n)){break Tb}}b=a;if(!w[(B(e,872)+d|0)+1075792|0]){break Tb}}sm(d,e,b&255|512,x[(B(e,872)+d|0)+1075680>>1])}V=(B(e,872)+d|0)+1075792|0;c=w[V|0];Xb:{Yb:{if(c){if((n|0)!=1|(b&255)!=(c|0)){break Yb}break Xb}if(!(t[(B(e,872)+d|0)+1075843|0]&1)|(n|0)!=1){break Xb}if(_c(w[h|0])){break Xb}c=a;if(!_c(a)){break Xb}}sm(d,e,c&255|256,0)}t[V|0]=w[Y|0]==1?b:0}Zb:{if(w[i+1075797|0]!=1){break Zb}if(vj(v[r>>2])){b=0;_b:{$b:{ac:{switch(y[d+1074392>>2]%3|0){case 1:b=w[(B(e,872)+d|0)+1075798|0]>>>4|0;break $b;case 0:break $b;case 2:break ac;default:break _b}}b=w[(B(e,872)+d|0)+1075798|0]&15}u[j+42>>1]=b}a=(B(e,872)+d|0)+1075843|0;t[a|0]=w[a|0]|96;break Zb}if(!(!(w[d+480209|0]&16)|v[d+480180>>2]!=1048576)){a=B(e,872)+d|0;b=eh(d,w[a+1075789|0],u[a+1075764>>1],v[a+1075696>>2]);v[j+36>>2]=b;v[a+1075692>>2]=b}b=d+1074312|0;Cb(k+8|0,b,13);if(Bb(v[v[k+8>>2]>>2],v[k+12>>2])){b=w[(B(e,872)+d|0)+1075798|0];if(!b){break Zb}a=65536;bc:{switch(((y[d+1074392>>2]%(v[d+1074400>>2]+v[d+1074416>>2]>>>0)>>>0)%3|0)-1|0){case 1:b=b<<4;case 0:a=v[((b&240)<<2)+37136>>2];break;default:break bc}}e=nj(d);b=v[j+36>>2];c=b;b=b>>31;if(e){a=Lka(c,b,a,a>>31)+32768|0;h=mb;a=Mka(a,a>>>0<32768?h+1|0:h,65536,0)}else{e=(a|0)/2|0;h=e>>31;n=b<<16|c>>>16;c=c<<16;b=c+e|0;n=h+n|0;a=Mka(b,b>>>0<c>>>0?n+1|0:n,a,a>>31)}b=mb;Xa=j,Ya=Hc(a,b),v[Xa+36>>2]=Ya;break Zb}Cb(k+8|0,b,51);if(Bb(v[v[k+8>>2]>>2],v[k+12>>2])){if(w[d+480209|0]&16){break Zb}cc:{dc:{a=v[d+1074416>>2];b=a-(y[d+1074392>>2]%(a>>>0)|0)|0;if((b|0)>16){break dc}if((b|0)==16){break Zb}a=0;ec:{switch((b|0)%3|0){case 0:break Zb;case 2:break dc;case 1:break ec;default:break cc}}a=w[(B(e,872)+d|0)+1075798|0]>>>4|0;break cc}a=w[(B(e,872)+d|0)+1075798|0]&15}c=a;a=B(e,872)+d|0;b=a+1075764|0;a=a+1075696|0;c=c+gt(d,v[j+36>>2],u[b>>1],v[a>>2])|0;b=eh(d,c,u[b>>1],v[a>>2]);v[j+36>>2]=b;if(c>>>0<109){break Zb}v[k+8>>2]=b;Xa=k,Ya=eh(d,109,0,v[a>>2]),v[Xa+4>>2]=Ya;Xa=j,Ya=v[Yc(k+8|0,k+4|0)>>2],v[Xa+36>>2]=Ya;break Zb}h=v[d+1074392>>2];n=d+480180|0;c=v[n>>2];fc:{if((c|0)!=1){a=w[(B(e,872)+d|0)+1075789|0];break fc}a=B(e,872)+d|0;a=gt(d,v[j+36>>2],u[a+1075764>>1],v[a+1075696>>2]);c=v[n>>2]}gc:{hc:{switch((((c&67633152?h+2|0:h)>>>0)%3|0)-1|0){case 0:a=(w[(B(e,872)+d|0)+1075798|0]>>>4|0)+a|0;break gc;case 1:break hc;default:break gc}}a=(w[(B(e,872)+d|0)+1075798|0]&15)+a|0}if(!(c&67633408|w[(B(e,872)+d|0)+1075789|0]!=(a&255))){Cb(k+8|0,b,82);if(!Bb(v[v[k+8>>2]>>2],v[k+12>>2])){break Zb}}if(w[d+480210|0]&32){c=a&255;if((c|0)==85){v[j+36>>2]=2147483647;break Zb}a=c>>>0>85?a-37|0:a}c=B(e,872)+d|0;h=eh(d,a&255,u[c+1075764>>1],v[c+1075696>>2]);v[j+36>>2]=h;if(v[d+480180>>2]&71860480){v[c+1075692>>2]=h;break Zb}Cb(k+8|0,b,82);if(!Bb(v[v[k+8>>2]>>2],v[k+12>>2])){break Zb}t[(B(e,872)+d|0)+1075792|0]=a}jb=k+16|0;if(!(!(w[I|0]&33)|v[j+36>>2]==2147483647)){ic:{if(v[F>>2]==2){c=452;a=3424;break ic}a=B(x[m+1075764>>1]>>>4&15,24);b=x[a+32870>>1]>>>1|0;c=b>>>0>452?b:452;a=x[a+32848>>1]<<1}oe(j+36|0,c,a);oe(l,c,a)}KN(d,g);b=v[p>>2]}jc:{if(!(b&256)|w[K|0]&64){break jc}Cb(j+16|0,o,37);if(!Bb(v[v[j+16>>2]>>2],v[j+20>>2])){break jc}v[m+1075676>>2]=128}l=q&65535;sM(d,l);kc:{if(!f){break kc}a=CN(d,g,j+36|0);if((a|0)<0|!(w[p+1|0]&2)){break kc}b=v[d+1298300>>2];if(!Ed(b)){break kc}_p(b,l,a>>>2&255,1)}lc:{if(w[m+1075782|0]!=8){break lc}mc:{nc:{a=w[m+1075783|0];switch(a-5|0){case 1:break lc;case 0:case 2:break mc;default:break nc}}if((a|0)!=26){break lc}}a=v[F>>2];if((a|0)==4){if(w[K|0]&16){break lc}a=m+1075811|0;t[a|0]=w[a|0]+w[m+1075815|0];break lc}if(!(a&16777248)){break lc}hl(g,w[m+1075784|0]);rM(d,l,j+36|0,j+44|0)}rM(d,l,j+36|0,j+44|0);oc:{if(!f){break oc}v[j+32>>2]=0;b=j+36|0;n=jb-16|0;jb=n;e=v[g+104>>2];pc:{if(!e|!w[e+40|0]){break pc}i=vj(v[g+656>>2]);f=nj(d);Cb(n+8|0,d+1074312|0,21);a=f?38160:37136;k=f?37136:38160;if(!(i|!Bb(v[v[n+8>>2]>>2],v[n+12>>2])|v[d+480180>>2]==1048576)){i=w[e+41|0];if(!i){break pc}c=w[g+818|0];v[n+4>>2]=v[g+756>>2]+w[e+39|0];ai(n+4|0,w[e+40|0]<<8);h=v[n+4>>2];t[g+818|0]=c+i;v[g+756>>2]=h;h=(h|0)/256|0;qc:{rc:{switch(w[e+38|0]-1|0){case 3:c=oM(Tn(d))+-64|0;break qc;case 2:c=64-(c+1>>>1|0)|0;break qc;case 1:c=(c+1>>>1|0)+-64|0;break qc;case 0:c=(c>>>1^-1)&64;break qc;default:break rc}}c=t[c+33440|0]}ai(b,8388607);e=v[b>>2]<<8;v[b>>2]=e;h=B(c,h);i=(h|0)/64|0;c=i>>31;i=(c^i)-c|0;r=i>>>2|0;c=e;sc:{tc:{if((h|0)<=-64){h=e>>31;a=v[(r<<2)+a>>2];a=Hc(Mka(Lka(e,h,a,a>>31),mb,65536,0),mb)-e|0;k=i&3;if(!k){break sc}f=(k<<2)+(f?37072:37008)|0;break tc}h=e>>31;a=v[k+(r<<2)>>2];a=Hc(Mka(Lka(e,h,a,a>>31),mb,65536,0),mb)-e|0;k=i&3;if(!k){break sc}f=(k<<2)+(f?37008:37072)|0}k=a;a=v[f>>2];a=(k+Hc(Mka(Lka(a,a>>31,e,h),mb,65536,0),mb)|0)-e|0}v[b>>2]=(a+c|0)/256;v[j+32>>2]=a&255;break pc}h=v[d+480180>>2]&16777248;c=w[e+39|0];uc:{if(!(h|c)){v[g+756>>2]=w[e+40|0]<<8;break uc}vc:{wc:{if(h){r=c<<1;f=v[g+756>>2];c=g+756|0;break wc}if(w[g+89|0]&8){break vc}f=((w[e+40|0]<<8&65280)>>>0)/(c>>>0)|0;r=v[g+756>>2];c=g+756|0}v[c>>2]=f+r}ai(g+756|0,w[e+40|0]<<8)}c=w[g+818|0]+w[e+41|0]|0;t[g+818|0]=c;c=c<<24>>24;xc:{yc:{switch(w[e+38|0]-1|0){case 3:t[g+818|0]=c+1;h=t[(c&63)+33376|0];break xc;case 2:h=(64-(c>>>1|0)&127)+-64|0;break xc;case 1:h=((c>>>1|0)- -64&127)+-64|0;break xc;case 0:h=(c|0)>=0?-64:64;break xc;default:break yc}}h=0-t[(c&255)+33440|0]|0;if(v[d+480180>>2]!=1048576){break xc}h=(64-t[(c+-64&255)+33440|0]|0)/2<<16>>16}c=h;h=B(c,v[g+756>>2]);f=(h|0)/256|0;if(i){z[j+44>>2]=z[j+44>>2]+C(C(C(C(w[e+40|0])*C(.05000000074505806))*C(c|0))*C(.000244140625));t[g+851|0]=w[g+851|0]|64;break pc}if(v[d+480180>>2]!=4){zc:{if((h|0)<=-256){f=0-f|0;c=0-h>>>16|0;e=(c<<2)+a|0;break zc}a=k;c=(h|0)/65536|0;e=a+(c<<2)|0}h=v[b>>2];c=v[((c<<2)+a|0)+4>>2];a=v[e>>2];a=((B(c-a|0,(f|0)/4&63)|0)/64|0)+a|0;a=Hc(Mka(Lka(h,h>>31,a,a>>31),mb,256,0),mb);v[b>>2]=a;v[j+32>>2]=a&255;v[b>>2]=v[b>>2]/256;break pc}v[b>>2]=v[b>>2]+((h|0)/16384|0)}jb=n+16|0;f=v[j+36>>2];if((f|0)<=v[d+480260>>2]){Cb(j+16|0,o,81);if(Bb(v[v[j+16>>2]>>2],v[j+20>>2])){v[m+1075068>>2]=0}f=v[d+480260>>2];v[j+36>>2]=f}Ac:{if(!vj(v[g+656>>2])){break Ac}a=m+1075843|0;b=w[a|0];if(!(v[d+1074392>>2]|!(b&32)?b&64:1)){break Ac}xP(g,z[j+44>>2],u[j+42>>1],d);b=a;a=w[a|0];t[b|0]=(a&64?-65:-33)&a}a=j+16|0;_y(a,d,g,f,v[j+32>>2]);b=Fb(a);a=Lka(v[j+16>>2],v[j+20>>2],v[d+480240>>2],0);f=mb;c=Mka(a,f,65536,0);e=mb;a=a+65535|0;f=a>>>0<65535?f+1|0:f;a=!f&a>>>0<131071;c=a?1:c;v[j+16>>2]=c;a=a?0:e;v[j+20>>2]=a;v[A>>2]=c;v[A+4>>2]=a;if((v[p>>2]&134219264)!=512){break oc}if(!Ed(v[d+1298300>>2])){break oc}Cb(j+8|0,o,99);Bc:{Cc:{if(Xa=Bb(v[v[j+8>>2]>>2],v[j+12>>2]),Ya=1,_a=w[p+1|0]&16,_a?Xa:Ya){a=v[F>>2];break Cc}a=v[F>>2];if((a|0)!=2){break Bc}}c=v[p>>2];e=c&2048;Dc:{if(e?(a|0)==2:0){break Dc}a=Lka(v[b>>2],0,261625,0)+66904|0;f=mb;b=Dc(Oka(a,a>>>0<66904?f+1|0:f,133808,0),mb);a=1;Ec:{if(e){break Ec}a=0;if(!(c&4096)){break Ec}a=!v[m+1075688>>2]}Cb(j+8|0,o,110);if(Xa=Bb(v[v[j+8>>2]>>2],v[j+12>>2]),Ya=0,_a=a,_a?Xa:Ya){break Dc}c=v[d+1298300>>2];Cb(j+8|0,o,95);rz(c,l,b,a,Bb(v[v[j+8>>2]>>2],v[j+12>>2]))}b=v[d+1298300>>2];a=Lka(B(v[m+1075744>>2],B(v[m+1075740>>2],v[Q>>2])),0,63,0)+33554432|0;f=mb;f=a>>>0<33554432?f+1|0:f;_p(b,l,Dc((f&67108863)<<6|a>>>26,f>>>26|0)&255,0);a=m+1075676|0;h=a;b=v[a>>2];c=0;a=v[d+1298300>>2];e=ol(a,l);Fc:{if((e|0)==255){break Fc}f=v[a>>2];if(ik(f)){break Fc}c=Kb(Md(a+318|0,e),10);n=v[a+4>>2];e=yt(e)|192;a=w[c|0]&-49;a=(b|0)<171?a|16:a;a=(b|0)>84?a|32:a;b=a&255;gh(f,n,l,e,b);c=(b>>>5&1)+(a<<27>>31)|0}v[h>>2]=(c<<7)+128}Gc:{a=v[J>>2];if(!a|(w[a+60|0]&7)!=1){break Gc}b=v[a+48>>2];a=v[a+52>>2];if(oc(b,a)){break Gc}b=v[qM(g,0)>>2];a=Aj(a);if(b>>>0<x[a>>1]|w[a+2|0]){break Gc}qj(v[d+1298300>>2],l,1);Cb(j+8|0,o,109);a=v[p>>2];Xa=p,Ya=(Bb(v[v[j+8>>2]>>2],v[j+12>>2])?a:a&-4609)|4096,v[Xa>>2]=Ya;v[m+1075688>>2]=0;break oc}Cb(j+8|0,o,99);if(!Bb(v[v[j+8>>2]>>2],v[j+12>>2])|!(w[p+1|0]&16)|v[m+1075688>>2]){break oc}qj(v[d+1298300>>2],l,1);v[p>>2]=v[p>>2]&-513}Hc:{if(!E){break Hc}Cb(j+16|0,o,31);if(Bb(v[v[j+16>>2]>>2],v[j+20>>2])){break Hc}jt(d,g)}b=v[p>>2];a=b&-65537;n=m+1075012|0;k=v[G>>2];i=m+1075016|0;c=v[n>>2]|(k|v[i>>2])?(a|b<<7&65536)^65536:a;v[p>>2]=c;r=m+1075664|0;a=r;v[a>>2]=0;v[a+4>>2]=0;h=m+1075834|0;a=w[h|0];b=a-4|0;b=a>>>0<b>>>0?0:b;t[h|0]=b;l=m+1075835|0;a=w[l|0];e=a-4|0;a=a>>>0<e>>>0?0:e;t[l|0]=a;Ic:{Jc:{Kc:{Lc:{Mc:{Nc:{Oc:{Pc:{Qc:{e=v[m+1075096>>2];Rc:{if(!e){break Rc}f=v[e+20>>2];if(!Zd(v[e>>2],f)|!v[m+1075068>>2]){break Rc}if(xi(v[g+8>>2],v[g+12>>2])){break Qc}}v[m+1075008>>2]=0;break Pc}v[m+1075008>>2]=f;if(f){break Oc}}if(!pj(v[g+656>>2])){break Nc}f=0;if(c&6144){break Nc}}G=v[m+1075676>>2];e=(B(k,256-G|0)|0)/16384|0;e=e>>>0<127?e:127;if(b<<24>>24<0){t[h|0]=e;V=e}else{V=b}b=e>>>1|0;if((V&255)>>>0<b>>>0){t[h|0]=b}b=(B(k,G)|0)/16384|0;b=b>>>0<127?b:127;if(a<<24>>24<0){t[l|0]=b;a=b}b=b>>>1|0;if(b>>>0>(a&255)>>>0){break Mc}break Lc}if((b&255)>>>0>=129){t[h|0]=0}f=0;b=0;if((a&255)>>>0<129){break Kc}}t[l|0]=b}if(!f){break Kc}f=128;h=v[d+24624>>2];if(h>>>0>=2){f=Xb(v[m+1075676>>2],0,256)}v[j+16>>2]=f;b=B(k,s)>>>(Pd(w[R|0])?7:8)|0;Sc:{Tc:{Uc:{switch(w[X|0]){case 0:if(!(w[d+24616|0]&16)){break Tc}case 1:if((f|0)<=127){a=b>>>1|0;b=(B(b,f)|0)/256|0;break Sc}a=(B(b,256-f|0)|0)/256|0;b=b>>>1|0;break Sc;case 3:break Uc;default:break Tc}}ai(j+16|0,255);e=v[j+16>>2];if((e|0)<=0){a=65536}else{a=x[(0-e<<1)+39696>>1]}a=B(a,b)>>>16|0;b=B(b,x[(e<<1)+39184>>1])>>>16|0;break Sc}a=(B(b,256-f|0)|0)/256|0;b=(B(b,f)|0)/256|0}e=v[J>>2];Vc:{if(e){f=w[e+14|0];if(Ho(f)){break Vc}}f=w[d+480268|0];if(Ho(f)){break Vc}e=w[d+24648|0];f=w[I|0]&128?v[d+24668>>2]?-1:e:e}k=m+1075668|0;l=m+1075786|0;t[l|0]=f;e=v[A>>2];n=v[A+4>>2];if(!(c&131072|((e|0)!=0|(n|0)!=1)|(v[m+1075748>>2]|(f&255)==255))){t[l|0]=0}f=a;a=1<<v[Z>>2];v[r>>2]=(f|0)/(a|0);a=(b|0)/(a|0)|0;v[k>>2]=(c&256)>>>8|0?(h|0)==2?0-a|0:a:a;if(c&128){v[A>>2]=0-e;v[A+4>>2]=0-(((e|0)!=0)+n|0)}f=0;k=jb-16|0;jb=k;v[g+28>>2]=0;v[g+32>>2]=0;ai(g+672|0,524287);ai(g+676|0,524287);Wc:{Xc:{e=v[g+88>>2];if(!(e&65536)){b=v[g+676>>2];a=v[g+672>>2];break Xc}a=v[g+20>>2];h=v[g+672>>2];Yc:{if((a|0)!=(h|0)){b=v[g+24>>2];c=v[g+676>>2];break Yc}b=v[g+24>>2];c=v[g+676>>2];if((b|0)==(c|0)){break Xc}}e=v[d+24620>>2];c=(a|0)<(h|0)|(b|0)<(c|0);Zc:{if(c){a=At(e,v[d+24636>>2]);break Zc}a=At(e,v[d+24640>>2])}Cb(k,d+1074312|0,4);if(!(!Bb(v[v[k>>2]>>2],v[k+4>>2])|!(v[d+480180>>2]&4))){a=v[d+24620>>2];a=Lka(a,a>>31,5,0)+500|0;h=mb;a=Hc(Mka(a,a>>>0<500?h+1|0:h,1e3,0),mb)}e=v[g+656>>2];_c:{if(!e){b=a;break _c}b=a;if(!c){break _c}c=x[e+12>>1];if(c){b=(B(c,v[d+24620>>2])>>>0)/1e5|0}f=(c|0)!=0}l=b?b:1;e=v[g+672>>2];n=v[g+20>>2];i=e-n<<12;r=g;c=v[g+676>>2];b=v[g+24>>2];h=c-b<<12;if(!(w[g+90|0]&32|(!(c|e)|(!(b|n)|f)))){v[k+12>>2]=v[d+1074380>>2];oe(k+12|0,a,2048);l=v[k+12>>2]}h=(h|0)/(l|0)|0;v[r+32>>2]=h;f=(i|0)/(l|0)|0;v[g+28>>2]=f;b=c+((B(h,l)|0)/-4096|0)|0;v[g+24>>2]=b;a=e+((B(f,l)|0)/-4096|0)|0;v[g+20>>2]=a;if(f|h){v[g+100>>2]=l;c=v[g+88>>2];break Wc}v[g+24>>2]=c;v[g+20>>2]=e;b=c;a=e;c=v[g+88>>2]&-65537;break Wc}v[g+24>>2]=b;v[g+20>>2]=a;c=e&-65537}v[g+88>>2]=c&-2097153;v[g+40>>2]=b<<12;v[g+36>>2]=a<<12;jb=k+16|0;c=v[p>>2];if(!(c&512)){break Jc}break Ic}v[n>>2]=0;v[i>>2]=0;v[m+1075068>>2]=0;if(v[m+1075088>>2]){break Jc}if(!v[m+1075084>>2]){break Ic}}a=x[d+480212>>1];u[d+480212>>1]=a+1;u[((a<<1)+d|0)+1074478>>1]=q}v[m+1075660>>2]=c}q=q+1|0;continue}break}}jb=j+48|0;if(N^1){a=v[d+480208>>2];break h}if(Pd(w[Ha|0])){b=v[d+480208>>2]|512;break i}l=0;$c:{a=v[d+24620>>2]/10|0;c=Hc(a,a>>31);if(!c){break $c}b=c>>>0<1048576?c:1048576;v[d+1074380>>2]=b;g=x[d+480212>>1];e=d+1074376|0;while(1){if((g|0)==(l|0)){break $c}a=e+B(x[(e+(l<<1)|0)+102>>1],872)|0;h=a+1288|0;v[h>>2]=0;v[h+4>>2]=0;v[a+716>>2]=b;h=v[a+640>>2]<<12;v[a+656>>2]=h;f=v[a+636>>2]<<12;v[a+652>>2]=f;v[a+704>>2]=v[a+704>>2]|65536;v[a+644>>2]=(0-f|0)/(b|0);v[a+648>>2]=(0-h|0)/(b|0);l=l+1|0;continue}}a=v[d+480208>>2];b=a|256;if(c){break i}b=a|512}a=b;v[d+480208>>2]=a}if(!(a&512)){break g}Xa=d+1074392|0,Ya=il(Ga),v[Xa>>2]=Ya}jb=M+112|0;break f}v[M+96>>2]=512;a=v[d+1074380>>2];v[M+104>>2]=fa;v[M+100>>2]=a;k=JB(M+96|0);if(v[d+24632>>2]){a=0;b=jb-48|0;jb=b;c=k<<2;while(1){if((a|0)==4){ad:{a=0;while(1){if((a|0)==4){break ad}v[(b+32|0)+(a<<2)>>2]=((a<<11)+d|0)+16396;a=a+1|0;continue}}}else{v[b+32>>2]=0;e=((a<<11)+d|0)+16396|0;Zz(e,c+e|0,b+32|0);a=a+1|0;continue}break}a=v[d+24632>>2];v[b+24>>2]=k;v[b+20>>2]=a;v[b+16>>2]=b+32;a=v[v[ma>>2]+8>>2];v[b+8>>2]=k;c=v[b+20>>2];v[b>>2]=v[b+16>>2];v[b+4>>2]=c;nb[a|0](ma,b);jb=b+48|0}if(Pd(Fa)){a=0;while(1){if((a|0)==4){a=v[d+24632>>2];v[M+88>>2]=k;v[M+84>>2]=a;v[M+80>>2]=M+96;a=v[v[oa>>2]+8>>2];v[M+40>>2]=k;b=v[M+84>>2];v[M+32>>2]=v[M+80>>2];v[M+36>>2]=b;nb[a|0](oa,M+32|0)}else{v[(M+96|0)+(a<<2)>>2]=((a<<11)+d|0)+16396;a=a+1|0;continue}break}}$=0;ga=0;E=jb-48|0;jb=E;if(k){o=d+12|0;r=d+24592|0;A=d+24588|0;_m(o,k,r,A);if(y[d+24624>>2]>=3){_m(d+8204|0,k,d+24600|0,d+24596|0)}u[E+42>>1]=0;ta=d+1074312|0;Ja=d+24648|0;ua=d+906300|0;Ka=d+24596|0;La=d+24600|0;Ma=d+8204|0;F=d+397452|0;G=d+397448|0;p=d+393352|0;va=d+397456|0;ia=d+1074376|0;Na=d+480190|0;while(1){if(x[d+480212>>1]<=$>>>0){Xa=d,Ya=x[ke(d+480214|0,E+42|0)>>1],u[Xa+480214>>1]=Ya}else{l=ia+($<<1)|0;h=x[l+102>>1];a=B(h,872);Q=a+ia|0;bd:{cd:{if(v[Q+632>>2]){break cd}b=a+d|0;if(v[b+1075088>>2]){break cd}if(!v[b+1075084>>2]){break bd}}j=a+d|0;a=w[j+1075786|0]+1&255;if(a>>>0<=5){f=v[(a<<2)+27776>>2]}else{f=0}I=j+1075080|0;g=v[I>>2];dd:{if(!(!(g&16777216)&w[d+24612|0]>>>5)){a=r;b=A;c=g;e=o;if(!(c&8388608)){break dd}}a=G;b=F;if(!w[va+12|0]){_m(p,k,a,b)}t[va+12|0]=1;h=x[l+102>>1];c=v[I>>2];e=p}n=b;b=c>>>8&y[d+24624>>2]>2;S=b?Ka:n;J=b?La:a;c=b?Ma:e;ja=Ol(d,ia,h,2,1)-1|0;wa=(ja&255)>>>0>249;ed:{if(wa){break ed}b=v[Ld(ua,ja)>>2];if(!b){break ed}a=v[b+24>>2];if(!a){break ed}S=b+36|0;J=b+40|0;if(!(t[b+28|0]&1)){_m(a,k,J,S);v[b+28>>2]=v[b+28>>2]|1}c=a}l=Q+616|0;if(w[j+1075843|0]&8){jD(l,c,k);a=j+1075084|0;v[J>>2]=v[J>>2]+v[a>>2];v[S>>2]=v[S>>2]+v[j+1075088>>2];v[a>>2]=0;v[a+4>>2]=0;break bd}ba=0;e=jb-16|0;jb=e;a=E+16|0;v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;b=e+8|0;h=d+1074312|0;Cb(b,h,33);Xa=a,Ya=Bb(v[v[e+8>>2]>>2],v[e+12>>2]),t[Xa+16|0]=Ya;Cb(b,h,116);Xa=a,Ya=Bb(v[v[e+8>>2]>>2],v[e+12>>2])^1,t[Xa+17|0]=Ya;if(v[l+16>>2]){hD(a,l);s=v[l+8>>2];n=v[l+12>>2];b=n>>31;n=(b^n)-((b>>>0>(b^s)>>>0)+b|0)|0;b=n;v[a+12>>2]=b>>>0>8191?2:16384/(b+1>>>0)|0}Oa=g>>>12&8|(g>>>5&2|(f|g&1));Pa=ga&65535;Qa=j+1075795|0;Ra=j+1075778|0;Sa=j+1075688|0;Ta=j+1075024|0;Ua=j+1075020|0;Va=j+1075668|0;Wa=j+1075664|0;R=j+1075088|0;X=j+1075084|0;xa=j+1075016|0;ya=j+1075012|0;ca=j+1075096|0;Z=j+1075076|0;N=j+1075068|0;K=j+1075e3|0;ha=j+1075072|0;Y=j+1075092|0;jb=e+16|0;q=a;a=k;while(1){fd:{b=v[Y>>2];ea=b?a>>>0>b>>>0?b:a:a;v[E+8>>2]=ea;gd:{hd:{if(!ea){break hd}j=v[K>>2];g=v[K+4>>2];if(!(j|g)){break hd}f=v[N>>2];if(!f){break hd}e=v[q>>2];if(!e){break hd}b=v[I>>2];n=v[ha>>2];v[Q+632>>2]=e;e=v[l>>2];id:{jd:{s=n&b<<30>>31;h=v[l+4>>2];m=h;if((s|0)>(h|0)){if((g|0)<0){e=Sg(0,s<<1,e,h);v[l>>2]=e;h=mb;v[l+4>>2]=h;if(!((h|0)>=(s|0)&h>>>0<f+s>>>1>>>0)){e=0;v[l>>2]=e;h=s;v[l+4>>2]=h}kd:{if(b&4){b=b&-129;v[I>>2]=b;g=0-(((j|0)!=0)+g|0)|0;j=0-j|0;v[K>>2]=j;v[K+4>>2]=g;break kd}v[l>>2]=e;h=f-1|0;v[l+4>>2]=h}if(!(b&2)){break hd}if(f>>>0>h>>>0){break id}break hd}if((h|0)>0|(h|0)>=0){break id}h=0;break jd}if(f>>>0>m>>>0){break id}if(!(b&2)){break hd}if(b&4){if(!!j&(g|0)>=0|(g|0)>0){g=0-(((j|0)!=0)+g|0)|0;j=0-j|0;v[K>>2]=j;v[K+4>>2]=g}b=b|128;v[I>>2]=b;if(w[E+33|0]){m=w[E+32|0];i=v[Z>>2]-(m+n|0)|0;e=Sg(e,h,0,f);h=mb;if(h>>>0<i>>>0){e=Sg(0,f-m|0,e,h);h=mb;break jd}h=n;e=0;break jd}h=1-((e|0)!=0)|0;e=0-e|0;i=(f<<1)-(h+m|0)|0;m=e;v[l>>2]=e;V=0;h=V|i;v[l+4>>2]=h;if(i>>>0>n>>>0&f>>>0>i>>>0){break id}v[E+44>>2]=w[E+32|0]+1;e=m;h=V|f-v[Jb(N,E+44|0)>>2];break jd}if((g|0)<0){g=0-(((j|0)!=0)+g|0)|0;j=0-j|0;v[K>>2]=j;v[K+4>>2]=g}Qb(l,0,s-f|0);b=v[I>>2]|8192;v[I>>2]=b;e=v[l>>2];h=v[l+4>>2];break id}v[l>>2]=e;v[l+4>>2]=h}V=h;ld:{if((h|0)<(s|0)){if((g|h)<0){break hd}v[E+44>>2]=ea;f=j;n=g;break ld}f=v[N>>2];if(f>>>0<V>>>0|(!!j&(g|0)>=0|(g|0)>0)&(f|0)==(V|0)){break hd}v[E+44>>2]=ea;f=g>>31;i=f^j;m=f;f=i-f|0;n=(g^m)-((i>>>0<m>>>0)+m|0)|0}m=f;i=n;wc(E+8|0,v[E+28>>2]);f=v[ha>>2];za=f+16|0;Aa=v[E+8>>2];Pf(e,h,kf(j,g,Aa-1|0),mb);n=mb;Ba=f>>>0>V>>>0;if(!(!Ba&V>>>0<za>>>0)){b=b&-8193;v[I>>2]=b}md:{nd:{ka=v[E+20>>2];od:{if(ka){f=v[E+24>>2];if(f>>>0<=V>>>0){pd:{if((g|0)<0){j=0;g=f;break pd}j=e;g=h;e=0;h=v[Z>>2]}Xa=E,Ya=Qo(Sg(Sg(e,h,j,g),mb,1,0),mb,m,i)+1|0,v[Xa+44>>2]=Ya;v[Q+632>>2]=ka;break md}if(!(!(b&8192)|Ba|V>>>0>=za>>>0)){Xa=E,Ya=Qo(Sg(Sg(0,s+16|0,e,h),mb,1,0),mb,m,i)+1|0,v[Xa+44>>2]=Ya;Xa=Q,Ya=B(v[Z>>2]-s|0,Ek(x[v[ca>>2]+34>>1]))+ka|0,v[Xa+632>>2]=Ya;break md}if(!j&(g|0)<=0|(g|0)<0){break od}if(ea>>>0<2|f>>>0>n>>>0){break nd}Xa=E,Ya=Qo(Sg(Sg(0,f,e,h),mb,1,0),mb,m,i)+1|0,v[Xa+44>>2]=Ya;break md}if((g|0)>0|(g|0)>=0){break nd}}if((n|0)>=(s|0)){break md}Xa=E,Ya=Qo(Sg(Sg(e,h,0,s),mb,1,0),mb,m,i)+1|0,v[Xa+44>>2]=Ya;break md}b=v[N>>2];if((b|0)>(n|0)){break md}Xa=E,Ya=Qo(Sg(Sg(0,b,e,h),mb,1,0),mb,m,i)+1|0,v[Xa+44>>2]=Ya}Po(E+44|0,1,Aa);g=v[E+44>>2];if((g|0)>0){break gd}}v[Q+632>>2]=0;v[N>>2]=0;v[l>>2]=0;v[l+4>>2]=0;v[Y>>2]=0;jD(l,c,a);v[J>>2]=v[J>>2]+v[X>>2];v[S>>2]=v[S>>2]+v[R>>2];v[R>>2]=0;v[X>>2]=0;v[I>>2]=v[I>>2]&-129;break fd}qd:{rd:{if(y[d+24608>>2]>Pa>>>0){b=4;if(v[Y>>2]){break rd}b=0;if(v[xa>>2]|v[ya>>2]){break rd}}Qb(l,kf(v[K>>2],v[K+4>>2],g),mb);ba=0;v[R>>2]=0;v[X>>2]=0;c=(g<<3)+c|0;break qd}e=(g<<3)+c|0;h=e-8|0;v[X>>2]=0-v[h>>2];f=e-4|0;v[R>>2]=0-v[f>>2];nb[v[((b|Oa)<<2)+27392>>2]](l,Ja,c,g);v[X>>2]=v[X>>2]+v[h>>2];v[R>>2]=v[R>>2]+v[f>>2];ba=1;c=e}b=v[Y>>2];sd:{if(!b){break sd}if(b>>>0<=g>>>0){v[Y>>2]=0;v[ya>>2]=v[Wa>>2];v[xa>>2]=v[Va>>2];v[Ua>>2]=0;v[Ta>>2]=0;if(v[Sa>>2]|!(w[I+1|0]&16)){break sd}v[N>>2]=0;v[Q+632>>2]=0;break sd}v[Y>>2]=b-g}e=0;h=0;b=v[l+4>>2];h=b>>>0>=y[Z>>2]?(w[I|0]&2)>>>1|0:h;f=b;b=v[N>>2];e=f>>>0<b>>>0|(!b|w[I|0]&2)?e:!x[Ra>>1];a=a-g|0;Cb(E+8|0,ta,85);td:{ud:{vd:{wd:{if(!Bb(v[v[E+8>>2]>>2],v[E+12>>2])){break wd}b=w[Qa|0];if(!b|b>>>0>x[Na>>1]){break wd}b=B(b,104)+d|0;g=b+484380|0;f=v[ca>>2];if((g|0)==(f|0)|(e|h)!=1){break vd}v[ca>>2]=g;v[Q+632>>2]=v[b+484400>>2];e=x[b+484414>>1];v[I>>2]=e|v[I>>2]&-768;h=e<<30>>31;e=v[b+484388>>2];v[N>>2]=h&e;b=v[b+484384>>2];v[ha>>2]=b;v[Z>>2]=e;v[l+4>>2]=b;hD(q,l);if(!v[Q+632>>2]){break fd}if((a|0)>0){continue}break fd}if(h){break ud}break td}if(!h|(f|0)!=(g|0)){break td}}Cb(E+8|0,ta,83);if(!Bb(v[v[E+8>>2]>>2],v[E+12>>2])|v[ha>>2]){break td}v[l>>2]=v[l>>2];v[l+4>>2]=0;b=v[v[ca>>2]+8>>2];v[N>>2]=b;v[Z>>2]=b}if((a|0)>0){continue}}break}v[Q+632>>2]=v[q>>2];ga=ba+ga|0;u[E+42>>1]=ga;if(!ba|wa){break bd}a=v[Ld(ua,ja)>>2];if(!a){break bd}nb[v[v[a>>2]+152>>2]](a)}$=$+1|0;continue}break}}jb=E+48|0;i=v[d+1298300>>2];if(Ed(i)){a=_;b=k;c=(B(v[d+480232>>2],v[d+480236>>2])>>>0)/48|0;l=jb-16|0;jb=l;xd:{if(!w[i+534|0]){break xd}e=Lka(c,0,6169,0);c=mb;f=c>>>16|0;p=Dc((c&65535)<<16|e>>>16,f);while(1){if(!b){break xd}f=v[i>>2];h=v[f>>2];c=v[f+4>>2];while(1){if((c|0)>=(h|0)){v[f+8>>2]=v[f+12>>2];h=0;j=0;q=0;c=jb-16|0;jb=c;while(1){if((q|0)==18){e=(h|0)<32767?h:32767;u[f+12>>1]=(e|0)>-32768?e:-32768;e=(j|0)<32767?j:32767;u[f+14>>1]=(e|0)>-32768?e:-32768;u[f+3832>>1]=x[f+3832>>1]+1;e=(x[f+3834>>1]+1>>>0)%13440|0;u[f+3834>>1]=e;e=e>>>0<6720?e:13440-e|0;u[f+3836>>1]=(e&65280)>>>8;if(!w[f+3843|0]){u[f+3836>>1]=(e&64512)>>>10}e=x[f+3838>>1]+1|0;u[f+3838>>1]=e;if((e&65535)>>>0>=1024){u[f+3838>>1]=0;u[f+3840>>1]=x[f+3840>>1]+1&7}jb=c+16|0}else{g=f+B(q,44)|0;yd:{if(!w[g+56|0]){u[c+12>>1]=0;u[c+14>>1]=0;break yd}n=v[g+32>>2];e=x[n+3840>>1];if(e&3){n=(x[g+36>>1]>>>7&7)>>>(w[n+3844|0]^1)>>>(e&1)<<x[g+38>>1];e=e&4?0-n|0:n}else{e=0}n=v[g+52>>2];zd:{if(n){r=x[n+32>>1];o=x[g+48>>1];n=hg(v[g+16>>2],v[g+40>>2],e<<16>>16,0,u[g+46>>1]);s=v[g+40>>2];m=v[g+20>>2];if(!r){if(!o){e=e<<16>>16;n=hg(m,s,e,n,0);n=hg(v[g+24>>2],v[g+40>>2],e,n,0);e=hg(v[g+28>>2],v[g+40>>2],e,n,0);break zd}e=e<<16>>16;s=hg(m,s,e,0,0);s=hg(v[g+24>>2],v[g+40>>2],e,s,0);e=hg(v[g+28>>2],v[g+40>>2],e,s,0)+n|0;break zd}if(!o){e=e<<16>>16;n=hg(m,s,e,n,0);s=hg(v[g+24>>2],v[g+40>>2],e,0,0);e=hg(v[g+28>>2],v[g+40>>2],e,s,0)+n|0;break zd}e=e<<16>>16;s=hg(m,s,e,0,0);e=(hg(v[g+24>>2],v[g+40>>2],e,s,0)+n|0)+hg(v[g+28>>2],v[g+40>>2],e,0,0)|0;break zd}o=x[g+48>>1];e=e<<16>>16;n=hg(v[g+16>>2],v[g+40>>2],e,0,u[g+46>>1]);s=v[g+40>>2];m=v[g+20>>2];if(!o){e=hg(m,s,e,n,0);break zd}e=hg(m,s,e,0,0)+n|0}u[c+14>>1]=w[g+57|0]?e:0;u[c+12>>1]=w[g+58|0]?e:0}q=q+1|0;j=u[c+12>>1]+j|0;h=u[c+14>>1]+h|0;continue}break}h=v[f>>2];c=v[f+4>>2]-h|0;v[f+4>>2]=c;continue}break}e=h-c|0;u[l+14>>1]=(B(u[f+12>>1],c)+B(e,u[f+8>>1])|0)/(h|0);u[l+12>>1]=(B(u[f+14>>1],c)+B(e,u[f+10>>1])|0)/(h|0);v[f+4>>2]=c+49716;v[a>>2]=v[a>>2]+B(p,u[l+14>>1]);v[a+4>>2]=v[a+4>>2]+B(p,u[l+12>>1]);a=a+8|0;b=b-1|0;continue}}jb=l+16|0}a=w[H+12|0];if(v[H+16>>2]?1:a){if(!a){_m(aa,k,sa,ra)}a=v[H>>2];b=v[H+80>>2];c=B(a,b)>>>4|0;c=c>>>0<32767?c:32767;u[H+98>>1]=c;u[H+96>>1]=c;c=v[H+49948>>2];e=B(c,a)>>>4|0;e=e>>>0<65536?e:65536;g=e+127>>>3|0;u[H+49946>>1]=g;e=e+255>>>4|0;u[H+49944>>1]=e;u[H+49942>>1]=e;u[H+49940>>1]=g;b=(b|0)>(c|0)?b:c;a=36-a>>>1|0;a=16-(a>>>0>8?a:8)|0;a=16-(B((b|0)<32768?b:32768,a>>>0>16?0:a)>>15)|0;q=0;while(1){if((k|0)!=(q|0)){b=q<<3;c=b+_|0;v[c>>2]=v[c>>2]+B(a,v[b+aa>>2]>>4);b=b|4;c=b+_|0;v[c>>2]=v[c>>2]+B(a,v[b+aa>>2]>>4);q=q+1|0;continue}break}n=H+68|0;l=0;b=u[H+84>>1];c=v[H+40>>2];h=v[H+36>>2];while(1){if((k|0)==(l|0)){v[H+40>>2]=c;v[H+36>>2]=h;g=k}else{a=(l<<3)+aa|0;e=v[a>>2]>>12;h=(B(b,e-h|0)>>15)+e|0;v[a>>2]=h;e=a;a=v[a+4>>2]>>12;c=(B(b,a-c|0)>>15)+a|0;v[e+4>>2]=c;l=l+1|0;continue}break}if(g){b=aa;a=g;r=v[n>>2]-1|0;i=x[n+22>>1];c=x[n+20>>1];e=u[n+26>>1];h=u[n+24>>1];s=u[n+18>>1];m=u[n+16>>1];q=v[n+4>>2];f=n+32928|0;while(1){if(a){j=jd(v[b>>2]);l=jd(v[b+4>>2]);c=jd((c<<16>>16)-j|0);i=jd((i<<16>>16)-l|0);c=dd(jd((B(c,m)|0)/65536<<1)+j|0);i=dd(jd((B(i,s)|0)/65536<<1)+l|0);l=f+(q<<2)|0;p=u[l>>1];j=dd(((B(p,h)|0)/-65536|0)+c|0);q=q+1&127;o=f+(q<<2)|0;l=u[l+2>>1];A=dd(((B(l,e)|0)/-65536|0)+i|0);u[o+2>>1]=A;u[o>>1]=j;r=r+1&8191;o=n+(r<<2)|0;Xa=o,Ya=dd(p+((B(h,j)|0)/65536|0)|0),u[Xa+160>>1]=Ya;Xa=o,Ya=dd(l+((B(e,A)|0)/65536|0)|0),u[Xa+162>>1]=Ya;b=b+8|0;a=a-1|0;continue}break}u[n+22>>1]=i;u[n+20>>1]=c;v[n+4>>2]=q}j=H+49892|0;G=H+33508|0;b=g;a=aa;while(1){if(b){e=v[H+76>>2];h=e&4095;i=G+(h<<2)|0;c=a;h=4096-h|0;A=e-v[H+49892>>2]&4095;e=4096-A|0;e=e>>>0>h>>>0?h:e;e=b>>>0<e>>>0?b:e;h=e>>>0<64?e:64;q=h;e=0;s=jb-32|0;jb=s;f=v[n>>2];while(1){if((e|0)==7){Ad:{p=u[n+28>>1]/8<<16>>16;Bd:while(1){if(!q){break Ad}q=q-1|0;e=0;l=0;f=0;while(1)if((e|0)==4){e=4;r=0;o=dd((f|0)/32768|0);F=dd((l|0)/32768|0);l=0;while(1)if((e|0)==7){e=dd(o+((l|0)/32768|0)|0);u[i>>1]=e;v[c>>2]=B(e,p);e=dd(F+((r|0)/32768|0)|0);u[i+2>>1]=e;v[c+4>>2]=B(e,p);c=c+8|0;i=i+4|0;continue Bd}else{f=s+(e<<2)|0;m=v[f>>2]+1&8191;v[f>>2]=m;m=n+(m<<2)|0;E=u[m+160>>1];f=n+(e<<4)|0;m=u[m+162>>1];r=(B(E,u[f+44>>1])+r|0)+B(m,u[f+46>>1])|0;l=(B(E,u[f+40>>1])+l|0)+B(m,u[f+42>>1])|0;e=e+1|0;continue}}else{m=s+(e<<2)|0;o=v[m>>2]+1&8191;v[m>>2]=o;V=l;l=n+(o<<2)|0;o=u[l+160>>1];m=n+(e<<4)|0;r=u[l+162>>1];l=(V+B(o,u[m+44>>1])|0)+B(r,u[m+46>>1])|0;f=(B(o,u[m+40>>1])+f|0)+B(r,u[m+42>>1])|0;e=e+1|0;continue}}}}else{v[s+(e<<2)>>2]=f+(v[(n+(e<<4)|0)+32>>2]^-1);e=e+1|0;continue}break}jb=s+32|0;q=G+(A<<2)|0;e=a;c=h;f=v[j+4>>2];l=j+8256|0;s=j- -64|0;m=j+24640|0;i=j+16448|0;while(1){p=f&2047;if(c){E=u[l+((f+1206&2047)<<2)>>1];J=u[(l+((f+754&2047)<<2)|0)+2>>1];F=u[(s+((f+1602&2047)<<2)|0)+2>>1];I=u[s+((f+1750&2047)<<2)>>1];o=u[q>>1];r=u[q+2>>1];A=m+((f+502&2047)<<2)|0;K=u[A>>1];Q=jd(u[j+32>>1]-K|0);A=u[A+2>>1];N=jd(u[j+34>>1]-A|0);S=u[j+26>>1];R=m+((f+22&2047)<<2)|0;X=u[R>>1];Z=jd(u[j+36>>1]-X|0);Y=u[j+28>>1];R=u[R+2>>1];V=jd(u[j+38>>1]-R|0);$=u[j+30>>1];K=dd(jd((B(Q,u[j+24>>1])|0)/65536<<1)+K|0);u[j+32>>1]=K;Xa=j,Ya=dd(jd((B(N,S)|0)/65536<<1)+A|0),u[Xa+34>>1]=Ya;Xa=j,Ya=dd(jd((B(Z,Y)|0)/65536<<1)+X|0),u[Xa+36>>1]=Ya;A=dd(jd((B(V,$)|0)/65536<<1)+R|0);u[j+38>>1]=A;K=jd((B(K,u[j+16>>1])|0)/32768|0);A=jd((B(A,u[j+22>>1])|0)/32768|0);K=jd(K+((o|0)/4<<16>>16)|0);Q=jd(A+((r|0)/4<<16>>16)|0);o=u[j+8>>1];N=jd(K+((B(o,I)|0)/-65536|0)|0);r=p<<2;S=r+s|0;A=u[j+10>>1];R=jd(Q+((B(A,F)|0)/-65536|0)|0);u[S+2>>1]=R;u[S>>1]=N;I=jd(I+((B(o,N)|0)/65536|0)|0);N=i+r|0;F=jd(F+((B(A,R)|0)/65536|0)|0);u[N+2>>1]=F;u[N>>1]=I;I=jd(I+K|0);K=jd(F+Q|0);F=i+((f+682&2047)<<2)|0;Q=u[F+2>>1];N=u[F>>1];F=jd((B(Q,u[j+42>>1])+B(N,u[j+40>>1])|0)/32768|0);f=i+((f+426&2047)<<2)|0;S=u[f+2>>1];R=u[f>>1];f=jd((B(S,u[j+46>>1])+B(R,u[j+44>>1])|0)/32768|0);N=jd(jd(I+N|0)-F|0);Q=jd(jd(K+Q|0)-f|0);I=jd(jd(I+R|0)-F|0);K=jd(jd(K+S|0)-f|0);F=jd(F+((B(o,E)|0)/-65536|0)|0);S=l+r|0;R=jd(f+((B(A,J)|0)/-65536|0)|0);u[S+2>>1]=R;u[S>>1]=F;o=(B(o,F)|0)/65536|0;f=jd(o+E|0);r=m+r|0;A=(B(A,R)|0)/65536|0;F=jd(A+J|0);u[r+2>>1]=F;u[r>>1]=f;Xa=e,Ya=(v[e>>2]+B(jd(f+N|0),u[j+48>>1])|0)+B(jd(F+Q|0),u[j+50>>1])|0,v[Xa>>2]=Ya;Xa=e,Ya=(v[e+4>>2]+B(jd(jd(o)+I|0),u[j+52>>1])|0)+B(jd(jd(A)+K|0),u[j+54>>1])|0,v[Xa+4>>2]=Ya;e=e+8|0;f=p+1|0;q=q+4|0;c=c-1|0;continue}break}v[j+4>>2]=p;v[H+76>>2]=h+v[H+76>>2]&4095;v[H+68>>2]=h+v[H+68>>2]&8191;b=b-h|0;a=(h<<3)+a|0;continue}break}v[H+68>>2]=v[H+68>>2]&8191;l=aa;e=_;c=g;h=0;f=0;j=v[H+56>>2];b=v[H- -64>>2];q=v[H+52>>2];a=v[H+60>>2];while(1){if(c){h=v[l>>2];f=v[l+4>>2];b=b-f|0;b=(((b|0)/1024|0)-b|0)+j|0;v[e+4>>2]=b+v[e+4>>2];a=a-h|0;a=(((a|0)/1024|0)-a|0)+q|0;v[e>>2]=a+v[e>>2];j=b+((b|0)/-512|0)|0;q=a+((a|0)/-512|0)|0;e=e+8|0;l=l+8|0;c=c-1|0;a=h;b=f;continue}break}v[H+64>>2]=f;v[H+60>>2]=h;v[H+56>>2]=j;v[H+52>>2]=q;a=v[H+20>>2];Cd:{if(w[H+12|0]){break Cd}a=v[H+16>>2];if(a>>>0>g>>>0){a=a-g|0;break Cd}zK(H,sa,ra);a=0}t[H+12|0]=0;v[H+16>>2]=a}if(v[d+946300>>2]){Dd:{f=0;e=0;g=k<<2;q=d+906300|0;i=x[d+480214>>1]!=0;Ca=z[d+1074336>>2];W=z[d+1074332>>2];while(1)if((f|0)==250){h=d+12|0;n=d+12300|0;s=d+14348|0;tv(h,n,s,k,W);a=d+1074476|0;A=w[a|0];t[a|0]=0;a=s;c=n;while(1){Ed:{Fd:{Gd:{if((e|0)!=250){m=Ld(q,e);l=v[m>>2];if(!l|!v[l+24>>2]){break Ed}if(!$h(l+44|0)){break Ed}j=l;Hd:{if(sv(w[m+24|0])){break Hd}b=nb[v[v[l>>2]+148>>2]](l)|0;j=v[m>>2];if(b){break Hd}f=0;if(w[j+28|0]&2){break Hd}while(1){if((e|0)==(f|0)){break Ed}b=Ld(q,f);f=f+1|0;if((Ym(v[b+28>>2])|0)!=(e|0)){continue}break}}b=v[l+44>>2];p=Jc(b,0);r=Jc(b,1);o=(c|0)==(p|0);c=o?n:c;b=c;a=o?s:a;f=v[m+28>>2];g=a;Id:{if(!f){break Id}b=c;f=Ym(f);g=a;if(f>>>0<=e>>>0){break Id}g=a;if(f>>>0>249){break Id}f=v[Ld(q,f)>>2];g=a;if(!f){break Id}if(!(w[j+28|0]&4)){nb[v[v[f>>2]+152>>2]](f)}g=a;if(!$h(f+44|0)){break Id}g=v[f+44>>2];b=Jc(g,0);g=Jc(g,1)}if(!sv(w[m+24|0])){break Fd}f=0;Jd:{if(o){break Jd}while(1){if((f|0)==(k|0)){break Jd}o=f<<2;F=o+p|0;G=c+o|0;z[F>>2]=z[G>>2]+z[F>>2];F=o+r|0;o=a+o|0;z[F>>2]=z[o>>2]+z[F>>2];v[G>>2]=0;v[o>>2]=0;f=f+1|0;continue}}a=g;c=b;if(!(i&1)){break Fd}a=v[m>>2];if(a){nb[v[v[a>>2]+152>>2]](a)}f=Ym(v[m+28>>2]);a=e;while(1){c=f;f=c&255;if(f>>>0>249|f>>>0<=(a&255)>>>0){break Gd}o=Ld(q,f);f=Ym(v[o+28>>2]);a=c;c=v[o>>2];if(!c){continue}nb[v[v[c>>2]+152>>2]](c);continue}}b=0;while(1){if((b|0)!=(k|0)){W=C(z[c>>2]*Ca);Kd:{if(C(D(W))<C(2147483648)){e=~~W;break Kd}e=-2147483648}v[h>>2]=e;W=C(z[a>>2]*Ca);Ld:{if(C(D(W))<C(2147483648)){e=~~W;break Ld}e=-2147483648}v[h+4>>2]=e;b=b+1|0;h=h+8|0;a=a+4|0;c=c+4|0;continue}break}break Dd}a=g;c=b}f=0;Md:{Nd:{o=w[m+24|0];if(!((o&2)>>>1|0)){if(!eD(o)|!(w[j+28|0]&4)){break Nd}}while(1){if((f|0)==(k|0)){break Md}l=f<<2;m=l+b|0;z[m>>2]=z[l+p>>2]+z[m>>2];m=g+l|0;z[m>>2]=z[l+r>>2]+z[m>>2];f=f+1|0;continue}}if(A){nb[v[v[l>>2]+132>>2]](l)}nb[v[v[l>>2]+60>>2]](l,b,g,k);v[j+32>>2]=k+v[j+32>>2];if(!eD(w[m+24|0])){break Md}if((nb[v[v[l>>2]+160>>2]](l)|0)<=0|y[j+32>>2]<v[d+24620>>2]<<2>>>0){break Md}Od:{while(1){if((f|0)==(k|0)){break Od}l=f<<2;W=z[l+b>>2];Pd:{if(W>=C(1.1920928955078125e-7)|W<=C(-1.1920928955078125e-7)){break Pd}W=z[g+l>>2];if(W>=C(1.1920928955078125e-7)){break Pd}f=f+1|0;if(!(W<=C(-1.1920928955078125e-7))){continue}}break}v[j+32>>2]=0;break Md}v[j+28>>2]=v[j+28>>2]|4}v[j+28>>2]=v[j+28>>2]&-3}e=e+1|0;continue}}else{h=Ld(q,f);a=v[h>>2];Qd:{if(!a|!v[a+24>>2]){break Qd}if(!$h(a+44|0)){break Qd}if(!(nb[v[v[a>>2]+116>>2]](a)|0)){nb[v[v[a>>2]+112>>2]](a,1);nb[v[v[a>>2]+124>>2]](a)}c=v[a+44>>2];b=Jc(c,0);c=Jc(c,1);Rd:{if(t[a+28|0]&1){tv(v[a+24>>2],b,c,k,W);break Rd}j=a+40|0;if(v[a+36>>2]?1:v[j>>2]){_m(v[a+24>>2],k,j,a+36|0);tv(v[a+24>>2],b,c,k,W);break Rd}Tb(b,0,g);Tb(c,0,g)}b=a;a=v[a+28>>2];v[b+28>>2]=a&-2;if(sv(w[h+24|0])){break Qd}i=!(a&4)|i}f=f+1|0;continue}}}if(v[d+24624>>2]==1){b=0;while(1){if((b|0)!=(k|0)){a=(b<<3)+_|0;v[(b<<2)+_>>2]=(v[a+4>>2]+v[a>>2]|0)/2;b=b+1|0;continue}break}}if(Pd(w[Ia|0])){c=0;g=jb-16|0;jb=g;Sd:{if(!v[d+1074376>>2]){l=d+1074460|0;a=l;v[a>>2]=0;v[a+4>>2]=0;a=v[d+1074456>>2];v[d+1074468>>2]=a;break Sd}a=v[d+1074456>>2];b=v[d+1074468>>2];Td:{if((a|0)==(b|0)){e=v[d+1074460>>2];break Td}v[d+1074468>>2]=a;e=v[d+24620>>2];h=d+1074460|0;Ud:{if((a|0)>(b|0)){e=At(e,v[d+24636>>2]);break Ud}e=At(e,v[d+24640>>2])}v[h>>2]=e;v[d+1074464>>2]=e;b=a}l=d+1074460|0;if((e|0)<=0){break Sd}b=(b<<12)-v[d+1074472>>2]|0;c=(b|0)/(e|0)|0;if(w[d+1074368|0]!=2){break Sd}v[g+12>>2]=50;h=v[d+1074464>>2];v[g+8>>2]=1e4/(h+1|0);f=v[Oe(g+12|0,g+8|0)>>2];while(1){j=c>>31;if((f|0)>=((j^c)-j|0)){break Sd}e=e+h|0;v[l>>2]=e;c=(b|0)/(e|0)|0;continue}}Vd:{Wd:{switch(v[d+24624>>2]-1|0){case 0:b=0;f=(k|0)>0?k:0;j=a<<12;e=d+12|0;n=a>>31;while(1){if((b|0)==(f|0)){break Vd}Xd:{if(v[l>>2]>0){h=v[d+1074472>>2]+c|0;v[d+1074472>>2]=h;s=v[e>>2];Xa=e,Ya=Hc(Mka(Lka(s,s>>31,h,h>>31),mb,1048576,0),mb),v[Xa>>2]=Ya;v[d+1074460>>2]=v[d+1074460>>2]-1;break Xd}h=v[e>>2];Xa=e,Ya=Hc(Mka(Lka(h,h>>31,a,n),mb,256,0),mb),v[Xa>>2]=Ya;v[d+1074472>>2]=j}b=b+1|0;e=e+4|0;continue};case 1:b=0;j=(k|0)>0?k:0;n=a<<12;e=d+12|0;h=a>>31;while(1){if((b|0)==(j|0)){break Vd}Yd:{if(v[l>>2]>0){f=v[d+1074472>>2]+c|0;v[d+1074472>>2]=f;s=v[e>>2];Xa=e,Ya=Hc(Mka(Lka(s,s>>31,f,f>>31),mb,1048576,0),mb),v[Xa>>2]=Ya;f=v[d+1074472>>2];m=f;s=f>>31;f=v[e+4>>2];Xa=e,Ya=Hc(Mka(Lka(m,s,f,f>>31),mb,1048576,0),mb),v[Xa+4>>2]=Ya;v[d+1074460>>2]=v[d+1074460>>2]-1;break Yd}f=v[e>>2];Xa=e,Ya=Hc(Mka(Lka(f,f>>31,a,h),mb,256,0),mb),v[Xa>>2]=Ya;f=v[e+4>>2];Xa=e,Ya=Hc(Mka(Lka(f,f>>31,a,h),mb,256,0),mb),v[Xa+4>>2]=Ya;v[d+1074472>>2]=n}b=b+1|0;e=e+8|0;continue};case 3:break Wd;default:break Vd}}f=0;n=(k|0)>0?k:0;s=a<<12;e=d+8204|0;b=d+12|0;h=a>>31;while(1){if((f|0)==(n|0)){break Vd}Zd:{if(v[l>>2]>0){j=v[d+1074472>>2]+c|0;v[d+1074472>>2]=j;m=v[b>>2];Xa=b,Ya=Hc(Mka(Lka(m,m>>31,j,j>>31),mb,1048576,0),mb),v[Xa>>2]=Ya;j=v[d+1074472>>2];m=j;i=j>>31;j=v[b+4>>2];Xa=b,Ya=Hc(Mka(Lka(m,i,j,j>>31),mb,1048576,0),mb),v[Xa+4>>2]=Ya;j=v[d+1074472>>2];m=j;i=j>>31;j=v[e>>2];Xa=e,Ya=Hc(Mka(Lka(m,i,j,j>>31),mb,1048576,0),mb),v[Xa>>2]=Ya;j=v[d+1074472>>2];m=j;i=j>>31;j=v[e+4>>2];Xa=e,Ya=Hc(Mka(Lka(m,i,j,j>>31),mb,1048576,0),mb),v[Xa+4>>2]=Ya;v[d+1074460>>2]=v[d+1074460>>2]-1;break Zd}j=v[b>>2];Xa=b,Ya=Hc(Mka(Lka(j,j>>31,a,h),mb,256,0),mb),v[Xa>>2]=Ya;j=v[b+4>>2];Xa=b,Ya=Hc(Mka(Lka(j,j>>31,a,h),mb,256,0),mb),v[Xa+4>>2]=Ya;j=v[e>>2];Xa=e,Ya=Hc(Mka(Lka(j,j>>31,a,h),mb,256,0),mb),v[Xa>>2]=Ya;j=v[e+4>>2];Xa=e,Ya=Hc(Mka(Lka(j,j>>31,a,h),mb,256,0),mb),v[Xa+4>>2]=Ya;v[d+1074472>>2]=s}f=f+1|0;e=e+8|0;b=b+8|0;continue}}jb=g+16|0}if(v[pa>>2]!=128){b=d+12|0;c=d+8204|0;a=v[d+24604>>2];e=v[d+24624>>2];_d:{if((a|0)==128|e>>>0<2){break _d}mM(b,k,a);if(e>>>0<4){break _d}mM(c,k,a)}}if(v[d+24624>>2]==4){a=k;while(1){a=a-1|0;if((a|0)>=0){b=(a<<4)+_|0;c=a<<3;e=c|4;v[b+12>>2]=v[e+qa>>2];v[b+8>>2]=v[c+qa>>2];v[b+4>>2]=v[e+_>>2];v[b>>2]=v[c+_>>2];continue}break}}if(Pd(Ea)){a=v[d+24624>>2];v[M+72>>2]=k;v[M+68>>2]=a;v[M+64>>2]=_;a=v[v[na>>2]+8>>2];v[M+24>>2]=k;b=v[M+68>>2];v[M+16>>2]=v[M+64>>2];v[M+20>>2]=b;nb[a|0](na,M+16|0)}a=v[d+24624>>2];v[M+56>>2]=k;v[M+52>>2]=a;v[M+48>>2]=_;a=v[v[la>>2]+8>>2];v[M+8>>2]=k;b=v[M+52>>2];v[M>>2]=v[M+48>>2];v[M+4>>2]=b;nb[a|0](la,M);v[d+1074380>>2]=v[d+1074380>>2]-k;v[d+1074376>>2]=k+v[d+1074376>>2];fa=fa-k|0;Da=k+Da|0;continue}break}jb=da+32|0;return Da}function vg(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=C(0),k=0,m=0,o=0,p=0,r=0,s=0,E=C(0),F=0,G=0,H=C(0),I=0,J=0,K=0,M=0,N=0;k=jb-2288|0;jb=k;a:{b:{c:{d:{e:{f:{if(vv(v[c>>2])){wc(b,268435456);J=v[c+8>>2];G=k+2264|0;e=G;v[e>>2]=0;v[e+4>>2]=0;Sb(e+8|0);v[k+2260>>2]=0;g:{h:{i:{j:{k:{l:{e=w[a+3|0];m:{n:{if((e-4&255)>>>0<=4){v[23588]=0;d=S(202,c|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break l}v[k+2260>>2]=d;break n}if(e>>>0>17){break m}o:{g=1<<e;if(!(g&63503)){if(!(g&198144)){break m}break o}if(w[a|0]){break o}break n}e=0;f=QA(a,v[b>>2]);v[23588]=0;U(203,k+96|0,c|0,f|0);f=v[23588];v[23588]=0;if((f|0)==1){break k}d=k+96|0;f=v[d+4>>2];v[G>>2]=v[d>>2];v[G+4>>2]=f;Km(G+8|0,d+8|0);Tc(d);f=Ie(G);d=v[G>>2];v[k+2260>>2]=d;if(!f){break g}}e=w[a+3|0]}h=1;p:{q:{switch(e&255){case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:h=!w[a|0];break p;case 9:case 10:case 16:case 17:break q;default:break p}}h=0}g=v[b>>2];if(!(g>>>0<262145|h)){e=e&255;v[k+96>>2]=((e|0)==10)<<4;h=d-v[Jb(k+96|0,k+2260|0)>>2]|0;if(e>>>0>15){break j}r:{if(!(1<<e&63503)){if((e|0)==10){break r}break j}if(!(w[a|0]&7)){break j}}e=(h|0)>=0?h<<1:-1;break i}e=e&255;if(e>>>0>8){break h}if(!(1<<e&432)){if((e|0)!=6){break h}e=0;if(d>>>0<10){break g}v[23588]=0;Q(188,c|0,4)|0;d=v[23588];v[23588]=0;if((d|0)==1){break l}v[23588]=0;e=S(157,c|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){v[k+96>>2]=e;v[k+72>>2]=v[k+2260>>2];d=v[Jb(k+96|0,k+72|0)>>2];yg(c,8);e=((d>>>0>50529027?-1:B(d,85))>>>0)/(w[a|0]>>>3>>>0)|0;break i}a=P()|0;O()|0;break a}e=8/(nq(w[a+1|0])>>>0)|0;Lka(e,0,d,0);e=mb?-1:B(e,d);break i}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}g=0;d=nq(w[a+1|0]);s:{t:{switch(e|0){case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:g=w[a|0];break s;case 9:g=16;break s;case 10:g=4;break s;case 16:case 17:break t;default:break s}}g=8}e=B(d,g&255)>>>3|0;d=(e+h|0)-1|0;e=((d>>>0<h>>>0?-1:d)>>>0)/(e>>>0)|0}wc(b,e);g=v[b>>2]}if(!g){e=0;break g}u[b+34>>1]=x[b+34>>1]&65470|w[a|0]>15|(w[a+1|0]!=1)<<6;if(!Ng(b)){e=0;v[b>>2]=0;break g}u:{if(ne(a,Zc(k+96|0,8,1,0,10))){v[23588]=0;d=Q(204,c|0,k+96|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){e=0;if(!d){break u}a=v[b>>2];d=0;v[23588]=0;v[k+72>>2]=a+1>>>1;e=S(202,c|0)|0;a=v[23588];v[23588]=0;if((a|0)==1){break b}wc(k+72|0,e);a=f+16|0;b=v[b+20>>2];h=v[k+72>>2];e=h;while(1)if(e){g=k+96|0;f=d+w[g|w[a|0]&15]|0;t[b|0]=f;d=w[g|w[a|0]>>>4]+(f&255)|0;t[b+1|0]=d;e=e-1|0;a=a+1|0;b=b+2|0;continue}else{e=h+16|0;break u}}a=P()|0;O()|0;break a}v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{g=w[a+3|0];switch(g-4|0){case 3:break D;case 4:break E;case 5:break F;case 2:break G;case 0:case 1:break H;default:break B}}v[23588]=0;b=fa(205,k+1168|0,c|0,b|0,(g|0)==5|0)|0;a=v[23588];v[23588]=0;if((a|0)==1){break f}Ab(b);e=v[c+8>>2]-J|0;break u}if(w[a+1|0]!=1){break C}v[23588]=0;Q(188,c|0,4)|0;a=v[23588];v[23588]=0;if((a|0)==1){break f}v[23588]=0;f=S(157,c|0)|0;a=v[23588];v[23588]=0;I:{J:{K:{if((a|0)!=1){v[23588]=0;v[k+72>>2]=f;h=S(206,c|0)|0;a=v[23588];v[23588]=0;if((a|0)==1){break K}v[23588]=0;U(207,k+96|0,c|0,f|0);a=v[23588];v[23588]=0;if((a|0)==1){break J}wc(k+72|0,v[k+96>>2]);g=v[k+72>>2];e=Ie(k+96|0);d=x[b+34>>1];f=v[b+20>>2];b=v[b>>2];a=v[k+96>>2];v[23588]=0;ea(208,e|0,a|0,f|0,Hj(b,d)|0,h<<24>>24);a=v[23588];v[23588]=0;if((a|0)==1){break I}e=g+9|0;Tc(k+96|0);break u}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Tc(k+96|0);break a}if(w[a+1|0]!=1|w[a|0]!=16){break C}e=v[k+2260>>2];d=zk(k+1160|0);a=v[b>>2];b=v[b+20>>2];g=x[d>>1];h=jb-16|0;jb=h;v[h+12>>2]=e>>>1;v[h+8>>2]=a;d=v[Jb(h+12|0,h+8|0)>>2];e=d;while(1){if(e){a=w[f|0]+g|0;g=a+w[f+1|0]|0;u[b>>1]=g<<8|a&255;b=b+2|0;f=f+2|0;e=e-1|0;continue}break}jb=h+16|0;e=d<<1;break u}if(w[a+1|0]!=1|w[a|0]>16){break C}d=v[c+8>>2];f=v[c>>2];e=0;v[23588]=0;d=W(156,f|0,d|0,8)|0;f=v[23588];v[23588]=0;if((f|0)==1){break f}if(!d){break u}v[23588]=0;d=S(157,c|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break f}v[k+2260>>2]=d;if(d>>>0<4){break u}v[23588]=0;U(190,k+72|0,c|0,d|0);f=v[23588];v[23588]=0;if((f|0)==1){break c}f=k+72|0;s=qr(k+96|0,f);Ab(f);f=v[s>>2];v[23588]=0;d=S(209,f|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break e}e=d+4|0;p=w[a|0];m=(p|0)!=16;g=0;h=0;while(1){if(y[b>>2]<=h>>>0){break w}L:{if(m){break L}v[23588]=0;r=Q(164,s|0,8)|0;a=v[23588];v[23588]=0;if((a|0)!=1){break L}a=V(30480)|0;break x}v[23588]=0;i=Q(164,s|0,1)|0;a=v[23588];v[23588]=0;if((a|0)==1){break y}v[23588]=0;f=Q(164,s|0,1)|0;a=v[23588];v[23588]=0;if((a|0)==1){break y}M:{N:{O:{if(!f){f=8;while(1){v[23588]=0;d=Q(164,s|0,1)|0;a=v[23588];v[23588]=0;if((a|0)==1){break M}if(d){break O}f=f+16|0;continue}}v[23588]=0;a=Q(164,s|0,3)|0;f=v[23588];v[23588]=0;if((f|0)!=1){break N}break y}v[23588]=0;d=Q(164,s|0,4)|0;a=v[23588];v[23588]=0;if((a|0)==1){break y}a=f+d|0}g=(g&255)+(((i?-1:0)^a)&255)|0;P:{if((p|0)!=16){t[v[b+20>>2]+h|0]=g;break P}u[v[b+20>>2]+(h<<1)>>1]=r&255|g<<8}h=h+1|0;continue}break}a=V(30480)|0;break x}if(w[a+1|0]!=1){break B}break A}if((g|0)!=7){break B}if(w[a+1|0]==1){break A}}e=w[a|0];break z}e=w[a|0];if(e>>>0>16){break z}e=0;if(y[k+2260>>2]<5){break u}d=x[b+34>>1];f=v[b+20>>2];a=v[b>>2];v[23588]=0;e=W(210,c|0,f|0,Hj(a,d)|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){break u}break f}Q:{if((g&254)!=16|(e&255)!=16){break Q}d=w[a+1|0];if((d-1&255)>>>0>1){break Q}K=k,M=B(v[b>>2],nq(d)),v[K+96>>2]=M;wc(k+96|0,v[k+2260>>2]);a=v[b+20>>2];e=v[k+96>>2];if((g|0)==16){b=e;while(1){if(!b){break u}K=a,M=x[cc(30512,w[f|0])>>1],u[K>>1]=M;a=a+2|0;f=f+1|0;b=b-1|0;continue}}b=e;while(1){if(!b){break u}K=a,M=x[cc(31024,w[f|0])>>1],u[K>>1]=M;a=a+2|0;f=f+1|0;b=b-1|0;continue}}d=(e&255)!=8;if(!(d|w[a+1|0]!=1)){R:{switch(g|0){case 0:a=v[b>>2];b=v[b+20>>2];d=jb-16|0;jb=d;v[d+12>>2]=v[k+2260>>2];v[d+8>>2]=a;a=v[Jb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){t[b|0]=w[f|0];b=b+1|0;f=f+1|0;e=e-1|0;continue}break};jb=d+16|0;e=a;break u;case 1:a=v[b>>2];b=v[b+20>>2];d=jb-16|0;jb=d;v[d+12>>2]=v[k+2260>>2];v[d+8>>2]=a;a=v[Jb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){t[b|0]=w[f|0]^128;b=b+1|0;f=f+1|0;e=e-1|0;continue}break};jb=d+16|0;e=a;break u;default:e=0;if((g|0)!=11){break u}break;case 2:break R}}e=v[k+2260>>2];d=Br(k- -64|0);a=v[b>>2];b=v[b+20>>2];g=w[d|0];d=jb-16|0;jb=d;v[d+12>>2]=e;v[d+8>>2]=a;a=v[Jb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){g=w[f|0]+g|0;t[b|0]=g;b=b+1|0;f=f+1|0;e=e-1|0;continue}break}jb=d+16|0;e=a;break u}if(!(w[a+1|0]!=3|d)){S:{switch(g|0){case 0:i=jb-16|0;jb=i;e=v[k+2260>>2];v[i+12>>2]=e;d=v[b>>2];v[i+8>>2]=d;a=i+8|0;g=v[Jb(a,i+12|0)>>2];v[i+8>>2]=d;v[i+4>>2]=e-g;e=v[Jb(a,i+4|0)>>2];h=v[b+20>>2];a=g;d=f;while(1){if(a){t[h|0]=w[d|0];h=h+2|0;d=d+1|0;a=a-1|0;continue}break};h=v[b+20>>2]+1|0;d=v[b>>2]+f|0;a=e;while(1){if(a){t[h|0]=w[d|0];h=h+2|0;d=d+1|0;a=a-1|0;continue}break};jb=i+16|0;e=e+g|0;break u;case 1:i=jb-16|0;jb=i;e=v[k+2260>>2];v[i+12>>2]=e;d=v[b>>2];v[i+8>>2]=d;a=i+8|0;g=v[Jb(a,i+12|0)>>2];v[i+8>>2]=d;v[i+4>>2]=e-g;e=v[Jb(a,i+4|0)>>2];h=v[b+20>>2];a=g;d=f;while(1){if(a){t[h|0]=w[d|0]^128;h=h+2|0;d=d+1|0;a=a-1|0;continue}break};h=v[b+20>>2]+1|0;d=v[b>>2]+f|0;a=e;while(1){if(a){t[h|0]=w[d|0]^128;h=h+2|0;d=d+1|0;a=a-1|0;continue}break};jb=i+16|0;e=e+g|0;break u;default:e=0;if((g|0)!=11){break u}break;case 2:break S}}h=v[k+2260>>2];e=w[Br(k+56|0)|0];p=jb-16|0;jb=p;v[p+12>>2]=h;g=v[b>>2];v[p+8>>2]=g;d=p+8|0;i=v[Jb(d,p+12|0)>>2];v[p+8>>2]=g;v[p+4>>2]=h-i;h=v[Jb(d,p+4|0)>>2];m=b;r=v[b+20>>2];d=e;b=i;g=f;while(1){if(b){d=w[g|0]+d|0;t[r|0]=d;r=r+2|0;g=g+1|0;b=b-1|0;continue}break}r=v[m+20>>2]+1|0;g=v[m>>2]+f|0;b=h;while(1){if(b){e=w[g|0]+e|0;t[r|0]=e;r=r+2|0;g=g+1|0;b=b-1|0;continue}break}jb=p+16|0;e=h+i|0;if(w[a+3|0]!=11){break u}a=v[m+20>>2];b=a+(v[m>>2]<<1)|0;while(1){if(a>>>0>=b>>>0){break u}t[a+1|0]=w[a+1|0]+w[a|0];a=a+2|0;continue}}d=e&255;if(!((d|0)!=8|w[a+1|0]!=2)){e=0;T:{switch(g|0){case 0:a=v[b>>2];b=v[b+20>>2];d=jb-16|0;jb=d;v[d+12>>2]=v[k+2260>>2]>>>1;v[d+8>>2]=a;a=v[Jb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){t[b|0]=w[f|0];t[b+1|0]=w[f+1|0];b=b+2|0;f=f+2|0;e=e-1|0;continue}break};jb=d+16|0;e=a<<1;break u;case 1:a=v[b>>2];b=v[b+20>>2];d=jb-16|0;jb=d;v[d+12>>2]=v[k+2260>>2]>>>1;v[d+8>>2]=a;a=v[Jb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){t[b|0]=w[f|0]^128;t[b+1|0]=w[f+1|0]^128;b=b+2|0;f=f+2|0;e=e-1|0;continue}break};jb=d+16|0;e=a<<1;break u;case 2:break T;default:break u}}e=v[k+2260>>2];a=Br(k+48|0);d=v[b>>2];g=v[b+20>>2];a=w[a|0];h=jb-16|0;jb=h;v[h+12>>2]=e>>>1;v[h+8>>2]=d;b=a;e=v[Jb(h+12|0,h+8|0)>>2];d=e;while(1){if(d){a=w[f|0]+a|0;t[g|0]=a;b=w[f+1|0]+b|0;t[g+1|0]=b;g=g+2|0;f=f+2|0;d=d-1|0;continue}break}jb=h+16|0;e=e<<1;break u}if(!(w[a+2|0]|((d|0)!=16|w[a+1|0]!=1))){U:{switch(g|0){case 0:a=v[b>>2];b=v[b+20>>2];d=jb-16|0;jb=d;v[d+12>>2]=v[k+2260>>2]>>>1;v[d+8>>2]=a;a=v[Jb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){u[b>>1]=w[f|0]|w[f+1|0]<<8;b=b+2|0;f=f+2|0;e=e-1|0;continue}break};jb=d+16|0;e=a<<1;break u;case 1:a=v[b>>2];b=v[b+20>>2];d=jb-16|0;jb=d;v[d+12>>2]=v[k+2260>>2]>>>1;v[d+8>>2]=a;a=v[Jb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){u[b>>1]=(w[f|0]|w[f+1|0]<<8)^32768;b=b+2|0;f=f+2|0;e=e-1|0;continue}break};jb=d+16|0;e=a<<1;break u;default:e=0;if((g|0)!=11){break u}break;case 2:break U}}e=v[k+2260>>2];d=zk(k+40|0);a=v[b>>2];b=v[b+20>>2];g=x[d>>1];d=jb-16|0;jb=d;v[d+12>>2]=e>>>1;v[d+8>>2]=a;a=v[Jb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){g=(w[f|0]+g|0)+(w[f+1|0]<<8)|0;u[b>>1]=g;b=b+2|0;f=f+2|0;e=e-1|0;continue}break}jb=d+16|0;e=a<<1;break u}d=e&255;if(!((d|0)!=16|w[a+1|0]!=1|w[a+2|0]!=1)){e=0;V:{switch(g|0){case 0:a=v[b>>2];b=v[b+20>>2];g=jb-16|0;jb=g;v[g+12>>2]=v[k+2260>>2]>>>1;v[g+8>>2]=a;d=v[Jb(g+12|0,g+8|0)>>2];e=d;while(1){if(e){a=w[f|0]|w[f+1|0]<<8;u[b>>1]=a<<8|a>>>8;b=b+2|0;f=f+2|0;e=e-1|0;continue}break};jb=g+16|0;e=d<<1;break u;case 1:a=v[b>>2];b=v[b+20>>2];g=jb-16|0;jb=g;v[g+12>>2]=v[k+2260>>2]>>>1;v[g+8>>2]=a;d=v[Jb(g+12|0,g+8|0)>>2];e=d;while(1){if(e){a=w[f|0]|w[f+1|0]<<8;u[b>>1]=(a<<8|a>>>8)^32768;b=b+2|0;f=f+2|0;e=e-1|0;continue}break};jb=g+16|0;e=d<<1;break u;case 2:break V;default:break u}}e=v[k+2260>>2];d=zk(k+32|0);a=v[b>>2];b=v[b+20>>2];g=x[d>>1];d=jb-16|0;jb=d;v[d+12>>2]=e>>>1;v[d+8>>2]=a;a=v[Jb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){g=(w[f+1|0]+g|0)+(w[f|0]<<8)|0;u[b>>1]=g;b=b+2|0;f=f+2|0;e=e-1|0;continue}break}jb=d+16|0;e=a<<1;break u}h=a;if(!(w[a+2|0]|((d|0)!=16|w[a+1|0]!=3))){W:{switch(g|0){case 0:m=jb-16|0;jb=m;d=v[k+2260>>2];v[m+12>>2]=d;i=v[b>>2]<<1;v[m+8>>2]=i;a=m+8|0;g=v[Jb(a,m+12|0)>>2];v[m+8>>2]=i;v[m+4>>2]=d-g;a=v[Jb(a,m+4|0)>>2];e=v[b+20>>2];h=g>>>1|0;g=h;d=f;while(1){if(g){u[e>>1]=w[d|0]|w[d+1|0]<<8;e=e+4|0;d=d+2|0;g=g-1|0;continue}break};e=f+i|0;d=v[b+20>>2]+2|0;a=a>>>1|0;g=a;while(1){if(g){u[d>>1]=w[e|0]|w[e+1|0]<<8;d=d+4|0;e=e+2|0;g=g-1|0;continue}break};jb=m+16|0;e=a+h<<1;break u;case 1:m=jb-16|0;jb=m;d=v[k+2260>>2];v[m+12>>2]=d;i=v[b>>2]<<1;v[m+8>>2]=i;a=m+8|0;g=v[Jb(a,m+12|0)>>2];v[m+8>>2]=i;v[m+4>>2]=d-g;a=v[Jb(a,m+4|0)>>2];e=v[b+20>>2];h=g>>>1|0;g=h;d=f;while(1){if(g){u[e>>1]=(w[d|0]|w[d+1|0]<<8)^32768;e=e+4|0;d=d+2|0;g=g-1|0;continue}break};e=f+i|0;d=v[b+20>>2]+2|0;a=a>>>1|0;g=a;while(1){if(g){u[d>>1]=(w[e|0]|w[e+1|0]<<8)^32768;d=d+4|0;e=e+2|0;g=g-1|0;continue}break};jb=m+16|0;e=a+h<<1;break u;default:e=0;if((g|0)!=11){break u}break;case 2:break W}}g=v[k+2260>>2];a=x[zk(k+24|0)>>1];s=jb-16|0;jb=s;v[s+12>>2]=g;p=v[b>>2]<<1;v[s+8>>2]=p;d=s+8|0;e=v[Jb(d,s+12|0)>>2];v[s+8>>2]=p;v[s+4>>2]=g-e;m=v[Jb(d,s+4|0)>>2];g=b;d=v[g+20>>2];b=a;i=e>>>1|0;r=i;e=f;while(1){if(r){b=(w[e|0]+b|0)+(w[e+1|0]<<8)|0;u[d>>1]=b;d=d+4|0;e=e+2|0;r=r-1|0;continue}break}e=f+p|0;d=v[g+20>>2]+2|0;b=m>>>1|0;r=b;while(1){if(r){a=(w[e|0]+a|0)+(w[e+1|0]<<8)|0;u[d>>1]=a;d=d+4|0;e=e+2|0;r=r-1|0;continue}break}jb=s+16|0;e=b+i<<1;if(w[h+3|0]!=11){break u}a=v[g+20>>2];b=a+(v[g>>2]<<2)|0;while(1){if(a>>>0>=b>>>0){break u}u[a+2>>1]=x[a+2>>1]+x[a>>1];a=a+4|0;continue}}a=e&255;if(!((a|0)!=16|w[h+1|0]!=3|w[h+2|0]!=1)){e=0;X:{switch(g|0){case 0:p=jb-16|0;jb=p;d=v[k+2260>>2];v[p+12>>2]=d;m=v[b>>2]<<1;v[p+8>>2]=m;a=p+8|0;g=v[Jb(a,p+12|0)>>2];v[p+8>>2]=m;v[p+4>>2]=d-g;i=v[Jb(a,p+4|0)>>2];e=v[b+20>>2];h=g>>>1|0;g=h;d=f;while(1){if(g){a=w[d|0]|w[d+1|0]<<8;u[e>>1]=a<<8|a>>>8;e=e+4|0;d=d+2|0;g=g-1|0;continue}break};e=f+m|0;d=v[b+20>>2]+2|0;b=i>>>1|0;g=b;while(1){if(g){a=w[e|0]|w[e+1|0]<<8;u[d>>1]=a<<8|a>>>8;d=d+4|0;e=e+2|0;g=g-1|0;continue}break};jb=p+16|0;e=b+h<<1;break u;case 1:p=jb-16|0;jb=p;d=v[k+2260>>2];v[p+12>>2]=d;m=v[b>>2]<<1;v[p+8>>2]=m;a=p+8|0;g=v[Jb(a,p+12|0)>>2];v[p+8>>2]=m;v[p+4>>2]=d-g;i=v[Jb(a,p+4|0)>>2];e=v[b+20>>2];h=g>>>1|0;g=h;d=f;while(1){if(g){a=w[d|0]|w[d+1|0]<<8;u[e>>1]=(a<<8|a>>>8)^32768;e=e+4|0;d=d+2|0;g=g-1|0;continue}break};e=f+m|0;d=v[b+20>>2]+2|0;b=i>>>1|0;g=b;while(1){if(g){a=w[e|0]|w[e+1|0]<<8;u[d>>1]=(a<<8|a>>>8)^32768;d=d+4|0;e=e+2|0;g=g-1|0;continue}break};jb=p+16|0;e=b+h<<1;break u;case 2:break X;default:break u}}e=v[k+2260>>2];a=x[zk(k+16|0)>>1];r=jb-16|0;jb=r;v[r+12>>2]=e;p=v[b>>2]<<1;v[r+8>>2]=p;d=r+8|0;g=v[Jb(d,r+12|0)>>2];v[r+8>>2]=p;v[r+4>>2]=e-g;m=v[Jb(d,r+4|0)>>2];e=b;h=v[b+20>>2];b=a;i=g>>>1|0;d=i;g=f;while(1){if(d){b=(w[g+1|0]+b|0)+(w[g|0]<<8)|0;u[h>>1]=b;h=h+4|0;g=g+2|0;d=d-1|0;continue}break}g=f+p|0;h=v[e+20>>2]+2|0;b=m>>>1|0;d=b;while(1){if(d){a=(w[g+1|0]+a|0)+(w[g|0]<<8)|0;u[h>>1]=a;h=h+4|0;g=g+2|0;d=d-1|0;continue}break}jb=r+16|0;e=b+i<<1;break u}if(!(w[h+2|0]|((a|0)!=16|w[h+1|0]!=2))){e=0;Y:{switch(g|0){case 0:a=v[b>>2];b=v[b+20>>2];d=jb-16|0;jb=d;v[d+12>>2]=v[k+2260>>2]>>>2;v[d+8>>2]=a;a=v[Jb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){u[b>>1]=w[f|0]|w[f+1|0]<<8;u[b+2>>1]=w[f+2|0]|w[f+3|0]<<8;b=b+4|0;f=f+4|0;e=e-1|0;continue}break};jb=d+16|0;e=a<<2;break u;case 1:a=v[b>>2];b=v[b+20>>2];d=jb-16|0;jb=d;v[d+12>>2]=v[k+2260>>2]>>>2;v[d+8>>2]=a;a=v[Jb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){u[b>>1]=(w[f|0]|w[f+1|0]<<8)^32768;u[b+2>>1]=(w[f+2|0]|w[f+3|0]<<8)^32768;b=b+4|0;f=f+4|0;e=e-1|0;continue}break};jb=d+16|0;e=a<<2;break u;case 2:break Y;default:break u}}e=v[k+2260>>2];a=zk(k+8|0);d=v[b>>2];g=v[b+20>>2];a=x[a>>1];h=jb-16|0;jb=h;v[h+12>>2]=e>>>2;v[h+8>>2]=d;b=a;e=v[Jb(h+12|0,h+8|0)>>2];d=e;while(1){if(d){a=(w[f|0]+a|0)+(w[f+1|0]<<8)|0;u[g>>1]=a;b=(w[f+2|0]+b|0)+(w[f+3|0]<<8)|0;u[g+2>>1]=b;g=g+4|0;f=f+4|0;d=d-1|0;continue}break}jb=h+16|0;e=e<<2;break u}a=e&255;if(!((a|0)!=16|w[h+1|0]!=2|w[h+2|0]!=1)){e=0;Z:{switch(g|0){case 0:a=v[b>>2];b=v[b+20>>2];g=jb-16|0;jb=g;v[g+12>>2]=v[k+2260>>2]>>>2;v[g+8>>2]=a;d=v[Jb(g+12|0,g+8|0)>>2];e=d;while(1){if(e){a=w[f|0]|w[f+1|0]<<8;u[b>>1]=a<<8|a>>>8;a=w[f+2|0]|w[f+3|0]<<8;u[b+2>>1]=a<<8|a>>>8;b=b+4|0;f=f+4|0;e=e-1|0;continue}break};jb=g+16|0;e=d<<2;break u;case 1:a=v[b>>2];b=v[b+20>>2];g=jb-16|0;jb=g;v[g+12>>2]=v[k+2260>>2]>>>2;v[g+8>>2]=a;d=v[Jb(g+12|0,g+8|0)>>2];e=d;while(1){if(e){a=w[f|0]|w[f+1|0]<<8;u[b>>1]=(a<<8|a>>>8)^32768;a=w[f+2|0]|w[f+3|0]<<8;u[b+2>>1]=(a<<8|a>>>8)^32768;b=b+4|0;f=f+4|0;e=e-1|0;continue}break};jb=g+16|0;e=d<<2;break u;case 2:break Z;default:break u}}e=v[k+2260>>2];a=zk(k);d=v[b>>2];g=v[b+20>>2];a=x[a>>1];h=jb-16|0;jb=h;v[h+12>>2]=e>>>2;v[h+8>>2]=d;b=a;e=v[Jb(h+12|0,h+8|0)>>2];d=e;while(1){if(d){a=(w[f+1|0]+a|0)+(w[f|0]<<8)|0;u[g>>1]=a;b=(w[f+3|0]+b|0)+(w[f+2|0]<<8)|0;u[g+2>>1]=b;g=g+4|0;f=f+4|0;d=d-1|0;continue}break}jb=h+16|0;e=e<<2;break u}if(!(g|w[h+1|0]!=1|(a|0)!=24)){a=v[b+20>>2];d=v[b>>2];b=v[k+2260>>2];if(!w[h+2|0]){g=jb-16|0;jb=g;v[g+12>>2]=(b>>>0)/3;v[g+8>>2]=d;b=v[Jb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){K=a,M=kd(w[f+1|0]<<16|w[f|0]<<8|w[f+2|0]<<24,16),u[K>>1]=M;a=a+2|0;f=f+3|0;e=e-1|0;continue}break}jb=g+16|0;e=B(b,3);break u}g=jb-16|0;jb=g;v[g+12>>2]=(b>>>0)/3;v[g+8>>2]=d;b=v[Jb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){K=a,M=kd(w[f+1|0]<<16|w[f+2|0]<<8|w[f|0]<<24,16),u[K>>1]=M;a=a+2|0;f=f+3|0;e=e-1|0;continue}break}jb=g+16|0;e=B(b,3);break u}a=e&255;if(!(g|w[h+1|0]!=2|(a|0)!=24)){a=v[b+20>>2];d=v[b>>2];b=v[k+2260>>2];if(!w[h+2|0]){g=jb-16|0;jb=g;v[g+12>>2]=(b>>>0)/6;v[g+8>>2]=d;b=v[Jb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){K=a,M=kd(w[f+1|0]<<16|w[f|0]<<8|w[f+2|0]<<24,16),u[K>>1]=M;K=a,M=kd(w[f+4|0]<<16|w[f+3|0]<<8|w[f+5|0]<<24,16),u[K+2>>1]=M;a=a+4|0;f=f+6|0;e=e-1|0;continue}break}jb=g+16|0;e=B(b,6);break u}g=jb-16|0;jb=g;v[g+12>>2]=(b>>>0)/6;v[g+8>>2]=d;b=v[Jb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){K=a,M=kd(w[f+1|0]<<16|w[f+2|0]<<8|w[f|0]<<24,16),u[K>>1]=M;K=a,M=kd(w[f+4|0]<<16|w[f+5|0]<<8|w[f+3|0]<<24,16),u[K+2>>1]=M;a=a+4|0;f=f+6|0;e=e-1|0;continue}break}jb=g+16|0;e=B(b,6);break u}if(!(g|w[h+1|0]!=1|(a|0)!=32)){a=v[b+20>>2];d=v[b>>2];b=v[k+2260>>2];if(!w[h+2|0]){g=jb-16|0;jb=g;v[g+12>>2]=b>>>2;v[g+8>>2]=d;b=v[Jb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){K=a,M=kd(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24),16),u[K>>1]=M;a=a+2|0;f=f+4|0;e=e-1|0;continue}break}jb=g+16|0;e=b<<2;break u}g=jb-16|0;jb=g;v[g+12>>2]=b>>>2;v[g+8>>2]=d;b=v[Jb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){d=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);K=a,M=kd(d<<24|d<<8&16711680|(d>>>8&65280|d>>>24),16),u[K>>1]=M;a=a+2|0;f=f+4|0;e=e-1|0;continue}break}jb=g+16|0;e=b<<2;break u}a=e&255;if(!(g|w[h+1|0]!=2|(a|0)!=32)){a=v[b+20>>2];d=v[b>>2];b=v[k+2260>>2];if(!w[h+2|0]){g=jb-16|0;jb=g;v[g+12>>2]=b>>>3;v[g+8>>2]=d;b=v[Jb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){K=a,M=kd(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24),16),u[K>>1]=M;K=a,M=kd(w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24),16),u[K+2>>1]=M;a=a+4|0;f=f+8|0;e=e-1|0;continue}break}jb=g+16|0;e=b<<3;break u}g=jb-16|0;jb=g;v[g+12>>2]=b>>>3;v[g+8>>2]=d;b=v[Jb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){d=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);K=a,M=kd(d<<24|d<<8&16711680|(d>>>8&65280|d>>>24),16),u[K>>1]=M;d=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);K=a,M=kd(d<<24|d<<8&16711680|(d>>>8&65280|d>>>24),16),u[K+2>>1]=M;a=a+4|0;f=f+8|0;e=e-1|0;continue}break}jb=g+16|0;e=b<<3;break u}if(!(g|w[h+1|0]!=1|(a|0)!=64)){a=v[b+20>>2];d=v[b>>2];b=v[k+2260>>2];if(!w[h+2|0]){g=jb-16|0;jb=g;v[g+12>>2]=b>>>3;v[g+8>>2]=d;b=v[Jb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){K=a,M=Xc(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24),w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24),48),u[K>>1]=M;a=a+2|0;f=f+8|0;e=e-1|0;continue}break}jb=g+16|0;e=b<<3;break u}i=jb-16|0;jb=i;v[i+12>>2]=b>>>3;v[i+8>>2]=d;d=v[Jb(i+12|0,i+8|0)>>2];e=d;while(1){if(e){h=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);b=h<<24|h<<8&16711680;m=h>>>8|0;g=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);h=h>>>24|0;b=b|((m|g<<24)&65280|(h|g<<8)&255);K=a,M=Xc((m|(g&255)<<24)&-16777216|(h|(g&16777215)<<8)&16711680|(g>>>8&65280|g>>>24),b,48),u[K>>1]=M;a=a+2|0;f=f+8|0;e=e-1|0;continue}break}jb=i+16|0;e=d<<3;break u}a=e&255;if(!(g|w[h+1|0]!=2|(a|0)!=64)){a=v[b+20>>2];d=v[b>>2];b=v[k+2260>>2];if(!w[h+2|0]){g=jb-16|0;jb=g;v[g+12>>2]=b>>>4;v[g+8>>2]=d;b=v[Jb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){K=a,M=Xc(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24),w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24),48),u[K>>1]=M;K=a,M=Xc(w[f+8|0]|w[f+9|0]<<8|(w[f+10|0]<<16|w[f+11|0]<<24),w[f+12|0]|w[f+13|0]<<8|(w[f+14|0]<<16|w[f+15|0]<<24),48),u[K+2>>1]=M;a=a+4|0;f=f+16|0;e=e-1|0;continue}break}jb=g+16|0;e=b<<4;break u}i=jb-16|0;jb=i;v[i+12>>2]=b>>>4;v[i+8>>2]=d;d=v[Jb(i+12|0,i+8|0)>>2];e=d;while(1){if(e){h=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);b=h<<24|h<<8&16711680;m=h>>>8|0;g=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);h=h>>>24|0;b=b|((m|g<<24)&65280|(h|g<<8)&255);K=a,M=Xc((m|(g&255)<<24)&-16777216|(h|(g&16777215)<<8)&16711680|(g>>>8&65280|g>>>24),b,48),u[K>>1]=M;h=w[f+8|0]|w[f+9|0]<<8|(w[f+10|0]<<16|w[f+11|0]<<24);g=w[f+12|0]|w[f+13|0]<<8|(w[f+14|0]<<16|w[f+15|0]<<24);b=h<<24|h<<8&16711680|((g<<24|h>>>8)&65280|(g<<8|h>>>24)&255);K=a,M=Xc(((g&255)<<24|h>>>8)&-16777216|((g&16777215)<<8|h>>>24)&16711680|(g>>>8&65280|g>>>24),b,48),u[K+2>>1]=M;a=a+4|0;f=f+16|0;e=e-1|0;continue}break}jb=i+16|0;e=d<<4;break u}if(!(w[h+1|0]!=1|(g|0)!=3|(a|0)!=32)){a=v[b+20>>2];d=v[b>>2];b=v[k+2260>>2];if(!w[h+2|0]){g=jb-16|0;jb=g;v[g+12>>2]=b>>>2;v[g+8>>2]=d;b=v[Jb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){j=Jf((l(2,w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24)),q()));j=Vh(C(Xd(ng(j)?j>=C(0)?C(1):C(-1):j,C(-1))*C(32768)));_:{if(C(D(j))<C(2147483648)){d=~~j;break _}d=-2147483648}K=a,M=dd(d),u[K>>1]=M;a=a+2|0;f=f+4|0;e=e-1|0;continue}break}jb=g+16|0;e=b<<2;break u}g=jb-16|0;jb=g;v[g+12>>2]=b>>>2;v[g+8>>2]=d;b=v[Jb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){d=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);j=Jf((l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),q()));j=Vh(C(Xd(ng(j)?j>=C(0)?C(1):C(-1):j,C(-1))*C(32768)));$:{if(C(D(j))<C(2147483648)){d=~~j;break $}d=-2147483648}K=a,M=dd(d),u[K>>1]=M;a=a+2|0;f=f+4|0;e=e-1|0;continue}break}jb=g+16|0;e=b<<2;break u}a=e&255;if(!(w[h+1|0]!=2|(g|0)!=3|(a|0)!=32)){a=v[b+20>>2];d=v[b>>2];b=v[k+2260>>2];if(!w[h+2|0]){g=jb-16|0;jb=g;v[g+12>>2]=b>>>3;v[g+8>>2]=d;b=v[Jb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){j=Jf((l(2,w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24)),q()));j=Vh(C(Xd(ng(j)?j>=C(0)?C(1):C(-1):j,C(-1))*C(32768)));aa:{if(C(D(j))<C(2147483648)){d=~~j;break aa}d=-2147483648}K=a,M=dd(d),u[K>>1]=M;j=Jf((l(2,w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24)),q()));j=Vh(C(Xd(ng(j)?j>=C(0)?C(1):C(-1):j,C(-1))*C(32768)));ba:{if(C(D(j))<C(2147483648)){d=~~j;break ba}d=-2147483648}K=a,M=dd(d),u[K+2>>1]=M;a=a+4|0;f=f+8|0;e=e-1|0;continue}break}jb=g+16|0;e=b<<3;break u}g=jb-16|0;jb=g;v[g+12>>2]=b>>>3;v[g+8>>2]=d;b=v[Jb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){d=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);j=Jf((l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),q()));j=Vh(C(Xd(ng(j)?j>=C(0)?C(1):C(-1):j,C(-1))*C(32768)));ca:{if(C(D(j))<C(2147483648)){d=~~j;break ca}d=-2147483648}K=a,M=dd(d),u[K>>1]=M;d=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);j=Jf((l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),q()));j=Vh(C(Xd(ng(j)?j>=C(0)?C(1):C(-1):j,C(-1))*C(32768)));da:{if(C(D(j))<C(2147483648)){d=~~j;break da}d=-2147483648}K=a,M=dd(d),u[K+2>>1]=M;a=a+4|0;f=f+8|0;e=e-1|0;continue}break}jb=g+16|0;e=b<<3;break u}if(!(w[h+1|0]!=1|(g|0)!=3|(a|0)!=64)){a=v[b+20>>2];d=v[b>>2];b=v[k+2260>>2];if(!w[h+2|0]){g=jb-32|0;jb=g;v[g+24>>2]=b>>>3;v[g+16>>2]=d;d=v[Jb(g+24|0,g+16|0)>>2];e=d;while(1){if(e){b=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);l(0,w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24));l(1,b|0);o=mg(+n());K=g,N=mf(o)?o>=0?1:-1:o,A[K+24>>3]=N;v[g+16>>2]=0;v[g+20>>2]=-1074790400;v[g+8>>2]=0;v[g+12>>2]=1072693248;o=we(A[Gg(g+24|0,g+16|0,g+8|0)>>3]*32768);ea:{if(D(o)<2147483648){b=~~o;break ea}b=-2147483648}K=a,M=dd(b),u[K>>1]=M;a=a+2|0;f=f+8|0;e=e-1|0;continue}break}jb=g+32|0;e=d<<3;break u}m=jb-32|0;jb=m;v[m+24>>2]=b>>>3;v[m+16>>2]=d;h=v[Jb(m+24|0,m+16|0)>>2];e=h;while(1){if(e){b=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);g=b<<24|b<<8&16711680;r=b>>>8|0;i=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);d=r|i<<24;b=b>>>24|0;l(0,(r|(i&255)<<24)&-16777216|(b|(i&16777215)<<8)&16711680|(i>>>8&65280|i>>>24));l(1,g|(d&65280|(b|i<<8)&255));o=mg(+n());K=m,N=mf(o)?o>=0?1:-1:o,A[K+24>>3]=N;v[m+16>>2]=0;v[m+20>>2]=-1074790400;v[m+8>>2]=0;v[m+12>>2]=1072693248;o=we(A[Gg(m+24|0,m+16|0,m+8|0)>>3]*32768);fa:{if(D(o)<2147483648){b=~~o;break fa}b=-2147483648}K=a,M=dd(b),u[K>>1]=M;a=a+2|0;f=f+8|0;e=e-1|0;continue}break}jb=m+32|0;e=h<<3;break u}a=e&255;if(!(w[h+1|0]!=2|(g|0)!=3|(a|0)!=64)){a=v[b+20>>2];d=v[b>>2];b=v[k+2260>>2];if(!w[h+2|0]){g=jb-32|0;jb=g;v[g+24>>2]=b>>>4;v[g+16>>2]=d;d=v[Jb(g+24|0,g+16|0)>>2];e=d;while(1){if(e){b=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);l(0,w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24));l(1,b|0);o=mg(+n());K=g,N=mf(o)?o>=0?1:-1:o,A[K+24>>3]=N;v[g+16>>2]=0;v[g+20>>2]=-1074790400;v[g+8>>2]=0;v[g+12>>2]=1072693248;o=we(A[Gg(g+24|0,g+16|0,g+8|0)>>3]*32768);ga:{if(D(o)<2147483648){b=~~o;break ga}b=-2147483648}K=a,M=dd(b),u[K>>1]=M;b=w[f+12|0]|w[f+13|0]<<8|(w[f+14|0]<<16|w[f+15|0]<<24);l(0,w[f+8|0]|w[f+9|0]<<8|(w[f+10|0]<<16|w[f+11|0]<<24));l(1,b|0);o=mg(+n());K=g,N=mf(o)?o>=0?1:-1:o,A[K+24>>3]=N;v[g+16>>2]=0;v[g+20>>2]=-1074790400;v[g+8>>2]=0;v[g+12>>2]=1072693248;o=we(A[Gg(g+24|0,g+16|0,g+8|0)>>3]*32768);ha:{if(D(o)<2147483648){b=~~o;break ha}b=-2147483648}K=a,M=dd(b),u[K+2>>1]=M;a=a+4|0;f=f+16|0;e=e-1|0;continue}break}jb=g+32|0;e=d<<4;break u}m=jb-32|0;jb=m;v[m+24>>2]=b>>>4;v[m+16>>2]=d;h=v[Jb(m+24|0,m+16|0)>>2];e=h;while(1){if(e){b=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);d=b<<24|b<<8&16711680;i=b>>>8|0;g=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);b=b>>>24|0;d=d|((i|g<<24)&65280|(b|g<<8)&255);l(0,(i|(g&255)<<24)&-16777216|(b|(g&16777215)<<8)&16711680|(g>>>8&65280|g>>>24));l(1,d|0);o=mg(+n());K=m,N=mf(o)?o>=0?1:-1:o,A[K+24>>3]=N;v[m+16>>2]=0;v[m+20>>2]=-1074790400;v[m+8>>2]=0;v[m+12>>2]=1072693248;o=we(A[Gg(m+24|0,m+16|0,m+8|0)>>3]*32768);ia:{if(D(o)<2147483648){b=~~o;break ia}b=-2147483648}K=a,M=dd(b),u[K>>1]=M;b=w[f+8|0]|w[f+9|0]<<8|(w[f+10|0]<<16|w[f+11|0]<<24);g=b<<24|b<<8&16711680;r=b>>>8|0;i=w[f+12|0]|w[f+13|0]<<8|(w[f+14|0]<<16|w[f+15|0]<<24);d=r|i<<24;b=b>>>24|0;l(0,(r|(i&255)<<24)&-16777216|(b|(i&16777215)<<8)&16711680|(i>>>8&65280|i>>>24));l(1,g|(d&65280|(b|i<<8)&255));o=mg(+n());K=m,N=mf(o)?o>=0?1:-1:o,A[K+24>>3]=N;v[m+16>>2]=0;v[m+20>>2]=-1074790400;v[m+8>>2]=0;v[m+12>>2]=1072693248;o=we(A[Gg(m+24|0,m+16|0,m+8|0)>>3]*32768);ja:{if(D(o)<2147483648){b=~~o;break ja}b=-2147483648}K=a,M=dd(b),u[K+2>>1]=M;a=a+4|0;f=f+16|0;e=e-1|0;continue}break}jb=m+32|0;e=h<<4;break u}if(!((g|0)!=15|(w[h+1|0]-1&255)>>>0>1|(a|0)!=24)){v[k+96>>2]=-2147483648;a=v[k+2260>>2];ka:{if(!w[h+2|0]){r=k+96|0;e=0;s=jb-16|0;jb=s;K=s,M=B(v[b>>2],Kd(x[b+34>>1])),v[K+12>>2]=M;wc(s+12|0,(a>>>0)/3|0);a=f;g=v[s+12>>2];h=g;while(1){if(h){i=w[a+1|0]<<16|w[a|0]<<8|w[a+2|0]<<24;la:{ma:{na:{if((i|0)>=0){d=i;break na}d=-2147483648;if((i|0)==-2147483648){break ma}d=0-i|0}if(d>>>0<=e>>>0){break la}}e=d}h=h-1|0;a=a+3|0;continue}else{oa:{if(!e){break oa}p=e-1|0;m=e>>>1|0;h=v[b+20>>2];a=g;while(1){if(!a){break oa}d=w[f+1|0]<<16|w[f|0]<<8|w[f+2|0]<<24;i=d>>31<<31|d>>>1;d=m|d<<31;pa:{if((i|0)>0|(i|0)>=0){d=Oka(d,i,e,0);i=mb;break pa}i=Oka(p-d|0,0-((d>>>0>p>>>0)+i|0)|0,e,0);d=0-i|0;i=0-(mb+((i|0)!=0)|0)|0}K=h,M=kd(Hc(d,i),16),u[K>>1]=M;a=a-1|0;f=f+3|0;h=h+2|0;continue}}}break}if(r){v[r>>2]=e}jb=s+16|0;e=B(g,3);break ka}r=k+96|0;e=0;s=jb-16|0;jb=s;K=s,M=B(v[b>>2],Kd(x[b+34>>1])),v[K+12>>2]=M;wc(s+12|0,(a>>>0)/3|0);a=f;g=v[s+12>>2];h=g;while(1){if(h){i=w[a+1|0]<<16|w[a+2|0]<<8|w[a|0]<<24;qa:{ra:{sa:{if((i|0)>=0){d=i;break sa}d=-2147483648;if((i|0)==-2147483648){break ra}d=0-i|0}if(d>>>0<=e>>>0){break qa}}e=d}h=h-1|0;a=a+3|0;continue}else{ta:{if(!e){break ta}p=e-1|0;m=e>>>1|0;h=v[b+20>>2];a=g;while(1){if(!a){break ta}d=w[f+1|0]<<16|w[f+2|0]<<8|w[f|0]<<24;i=d>>31<<31|d>>>1;d=m|d<<31;ua:{if((i|0)>0|(i|0)>=0){d=Oka(d,i,e,0);i=mb;break ua}i=Oka(p-d|0,0-((d>>>0>p>>>0)+i|0)|0,e,0);d=0-i|0;i=0-(mb+((i|0)!=0)|0)|0}K=h,M=kd(Hc(d,i),16),u[K>>1]=M;a=a-1|0;f=f+3|0;h=h+2|0;continue}}}break}if(r){v[r>>2]=e}jb=s+16|0;e=B(g,3)}if(!e){break u}a=v[k+96>>2];if((a|0)==-2147483648){break u}f=Lka(x[b+32>>1],0,a,0)+1073741824|0;a=mb;a=f>>>0<1073741824?a+1|0:a;K=b,M=Cd(Dc((a&2147483647)<<1|f>>>31,a>>>31|0),1,64),u[K+32>>1]=M;u[b+34>>1]=x[b+34>>1]|8192;break u}va:{a=e&255;if((a|0)!=32){break va}if(!((g|0)!=15|(w[h+1|0]-1&255)>>>0>1)){v[k+96>>2]=-2147483648;d=v[k+2260>>2];wa:{if(!w[h+2|0]){r=k+96|0;a=0;s=jb-16|0;jb=s;K=s,M=B(v[b>>2],Kd(x[b+34>>1])),v[K+12>>2]=M;wc(s+12|0,d>>>2|0);e=f;h=f;g=v[s+12>>2];f=g;while(1){if(f){i=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);xa:{ya:{za:{if((i|0)>=0){d=i;break za}d=-2147483648;if((i|0)==-2147483648){break ya}d=0-i|0}if(d>>>0<=a>>>0){break xa}}a=d}f=f-1|0;h=h+4|0;continue}else{Aa:{if(!a){break Aa}p=a-1|0;m=a>>>1|0;h=v[b+20>>2];f=g;while(1){if(!f){break Aa}d=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);i=d>>31<<31|d>>>1;d=m|d<<31;Ba:{if((i|0)>0|(i|0)>=0){d=Oka(d,i,a,0);i=mb;break Ba}i=Oka(p-d|0,0-((d>>>0>p>>>0)+i|0)|0,a,0);d=0-i|0;i=0-(mb+((i|0)!=0)|0)|0}K=h,M=kd(Hc(d,i),16),u[K>>1]=M;f=f-1|0;e=e+4|0;h=h+2|0;continue}}}break}if(r){v[r>>2]=a}jb=s+16|0;e=g<<2;break wa}r=k+96|0;a=0;s=jb-16|0;jb=s;K=s,M=B(v[b>>2],Kd(x[b+34>>1])),v[K+12>>2]=M;wc(s+12|0,d>>>2|0);e=f;h=f;g=v[s+12>>2];f=g;while(1){if(f){d=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);i=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24);Ca:{Da:{Ea:{if((i|0)>=0){d=i;break Ea}d=-2147483648;if((i|0)==-2147483648){break Da}d=0-i|0}if(a>>>0>=d>>>0){break Ca}}a=d}f=f-1|0;h=h+4|0;continue}else{Fa:{if(!a){break Fa}p=a-1|0;m=a>>>1|0;h=v[b+20>>2];f=g;while(1){if(!f){break Fa}d=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);d=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24);i=d>>31<<31|d>>>1;d=m|d<<31;Ga:{if((i|0)>0|(i|0)>=0){d=Oka(d,i,a,0);i=mb;break Ga}i=Oka(p-d|0,0-((d>>>0>p>>>0)+i|0)|0,a,0);d=0-i|0;i=0-(mb+((i|0)!=0)|0)|0}K=h,M=kd(Hc(d,i),16),u[K>>1]=M;f=f-1|0;e=e+4|0;h=h+2|0;continue}}}break}if(r){v[r>>2]=a}jb=s+16|0;e=g<<2}if(!e){break u}a=v[k+96>>2];if((a|0)==-2147483648){break u}f=Lka(x[b+32>>1],0,a,0)+1073741824|0;a=mb;a=f>>>0<1073741824?a+1|0:a;K=b,M=Cd(Dc((a&2147483647)<<1|f>>>31,a>>>31|0),1,64),u[K+32>>1]=M;u[b+34>>1]=x[b+34>>1]|8192;break u}if((g|0)!=14|(w[h+1|0]-1&255)>>>0>1){break va}v[k+96>>2]=1065353216;a=v[k+2260>>2];Ha:{if(!w[h+2|0]){e=k+96|0;h=jb-16|0;jb=h;K=h,M=B(v[b>>2],Kd(x[b+34>>1])),v[K+12>>2]=M;wc(h+12|0,a>>>2|0);g=f;d=v[h+12>>2];a=d;while(1){if(a){j=Jf((l(2,w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24)),q()));j=C(D(ng(j)?j>=C(0)?C(1):C(-1):j));E=j>E?j:E;a=a-1|0;g=g+4|0;continue}else{Ia:{a=E==C(0);if(a){break Ia}H=a?C(1):C(C(1)/E);g=v[b+20>>2];a=d;while(1){if(!a){break Ia}j=Jf((l(2,w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24)),q()));j=Vh(C(Xd(C(H*(ng(j)?j>=C(0)?C(1):C(-1):j)),C(-1))*C(32768)));Ja:{if(C(D(j))<C(2147483648)){i=~~j;break Ja}i=-2147483648}K=g,M=dd(i),u[K>>1]=M;a=a-1|0;f=f+4|0;g=g+2|0;continue}}if(e){z[e>>2]=E}jb=h+16|0;e=d<<2}break}break Ha}e=k+96|0;i=jb-16|0;jb=i;K=i,M=B(v[b>>2],Kd(x[b+34>>1])),v[K+12>>2]=M;wc(i+12|0,a>>>2|0);g=f;d=v[i+12>>2];a=d;while(1){if(a){h=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);j=Jf((l(2,h<<24|h<<8&16711680|(h>>>8&65280|h>>>24)),q()));j=C(D(ng(j)?j>=C(0)?C(1):C(-1):j));E=j>E?j:E;a=a-1|0;g=g+4|0;continue}else{Ka:{a=E==C(0);if(a){break Ka}H=a?C(1):C(C(1)/E);g=v[b+20>>2];a=d;while(1){if(!a){break Ka}h=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);j=Jf((l(2,h<<24|h<<8&16711680|(h>>>8&65280|h>>>24)),q()));j=Vh(C(Xd(C(H*(ng(j)?j>=C(0)?C(1):C(-1):j)),C(-1))*C(32768)));La:{if(C(D(j))<C(2147483648)){h=~~j;break La}h=-2147483648}K=g,M=dd(h),u[K>>1]=M;a=a-1|0;f=f+4|0;g=g+2|0;continue}}if(e){z[e>>2]=E}jb=i+16|0;e=d<<2}break}}if(!e){break u}j=z[k+96>>2];if(j==C(1)){break u}j=Vh(az(C(j*C(x[b+32>>1])),C(1),C(64)));a=65535;Ma:{if(j>=C(65535)){break Ma}a=0;if(j<=C(0)){break Ma}a=~~j>>>0;if(j<C(4294967296)&j>=C(0)){break Ma}a=0}u[b+32>>1]=a;u[b+34>>1]=x[b+34>>1]|8192;break u}if(!((g|0)!=14|(w[h+1|0]-1&255)>>>0>1|(a|0)!=64)){v[k+96>>2]=0;v[k+100>>2]=1072693248;a=v[k+2260>>2];Na:{if(!w[h+2|0]){h=k+96|0;i=jb-32|0;jb=i;K=i,M=B(v[b>>2],Kd(x[b+34>>1])),v[K+4>>2]=M;wc(i+4|0,a>>>3|0);d=f;e=v[i+4>>2];a=e;while(1){if(a){g=w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24);l(0,w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));l(1,g|0);o=mg(+n());o=D(mf(o)?o>=0?1:-1:o);F=o>F?o:F;a=a-1|0;d=d+8|0;continue}else{Oa:{a=F==0;if(a){break Oa}I=a?1:1/F;d=v[b+20>>2];a=e;while(1){if(!a){break Oa}g=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);l(0,w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24));l(1,g|0);o=mg(+n());K=i,N=I*(mf(o)?o>=0?1:-1:o),A[K+24>>3]=N;v[i+16>>2]=0;v[i+20>>2]=-1074790400;v[i+8>>2]=0;v[i+12>>2]=1072693248;o=we(A[Gg(i+24|0,i+16|0,i+8|0)>>3]*32768);Pa:{if(D(o)<2147483648){g=~~o;break Pa}g=-2147483648}K=d,M=dd(g),u[K>>1]=M;a=a-1|0;f=f+8|0;d=d+2|0;continue}}if(h){A[h>>3]=F}jb=i+32|0;e=e<<3}break}break Na}i=k+96|0;p=jb-32|0;jb=p;K=p,M=B(v[b>>2],Kd(x[b+34>>1])),v[K+4>>2]=M;wc(p+4|0,a>>>3|0);d=f;g=v[p+4>>2];a=g;while(1){if(a){e=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);h=e<<24|e<<8&16711680;r=e>>>8|0;m=w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24);e=e>>>24|0;h=h|((r|m<<24)&65280|(e|m<<8)&255);l(0,(r|(m&255)<<24)&-16777216|(e|(m&16777215)<<8)&16711680|(m>>>8&65280|m>>>24));l(1,h|0);o=mg(+n());o=D(mf(o)?o>=0?1:-1:o);F=o>F?o:F;a=a-1|0;d=d+8|0;continue}else{Qa:{a=F==0;if(a){break Qa}I=a?1:1/F;d=v[b+20>>2];a=g;while(1){if(!a){break Qa}m=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);e=m<<24|m<<8&16711680;r=m>>>8|0;h=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);m=m>>>24|0;e=e|((r|h<<24)&65280|(m|h<<8)&255);l(0,(r|(h&255)<<24)&-16777216|(m|(h&16777215)<<8)&16711680|(h>>>8&65280|h>>>24));l(1,e|0);o=mg(+n());K=p,N=I*(mf(o)?o>=0?1:-1:o),A[K+24>>3]=N;v[p+16>>2]=0;v[p+20>>2]=-1074790400;v[p+8>>2]=0;v[p+12>>2]=1072693248;o=we(A[Gg(p+24|0,p+16|0,p+8|0)>>3]*32768);Ra:{if(D(o)<2147483648){e=~~o;break Ra}e=-2147483648}K=d,M=dd(e),u[K>>1]=M;a=a-1|0;f=f+8|0;d=d+2|0;continue}}if(i){A[i>>3]=F}jb=p+32|0;e=g<<3}break}}if(!e){break u}o=A[k+96>>3];if(o==1){break u}K=b,M=aU(su(o*+x[b+32>>1],1,64)),u[K+32>>1]=M;u[b+34>>1]=x[b+34>>1]|8192;break u}Sa:{Ta:{Ua:{Va:{a=(e&255)!=32;Wa:{if(!(a|(w[h+1|0]!=1|(g|0)!=12))){E=C(30517578125e-15);e=v[k+2260>>2];if(!w[h+2|0]){break Wa}break Sa}if(!(w[h+1|0]!=2|(g|0)!=12|a)){E=C(30517578125e-15);e=v[k+2260>>2];if(!w[h+2|0]){break Ua}break Ta}a=(e&255)!=32;if(a|(w[h+1|0]!=1|(g|0)!=13)){break Va}E=C(1.1920928955078125e-7);e=v[k+2260>>2];if(w[h+2|0]){break Sa}}a=v[b>>2];b=v[b+20>>2];d=jb-16|0;jb=d;v[d+12>>2]=e>>>2;v[d+8>>2]=a;a=v[Jb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){j=Jf((l(2,w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24)),q()));j=Vh(C(Xd(C((ng(j)?j>=C(0)?C(1):C(-1):j)*E),C(-1))*C(32768)));Xa:{if(C(D(j))<C(2147483648)){g=~~j;break Xa}g=-2147483648}K=b,M=dd(g),u[K>>1]=M;b=b+2|0;f=f+4|0;e=e-1|0;continue}break}jb=d+16|0;e=a<<2;break u}e=0;if(w[h+1|0]!=2|(g|0)!=13|a){break u}E=C(1.1920928955078125e-7);e=v[k+2260>>2];if(w[h+2|0]){break Ta}}a=v[b>>2];b=v[b+20>>2];d=jb-16|0;jb=d;v[d+12>>2]=e>>>3;v[d+8>>2]=a;a=v[Jb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){j=Jf((l(2,w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24)),q()));j=Vh(C(Xd(C((ng(j)?j>=C(0)?C(1):C(-1):j)*E),C(-1))*C(32768)));Ya:{if(C(D(j))<C(2147483648)){g=~~j;break Ya}g=-2147483648}K=b,M=dd(g),u[K>>1]=M;j=Jf((l(2,w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24)),q()));j=Vh(C(Xd(C((ng(j)?j>=C(0)?C(1):C(-1):j)*E),C(-1))*C(32768)));Za:{if(C(D(j))<C(2147483648)){g=~~j;break Za}g=-2147483648}K=b,M=dd(g),u[K+2>>1]=M;b=b+4|0;f=f+8|0;e=e-1|0;continue}break}jb=d+16|0;e=a<<3;break u}a=v[b>>2];b=v[b+20>>2];g=jb-16|0;jb=g;v[g+12>>2]=e>>>3;v[g+8>>2]=a;a=v[Jb(g+12|0,g+8|0)>>2];e=a;while(1){if(e){d=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);j=Jf((l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),q()));j=Vh(C(Xd(C((ng(j)?j>=C(0)?C(1):C(-1):j)*E),C(-1))*C(32768)));_a:{if(C(D(j))<C(2147483648)){d=~~j;break _a}d=-2147483648}K=b,M=dd(d),u[K>>1]=M;d=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);j=Jf((l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),q()));j=Vh(C(Xd(C((ng(j)?j>=C(0)?C(1):C(-1):j)*E),C(-1))*C(32768)));$a:{if(C(D(j))<C(2147483648)){d=~~j;break $a}d=-2147483648}K=b,M=dd(d),u[K+2>>1]=M;b=b+4|0;f=f+8|0;e=e-1|0;continue}break}jb=g+16|0;e=a<<3;break u}a=v[b>>2];b=v[b+20>>2];g=jb-16|0;jb=g;v[g+12>>2]=e>>>2;v[g+8>>2]=a;a=v[Jb(g+12|0,g+8|0)>>2];e=a;while(1){if(e){d=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);j=Jf((l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),q()));j=Vh(C(Xd(C((ng(j)?j>=C(0)?C(1):C(-1):j)*E),C(-1))*C(32768)));ab:{if(C(D(j))<C(2147483648)){d=~~j;break ab}d=-2147483648}K=b,M=dd(d),u[K>>1]=M;b=b+2|0;f=f+4|0;e=e-1|0;continue}break}jb=g+16|0;e=a<<2;break u}a=V(30480)|0}if((O()|0)!=(da(30480)|0)){break d}_(a|0)|0;v[23588]=0;Z(18);a=v[23588];v[23588]=0;if((a|0)==1){break v}}Ab(s);break u}a=P()|0;O()|0;break d}v[23588]=0;Q(155,c|0,e+J|0)|0;a=v[23588];v[23588]=0;if((a|0)==1){break f}}Tc(G)}jb=k+2288|0;return e|0}a=P()|0;O()|0;break a}a=P()|0;O()|0}Ab(s);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}Tc(G);T(a|0);L()}function Jia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;d=jb-640|0;jb=d;yc(b);f=jb-16|0;jb=f;h=d+448|0;Lq(f+8|0,h);j=v[f+12>>2];g=b;mc(f,v[b>>2],v[b+8>>2],v[f+8>>2],v[f+12>>2]);b=v[f+4>>2];if((b|0)==(j|0)){Zb(g,v[f+12>>2])}jb=f+16|0;b=(b|0)==(j|0);if(!b){yT(h)}a:{b:{c:{if(!b){break c}if(!AT(d+448|0)){break c}if(!Pb(v[g>>2],v[g+8>>2],Dc(zT(d+448|0),mb))){break c}if(!c){e=1;break c}Ad(a,32);t[d+447|0]=0;j=Lb(d+432|0);d:{e:{f:{g:{h:{i:{j:{k:{if(!Rb(d+448|0,16245,4)){v[23588]=0;R(406,a|0,16777216);b=v[23588];v[23588]=0;if((b|0)==1){break b}b=v[g>>2];v[23588]=0;b=S(160,b|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break b}v[23588]=0;Q(155,g|0,b-4|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break b}v[23588]=0;A=S(157,g|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break k}break b}l:{m:{n:{o:{p:{q:{if((x[d+488>>1]-2185&65535)>>>0>1910){break q}b=v[g>>2];v[23588]=0;b=S(160,b|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break b}v[23588]=0;Q(155,g|0,b-4|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break b}v[23588]=0;A=S(157,g|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break b}if(A>>>0<256){break q}b=v[g>>2];v[23588]=0;b=S(160,b|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break b}if(b>>>0<=A>>>0){break q}v[23588]=0;b=Q(155,g|0,A|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break b}if(!b){break q}v[23588]=0;b=S(407,g|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break b}if(!b){break q}v[23588]=0;R(406,a|0,16777216);b=v[23588];v[23588]=0;if((b|0)==1){break b}b=x[d+488>>1];if(b>>>0>=4096){v[23588]=0;c=Q(1,d+168|0,16460)|0;b=v[23588];v[23588]=0;if((b|0)==1){break j}a=v[a+1298464>>2];v[23588]=0;U(376,a|0,1,c|0);a=v[23588];v[23588]=0;if((a|0)!=1){zb(c);e=0;break d}b=P()|0;O()|0;zb(c);break a}if(b>>>0<2194){break q}v[23588]=0;e=Q(1,d+416|0,15984)|0;b=v[23588];v[23588]=0;if((b|0)==1){break p}b=v[a+1298464>>2];v[23588]=0;U(376,b|0,4,e|0);b=v[23588];v[23588]=0;if((b|0)==1){break o}zb(e)}if(v[a+480180>>2]!=32){break k}b=x[d+488>>1];if((b&61440)!=20480){break l}b=b&4095;e=b<<16;if(Rb(d+508|0,13568,4)){break n}t[d+447|0]=1;break m}b=P()|0;O()|0;break a}b=P()|0;O()|0;zb(e);break a}if(b>>>0<297){break m}e=x[d+508>>1]|e}v[a+1074308>>2]=e;break k}e=x[d+490>>1];if(!((e|0)!=2184&(b|0)!=2184)){t[d+447|0]=1;v[a+1074308>>2]=18284544;break k}r:{switch(b-532|0){default:if(v[d+508>>2]|((b|0)!=768|(e|0)!=768)|(x[d+480>>1]!=256|w[d+500|0]!=128)){break k}if(w[d+501|0]){break k}v[a+1074308>>2]=18285088;t[d+447|0]=1;break k;case 3:if(v[d+508>>2]|(e|0)!=512){break k}s:{if(VA(d+512|0,255,64)){v[a+1074308>>2]=18219008;v[23588]=0;b=Q(1,d+400|0,14786)|0;e=v[23588];v[23588]=0;if((e|0)!=1){break s}b=P()|0;O()|0;break a}v[a+1074308>>2]=18284544;v[23588]=0;b=Q(1,d+400|0,16834)|0;e=v[23588];v[23588]=0;if((e|0)==1){break i}}Ib(j,b);zb(b);t[d+447|0]=1;break k;case 1:case 2:break k;case 0:break r}}if(v[d+508>>2]|(e|0)!=514){break k}v[a+1074308>>2]=17367040;v[23588]=0;b=Q(1,d+400|0,14671)|0;e=v[23588];v[23588]=0;if((e|0)==1){break f}Ib(j,b);zb(b);t[d+447|0]=1}b=x[d+492>>1];e=b>>>2|0;v[a+480208>>2]=b<<3&32768|(e&8|(e&4|(v[a+480208>>2]&-32797|b<<1&16)));b=d+280|0;br(b,d+448|4);v[23588]=0;R(222,d+168|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break h}b=d+168|0;Ac(a+1298308|0,b);yb(b);if(!(!(w[d+494|0]&4)|v[a+1074308>>2]-18285314>>>0>4276681982)){v[a+480216>>2]=w[d+478|0];v[a+480220>>2]=w[d+479|0]}b=w[d+496|0];v[a+480200>>2]=b>>>0>128?256:b<<1;b=w[d+498|0];if(b){v[a+480196>>2]=b}t[d+168|0]=31;t[d+280|0]=w[d+499|0];b=d+168|0;e=d+280|0;I=a,J=B(w[jf(b,e)|0],1e4),v[I+480204>>2]=J;t[d+168|0]=w[d+497|0];t[d+280|0]=128;I=a,J=w[Wb(b,e)|0],v[I+480228>>2]=J;e=0;while(1){if((e|0)==64){t:{v[23588]=0;Q(155,g|0,192)|0;b=v[23588];v[23588]=0;if((b|0)==1){break b}if(v[a+480180>>2]==16777216&(x[d+488>>1]-2187&65535)>>>0<=2){break t}b=w[a+484376|0];e=v[a+484360>>2];v[23588]=0;ea(340,Vb(e,b)|0,g|0,x[d+480>>1],255,254);b=v[23588];v[23588]=0;if((b|0)==1){break b}break e}}else{h=(d+448|0)+e|0;i=h- -64|0;u:{if(w[i|0]==255){break u}f=(e<<5)+a|0;b=f+480280|0;df(b);I=f+480286|0,J=Cd(w[h+128|0],0,64),u[I>>1]=J;h=t[i|0];if((h|0)<0){v[b>>2]=v[b>>2]|1024}h=h&127;if(h>>>0<=64){u[f+480284>>1]=h<<2;break u}if((h|0)!=100){break u}v[b>>2]=v[b>>2]|256}e=e+1|0;continue}break}e=0;v[23588]=0;b=S(194,g|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break g}if(b){break d}v[23588]=0;b=S(157,g|0)|0;f=v[23588];v[23588]=0;v:{if((f|0)==1){break v}if(b>>>0>4e3){break d}f=w[a+484376|0];h=v[a+484360>>2];v[23588]=0;b=W(408,Vb(h,f)|0,g|0,b|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break v}if(!b){break d}break e}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}s=Sb(d+384|0);p=Sb(d+368|0);e=0;n=Sb(d+352|0);v[23588]=0;b=W(409,g|0,s|0,x[d+482>>1])|0;f=v[23588];v[23588]=0;w:{x:{y:{if((f|0)==1){break y}if(!b){break w}v[23588]=0;b=W(409,g|0,p|0,x[d+484>>1])|0;f=v[23588];v[23588]=0;if((f|0)==1){break y}if(!b){break w}v[23588]=0;b=W(409,g|0,n|0,x[d+486>>1])|0;f=v[23588];v[23588]=0;if((f|0)==1){break y}if(!b){break w}v[d+348>>2]=-1;I=d,J=Eb(v[s>>2]),v[I+168>>2]=J;e=Eb(v[s+4>>2]);while(1){b=v[d+168>>2];if(Ob(b,e)){b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if(!(!b|b>>>0>=y[d+348>>2])){v[d+348>>2]=b}Ke(d+168|0);continue}else{I=d,J=Eb(v[p>>2]),v[I+168>>2]=J;e=Eb(v[p+4>>2]);while(1){b=v[d+168>>2];if(Ob(b,e)){b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if(!(!b|b>>>0>=y[d+348>>2])){v[d+348>>2]=b}Ke(d+168|0);continue}else{I=d,J=Eb(v[n>>2]),v[I+168>>2]=J;e=Eb(v[n+4>>2]);z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{while(1){b=v[d+168>>2];if(Ob(b,e)){b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if(!(!b|b>>>0>=y[d+348>>2])){v[d+348>>2]=b}Ke(d+168|0);continue}else{if(t[d+494|0]&1){v[d+168>>2]=v[d+504>>2];I=d,J=v[Jb(d+348|0,d+168|0)>>2],v[I+348>>2]=J}e=0;if(x[d+490>>1]!=532){break H}b=x[d+488>>1];if(w[d+479|0]|(b?(b|0)!=532:0)|(w[d+478|0]|w[d+501|0])){break H}if(v[d+508>>2]|w[d+492|0]&192){break H}if(x[d+482>>1]){break I}f=x[d+484>>1];if(!f){break I}if((v[g+8>>2]+(uc(v[p>>2],v[p+4>>2])<<2)|0)+2>>>0>y[d+348>>2]){break I}}break}while(1){if((e&65535)>>>0<(f&65535)>>>0){v[23588]=0;b=S(157,g|0)|0;f=v[23588];v[23588]=0;J:{if((f|0)!=1){if(!b){break J}yg(g,((e&65535)<<2)+4|0);break I}b=P()|0;O()|0;break x}e=e+1|0;f=x[d+484>>1];continue}break}v[23588]=0;b=Q(1,d+336|0,14930)|0;e=v[23588];v[23588]=0;if((e|0)==1){break G}Ib(j,b);zb(b)}e=1;if(x[d+488>>1]){break H}v[23588]=0;b=Q(1,d+320|0,15393)|0;f=v[23588];v[23588]=0;if((f|0)==1){break F}Ib(j,b);zb(b)}b=x[d+494>>1];K:{if(b&2){v[23588]=0;f=S(194,g|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break A}b=v[g+8>>2];h=v[g>>2];v[23588]=0;i=b;b=f<<3;h=W(156,h|0,i|0,b|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break A}if(!(!h|y[d+348>>2]<b+v[g+8>>2]>>>0)){v[23588]=0;b=a+1298408|0;R(410,b|0,f|0);h=v[23588];v[23588]=0;if((h|0)==1){break A}I=d,J=Eb(v[b>>2]),v[I+280>>2]=J;h=Eb(v[a+1298412>>2]);L:{M:{while(1){b=v[d+280>>2];if(!Ob(b,h)){if(!(!f&e)){break K}if(!(w[d+494|0]&4)){break L}v[23588]=0;b=Q(1,d+304|0,15426)|0;e=v[23588];v[23588]=0;if((e|0)==1){break M}Ib(j,b);zb(b);break K}v[23588]=0;R(411,g|0,d+168|0);i=v[23588];v[23588]=0;if((i|0)!=1){v[b>>2]=0;v[b+4>>2]=0;v[b+24>>2]=0;v[b+28>>2]=0;v[b+8>>2]=0;v[b+12>>2]=0;v[b+16>>2]=0;i=w[d+168|0]|w[d+169|0]<<8;if(i|(w[d+170|0]|w[d+171|0]<<8)){v[b>>2]=((i&65024)>>>9|0)+1980;I=b,J=Xb((w[d+168|0]|w[d+169|0]<<8)>>>5&15,1,12),v[I+4>>2]=J;I=b,J=Xb((w[d+168|0]|w[d+169|0]<<8)&31,1,31),v[I+8>>2]=J;I=b,J=Xb((w[d+170|0]|w[d+171|0]<<8)>>>11|0,0,23),v[I+12>>2]=J;I=b,J=Xb((w[d+170|0]|w[d+171|0]<<8)>>>5&63,0,59),v[I+16>>2]=J;i=Xb((w[d+170|0]|w[d+171|0]<<8)<<1&62,0,59);v[b+24>>2]=i;v[b+28>>2]=i>>31}v[b+32>>2]=w[d+172|0]|w[d+173|0]<<8|(w[d+174|0]<<16|w[d+175|0]<<24);v[d+280>>2]=v[d+280>>2]+40;continue}break}b=P()|0;O()|0;break x}b=P()|0;O()|0;break x}v[23588]=0;b=Q(1,d+304|0,14970)|0;e=v[23588];v[23588]=0;if((e|0)!=1){Ib(j,b);zb(b);break K}b=P()|0;O()|0;break x}yg(g,2);break K}if(!(b>>>0<2&e)){break K}v[23588]=0;b=S(194,g|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break z}if(!b){v[23588]=0;b=Q(1,d+304|0,14930)|0;e=v[23588];v[23588]=0;if((e|0)!=1){Ib(j,b);zb(b);break K}b=P()|0;O()|0;break x}yg(g,2)}N:{if(!(w[d+494|0]&8?1:w[d+492|0]&128)){break N}v[23588]=0;b=a+901404|0;e=Q(412,g|0,b|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break E}if(!e){break N}UA(b)}if(x[d+488>>1]<=531){pq(a+901404|0)}v[23588]=0;C=S(174,d+280|0)|0;b=v[23588];v[23588]=0;O:{P:{Q:{if((b|0)!=1){v[23588]=0;b=Q(402,g|0,13805)|0;e=v[23588];v[23588]=0;if((e|0)==1){break Q}if(b){v[23588]=0;b=S(157,g|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break P}v[23588]=0;U(190,d+256|0,g|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break P}b=d+256|0;e=jc(d+168|0,b);gd(C,e);Ab(e);Ab(b)}u[a+480188>>1]=1;v[23588]=0;b=Q(402,g|0,13810)|0;e=v[23588];v[23588]=0;if((e|0)==1){break Q}if(!b){break C}v[23588]=0;b=S(157,g|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){v[23588]=0;U(190,d+256|0,g|0,b|0);b=v[23588];v[23588]=0;if((b|0)!=1){break O}}b=P()|0;O()|0;break B}b=P()|0;O()|0;break x}b=P()|0;O()|0;break B}b=P()|0;O()|0;break B}b=d+256|0;f=jc(d+168|0,b);Ab(b);b=v[f>>2];v[23588]=0;b=S(160,b|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break D}u[d+256>>1]=(b>>>0)/20;b=x[Vc(26644,d+256|0)>>1];u[a+480188>>1]=b;e=0;while(1){if((b|0)==(e|0)){Ab(f);break C}v[23588]=0;U(413,f|0,((e<<5)+a|0)+480289|0,20);h=v[23588];v[23588]=0;if((h|0)!=1){e=e+1|0;continue}break}break D}b=P()|0;O()|0;break x}b=P()|0;O()|0;break x}b=P()|0;O()|0;break x}b=P()|0;O()|0;Ab(f);break B}R:{b=v[d+348>>2];e=v[g+8>>2];S:{if(b>>>0>=e>>>0){e=b-e|0;break S}v[23588]=0;e=S(202,g|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break R}}v[23588]=0;U(190,d+168|0,g|0,e|0);b=v[23588];v[23588]=0;if((b|0)==1){break R}b=d+168|0;D=jc(d+256|0,b);Ab(b);v[23588]=0;E=Q(414,a|0,D|0)|0;b=v[23588];v[23588]=0;T:{U:{V:{if((b|0)==1){break V}if(!(t[d+494|0]&1)|!x[d+502>>1]){break U}v[23588]=0;b=Q(155,g|0,v[d+504>>2])|0;e=v[23588];v[23588]=0;if((e|0)==1){break V}if(!b){break U}v[23588]=0;X(331,a+1298332|0,g|0,x[d+502>>1],4);b=v[23588];v[23588]=0;if((b|0)!=1){break U}}b=P()|0;O()|0;break T}h=a+480192|0;u[h>>1]=0;f=0;if(w[d+492|0]&4){u[d+168>>1]=x[d+482>>1];u[d+96>>1]=255;f=x[Vc(d+168|0,d+96|0)>>1];u[h>>1]=f}e=0;W:{while(1){if((f&65535)>>>0<=e>>>0){v[d+252>>2]=0;e=x[d+484>>1];if(e){b=Db(v[p>>2],e-1|0);v[d+252>>2]=(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))+80}u[d+168>>1]=e;u[d+96>>1]=3999;q=a+480190|0;f=x[Vc(d+168|0,d+96|0)>>1];u[q>>1]=f;m=c&2;o=d+188|0;z=a+1298464|0;e=0;b=0;while(1){X:{Y:{Z:{_:{$:{aa:{ba:{ca:{if((f&65535)>>>0>e>>>0){f=Db(v[p>>2],e);f=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);if(!f){break Y}v[23588]=0;f=Q(155,g|0,f|0)|0;h=v[23588];v[23588]=0;da:{ea:{fa:{ga:{ha:{if((h|0)==1){break ha}if(!f){break Y}v[23588]=0;f=Q(415,g|0,d+168|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break ha}if(!f){break Y}v[23588]=0;i=e+1|0;f=B(i,104)+a|0;h=f+484380|0;k=Q(416,d+168|0,h|0)|0;l=v[23588];v[23588]=0;if((l|0)==1){break ga}l=d+152|0;br(l,o);v[23588]=0;R(222,d+96|0,l|0);l=v[23588];v[23588]=0;if((l|0)==1){break fa}l=d+96|0;Cc(((i<<5)+a|0)+946304|0,l);yb(l);v[23588]=0;k=Q(155,g|0,k|0)|0;l=v[23588];v[23588]=0;if((l|0)==1){break ga}if(!k){break Y}f=x[f+484414>>1];if(!(f&512)){break ea}v[23588]=0;f=Q(417,g|0,d+96|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break ca}if(!f){break da}v[d+8>>2]=v[d+104>>2];f=v[d+100>>2];v[d>>2]=v[d+96>>2];v[d+4>>2]=f;Fl(h,1,d);break da}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}if(!(f&16384)){r=x[d+488>>1];k=w[d+186|0];l=k&2;f=w[d+214|0];i=Zc(d+96|0,l?16:8,1,0,(f^-1)&1);if(!(!(k&4)|r>>>0<532)){Jo(i,3)}ia:{ja:{if(k&8){k=f&4?5:4;break ja}if(!l){k=10;if((f|0)==255){break ja}}if(f&2){t[i+2|0]=1}if(f&4){cg(i,2)}if(!(f&8)){break ia}k=9;if(!l){break ia}}cg(i,k)}if(m){f=0;v[23588]=0;W(219,d+96|0,h|0,g|0)|0;i=v[23588];v[23588]=0;if((i|0)!=1){break _}break X}f=1;i=w[d+99|0];if(i>>>0>17){break Z}i=1<<i;if(!(i&63503)){if(!(i&198144)){break Z}break $}if(w[d+96|0]){break $}break _}v[23588]=0;R(418,g|0,d+80|0);f=v[23588];v[23588]=0;if((f|0)==1){break aa}h=v[d+80>>2];if(!(!m|!h)){f=Lb(d+96|0);v[23588]=0;U(268,g|0,f|0,h|0);h=v[23588];v[23588]=0;ka:{la:{ma:{na:{oa:{pa:{qa:{if((h|0)!=1){v[23588]=0;R(374,d+136|0,16382);h=v[23588];v[23588]=0;if((h|0)==1){break qa}v[d+64>>2]=i;v[23588]=0;U(11,d+120|0,0,f|0);h=v[23588];v[23588]=0;if((h|0)==1){break pa}v[23588]=0;X(419,d+152|0,d+136|0,d- -64|0,d+120|0);h=v[23588];v[23588]=0;if((h|0)==1){break oa}h=v[z>>2];v[23588]=0;U(376,h|0,2,d+152|0);h=v[23588];v[23588]=0;if((h|0)==1){break na}zb(d+152|0);zb(d+120|0);ac(d+136|0);yb(f);break da}b=P()|0;O()|0;break ka}b=P()|0;O()|0;break ka}b=P()|0;O()|0;break la}b=P()|0;O()|0;break ma}b=P()|0;O()|0;zb(d+152|0)}zb(d+120|0)}ac(d+136|0)}yb(f);break T}v[23588]=0;Q(188,g|0,h|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break aa}}f=0;break Z}u[d+168>>1]=1;u[d+96>>1]=f;I=a+480190|0,J=x[ke(d+168|0,d+96|0)>>1],u[I>>1]=J;if(!(x[d+488>>1]==516&b)|x[d+490>>1]!=512|(x[d+494>>1]|v[d+508>>2])){break ba}if((x[d+492>>1]&65527)!=21|w[d+496|0]!=128|(w[d+497|0]!=48|w[d+500|0]!=128)){break ba}if(w[d+501|0]|x[d+502>>1]){break ba}f=d+576|0;b=d+512|0;e=1;while(1)if((b|0)==(f|0)){b=d+640|0;while(1)if((b|0)==(f|0)){f=20;while(1){if((f|0)==26){ra:{if(!(e&1)){break ba}v[23588]=0;b=Q(1,d+152|0,9829)|0;e=v[23588];v[23588]=0;if((e|0)==1){break ra}Ib(j,b);zb(b);break ba}}else{e=!w[(d+f|0)+452|0]&e;f=f+1|0;continue}break}b=P()|0;O()|0;break T}else{e=w[f|0]==64&e;f=f+1|0;continue}}else{e=(w[b|0]&127)==32&e;b=b+1|0;continue}}b=P()|0;O()|0;break T}v[a+480260>>2]=0;v[a+480264>>2]=2147483647;b=uc(v[n>>2],v[n+4>>2]);u[d+168>>1]=b;q=x[Vc(d+168|0,v[a+8>>2]+10|0)>>1];u[d+118>>1]=q;sa:{ta:{ua:{va:{if((b|0)!=(q|0)){v[23588]=0;Y(420,d+96|0);b=v[23588];v[23588]=0;if((b|0)==1){break sa}b=v[n+4>>2];e=v[n>>2];v[23588]=0;I=d,J=uc(e,b),v[I+136>>2]=J;X(421,d+168|0,d+96|0,d+136|0,d+118|0);b=v[23588];v[23588]=0;if((b|0)==1){break ua}b=v[a+1298464>>2];v[23588]=0;U(376,b|0,2,d+168|0);b=v[23588];v[23588]=0;if((b|0)==1){break va}zb(d+168|0);ac(d+96|0)}if(!(c&1)){u[d+118>>1]=0;q=0}m=a+480188|0;h=0;wa:{xa:{ya:{za:{Aa:{Ba:{while(1){Ca:{if((h|0)==(q|0)){Da:{Ea:{b=v[d+252>>2];if(!b){break Ea}v[23588]=0;Q(155,g|0,b|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break Da}if(!(r&1)){break Ea}while(1){Fa:{b=v[g+8>>2];c=v[g>>2];v[23588]=0;b=W(156,c|0,b|0,4)|0;c=v[23588];v[23588]=0;if((c|0)==1){break Fa}if(!b){break Ea}v[23588]=0;b=Q(402,g|0,13779)|0;c=v[23588];v[23588]=0;if((c|0)==1){break Fa}Ga:{if(!b){v[23588]=0;b=Q(402,g|0,13784)|0;c=v[23588];v[23588]=0;if((c|0)==1){break Fa}if(!b){break Ga}}v[23588]=0;b=S(157,g|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){yg(g,8);if(!(b&1616928864)|b&-2139062144){break Ga}break Ea}b=P()|0;O()|0;break T}v[23588]=0;b=S(194,g|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break Fa}v[23588]=0;Q(188,g|0,b|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){continue}}break}b=P()|0;O()|0;break T}v[23588]=0;b=Q(422,a|0,g|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break Da}b=b|w[d+447|0];t[d+447|0]=b;if(!(!b|E)){mu(a+1074312|0);t[a+1074368|0]=0}v[23588]=0;X(423,a|0,g|0,0,d+447|0);b=v[23588];v[23588]=0;if((b|0)==1){break Da}v[23588]=0;o=a+484344|0;R(225,o|0,q|0);b=v[23588];v[23588]=0;if((b|0)==1){break Da}z=a+480188|0;H=a+480183|0;h=0;Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{while(1){Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{cb:{db:{eb:{fb:{if((h|0)!=(q|0)){b=Db(v[n>>2],h);b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if(b){v[23588]=0;b=Q(155,g|0,b|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break ab}if(b){break $a}}v[23588]=0;b=W(226,o|0,h&65535,64)|0;c=v[23588];v[23588]=0;if((c|0)==1){break ab}if(b){break bb}u[d+48>>1]=h;v[23588]=0;Y(424,d+96|0);b=v[23588];v[23588]=0;if((b|0)==1){break fb}v[23588]=0;U(425,d+168|0,d+96|0,d+48|0);b=v[23588];v[23588]=0;if((b|0)==1){break eb}b=v[a+1298464>>2];v[23588]=0;U(376,b|0,2,d+168|0);b=v[23588];v[23588]=0;if((b|0)==1){break db}zb(d+168|0);ac(d+96|0)}if(!v[a+1074308>>2]){e=x[d+488>>1];if((e|0)!=2184){break Za}v[a+1074308>>2]=18284544}if(!rh(v[j+4>>2],w[j+11|0])){break _a}v[23588]=0;c=Q(1,d+96|0,17579)|0;b=v[23588];v[23588]=0;if((b|0)==1){break Ra}b=v[a+1074308>>2];v[23588]=0;R(140,d- -64|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break Ta}v[23588]=0;U(2,d+168|0,c|0,d- -64|0);b=v[23588];v[23588]=0;if((b|0)==1){break Ua}e=d+168|0;b=Ib(j,e);zb(e);zb(d- -64|0);zb(c);if(!Rb(d+508|0,13568,4)|(x[d+488>>1]&61440)!=20480){break Ya}v[23588]=0;c=Q(1,d+168|0,16846)|0;e=v[23588];v[23588]=0;if((e|0)==1){break Va}v[23588]=0;Q(98,b|0,c|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break Wa}zb(c);break Xa}b=P()|0;O()|0;break T}b=P()|0;O()|0;break cb}b=P()|0;O()|0;zb(d+168|0)}ac(d+96|0);break T}b=v[o>>2];v[23588]=0;R(426,Yb(b,h)|0,C|0);b=v[23588];v[23588]=0;if((b|0)!=1){break Pa}}b=P()|0;O()|0;break T}v[23588]=0;b=S(194,g|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break Ha}v[23588]=0;F=S(194,g|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break Ia}v[23588]=0;c=Q(188,g|0,4)|0;e=v[23588];v[23588]=0;if((e|0)==1){break Ia}if(!c){break Pa}v[23588]=0;c=W(226,o|0,h&65535,F|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break Ia}if(!c){break Pa}v[23588]=0;U(190,d+96|0,g|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break Ja}b=d+96|0;m=jc(d+168|0,b);Ab(b);b=v[o>>2];v[23588]=0;R(426,Yb(b,h)|0,C|0);b=v[23588];v[23588]=0;if((b|0)==1){break La}b=x[z>>1];v[23588]=0;l=Q(427,d+120|0,b|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break Ma}b=x[z>>1];c=d+96|0;Ej(c);v[23588]=0;k=W(428,d+80|0,b|0,c|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break Oa}I=d,J=Eb(v[Yb(v[o>>2],h)>>2]),v[I+64>>2]=J;r=0;while(1){gb:{hb:{ib:{jb:{if(r>>>0>=F>>>0){break jb}b=v[m>>2];v[23588]=0;b=W(156,b|0,v[d+176>>2],1)|0;c=v[23588];v[23588]=0;if((c|0)==1){break Qa}if(!b){break jb}v[23588]=0;b=S(206,m|0)|0;c=v[23588];v[23588]=0;kb:{if((c|0)!=1){b=b<<24>>24;if(b){break kb}kU(d- -64|0,x[z>>1]);r=r+1|0;continue}break Qa}lb:{c=b&127;i=c?c-1&65535:0;if(ed(v[l>>2],v[d+124>>2])>>>0>i>>>0){break lb}v[23588]=0;t[d+96|0]=0;c=i+1|0;U(429,l|0,c|0,d+96|0);e=v[23588];v[23588]=0;if((e|0)==1){break Qa}e=d+96|0;Ej(e);v[23588]=0;U(430,k|0,c|0,e|0);c=v[23588];v[23588]=0;if((c|0)!=1){break lb}break Qa}if((b|0)<0){v[23588]=0;b=S(206,m|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break Qa}I=Kb(v[l>>2],i),J=b,t[I|0]=J}f=d+96|0;Ej(f);if(i>>>0<x[z>>1]){f=Hd(v[d+64>>2],i)}b=Kb(v[l>>2],i);e=w[b|0];if(e&16){I=f,J=w[Hd(v[k>>2],i)|0],t[I|0]=J;e=w[b|0]}if(e&32){I=f,J=w[Hd(v[k>>2],i)+1|0],t[I+1|0]=J;e=w[b|0]}if(e&64){c=Hd(v[k>>2],i);t[f+2|0]=w[c+2|0];t[f+4|0]=w[c+4|0];e=w[b|0]}if(e<<24>>24<0){c=Hd(v[k>>2],i);t[f+3|0]=w[c+3|0];t[f+5|0]=w[c+5|0];e=w[b|0]}if(e&1){v[23588]=0;b=S(206,m|0)|0;c=v[23588];v[23588]=0;mb:{nb:{if((c|0)!=1){b=b<<24>>24;b=(((b^-1)&128)>>>7|0)+b|0;if(!(t[H|0]&1)){break nb}c=b;break mb}break Qa}c=253;if((b-121&255)>>>0<132){break mb}c=(b&255)==253?0:b}t[f|0]=c;I=Hd(v[k>>2],i),J=c,t[I|0]=J;b=Kb(v[l>>2],i)}if(w[b|0]&2){v[23588]=0;b=S(206,m|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break Qa}t[f+1|0]=b;I=Hd(v[k>>2],i),J=b,t[I+1|0]=J;b=Kb(v[l>>2],i)}if(!(w[b|0]&4)){break gb}v[23588]=0;b=S(206,m|0)|0;c=v[23588];v[23588]=0;ob:{pb:{if((c|0)!=1){if(b>>>0>64){break pb}t[f+4|0]=b;e=1;break ob}break Qa}if(b<<24>>24<=-64){e=2;t[f+2|0]=2;b=b^-128;t[f+4|0]=b;break hb}if(b>>>0<=74){e=5;t[f+2|0]=5;b=b-65|0;t[f+4|0]=b;break hb}if(b>>>0<=84){e=6;t[f+2|0]=6;b=b-75|0;t[f+4|0]=b;break hb}if(b>>>0<=94){e=3;t[f+2|0]=3;b=b-85|0;t[f+4|0]=b;break hb}if(b>>>0<=104){e=4;t[f+2|0]=4;b=b-95|0;t[f+4|0]=b;break hb}if(b>>>0<=114){e=13;t[f+2|0]=13;b=b-105|0;t[f+4|0]=b;break hb}if(b>>>0<=124){e=12;t[f+2|0]=12;b=b-115|0;t[f+4|0]=b;break hb}c=b+63|0;if((c&255)>>>0<=9){t[f+4|0]=c;e=11;t[f+2|0]=11;b=c;break hb}c=b+53|0;G=c&255;if(G>>>0<=9){t[f+4|0]=c;e=8;t[f+2|0]=8;if(!G){b=0;break hb}if(v[a+1074308>>2]-1>>>0>18285139){break ib}e=7;t[f+2|0]=7;break ib}b=b+33|0;if((b&255)>>>0>=10){b=w[f+4|0];e=w[f+2|0];break hb}t[f+4|0]=b;e=15}t[f+2|0]=e;break hb}uk(k);hc(l);Ab(m);break Pa}b=c}c=Hd(v[k>>2],i);t[c+4|0]=b;t[c+2|0]=e;b=Kb(v[l>>2],i)}if(!(w[b|0]&8)){continue}v[23588]=0;R(260,d+32|0,m|0);b=v[23588];v[23588]=0;if((b|0)!=1){RA(f,w[d+32|0],w[Nc(d+32|0)|0],1);b=Hd(v[k>>2],i);t[b+3|0]=w[f+3|0];t[b+5|0]=w[f+5|0];continue}break}break Qa}e=x[d+488>>1]}qb:{rb:{sb:{tb:{ub:{vb:{wb:{xb:{b=e&65535;switch(b>>>12|0){case 13:break rb;case 7:break sb;case 6:break tb;case 4:break ub;case 1:break wb;case 0:break xb;default:break Xa}}if(E){v[23588]=0;b=Q(1,d+168|0,8300)|0;c=v[23588];v[23588]=0;if((c|0)!=1){Ib(j,b);zb(b);break Xa}b=P()|0;O()|0;break T}yb:{zb:{Ab:{Bb:{Cb:{Db:{Eb:{Fb:{Gb:{Hb:{Ib:{Jb:{Kb:{Lb:{if((e&65535)==532){f=x[d+490>>1];if((f|0)!=532){if((f|0)!=512){e=532;break Kb}Mb:{if(x[d+494>>1]|x[d+492>>1]!=9|(w[d+479|0]|w[d+478|0])){break Mb}if(x[d+482>>1]|x[d+480>>1]!=(x[d+486>>1]+1|0)|(w[d+496|0]!=128|w[d+497|0]!=100)){break Mb}if(w[d+498|0]!=1|w[d+500|0]!=128|(w[d+501|0]|x[d+502>>1])){break Mb}if(v[d+504>>2]|v[d+508>>2]){break Mb}v[23588]=0;b=Q(1,d+168|0,9810)|0;c=v[23588];v[23588]=0;if((c|0)!=1){Ib(j,b);zb(b);break Xa}b=P()|0;O()|0;break T}e=532;if(v[d+508>>2]|(w[d+479|0]|w[d+478|0])){break Jb}v[a+1074308>>2]=16777381;v[23588]=0;b=Q(1,d+168|0,14867)|0;c=v[23588];v[23588]=0;if((c|0)!=1){Ib(j,b);zb(b);t[d+447|0]=1;break Xa}b=P()|0;O()|0;break T}if(!Rb(d+508|0,14048,4)){v[23588]=0;b=Q(1,d+168|0,8338)|0;c=v[23588];v[23588]=0;if((c|0)!=1){Ib(j,b);zb(b);e=a+1074312|0;f=38;break vb}b=P()|0;O()|0;break T}e=532;if(w[d+501|0]|x[d+494>>1]>1|(v[d+508>>2]|(x[d+492>>1]&4294)!=4)){break Lb}if(!x[a+480190>>1]){break Lb}v[23588]=0;e=Q(55,d+96|0,13388)|0;b=v[23588];v[23588]=0;if((b|0)==1){break Hb}b=jb-32|0;jb=b;c=jb-16|0;jb=c;ov(c+8|0,a+484527|0);kT(b+24|0,v[c+8>>2],v[c+12>>2]);jb=c+16|0;Fe(b+16|0,e);c=v[b+20>>2];v[b+8>>2]=v[b+16>>2];v[b+12>>2]=c;c=Pc(v[b+24>>2],v[b+28>>2],b+8|0);jb=b+32|0;yb(e);if(c){break Ib}e=x[d+488>>1]}if(e&65535){break Lb}if(rh(v[j+4>>2],w[j+11|0])){break Fb}}f=x[d+490>>1]}if((f&65535)>>>0>767){break Xa}}if(!rh(v[j+4>>2],w[j+11|0])){break Xa}if((f&65535)>>>0<533){break Db}v[23588]=0;b=Q(1,d- -64|0,14900)|0;c=v[23588];v[23588]=0;if((c|0)==1){break Eb}Ib(j,b);zb(b);break Cb}v[23588]=0;b=Q(1,d+168|0,8364)|0;c=v[23588];v[23588]=0;if((c|0)==1){break Gb}Ib(j,b);zb(b);break Xa}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}v[23588]=0;b=Q(1,d+168|0,9700)|0;c=v[23588];v[23588]=0;if((c|0)!=1){Ib(j,b);zb(b);break Xa}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}if((e&65535)>>>0>=533){v[23588]=0;R(431,d- -64|0,4018);b=v[23588];v[23588]=0;Nb:{if((b|0)!=1){v[23588]=0;v[d+48>>2]=x[d+488>>1]-532;U(432,d+168|0,d- -64|0,d+48|0);b=v[23588];v[23588]=0;if((b|0)==1){break Nb}b=d+168|0;Ib(j,b);zb(b);ac(d- -64|0);break Cb}b=P()|0;O()|0;break T}b=P()|0;O()|0;ac(d- -64|0);break T}v[23588]=0;R(266,d- -64|0,4317);b=v[23588];v[23588]=0;if((b|0)==1){break Bb}b=x[d+488>>1];v[d+32>>2]=b>>>8&15;v[23588]=0;v[d+16>>2]=b&255;R(433,d+48|0,d+16|0);b=v[23588];v[23588]=0;if((b|0)==1){break Ab}v[23588]=0;X(419,d+168|0,d- -64|0,d+32|0,d+48|0);b=v[23588];v[23588]=0;if((b|0)==1){break zb}b=d+168|0;Ib(j,b);zb(b);zb(d+48|0);ac(d- -64|0)}b=a+1298408|0;if(!oc(v[b>>2],v[a+1298412>>2])){break Xa}c=v[d+508>>2];if(!c){break Xa}c=WC(x[d+488>>1],c);e=xo(d+168|0);v[e+32>>2]=c;v[23588]=0;R(434,b|0,e|0);b=v[23588];v[23588]=0;if((b|0)!=1){break Xa}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;break yb}b=P()|0;O()|0;zb(d+48|0)}ac(d- -64|0);break T}c=v[d+508>>2];v[23588]=0;U(435,d+168|0,b|0,v[d+508>>2]);e=v[23588];v[23588]=0;Ob:{Pb:{Qb:{Rb:{Sb:{Tb:{Ub:{Vb:{if((e|0)!=1){e=d+168|0;Ib(j,e);zb(e);b=(b|0)==8191?c:b-4176|0;if((b|0)>1915){break Vb}f=v[a+480208>>2];if(!(f&16)){break Ub}v[23588]=0;Q(265,a+1074312|0,7)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break Tb}break qb}b=P()|0;O()|0;break T}if(b>>>0>4200){break Rb}f=v[a+480208>>2]}if(!(f&16)){v[23588]=0;Q(265,a+1074312|0,7)|0;c=v[23588];v[23588]=0;if((c|0)==1){break qb}}if((b|0)>2385){break Sb}}v[23588]=0;Q(265,a+1074312|0,38)|0;b=v[23588];v[23588]=0;if((b|0)==1){break qb}}v[23588]=0;b=Q(265,a+1074312|0,102)|0;c=v[23588];v[23588]=0;if((c|0)==1){break qb}v[23588]=0;Q(265,b|0,48)|0;b=v[23588];v[23588]=0;if((b|0)==1){break qb}break Qb}if(b>>>0>4383){break Pb}}v[23588]=0;b=W(264,a+1074312|0,116,1)|0;c=v[23588];v[23588]=0;if((c|0)==1){break qb}v[23588]=0;Q(265,b|0,115)|0;b=v[23588];v[23588]=0;if((b|0)==1){break qb}break Ob}if(b>>>0>4563){break Xa}}v[23588]=0;b=Q(265,a+1074312|0,43)|0;c=v[23588];v[23588]=0;if((c|0)==1){break qb}v[23588]=0;e=Q(265,b|0,42)|0;b=v[23588];v[23588]=0;f=87;if((b|0)==1){break qb}}v[23588]=0;Q(265,e|0,f|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break qb}break Xa}v[23588]=0;Y(436,d+96|0);b=v[23588];v[23588]=0;Wb:{Xb:{Yb:{if((b|0)!=1){b=x[d+488>>1];v[d+48>>2]=b>>>8&15;v[23588]=0;v[d+32>>2]=b&255;R(433,d- -64|0,d+32|0);b=v[23588];v[23588]=0;if((b|0)==1){break Yb}v[23588]=0;X(419,d+168|0,d+96|0,d+48|0,d- -64|0);b=v[23588];v[23588]=0;if((b|0)==1){break Xb}b=d+168|0;Ib(j,b);zb(b);zb(d- -64|0);ac(d+96|0);break Xa}b=P()|0;O()|0;break T}b=P()|0;O()|0;break Wb}b=P()|0;O()|0;zb(d- -64|0)}ac(d+96|0);break T}v[23588]=0;b=Q(1,d+168|0,8300)|0;c=v[23588];v[23588]=0;if((c|0)!=1){Ib(j,b);zb(b);break Xa}b=P()|0;O()|0;break T}if(!((b|0)!=32767|x[d+490>>1]!=533)){v[23588]=0;b=Q(1,d+168|0,5045)|0;c=v[23588];v[23588]=0;if((c|0)!=1){Ib(j,b);zb(b);break Xa}b=P()|0;O()|0;break T}v[23588]=0;R(137,d+96|0,4153);b=v[23588];v[23588]=0;Zb:{if((b|0)!=1){b=x[d+488>>1];v[d+64>>2]=b>>>8&15;v[d+48>>2]=b>>>4&15;v[23588]=0;v[d+32>>2]=b&15;ea(138,d+168|0,d+96|0,d- -64|0,d+48|0,d+32|0);b=v[23588];v[23588]=0;if((b|0)==1){break Zb}b=d+168|0;Ib(j,b);zb(b);ac(d+96|0);break Xa}b=P()|0;O()|0;break T}b=P()|0;O()|0;ac(d+96|0);break T}v[23588]=0;b=Q(1,d+168|0,6126)|0;c=v[23588];v[23588]=0;if((c|0)!=1){Ib(j,b);zb(b);break Xa}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}if(!bE(v[a+1074308>>2])){break Xa}v[23588]=0;c=Q(1,d+168|0,17082)|0;e=v[23588];v[23588]=0;_b:{if((e|0)!=1){v[23588]=0;Q(98,b|0,c|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break _b}zb(c);break Xa}b=P()|0;O()|0;break T}b=P()|0;O()|0;zb(c);break T}$b:{ac:{bc:{cc:{dc:{ec:{e=v[a+480180>>2];if(!((e|0)!=16777216|x[d+488>>1]<2186)){v[23588]=0;b=Q(155,g|0,A|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break Da}if(b){v[23588]=0;U(437,a|0,g|0,x[d+488>>1]);b=v[23588];v[23588]=0;if((b|0)==1){break Da}}e=v[a+480180>>2]}fc:{if((e|0)==16777216){v[23588]=0;b=Q(1,d+48|0,13752)|0;c=v[23588];v[23588]=0;if((c|0)==1){break ec}Ib(a+1298344|0,b);zb(b);break fc}v[23588]=0;R(266,d+32|0,4317);b=v[23588];v[23588]=0;if((b|0)==1){break dc}b=x[d+490>>1];v[d+28>>2]=b>>>8;v[23588]=0;v[d+12>>2]=b&255;R(433,d+16|0,d+12|0);b=v[23588];v[23588]=0;if((b|0)==1){break cc}v[23588]=0;X(419,d+48|0,d+32|0,d+28|0,d+16|0);b=v[23588];v[23588]=0;if((b|0)==1){break bc}b=d+48|0;Ib(a+1298344|0,b);zb(b);zb(d+16|0);ac(d+32|0)}b=v[a+480180>>2];v[23588]=0;b=Q(1,d+48|0,((b|0)==16777216?10074:6130)|0)|0;c=v[23588];v[23588]=0;e=1;if((c|0)==1){break $b}Ib(a+1298356|0,b);zb(b);Ib(a+1298368|0,j);v[a+1298404>>2]=v[a+1074308>>2]?8:5;Ab(D);Ab(C);break w}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;break ac}b=P()|0;O()|0;zb(d+16|0)}ac(d+32|0);break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;zb(c);break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;zb(d- -64|0);break Sa}b=P()|0;O()|0}zb(c);break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;u[d+48>>1]=h;uk(k);break Na}h=h+1|0;continue}break}b=P()|0;O()|0;u[d+48>>1]=h}hc(l);break Ka}b=P()|0;O()|0;u[d+48>>1]=h;break Ka}b=P()|0;O()|0;u[d+48>>1]=h}Ab(m);break T}b=P()|0;O()|0;u[d+48>>1]=h;break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}gc:{b=Db(v[n>>2],h);b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);hc:{if(!b){break hc}v[23588]=0;b=Q(155,g|0,b|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break Ba}if(!b){break hc}v[23588]=0;b=S(194,g|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break wa}v[23588]=0;l=S(194,g|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break xa}if((l-1025&65535)>>>0<64512){break hc}v[23588]=0;c=Q(188,g|0,4)|0;e=v[23588];v[23588]=0;if((e|0)==1){break xa}if(!c){break hc}v[23588]=0;U(190,d+96|0,g|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break ya}b=d+96|0;f=jc(d+168|0,b);Ab(b);c=x[m>>1];b=0;v[23588]=0;i=Q(427,d+136|0,c|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break Aa}ic:{while(1){if(b>>>0>=l>>>0){break ic}c=v[f>>2];v[23588]=0;c=W(156,c|0,v[d+176>>2],1)|0;e=v[23588];v[23588]=0;if((e|0)==1){break gc}if(!c){break ic}v[23588]=0;c=S(206,f|0)|0;e=v[23588];v[23588]=0;jc:{if((e|0)!=1){c=c<<24>>24;if(c){break jc}b=b+1|0;continue}break Ca}kc:{e=c&127;o=e?e-1|0:0;k=o&65535;if(ed(v[i>>2],v[d+140>>2])>>>0>k>>>0){break kc}v[23588]=0;t[d+96|0]=0;U(429,i|0,k+1|0,d+96|0);e=v[23588];v[23588]=0;if((e|0)!=1){break kc}break Ca}lc:{if((c|0)<0){v[23588]=0;c=S(206,f|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break lc}I=Kb(v[i>>2],k),J=c,t[I|0]=J}e=Kb(v[i>>2],k);c=w[e|0];if(!(!(c&15)|k>>>0<x[m>>1])){u[m>>1]=o+1;c=w[e|0]}if(c&1){v[23588]=0;Q(188,f|0,1)|0;c=v[23588];v[23588]=0;if((c|0)==1){break lc}e=Kb(v[i>>2],k)}if(w[e|0]&2){v[23588]=0;Q(188,f|0,1)|0;c=v[23588];v[23588]=0;if((c|0)==1){break lc}e=Kb(v[i>>2],k)}if(w[e|0]&4){v[23588]=0;Q(188,f|0,1)|0;c=v[23588];v[23588]=0;if((c|0)==1){break lc}e=Kb(v[i>>2],k)}if(!(w[e|0]&8)){continue}v[23588]=0;Q(188,f|0,2)|0;c=v[23588];v[23588]=0;if((c|0)!=1){continue}}break}break Ca}v[d+96>>2]=v[g+8>>2];I=d,J=v[Yc(d+252|0,d+96|0)>>2],v[I+252>>2]=J;hc(i);Ab(f)}h=h+1|0;continue}}break}b=P()|0;O()|0;hc(i);break za}b=P()|0;O()|0;break T}b=P()|0;O()|0}Ab(f);break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;zb(d+168|0);break ta}b=P()|0;O()|0}ac(d+96|0);break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}f=0;i=QA(d+96|0,v[h>>2]);v[23588]=0;Q(188,g|0,i|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break X}}if(w[d+99|0]!=1){break Z}b=v[h>>2]!=0|b}v[d+96>>2]=v[g+8>>2];I=d,J=v[Yc(d+252|0,d+96|0)>>2],v[I+252>>2]=J;r=(f|0)!=0}e=e+1|0;f=x[q>>1];continue}break}b=P()|0;O()|0;break T}mc:{b=Db(v[s>>2],e);b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);nc:{if(!b){break nc}v[23588]=0;b=Q(155,g|0,b|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break mc}if(!b){break nc}b=v[g+8>>2];f=v[g>>2];v[23588]=0;b=W(156,f|0,b|0,554)|0;f=v[23588];v[23588]=0;if((f|0)==1){break mc}if(!b){break nc}v[23588]=0;b=W(251,a|0,e+1&65535,0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break W}if(!b){break nc}v[23588]=0;X(438,a|0,g|0,b|0,x[d+490>>1]);f=v[23588];v[23588]=0;if((f|0)==1){break W}t[b+33|0]=w[d+501|0]}e=e+1|0;f=x[h>>1];continue}break}b=P()|0;O()|0;break T}b=P()|0;O()|0}Ab(D);break B}b=P()|0;O()|0}Ab(C);break x}b=P()|0;O()|0;break x}b=P()|0;O()|0;break x}}}}}b=P()|0;O()|0}vc(n);vc(p);vc(s);break a}vc(n);vc(p);vc(s)}zb(j)}jb=d+640|0;return e|0}b=P()|0;O()|0}zb(j);T(b|0);L()}function fha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,V=0;e=jb-1760|0;jb=e;yc(b);a:{if(!ci(b,e+1752|0)){break a}if(!yS(e+1752|0)){break a}if(!c){g=1;break a}p=w[e+1755|0];t[e+1751|0]=p;v[e+1744>>2]=-1;v[e+1740>>2]=1048576;if(p>>>0>=5){d=Bg(b);v[e+1744>>2]=d;if(!Pb(v[b>>2],v[b+8>>2],d)){break a}v[e+320>>2]=134217727;N=e,V=v[Jb(e+320|0,e+1744|0)>>2]<<5,v[N+1740>>2]=V}C=Sb(e+1728|0);v[e+320>>2]=v[e+1756>>2];d=v[Jb(e+1740|0,e+320|0)>>2];v[23588]=0;R(538,C|0,d|0);d=v[23588];v[23588]=0;b:{c:{d:{e:{f:{if((d|0)!=1){v[23588]=0;d=W(539,b|0,C|0,v[e+1756>>2])|0;f=v[23588];v[23588]=0;g:{if((f|0)==1){break g}if(!d){break b}if(p>>>0>=5){v[23588]=0;Q(155,b|0,v[e+1744>>2]+12|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break g}}v[23588]=0;R(246,a|0,0);d=v[23588];v[23588]=0;if((d|0)==1){break g}$f(a);re(e+1696|0,v[C>>2],v[C+4>>2]);d=ee(e+1688|0);v[23588]=0;f=v[d+4>>2];v[e+88>>2]=v[d>>2];v[e+92>>2]=f;m=Eg(540,e+1704|0,v[e+1696>>2],v[e+1700>>2],e+88|0);d=v[23588];v[23588]=0;h:{i:{j:{if((d|0)!=1){v[23588]=0;U(350,m|0,a+1298308|0,-1);d=v[23588];v[23588]=0;if((d|0)==1){break j}v[23588]=0;U(350,m|0,a+1298332|0,-1);d=v[23588];v[23588]=0;if((d|0)==1){break j}v[23588]=0;d=Q(541,m|0,e+1264|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break f}if(!d){break c}d=t[e+1264|0];if((d|0)<=0|(w[e+1273|0]|w[e+1274|0]<<8)>>>0>255|(w[e+1275|0]|w[e+1276|0]<<8)>>>0>3999){break c}D=a+480188|0;u[D>>1]=d&255;Ue(Vb(v[a+484360>>2],w[a+484376|0]),w[e+1267|0]|w[e+1268|0]<<8);u[a+480192>>1]=w[e+1273|0]|w[e+1274|0]<<8;u[a+480190>>1]=w[e+1275|0]|w[e+1276|0]<<8;d=w[e+1277|0];v[a+480196>>2]=d?d:6;d=w[e+1278|0];v[a+480204>>2]=B(d?d:125,1e4);f=w[e+1279|0]|w[e+1280|0]<<8|(w[e+1281|0]<<16|w[e+1282|0]<<24);d=32;k:{if(f&256){break k}d=2;if(f&2){break k}d=1;if(f&128){break k}d=f&8?16:4}v[23588]=0;R(406,a|0,d|0);d=v[23588];v[23588]=0;if((d|0)==1){break f}h=v[a+480208>>2];f=h|16777216;v[a+480208>>2]=f;d=w[e+1279|0]|w[e+1280|0]<<8|(w[e+1281|0]<<16|w[e+1282|0]<<24);if(d&1){f=h|16777232;v[a+480208>>2]=f}h=v[a+480180>>2];i=(h|0)==32;g=i&!(d&1024);j=(h|0)==2;n=j&d>>>2;j=j&d>>>4;i=i&!(d&2048);r=d&2097152;if(r?1:n|j|(i|g)){f=j?f|65536:f;f=n?f|2:f;f=i?f|4:f;v[a+480208>>2]=r>>>6|(g?f|8:f)}if(d&524288){v[23588]=0;W(264,a+1074312|0,5,1)|0;d=v[23588];v[23588]=0;if((d|0)==1){break f}h=v[a+480180>>2]}if((h|0)==2){break i}if((h|0)!=32){break h}t[e+320|0]=w[e+1283|0];t[e+240|0]=128;N=a,V=w[Wb(e+320|0,e+240|0)|0]<<1,v[N+480200>>2]=V;break h}d=P()|0;O()|0;break d}d=P()|0;O()|0;break e}t[e+320|0]=w[e+1283|0];t[e+240|0]=64;N=a,V=w[Wb(e+320|0,e+240|0)|0]<<2,v[N+480200>>2]=V}d=t[e+1285|0];l:{if((d|0)<0){d=d+52|0;break l}F=Es(+(d|0)*3.1/20);m:{if(F<4294967296&F>=0){d=~~F>>>0;break m}d=0}d=d+51|0}v[a+480228>>2]=d;u[e+320>>1]=64;i=x[Vc(D,e+320|0)>>1];f=0;j=(h|0)!=32;n=(h|0)==4;g=0;while(1)if((g|0)==(i|0)){g=0;i=0;while(1){if((f|0)!=16){i=w[(e+f|0)+1414|0]!=0|i;f=f+1|0;continue}break}while(1){if((g|0)!=128){i=w[((g<<1)+e|0)+1431|0]!=0|i;g=g+1|0;continue}break}n:{if(!(i&1)){break n}d=a+901692|0;g=0;while(1){if((g|0)==16){d=a+902204|0;g=0;while(1){if((g|0)!=128){f=(e+1264|0)+(g<<1)|0;o:{if(w[f+167|0]){v[23588]=0;Y(542,e+240|0);h=v[23588];v[23588]=0;p:{q:{r:{s:{t:{if((h|0)!=1){h=w[f+167|0];v[23588]=0;v[e+264>>2]=h-1;R(543,e+1208|0,e+264|0);h=v[23588];v[23588]=0;if((h|0)==1){break t}f=w[f+166|0];v[23588]=0;t[e+208|0]=f;R(544,e+1184|0,e+208|0);f=v[23588];v[23588]=0;if((f|0)==1){break s}v[23588]=0;X(545,e+320|0,e+240|0,e+1208|0,e+1184|0);f=v[23588];v[23588]=0;if((f|0)==1){break r}f=e+320|0;Fe(e+1240|0,f);gf(ye(d,g),v[e+1240>>2],v[e+1244>>2]);yb(f);yb(e+1184|0);yb(e+1208|0);_b(e+240|0);break o}d=P()|0;O()|0;break e}d=P()|0;O()|0;break p}d=P()|0;O()|0;break q}d=P()|0;O()|0;yb(e+1184|0)}yb(e+1208|0)}_b(e+240|0);break e}f=qc(e+1232|0,21619);gf(ye(d,g),v[f>>2],v[e+1236>>2])}g=g+1|0;continue}break}h=v[a+480180>>2];break n}f=(e+g|0)+1414|0;u:{if(w[f|0]){v[23588]=0;Y(546,e+240|0);h=v[23588];v[23588]=0;v:{w:{x:{if((h|0)!=1){f=w[f|0];v[23588]=0;v[e+1184>>2]=f-1;R(543,e+1208|0,e+1184|0);f=v[23588];v[23588]=0;if((f|0)==1){break x}v[23588]=0;U(288,e+320|0,e+240|0,e+1208|0);f=v[23588];v[23588]=0;if((f|0)==1){break w}f=e+320|0;Fe(e+1256|0,f);gf(ye(d,g),v[e+1256>>2],v[e+1260>>2]);yb(f);yb(e+1208|0);_b(e+240|0);break u}d=P()|0;O()|0;break e}d=P()|0;O()|0;break v}d=P()|0;O()|0;yb(e+1208|0)}_b(e+240|0);break e}f=qc(e+1248|0,21619);gf(ye(d,g),v[f>>2],v[e+1252>>2])}g=g+1|0;continue}}d=w[a+484376|0];f=v[a+484360>>2];v[23588]=0;f=Vb(f,d);d=h&5;ea(340,f|0,m|0,w[e+1265|0]|w[e+1266|0]<<8,(d?65535:255)|0,(d?65535:254)|0);d=v[23588];v[23588]=0;if((d|0)!=1){v[23588]=0;U(190,e+320|0,m|0,B(w[e+1264|0],w[e+1269|0]|w[e+1270|0]<<8)<<1);d=v[23588];v[23588]=0;if((d|0)!=1){d=e+320|0;G=jc(e+1208|0,d);Ab(d);v[23588]=0;U(190,d|0,m|0,(w[e+1269|0]|w[e+1270|0]<<8)<<1);d=v[23588];v[23588]=0;y:{if((d|0)!=1){d=e+320|0;H=jc(e+1184|0,d);Ab(d);v[23588]=0;r=Q(218,e+1168|0,w[e+1271|0]|w[e+1272|0]<<8)|0;d=v[23588];v[23588]=0;z:{if((d|0)!=1){N=e,V=Eb(v[r>>2]),v[N+264>>2]=V;d=Eb(v[r+4>>2]);A:{B:{C:{while(1){f=v[e+264>>2];if(!Ob(f,d)){j=a+480180|0;d=v[j>>2];A=c&1;if(!A){break B}v[23588]=0;R(225,a+484344|0,w[e+1269|0]|w[e+1270|0]<<8);f=v[23588];v[23588]=0;if((f|0)!=1){break B}d=P()|0;O()|0;break A}v[23588]=0;h=S(157,m|0)|0;g=v[23588];v[23588]=0;if((g|0)!=1){v[23588]=0;U(190,e+240|0,m|0,h|0);h=v[23588];v[23588]=0;if((h|0)==1){break C}g=f;f=e+240|0;h=jc(e+320|0,f);gd(g,h);Ab(h);Ab(f);Mf(e+264|0);continue}break}d=P()|0;O()|0;break A}d=P()|0;O()|0;break A}s=(d|0)==16?14:(d|0)==32?1:13;I=a+484344|0;n=1;while(1){D:{E:{F:{G:{H:{I:{if((w[e+1269|0]|w[e+1270|0]<<8)>>>0<=q>>>0){switch(v[a+480180>>2]-1|0){case 0:break G;case 3:break I;default:break F}}v[23588]=0;d=S(194,H|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break H}v[e+240>>2]=d;if(!A){break D}v[23588]=0;d=W(226,I|0,q&65535,d|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break H}l=0;if(!d){break D}while(1){h=l&65535;if(h>>>0>=w[e+1264|0]){break D}v[23588]=0;d=S(194,G|0)|0;f=v[23588];v[23588]=0;J:{if((f|0)!=1){f=v[r>>2];if(Bf(f,v[r+4>>2])>>>0<=d>>>0){break J}k=Og(f,d);yc(k);f=0;d=Yb(v[I>>2],q);g=id(v[d>>2],v[v[d+48>>2]+12>>2],0,h);K:while(1){if(y[e+240>>2]<=f>>>0){break J}v[23588]=0;d=S(206,k|0)|0;h=v[23588];v[23588]=0;if((h|0)!=1){if(!d){break J}z=d>>>4|0;J=d&15;i=0;h=tg(e+320|0);while(1){L:{M:{N:{if(J>>>0>(i&255)>>>0){v[23588]=0;R(260,e+264|0,k|0);d=v[23588];v[23588]=0;if((d|0)==1){break N}O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{d=w[Kb(e+264|0,0)|0];switch(d-1|0){case 2:case 3:case 4:case 7:case 8:case 9:case 11:case 12:case 13:case 16:case 18:case 21:case 22:case 23:case 24:case 25:case 27:case 32:break O;case 33:break S;case 30:case 31:break T;case 29:break U;case 28:break V;case 26:break W;case 19:case 20:break X;case 17:break Y;case 15:break Z;case 14:break _;case 10:break $;case 6:break aa;case 5:break ba;case 1:break ca;case 0:break da;default:break ea}}switch(d-48|0){case 4:break P;case 1:case 2:break Q;case 0:break R;default:break O}}d=w[Kb(e+264|0,1)|0];fa:{if(d>>>0<=119){d=d+s|0;break fa}ga:{switch(d-254|0){case 1:d=255;break fa;case 0:d=254;break fa;default:break ga}}d=253}t[h|0]=d;n=gB(d)&n;break L}N=e,V=w[Kb(e+264|0,1)|0]+1|0,t[N+321|0]=V;break L}ha:{if(w[e+322|0]){break ha}d=v[j>>2];if((d|0)!=32){if((d|0)!=4){break ha}d=w[Kb(e+264|0,1)|0];if(d&15){break ha}t[e+322|0]=11;t[e+324|0]=d>>>4;break L}o=w[Kb(e+264|0,1)|0];d=0;while(1){if((d|0)==10){break ha}if((o|0)==w[d+43744|0]){t[e+324|0]=d;t[e+322|0]=11;break L}else{d=d+1|0;continue}}}N=e,V=w[Kb(e+264|0,1)|0],t[N+325|0]=V;t[e+323|0]=4;break L}d=Kb(e+264|0,1);ia:{if(w[e+322|0]){break ia}o=w[d|0];if(v[j>>2]!=32|o>>>0>9){break ia}t[e+324|0]=o;t[e+322|0]=8;break L}t[e+325|0]=w[d|0];t[e+323|0]=5;break L}ja:{if(w[e+322|0]){break ja}ka:{d=v[j>>2];if((d|0)!=4){if((d|0)!=32){break ja}d=Kb(e+264|0,1);o=w[d|0];if((o|0)!=255){break ka}t[e+324|0]=64;t[e+322|0]=2;break L}d=Kb(e+264|0,1);if(w[d|0]&15){break ja}break M}if(!(o&3)){break M}}N=e,V=w[Kb(e+264|0,1)|0],t[N+325|0]=V;t[e+323|0]=9;break L}o=w[e+322|0];d=Kb(e+264|0,1);la:{if(o|v[j>>2]==1){break la}o=w[d|0];if(o>>>0>64){break la}t[e+324|0]=o;t[e+322|0]=1;break L}t[e+325|0]=w[d|0];t[e+323|0]=13;break L}d=w[Kb(e+264|0,1)|0];t[e+325|0]=d;t[e+323|0]=14;if(v[j>>2]==32){break L}t[e+325|0]=B((d&240)>>>4|0,10)+(d&15);break L}d=w[Kb(e+264|0,1)|0];t[e+325|0]=d;t[e+323|0]=d>>>0<32?16:17;break L}o=w[Kb(e+264|0,1)|0];if(o>>>0>=16){t[e+324|0]=o>>>4;t[e+322|0]=(d|0)==20?3:5;break L}t[e+324|0]=o&15;t[e+322|0]=(d|0)==20?4:6;break L}d=w[Kb(e+264|0,1)|0];if(d>>>0>=16){t[e+322|0]=10;t[e+324|0]=d>>>4;break L}t[e+322|0]=9;t[e+324|0]=d&15;break L}d=w[Kb(e+264|0,1)|0];t[e+323|0]=28;t[e+325|0]=d|16;break L}d=w[Kb(e+264|0,1)|0];t[e+323|0]=28;t[e+325|0]=d|32;break L}N=e,V=w[Kb(e+264|0,1)|0],t[N+324|0]=V;t[e+322|0]=(d|0)==31?7:8;break L}d=w[e+323|0];t[e+323|0]=(d|0)==4?6:(d|0)==5?7:11;N=e,V=w[Kb(e+264|0,1)|0],t[N+325|0]=V;break L}d=Kb(e+264|0,1);t[e+324|0]=w[d|0]%10;d=w[d|0];if(d>>>0<=9){t[e+322|0]=5;break L}if(d>>>0<=19){t[e+322|0]=6;break L}if(d>>>0<=29){t[e+322|0]=3;break L}if(d>>>0>39){break L}t[e+322|0]=4;break L}N=e,V=w[Kb(e+264|0,1)|0],t[N+324|0]=V;t[e+322|0]=(d|0)==49?13:12;break L}d=w[Kb(e+264|0,1)|0]+33|0;if((d&255)>>>0>9){break L}t[e+322|0]=15;t[e+324|0]=d;break L}if(d>>>0>57){break L}N=e,V=w[Kb(e+264|0,1)|0],t[N+325|0]=V;t[e+323|0]=w[d+26816|0];break L}v[e+264>>2]=f+z;d=v[Jb(e+264|0,e+240|0)>>2];d=d>>>0<f>>>0?f:d;while(1){if((d|0)!=(f|0)){i=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);t[g|0]=i;t[g+1|0]=i>>>8;t[g+2|0]=i>>>16;t[g+3|0]=i>>>24;i=w[h+4|0]|w[h+5|0]<<8;t[g+4|0]=i;t[g+5|0]=i>>>8;f=f+1|0;g=B(w[e+1264|0],6)+g|0;continue}break}f=d;continue K}d=P()|0;O()|0;break A}d=w[d|0];t[e+322|0]=2;t[e+324|0]=d>>>2}i=i+1|0;continue}}break}d=P()|0;O()|0;break A}d=P()|0;O()|0;break A}l=l+1|0;continue}}g=x[a+480192>>1];d=0;break E}d=P()|0;O()|0;break A}if((n^1)&1|x[D>>1]!=4){break F}v[a+480208>>2]=v[a+480208>>2]|8454144}g=0;d=!((w[e+1279|0]|w[e+1280|0]<<8|(w[e+1281|0]<<16|w[e+1282|0]<<24))&512)}v[23588]=0;o=Q(547,e+1152|0,g|0)|0;f=v[23588];v[23588]=0;ma:{na:{oa:{pa:{qa:{if((f|0)!=1){q=a+480192|0;j=p>>>0<5;n=a+480180|0;i=1;ra:{while(1){g=i&65535;if(g>>>0>x[q>>1]){break ra}sa:{ta:{ua:{va:{if(!d){v[23588]=0;h=W(251,a|0,g|0,0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break va}if(h){break ua}}while(1){v[23588]=0;f=S(206,m|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break na}if(f){continue}break}if(!j){while(1){v[23588]=0;f=S(206,m|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){d=P()|0;O()|0;break ma}if(f){continue}break}}v[23588]=0;Q(188,m|0,826)|0;f=v[23588];v[23588]=0;if((f|0)!=1){break ta}}d=P()|0;O()|0;break ma}f=Lb(e+240|0);v[23588]=0;U(350,m|0,f|0,-1);l=v[23588];v[23588]=0;if((l|0)==1){break sa}Cc(h+492|0,f);if(!j){v[23588]=0;U(350,m|0,f|0,-1);l=v[23588];v[23588]=0;if((l|0)==1){break sa}Cc(h+524|0,f)}v[23588]=0;l=Q(548,m|0,e+320|0)|0;k=v[23588];v[23588]=0;if((k|0)==1){break oa}if(!l){break qa}l=v[n>>2];v[23588]=0;U(549,e+320|0,h|0,l|0);h=v[23588];v[23588]=0;if((h|0)==1){break oa}if(v[n>>2]==4){h=Db(v[o>>2],g-1|0);g=x[e+1122>>1]|x[e+1124>>1]<<16;t[h|0]=g;t[h+1|0]=g>>>8;t[h+2|0]=g>>>16;t[h+3|0]=g>>>24}yb(f)}i=i+1|0;continue}break}break oa}if(!d){break pa}u[a+480192>>1]=0;break pa}d=P()|0;O()|0;break A}yb(f)}d=x[a+480190>>1];v[23588]=0;q=Q(550,e+304|0,d|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){J=!(t[e+1279|0]&1)|p>>>0>4;A=c&2;M=a+480180|0;i=1;d=0;while(1){c=d;wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{n=i&65535;if(n>>>0<=x[a+480190>>1]){g=Lb(e+288|0);v[23588]=0;U(350,m|0,g|0,-1);d=v[23588];v[23588]=0;if((d|0)==1){break Ra}j=B(n,104)+a|0;Cc(((n<<5)+a|0)+946304|0,g);d=p>>>0<5;if(!d){v[23588]=0;U(350,m|0,g|0,-1);f=v[23588];v[23588]=0;if((f|0)==1){break Ra}Be(j+484423|0,g)}v[23588]=0;f=Q(551,m|0,e+320|0)|0;h=v[23588];v[23588]=0;Sa:{Ta:{if((h|0)==1){break Ta}if(!f){break Sa}h=v[M>>2];v[23588]=0;f=j+484380|0;X(552,e+320|0,f|0,h|0,J|0);h=v[23588];v[23588]=0;if((h|0)==1){break Ta}s=0;Ua:{if((x[e+340>>1]&61440)!=28672|d){break Ua}v[23588]=0;s=S(553,m|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){break Ua}d=P()|0;O()|0;break za}if(!A){break xa}h=w[e+355|0]|w[e+356|0]<<8|(w[e+357|0]<<16|w[e+358|0]<<24);d=x[e+340>>1];l=d&61440;if(!(h|l)){d=Zc(e+240|0,d&1?16:8,d&1024?3:1,0,0);v[23588]=0;W(219,d|0,f|0,b|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){break xa}d=P()|0;O()|0;break za}if((h|0)<0){d=h+n|0;if((d|0)<=0){break xa}xS(f,(B(d,104)+a|0)+484380|0);break xa}if((h|0)<=0){break xa}if(d&1){k=j+484414|0;u[k>>1]=x[k>>1]|1}if(d&1024){k=j+484414|0;u[k>>1]=x[k>>1]|64}v[23588]=0;U(190,e+240|0,b|0,h|0);h=v[23588];v[23588]=0;Va:{Wa:{Xa:{Ya:{Za:{_a:{if((h|0)!=1){k=e+240|0;h=jc(e+264|0,k);Ab(k);k=Kd(x[f+34>>1]);K=(l|0)==16384;if(!K&(l|0)!=8192){break Ya}z=v[h>>2];v[23588]=0;z=S(160,z|0)|0;E=v[23588];v[23588]=0;if((E|0)==1){break Va}E=4/(k>>>0)|0;Lka(E,0,z,0);wc(f,mb?-1:B(E,z));if((l|0)==8192){break _a}if(!K){break Ya}if(!Ng(f)){break Xa}d=v[j+484400>>2];f=v[f>>2];if(!(t[e+340|0]&1)){break Za}v[23588]=0;X(554,h|0,d|0,f|0,k|0);f=v[23588];v[23588]=0;d=c;if((f|0)==1){break Ba}break Wa}d=P()|0;O()|0;break za}if(!Ng(f)){break Xa}d=v[j+484400>>2];f=v[f>>2];if(t[e+340|0]&1){v[23588]=0;X(555,h|0,d|0,f|0,k|0);f=v[23588];v[23588]=0;d=c;if((f|0)!=1){break Wa}break Ba}v[23588]=0;X(556,h|0,d|0,f|0,k|0);f=v[23588];v[23588]=0;d=c;if((f|0)==1){break Ba}break Wa}v[23588]=0;X(557,h|0,d|0,f|0,k|0);f=v[23588];v[23588]=0;d=c;if((f|0)==1){break Ba}break Wa}if((d&45056)==12288){d=wS(e+240|0,h,w[e+359|0]|w[e+360|0]<<8,s);N=gd(lf(v[q>>2],n-1|0),d),V=v[d+20>>2],v[N+20>>2]=V;Ab(d);break Xa}if((l|0)!=32768){d=1;if((l|0)!=4096){break Wa}l=je(e+240|0,h);v[23588]=0;d=Q(558,e+232|0,h|0)|0;k=v[23588];v[23588]=0;if((k|0)!=1){$a:{ab:{if(!w[e+237|0]){break ab}s=w[e+359|0]|w[e+360|0]<<8;k=x[e+234>>1]<<1;if(s>>>0<(k&65535)>>>0){break ab}k=s-k|0;t[e+359|0]=k;t[e+360|0]=k>>>8;d=x[d>>1];v[23588]=0;Q(155,h|0,d|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break $a}v[23588]=0;d=S(202,h|0)|0;k=v[23588];v[23588]=0;if((k|0)==1){break $a}v[23588]=0;U(190,e+184|0,h|0,d|0);d=v[23588];v[23588]=0;if((d|0)==1){break $a}d=e+184|0;k=jc(e+208|0,d);gd(l,k);Ab(k);Ab(d)}v[23588]=0;n=W(559,a|0,n|0,l|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break $a}d=1;if(n){d=w[e+359|0]|w[e+360|0]<<8;bb:{if(!d){break bb}n=x[f+34>>1];k=Hj(v[f>>2],n);if(k>>>0<=d>>>0){break bb}n=Ek(n);j=v[j+484400>>2];gj(j,d+j|0,k-d|0);v[f>>2]=v[f>>2]-((d>>>0)/(n>>>0)|0)}wc(f,v[e+328>>2]);d=c}Ab(l);break Wa}}d=P()|0;O()|0;Ab(l);break Aa}v[23588]=0;d=Q(417,h|0,e+240|0)|0;j=v[23588];v[23588]=0;if((j|0)==1){break Qa}if(!d){break Xa}v[e+80>>2]=v[e+248>>2];d=v[e+244>>2];v[e+72>>2]=v[e+240>>2];v[e+76>>2]=d;Fl(f,1,e+72|0)}d=c}Ab(h);break wa}d=P()|0;O()|0;break Aa}d=P()|0;O()|0;break za}yb(g)}cb:{if(!A){break cb}n=1;while(1){g=n&65535;if(g>>>0>x[a+480190>>1]){break cb}b=lf(v[q>>2],g-1|0);d=v[b>>2];v[23588]=0;d=S(178,d|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break Pa}db:{eb:{if(!d){break eb}f=x[b+22>>1];d=f+n&65535;i=x[b+20>>1];j=(f|0)!=0&(d|0)!=0&d>>>0<=x[a+480190>>1]&(i|0)!=0;fb:{if(j){f=lf(v[q>>2],d-1|0);break fb}d=v[b>>2];v[23588]=0;i=S(160,d|0)|0;d=v[23588];v[23588]=0;f=b;if((d|0)==1){break Oa}}yc(f);gb:{if(j){d=v[f+8>>2];h=v[f>>2];p=x[b+20>>1];v[23588]=0;d=W(156,h|0,d|0,p|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break Oa}if(!d){break eb}v[e+240>>2]=0;v[e+264>>2]=0;v[23588]=0;U(203,e+320|0,f|0,i|0);d=v[23588];v[23588]=0;hb:{if((d|0)!=1){h=qA(Ie(e+320|0),Ei(v[e+320>>2]),e+240|0,e+264|0);v[23588]=0;Q(188,f|0,v[e+240>>2])|0;d=v[23588];v[23588]=0;if((d|0)==1){break hb}Tc(e+320|0);break gb}d=P()|0;O()|0;break ya}d=P()|0;O()|0;Tc(e+320|0);break ya}h=0;v[e+240>>2]=0;v[e+264>>2]=0}v[23588]=0;R(560,e+320|0,b|0);d=v[23588];v[23588]=0;ib:{jb:{if((d|0)!=1){d=Ie(e+320|0);i=v[e+320>>2];if(!j){h=qA(d,Ei(i),e+240|0,e+264|0);v[23588]=0;f=v[e+240>>2];Q(188,b|0,f|0)|0;j=v[23588];v[23588]=0;if((j|0)==1){break db}i=i-f|0;d=d+f|0}if(h){break jb}c=1;break ib}d=P()|0;O()|0;break ya}f=B(g,104)+a|0;p=f+484380|0;Ng(p);s=f+484400|0;f=0;g=v[e+264>>2];while(1){kb:{if(!i|(g|0)!=1?g:0){break kb}g=v[p>>2];if(g>>>0<=f>>>0){break kb}if(!Zd(g,v[p+20>>2])){break kb}v[e+208>>2]=0;v[e+184>>2]=0;l=vS(h,d,Ei(i),e+208|0,e+288|0,e+184|0);v[23588]=0;v[e+240>>2]=l;Q(188,b|0,l|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break Ca}ai(e+184|0,Ei(v[p>>2]-f|0));j=v[e+184>>2];lb:{if((j|0)<=0){break lb}g=v[e+208>>2];z=x[p+34>>1];if((Kd(z)|0)!=(g|0)){break lb}k=B(f,g);A=v[s>>2];if(z&1){v[e+176>>2]=j;v[e+160>>2]=j;v[e- -64>>2]=j;v[e+48>>2]=j;v[e+156>>2]=g;v[e+152>>2]=v[e+288>>2];v[e+172>>2]=g;v[e+168>>2]=A+(k<<1);v[23588]=0;g=v[e+156>>2];v[e+40>>2]=v[e+152>>2];v[e+44>>2]=g;g=v[e+172>>2];v[e+56>>2]=v[e+168>>2];v[e+60>>2]=g;R(561,e+56|0,e+40|0);g=v[23588];v[23588]=0;if((g|0)!=1){break lb}break Ca}v[e+144>>2]=j;v[e+128>>2]=j;v[e+32>>2]=j;v[e+16>>2]=j;v[e+124>>2]=g;v[e+120>>2]=v[e+288>>2];v[e+140>>2]=g;v[e+136>>2]=k+A;v[23588]=0;g=v[e+124>>2];v[e+8>>2]=v[e+120>>2];v[e+12>>2]=g;g=v[e+140>>2];v[e+24>>2]=v[e+136>>2];v[e+28>>2]=g;R(562,e+24|0,e+8|0);g=v[23588];v[23588]=0;if((g|0)==1){break Ca}}i=i-l|0;d=d+l|0;g=uS(h);v[e+264>>2]=g;f=f+j|0;continue}break}tS(h)}Tc(e+320|0)}n=n+1|0;continue}break}break Ca}mb:{if(v[a+480180>>2]!=4){break mb}g=0;d=a+480192|0;while(1){if(x[d>>1]<=g>>>0){break mb}b=Db(v[o>>2],g);f=w[b+3|0];h=w[b+2|0];i=w[b+1|0];b=w[b|0];v[23588]=0;g=g+1|0;ma(391,a|0,g&65535,b|0,i|0,h|0,f|0);b=v[23588];v[23588]=0;if((b|0)!=1){continue}break}d=P()|0;O()|0;break ya}if(!(w[e+1281|0]&16)){break Ka}b=v[m+8>>2];d=v[m>>2];v[23588]=0;b=W(156,d|0,b|0,1)|0;d=v[23588];v[23588]=0;if((d|0)==1){break Ma}if(!b){break Ka}g=0;v[23588]=0;b=S(206,m|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break Na}if(!(b&1)){break La}while(1){if(x[D>>1]<=g>>>0){break La}v[23588]=0;b=S(157,m|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){t[((g<<5)+a|0)+480288|0]=b;g=g+1|0;continue}break}d=P()|0;O()|0;break ya}d=P()|0;O()|0;break za}d=P()|0;O()|0;break Aa}d=P()|0;O()|0;break ya}d=P()|0;O()|0;break ya}d=P()|0;O()|0;break ya}d=P()|0;O()|0;break ya}d=a+906300|0;while(1){b=v[m+8>>2];f=v[m>>2];v[23588]=0;b=W(156,f|0,b|0,1)|0;f=v[23588];v[23588]=0;if((f|0)==1){break Da}if(!b){break Ka}v[23588]=0;b=S(206,m|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break Ia}if(!b){break Ka}v[23588]=0;f=S(157,m|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break Ja}v[23588]=0;U(190,e+240|0,m|0,f|0);f=v[23588];v[23588]=0;if((f|0)==1){break Ja}h=e+240|0;f=jc(e+320|0,h);Ab(h);nb:{if(b>>>0<=250){v[23588]=0;R(439,f|0,Ld(d,b-1|0)|0);b=v[23588];v[23588]=0;if((b|0)==1){break nb}}Ab(f);continue}break}d=P()|0;O()|0;Ab(f);break ya}j=a+901404|0;i=Lb(e+208|0);n=a+480180|0;p=a+484348|0;d=0;h=0;while(1){b=v[m+8>>2];f=v[m>>2];v[23588]=0;b=W(156,f|0,b|0,8)|0;f=v[23588];v[23588]=0;ob:{pb:{qb:{rb:{sb:{if((f|0)!=1){if(b){v[23588]=0;f=S(157,m|0)|0;b=v[23588];v[23588]=0;tb:{ub:{vb:{wb:{xb:{yb:{zb:{Ab:{if((b|0)!=1){v[23588]=0;b=S(157,m|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break Ab}v[23588]=0;U(190,e+320|0,m|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break zb}g=e+320|0;b=jc(e+240|0,g);Ab(g);if((f|0)==1229211981){break wb}if((f|0)==1229476432){break xb}if((f|0)==1397900630){break yb}if((f|0)!=1414548815){break ob}v[23588]=0;f=Q(402,b|0,13805)|0;g=v[23588];v[23588]=0;if((g|0)==1){break Ha}if(!f){break pb}v[23588]=0;f=S(157,b|0)|0;g=v[23588];v[23588]=0;if((g|0)!=1){v[23588]=0;U(190,e+320|0,b|0,f|0);f=v[23588];v[23588]=0;if((f|0)!=1){break vb}}d=P()|0;O()|0;break Ga}d=P()|0;O()|0;break Ea}d=P()|0;O()|0;break Ea}d=P()|0;O()|0;break Ea}Bb:{Cb:{Db:{f=v[n>>2];switch(f-2|0){case 1:break ob;case 0:break ub;case 2:break Cb;default:break Db}}if((f|0)==16){break Bb}if((f|0)!=32){break ob}v[23588]=0;d=S(194,b|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break Ha}v[23588]=0;h=S(194,b|0)|0;f=v[23588];v[23588]=0;if((f|0)!=1){break ob}break Ha}v[e+320>>2]=32;f=v[b>>2];v[23588]=0;f=S(160,f|0)|0;g=v[23588];v[23588]=0;if((g|0)!=1){v[e+264>>2]=f;f=v[Jb(e+320|0,e+264|0)>>2];v[23588]=0;U(563,b|0,i|0,f|0);f=v[23588];v[23588]=0;if((f|0)!=1){break ob}}d=P()|0;O()|0;break Ga}v[23588]=0;f=S(206,b|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break tb}v[23588]=0;R(564,e+264|0,4214);g=v[23588];v[23588]=0;Eb:{if((g|0)!=1){v[e+288>>2]=f>>>4;v[23588]=0;v[e+104>>2]=f&15;X(302,e+320|0,e+264|0,e+288|0,e+104|0);f=v[23588];v[23588]=0;if((f|0)==1){break Eb}f=e+320|0;Ib(i,f);zb(f);ac(e+264|0);break ob}d=P()|0;O()|0;break Ga}d=P()|0;O()|0;ac(e+264|0);break Ga}v[23588]=0;f=S(206,b|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break Ha}v[a+480216>>2]=f;v[23588]=0;f=S(206,b|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break Ha}v[a+480220>>2]=f;break ob}v[23588]=0;Q(412,b|0,j|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break Ha}UA(j);break ob}g=e+320|0;f=jc(e+264|0,g);Ab(g);g=v[f>>2];v[23588]=0;g=S(160,g|0)|0;l=v[23588];v[23588]=0;if((l|0)==1){break qb}u[e+320>>1]=g>>>5;N=e,V=Af(v[a+484344>>2],v[p>>2]),u[N+288>>1]=V;l=x[Vc(e+320|0,e+288|0)>>1];g=0;while(1){if((g|0)==(l|0)){Ab(f);break pb}v[23588]=0;R(565,f|0,e+320|0);k=v[23588];v[23588]=0;Fb:{if((k|0)==1){break Fb}k=v[I>>2];v[23588]=0;R(566,Yb(k,g)|0,e+320|0);k=v[23588];v[23588]=0;if((k|0)==1){break Fb}g=g+1|0;continue}break}break qb}v[23588]=0;d=S(194,b|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break Ha}break ob}d=P()|0;O()|0;break Ga}b=v[a+480180>>2];Gb:{Hb:{Ib:{if((b|0)!=32){break Ib}f=d&65535;if(f>>>0<256){break Ib}if(f>>>0<532){break Hb}}b=(b|0)!=2;Jb:{if(b){break Jb}f=d&65535;if(f>>>0<12544){break Jb}if(f>>>0<12820){break Hb}}if(b){break Gb}b=d&65535;if(b>>>0<4864|b>>>0>4895){break Gb}}pq(j)}g=1;Kb:{if(!(t[e+1281|0]&1)){break Kb}f=v[a+1074308>>2];if(!f){d=a+480192|0;f=a+480180|0;while(1){b=g&65535;if(b>>>0<=x[d>>1]){b=v[((b<<2)+a|0)+900380>>2];if(b){j=v[f>>2];v[23588]=0;R(567,Gh(b,2)|0,j|0);j=v[23588];v[23588]=0;if((j|0)==1){break sb}t[b+19|0]=w[b+19|0]+3>>>2}g=g+1|0;continue}break}f=v[a+1074308>>2]}if(f>>>0<=18350079){v[23588]=0;b=Q(265,a+1074312|0,27)|0;d=v[23588];v[23588]=0;if((d|0)==1){break Fa}v[23588]=0;Q(265,b|0,57)|0;b=v[23588];v[23588]=0;if((b|0)==1){break Fa}f=v[a+1074308>>2]}if(f>>>0<=19070975){v[23588]=0;Q(265,a+1074312|0,73)|0;b=v[23588];v[23588]=0;if((b|0)==1){break Fa}f=v[a+1074308>>2]}if(f>>>0>19267583){break Kb}v[23588]=0;Q(265,a+1074312|0,50)|0;b=v[23588];v[23588]=0;if((b|0)==1){break Fa}}Lb:{Mb:{Nb:{Ob:{Pb:{Qb:{Rb:{Sb:{Tb:{Ub:{Vb:{Wb:{Xb:{Yb:{if(rh(v[i+4>>2],w[i+11|0])){v[23588]=0;Y(568,e+240|0);b=v[23588];v[23588]=0;Zb:{if((b|0)!=1){v[23588]=0;U(536,e+320|0,e+240|0,e+1751|0);b=v[23588];v[23588]=0;if((b|0)==1){break Zb}break Yb}d=P()|0;O()|0;break Ea}d=P()|0;O()|0;ac(e+240|0);break Ea}v[23588]=0;Y(569,e+240|0);b=v[23588];v[23588]=0;if((b|0)==1){break Xb}v[23588]=0;X(570,e+320|0,e+240|0,e+1751|0,i|0);b=v[23588];v[23588]=0;if((b|0)==1){break Wb}}b=e+320|0;Ib(i,b);zb(b);b=e+240|0;ac(b);v[23588]=0;R(535,b|0,3980);b=v[23588];v[23588]=0;if((b|0)==1){break Ub}v[23588]=0;U(536,e+320|0,e+240|0,e+1751|0);b=v[23588];v[23588]=0;if((b|0)==1){break Tb}b=e+320|0;Ib(a+1298344|0,b);zb(b);ac(e+240|0);v[23588]=0;b=Q(1,b|0,14948)|0;d=v[23588];v[23588]=0;if((d|0)==1){break Sb}Ib(a+1298356|0,b);zb(b);b=v[a+480180>>2];switch(b-1|0){case 2:break rb;case 1:break Ob;case 3:break Pb;case 0:break Qb;default:break Vb}}d=P()|0;O()|0;break Ea}d=P()|0;O()|0;ac(e+240|0);break Ea}if((b|0)==16){break Rb}if((b|0)==32){break Nb}if((b|0)!=16777216){break rb}v[23588]=0;b=Q(1,e+240|0,10074)|0;d=v[23588];v[23588]=0;if((d|0)==1){break Mb}Ib(a+1298392|0,b);zb(b);v[23588]=0;b=Q(1,e+264|0,13752)|0;d=v[23588];v[23588]=0;if((d|0)==1){break Lb}Ib(a+1298380|0,b);zb(b);break rb}d=P()|0;O()|0;break Ea}d=P()|0;O()|0;ac(e+240|0);break Ea}d=P()|0;O()|0;break Ea}v[23588]=0;b=Q(1,e+240|0,10079)|0;d=v[23588];v[23588]=0;_b:{if((d|0)!=1){Ib(a+1298392|0,b);zb(b);v[23588]=0;b=Q(1,e+264|0,8325)|0;d=v[23588];v[23588]=0;if((d|0)==1){break _b}Ib(a+1298380|0,b);zb(b);break rb}d=P()|0;O()|0;break Ea}d=P()|0;O()|0;break Ea}v[23588]=0;b=Q(1,e+240|0,12238)|0;d=v[23588];v[23588]=0;$b:{if((d|0)!=1){Ib(a+1298392|0,b);zb(b);v[23588]=0;b=Q(1,e+264|0,14219)|0;d=v[23588];v[23588]=0;if((d|0)==1){break $b}Ib(a+1298380|0,b);zb(b);break rb}d=P()|0;O()|0;break Ea}d=P()|0;O()|0;break Ea}v[23588]=0;b=Q(1,e+240|0,10052)|0;d=v[23588];v[23588]=0;ac:{if((d|0)!=1){Ib(a+1298392|0,b);zb(b);v[23588]=0;b=Q(1,e+264|0,15251)|0;d=v[23588];v[23588]=0;if((d|0)==1){break ac}Ib(a+1298380|0,b);zb(b);break rb}d=P()|0;O()|0;break Ea}d=P()|0;O()|0;break Ea}v[23588]=0;b=Q(1,e+240|0,10424)|0;d=v[23588];v[23588]=0;bc:{if((d|0)!=1){Ib(a+1298392|0,b);zb(b);v[23588]=0;b=Q(1,e+264|0,15001)|0;d=v[23588];v[23588]=0;if((d|0)==1){break bc}Ib(a+1298380|0,b);zb(b);break rb}d=P()|0;O()|0;break Ea}d=P()|0;O()|0;break Ea}v[23588]=0;b=Q(1,e+240|0,6130)|0;d=v[23588];v[23588]=0;cc:{dc:{ec:{fc:{gc:{if((d|0)!=1){Ib(a+1298392|0,b);zb(b);if(!(h&65535)){break cc}v[23588]=0;R(266,e+288|0,4317);b=v[23588];v[23588]=0;if((b|0)==1){break gc}v[e+116>>2]=(h&65280)>>>8;v[23588]=0;v[e+100>>2]=h&255;R(433,e+104|0,e+100|0);b=v[23588];v[23588]=0;if((b|0)==1){break fc}v[23588]=0;X(419,e+264|0,e+288|0,e+116|0,e+104|0);b=v[23588];v[23588]=0;if((b|0)==1){break ec}b=e+264|0;Ib(a+1298380|0,b);zb(b);zb(e+104|0);ac(e+288|0);break rb}d=P()|0;O()|0;break Ea}d=P()|0;O()|0;break Ea}d=P()|0;O()|0;break dc}d=P()|0;O()|0;zb(e+104|0)}ac(e+288|0);break Ea}v[23588]=0;b=Q(1,e+264|0,8517)|0;d=v[23588];v[23588]=0;if((d|0)!=1){Ib(a+1298380|0,b);zb(b);break rb}d=P()|0;O()|0;break Ea}d=P()|0;O()|0;break Ea}d=P()|0;O()|0;break Ea}d=P()|0;O()|0;break Ea}d=P()|0;O()|0;break Ea}Ib(a+1298368|0,i);hc:{if(v[a+1074308>>2]){v[a+1298404>>2]=8;break hc}if(v[a+480180>>2]==1){v[a+1298404>>2]=14;break hc}v[a+1298404>>2]=5}g=1;ic:{jc:{if(c&1){v[23588]=0;b=Q(1,e+288|0,16594)|0;c=v[23588];v[23588]=0;if((c|0)==1){break jc}a=v[a+1298464>>2];v[23588]=0;U(376,a|0,2,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break ic}zb(b)}zb(i);sS(q);vc(o);Uc(r);Ab(H);Ab(G);break c}d=P()|0;O()|0;break Ea}d=P()|0;O()|0;zb(b);break Ea}d=P()|0;O()|0;Ab(f);break Ga}v[23588]=0;f=Q(402,b|0,13810)|0;g=v[23588];v[23588]=0;if((g|0)==1){break Ha}kc:{if(!f){break kc}v[23588]=0;f=S(157,b|0)|0;g=v[23588];v[23588]=0;lc:{if((g|0)!=1){v[23588]=0;U(190,e+264|0,b|0,f|0);f=v[23588];v[23588]=0;if((f|0)!=1){break lc}}d=P()|0;O()|0;break Ga}g=e+264|0;f=jc(e+320|0,g);Ab(g);g=v[f>>2];v[23588]=0;g=S(160,g|0)|0;l=v[23588];v[23588]=0;if((l|0)!=1){u[e+264>>1]=(g>>>0)/20;u[e+288>>1]=x[D>>1];l=x[Vc(e+264|0,e+288|0)>>1];g=0;while(1){if((g|0)==(l|0)){Ab(f);break kc}v[23588]=0;U(413,f|0,((g<<5)+a|0)+480289|0,20);k=v[23588];v[23588]=0;if((k|0)!=1){g=g+1|0;continue}break}}d=P()|0;O()|0;Ab(f);break Ga}v[23588]=0;Q(422,a|0,b|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break Ha}v[23588]=0;X(423,a|0,b|0,1,0);f=v[23588];v[23588]=0;if((f|0)==1){break Ha}if((d-2186&65535)>>>0<=117){v[n>>2]=16777216;v[23588]=0;U(437,a|0,b|0,d&65535);f=v[23588];v[23588]=0;if((f|0)==1){break Ha}}if(!v[a+1074308>>2]){break ob}v[23588]=0;f=Q(1,e+184|0,17579)|0;g=v[23588];v[23588]=0;mc:{nc:{oc:{if((g|0)!=1){g=v[a+1074308>>2];v[23588]=0;R(140,e+264|0,g|0);g=v[23588];v[23588]=0;if((g|0)==1){break oc}v[23588]=0;U(2,e+320|0,f|0,e+264|0);g=v[23588];v[23588]=0;if((g|0)==1){break nc}g=e+320|0;Ib(i,g);zb(g);zb(e+264|0);zb(f);break ob}d=P()|0;O()|0;break Ga}d=P()|0;O()|0;break mc}d=P()|0;O()|0;zb(e+264|0)}zb(f);break Ga}Ab(b);continue}}d=P()|0;O()|0;break ya}d=P()|0;O()|0;break ya}d=P()|0;O()|0}Ab(b);break Ea}d=P()|0;O()|0}zb(i);break ya}d=P()|0;O()|0;break ya}d=P()|0;O()|0;Tc(e+320|0);break ya}d=P()|0;O()|0}Ab(h)}yb(g)}sS(q);break ma}d=c}yb(g);i=i+1|0;continue}}d=P()|0;O()|0;break ma}d=P()|0;O()|0;yb(f);break ma}d=P()|0;O()|0}vc(o);break A}q=q+1|0;continue}}Uc(r);break z}d=P()|0;O()|0}Ab(H);break y}d=P()|0;O()|0}Ab(G);break e}d=P()|0;O()|0;break e}d=P()|0;O()|0;break e}else{pc:{qc:{if(!j){t[e+320|0]=w[(e+g|0)+1286|0];t[e+240|0]=64;N=((g<<5)+a|0)+480286|0,V=w[Wb(e+320|0,e+240|0)|0],u[N>>1]=V;break qc}if(n){break pc}}rc:{d=w[(e+g|0)+1350|0];if((d|0)!=255){if((d|0)!=127){break rc}v[((g<<5)+a|0)+480280>>2]=256;break pc}u[((g<<5)+a|0)+480284>>1]=256;break pc}u[((g<<5)+a|0)+480284>>1]=d}g=g+1|0;continue}}d=P()|0;O()|0;break d}d=P()|0;O()|0;break d}d=P()|0;O()|0}Ab(m)}hc(C);T(d|0);L()}Ab(m)}hc(C)}jb=e+1760|0;return g|0}function sha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,V=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0;e=jb-976|0;jb=e;yc(b);a:{if(!GS(b,e+920|0)){break a}if(!KS(e+920|0)){break a}if(!Pb(v[b>>2],v[b+8>>2],Dc(JS(e+920|0),mb))){break a}if(!c){d=1;break a}Ad(a,8);$f(a);aa=w[e+923|0];K=aa-48|0;t[e+919|0]=K;cd(b,bc(v[e+928>>2]));f=e+608|0;$d(f,b,504);_=jc(e+896|0,f);Ab(f);v[23588]=0;R(509,b|0,f|0);f=v[23588];v[23588]=0;b:{c:{d:{e:{f:{g:{if((f|0)!=1){if(w[e+891|0]>63){break b}if(Hb(x[e+608>>1])<<16>>16<0){break b}Tb(e+528|0,0,80);h:{d=bc(v[e+952>>2]);if(!d){break h}v[23588]=0;f=Q(155,b|0,d|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){if(!f){break h}v[23588]=0;R(510,b|0,e+528|0);d=v[23588];v[23588]=0;if((d|0)!=1){break h}}i=P()|0;O()|0;break e}v[23588]=0;U(511,e+520|0,b|0,K&255);d=v[23588];v[23588]=0;if((d|0)!=1){ba=Se(e+520|0);d=0;f=x[e+520>>1];if((f-128&65535)>>>0<65409){break b}u[a+480188>>1]=f;M=Sb(e+504|0);d=bc(v[e+944>>2]);i:{if(d){v[23588]=0;Q(155,b|0,d|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break g}v[23588]=0;U(512,b|0,M|0,w[e+891|0]);d=v[23588];v[23588]=0;if((d|0)==1){break g}j=w[e+891|0];break i}j=w[e+891|0];d=0;if(j){break c}}j=j&255;u[a+480192>>1]=j;u[a+480190>>1]=j;ca=(K&255)>>>0<2|t[e+872|0]>=0;r=!ca;p=c&2;s=1;C=1;while(1){j:{k:{l:{m:{n:{o:{g=C&65535;if(g>>>0<=(j&65535)>>>0){v[23588]=0;y=s&65535;f=W(251,a|0,g|0,y|0)|0;d=v[23588];v[23588]=0;p:{if((d|0)!=1){if(f){break p}break d}i=P()|0;O()|0;break f}z=v[((g<<2)+a|0)+900380>>2];u[e+84>>1]=0;v[e+80>>2]=0;v[23588]=0;D=S(174,e+480|0)|0;d=v[23588];v[23588]=0;q:{if((d|0)!=1){d=Db(v[M>>2],g-1|0);d=bc(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));r:{if(!d){break r}v[23588]=0;f=Q(155,b|0,d|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break k}if(!f){break r}v[23588]=0;R(513,b|0,e+80|0);d=v[23588];v[23588]=0;if((d|0)==1){break k}f=v[e+80>>2];d=u[e+84>>1];v[23588]=0;f=bc(f);d=pe(d);U(190,e+120|0,b|0,f<<(d>>>5&1&(d|0)>0));d=v[23588];v[23588]=0;if((d|0)==1){break k}f=e+120|0;d=jc(e+192|0,f);gd(D,d);Ab(d);Ab(f)}q=pe(u[e+84>>1]);d=q&15;if((q|0)>=0){break q}du(z,0);ea=1;break o}i=P()|0;O()|0;break f}if(d>>>0>6){break o}A=w[d+26694|0];if(!d){break m}u[a+480190>>1]=(x[a+480190>>1]+A|0)-1;l=z+108|0;m=z+236|0;n=A-2|0;j=4;s:while(1){g=1;if((j|0)==10){break n}k=B(j,12);d=(n<<3)+j|0;h=w[d+26700|0]+s|0;g=w[d+26748|0];d=0;while(1)if((d|0)==12){j=j+1|0;continue s}else{f=d+k|0;fa=cc(m,f),ga=h,u[fa>>1]=ga;f=Kb(l,f);t[f|0]=g+w[f|0];d=d+1|0;continue}}}t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{d=bc(v[e+532>>2]);if(!d){break D}if(!Hb(x[e+536>>1])){break D}v[23588]=0;f=Q(155,b|0,d|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break C}if(!f){break D}fa=e,ga=Hb(x[e+536>>1]),u[fa+192>>1]=ga;u[e+120>>1]=w[e+891|0];f=e+120|0;p=x[Vc(e+192|0,f)>>1];d=e+128|0;l=f|4;y=Hb(x[e+538>>1]);m=y>>>0<19;n=y>>>0<21;k=y>>>0<15;h=y>>>0<6;j=0;while(1){if((j|0)==(p|0)){break D}v[23588]=0;U(514,b|0,e+192|0,y|0);f=v[23588];v[23588]=0;E:{F:{G:{if((f|0)!=1){j=j+1|0;q=v[((j<<2)+a|0)+900380>>2];r=w[e+192|0];if(r){g=zl(e+120|0,0,64);zl(l,r-1&65535,64);f=w[e+193|0];if(f){f=64/(f>>>0)|0}else{f=0}zl(d,f+r|0,0);v[23588]=0;r=q+48|0;U(515,r|0,g|0,3);f=v[23588];v[23588]=0;if((f|0)==1){break G}if(w[e+192|0]==1){g=v[ec(e+472|0,Eb(v[r>>2]))>>2];f=Eb(v[r>>2]);f=v[r>>2]+(bu(g,f)<<2)|0;Nd(r,Pi(f+4|0,v[r+4>>2],f));Eb(f)}f=w[e+193|0];v[q>>2]=f?f<<9:32767;t[q+60|0]=w[q+60|0]|1;F=1}H:{if(m){break H}v[q+4>>2]=w[e+210|0]+1>>>1;if(n){break H}u[q+28>>1]=x[e+212>>1]}g=B(x[cc(q+236|0,61)>>1],104)+a|0;t[g+484417|0]=w[e+195|0]<<4;if(k){break F}f=bc(x[e+202>>1]|x[e+204>>1]<<16);v[g+484384>>2]=f;fa=g+484388|0,ga=bc(x[e+206>>1]|x[e+208>>1]<<16)+f|0,v[fa>>2]=ga;break E}i=P()|0;O()|0;break f}i=P()|0;O()|0;break f}if(h){continue}}f=g+484414|0;i=f;o=x[f>>1]&65529;f=w[e+197|0];u[i>>1]=o|f<<1&2|f>>>1&4;if(!(f&4)){continue}u[g+484412>>1]=0;continue}}I:{d=bc(v[e+548>>2]);if(!d){break I}if(!Hb(x[e+552>>1])){break I}v[23588]=0;f=Q(155,b|0,d|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break C}if(!f){break I}fa=e,ga=Hb(x[e+552>>1]),u[fa+192>>1]=ga;u[e+120>>1]=w[e+891|0];n=x[Vc(e+192|0,e+120|0)>>1];k=Hb(x[e+554>>1]);d=0;J:while(1){if((d|0)==(n|0)){break I}v[23588]=0;U(516,b|0,e+192|0,k|0);f=v[23588];v[23588]=0;if((f|0)==1){break t}f=e+80|0;rU(f,e+192|0);v[23588]=0;R(222,e+120|0,f|0);f=v[23588];v[23588]=0;if((f|0)==1){break u}d=d+1|0;m=((d<<2)+a|0)+900380|0;g=e+120|0;Cc(v[m>>2]+492|0,g);yb(g);f=v[m>>2];v[23588]=0;R(380,g|0,f|0);f=v[23588];v[23588]=0;if((f|0)==1){break v}fa=e,ga=Fi(v[e+120>>2]),v[fa+80>>2]=ga;h=wf(e+120|0);while(1){f=v[e+80>>2];if(Ob(f,h)){l=(x[qo(f)>>1]<<5)+a|0;g=l+946328|0;p=v[m>>2];f=v[p+520>>2];v[g>>2]=v[p+516>>2];v[g+4>>2]=f;f=v[p+512>>2];g=l+946320|0;v[g>>2]=v[p+508>>2];v[g+4>>2]=f;f=v[p+504>>2];g=l+946312|0;v[g>>2]=v[p+500>>2];v[g+4>>2]=f;f=v[p+496>>2];g=l+946304|0;v[g>>2]=v[p+492>>2];v[g+4>>2]=f;Kg(e+80|0);continue}else{qu(e+120|0);continue J}}}}pq(a+901404|0);d=qc(e+464|0,4943);gf(ye(a+901692|0,0),v[d>>2],v[d+4>>2]);yc(b);D=c&1;G=a+484344|0;H=a+1298332|0;da=a+1298308|0;$=a+484360|0;c=0;while(1){K:{f=c&255;if(f>>>0<w[ba|0]){v[23588]=0;X(517,b|0,e+920|0,e+528|0,e+608|0);d=v[23588];v[23588]=0;L:{M:{N:{O:{P:{if((d|0)==1){break P}Q:{if(!f){d=0;break Q}v[23588]=0;f=S(272,$|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break P}d=c;if((f|0)==255){break d}}o=xj(v[$>>2],d&255);E=Xf(e+448|0);Kc(o);I=K&255;if(I>>>0>1){break N}i=0;f=Hb(x[e+610>>1]);if(f>>>0>256|x[a+480188>>1]>16){break L}d=e+192|0;ES(d,e+608|0);v[23588]=0;U(518,o|0,d|0,f|0);d=v[23588];v[23588]=0;if((d|0)==1){break O}fa=e,ga=Eb(v[o>>2]),v[fa+192>>2]=ga;d=Eb(v[o+4>>2]);while(1){f=v[e+192>>2];if(Ob(f,d)){u[f>>1]=x[f>>1]+J;Re(e+192|0);continue}else{nh(a,1);f=x[a+480188>>1];d=0;while(1)if((d|0)==(f|0)){d=32;break M}else{t[e+192|0]=w[(d+e|0)+874|0];t[e+120|0]=64;fa=((d<<5)+a|0)+480286|0,ga=w[Wb(e+192|0,e+120|0)|0],u[fa>>1]=ga;d=d+1|0;continue}}}}i=P()|0;O()|0;break f}i=P()|0;O()|0;break w}ES(e+192|0,e+608|0);R:{S:{T:{U:{d=Hb(x[e+204>>1]);if(!(!d|d>>>0>64|x[a+480188>>1]>64)){l=bc(v[e+212>>2]);d=Hb(x[e+216>>1]);if(d){u[e+120>>1]=d;u[e+80>>1]=800;f=Dc(((x[Vc(e+120|0,e+80|0)>>1]<<5)+50>>>0)/100|0,0)}else{f=32}d=v[e+200>>2];v[23588]=0;g=Q(155,b|0,bc(d)|0)|0;d=v[23588];v[23588]=0;V:{if((d|0)==1){break V}d=0;W:{if(!g){break W}while(1){if(x[a+480188>>1]<=d>>>0){break W}v[23588]=0;h=S(206,b|0)|0;g=v[23588];v[23588]=0;if((g|0)!=1){t[e+120|0]=h;t[e+80|0]=64;fa=((d<<5)+a|0)+480286|0,ga=w[Wb(e+120|0,e+80|0)|0],u[fa>>1]=ga;d=d+1|0;continue}break}i=P()|0;O()|0;break w}X:{Y:{d=bc(v[e+208>>2]);if(!d){break Y}v[23588]=0;g=Q(155,b|0,d|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break V}d=0;if(!g){break Y}while(1){if(x[a+480188>>1]<=d>>>0){break X}v[23588]=0;h=S(519,b|0)|0;g=v[23588];v[23588]=0;if((g|0)!=1){fa=((d<<5)+a|0)+480284|0,ga=(Xb(h,-16,16)<<3)+128|0,u[fa>>1]=ga;d=d+1|0;continue}break}i=P()|0;O()|0;break w}nh(a,1)}p=Sb(e+176|0);d=v[e+196>>2];v[23588]=0;g=Q(155,b|0,bc(d)|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break U}i=1;d=0;if(!g){break R}k=x[e+610>>1];h=v[b+8>>2];g=v[b>>2];v[23588]=0;h=W(156,g|0,h|0,Hb(k)<<1)|0;g=v[23588];v[23588]=0;if((g|0)==1){break U}if(!h){break R}g=x[e+610>>1];v[23588]=0;h=W(520,b|0,p|0,Hb(g)|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break U}if(!h){break R}fa=e,ga=Eb(v[p>>2]),v[fa+168>>2]=ga;m=Eb(v[e+180>>2]);while(1){d=v[e+168>>2];if(!Ob(d,m)){i=0;d=1;break R}g=Hb(w[d|0]|w[d+1|0]<<8);Z:{if(Hb(x[e+206>>1])>>>0<g>>>0){break Z}d=v[e+192>>2];v[23588]=0;Q(155,b|0,bc(d)+(g<<2)|0)|0;d=v[23588];v[23588]=0;_:{$:{aa:{ba:{ca:{if((d|0)==1){break ca}v[23588]=0;g=S(279,b|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break ca}v[23588]=0;g=Q(155,b|0,g|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break ca}if(!g){break Z}g=v[b+8>>2];d=v[b>>2];v[23588]=0;g=W(156,d|0,g|0,42)|0;d=v[23588];v[23588]=0;if((d|0)==1){break ca}if(!g){break Z}v[23588]=0;R(521,b|0,e+120|0);d=v[23588];v[23588]=0;da:{if((d|0)!=1){if(oc(v[o>>2],v[o+4>>2])){break da}v[23588]=0;R(522,o|0,65534);d=v[23588];v[23588]=0;if((d|0)!=1){break da}}i=P()|0;O()|0;break S}h=Hb(x[e+160>>1]);v[e+116>>2]=h;g=v[b+8>>2];d=v[b>>2];v[23588]=0;g=W(156,d|0,g|0,h|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break ba}if(!g){v[23588]=0;g=S(202,b|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break ba}wc(e+116|0,g)}wc(e+116|0,65534);h=v[o+4>>2];g=v[o>>2];d=0;v[23588]=0;n=v[e+116>>2];k=Qc(g,h);R(523,o|0,n+k|0);g=v[23588];v[23588]=0;if((g|0)==1){break $}while(1){ea:{if((d|0)==(n|0)){if(w[e+120|0]){break ea}break aa}v[23588]=0;h=S(271,b|0)|0;g=v[23588];v[23588]=0;fa:{if((g|0)!=1){g=h<<16>>16;if((g|0)<0){break fa}v[23588]=0;R(522,o|0,g+J&65535);g=v[23588];v[23588]=0;if((g|0)!=1){break fa}}i=P()|0;O()|0;break S}d=d+1|0;continue}break}Um(e+104|0,e+120|0);v[23588]=0;U(524,e+56|0,v[e+104>>2],v[e+108>>2]);d=v[23588];v[23588]=0;ga:{ha:{ia:{if((d|0)!=1){v[23588]=0;U(11,e+80|0,14,e+56|0);d=v[23588];v[23588]=0;if((d|0)==1){break ia}v[23588]=0;R(273,o|0,e+80|0);d=v[23588];v[23588]=0;if((d|0)==1){break ha}zb(e+80|0);yb(e+56|0);break aa}i=P()|0;O()|0;break S}i=P()|0;O()|0;break ga}i=P()|0;O()|0;zb(e+80|0)}yb(e+56|0);break S}i=P()|0;O()|0;break S}i=P()|0;O()|0;break S}d=bc(v[e+152>>2]);if(!d){break Z}v[23588]=0;g=Q(155,b|0,d|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){break _}}i=P()|0;O()|0;break S}if(!g){break Z}while(1){ja:{v[23588]=0;g=Q(525,b|0,e+104|0)|0;d=v[23588];v[23588]=0;ka:{la:{ma:{if((d|0)!=1){if(!g){break Z}v[23588]=0;U(190,e+56|0,b|0,w[e+107|0]);d=v[23588];v[23588]=0;if((d|0)==1){break ma}d=e+56|0;n=jc(e+80|0,d);Ab(d);d=Hb(x[e+104>>1]);g=Cl(d+k|0);u[e+56>>1]=g;if((d|0)==65535){break ja}d=v[o>>2];if(Qc(d,v[o+4>>2])>>>0<=g>>>0){break ja}na:{switch(w[e+106|0]-1|0){case 1:break ka;case 0:break la;default:break na}}Ab(n);continue}i=P()|0;O()|0;break S}i=P()|0;O()|0;break S}fa=cc(d,g),ga=65535,u[fa>>1]=ga;Ab(n);continue}v[23588]=0;h=S(271,n|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break T}v[23588]=0;g=Q(526,E|0,e+56|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break T}u[g>>1]=h;fa=cc(v[o>>2],x[e+56>>1]),ga=65534,u[fa>>1]=ga;Ab(n);continue}break}Ab(n)}Re(e+168|0);continue}}i=P()|0;O()|0;break w}i=0;break L}i=P()|0;O()|0;break S}i=P()|0;O()|0;Ab(n)}nd(p);break w}nd(p);if(d){d=f>>>(l>>>1&1)|0;break M}au(E);if(!i){break d}break K}g=Hb(x[e+868>>1]);h=w[e+871|0];q=h&64;f=w[e+872|0];z=f&32;N=(f&31)+1|0;fa=a,ga=BS(g,q>>>6|0,z>>>5|0,N),v[fa+480204>>2]=ga;fa=a,ga=Cd(w[e+873|0],1,32),v[fa+480196>>2]=ga;if(z){v[a+480216>>2]=N;v[a+480220>>2]=N<<2}f=w[e+890|0];if(f){t[e+192|0]=f;t[e+120|0]=64;fa=a,ga=w[Wb(e+192|0,e+120|0)|0]<<2,v[fa+480200>>2]=ga}v[a+480228>>2]=d;v[a+480232>>2]=d;v[a+480208>>2]=v[a+480208>>2]&-3|(h>>>4^-1)&2;oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{d=bc(v[e+572>>2]);if(!d){break ya}v[23588]=0;f=Q(155,b|0,d|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break xa}if(!f){break ya}d=v[e+576>>2];v[23588]=0;U(268,b|0,da|0,bc(d)|0);d=v[23588];v[23588]=0;if((d|0)==1){break xa}if(w[ba|0]<2){break ya}v[23588]=0;U(11,e+192|0,14,da|0);d=v[23588];v[23588]=0;za:{if((d|0)!=1){v[23588]=0;R(273,o|0,e+192|0);d=v[23588];v[23588]=0;if((d|0)==1){break za}zb(e+192|0);break ya}i=P()|0;O()|0;break w}i=P()|0;O()|0;zb(e+192|0);break w}Aa:{if(bc(v[e+544>>2])>>>0<2){break Aa}d=v[e+540>>2];v[23588]=0;f=Q(155,b|0,bc(d)|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break xa}if(!f){break Aa}d=v[e+544>>2];v[23588]=0;X(331,H|0,b|0,bc(d)-1|0,4);d=v[23588];v[23588]=0;if((d|0)==1){break xa}}d=bc(v[e+584>>2]);if(!d){break oa}v[23588]=0;f=Q(155,b|0,d|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break xa}if(!f){break oa}f=v[b+8>>2];d=v[b>>2];v[23588]=0;f=W(156,d|0,f|0,12)|0;d=v[23588];v[23588]=0;if((d|0)==1){break xa}if(!f){break oa}v[23588]=0;Q(188,b|0,6)|0;d=v[23588];v[23588]=0;if((d|0)==1){break xa}v[23588]=0;f=S(271,b|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break xa}if((f|0)!=1){break oa}v[23588]=0;g=S(279,b|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break va}if(!g){break oa}f=v[b+8>>2];d=v[b>>2];v[23588]=0;f=W(156,d|0,f|0,g|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break va}if(f){break wa}break oa}i=P()|0;O()|0;break w}k=dE(e+192|0,H);v[23588]=0;X(331,H|0,b|0,g|0,4);d=v[23588];v[23588]=0;if((d|0)==1){break qa}if(!Qe(k)){v[23588]=0;f=W(527,e+24|0,2,13)|0;d=v[23588];v[23588]=0;if((d|0)==1){break ua}v[23588]=0;U(528,e+120|0,k|0,f|0);d=v[23588];v[23588]=0;if((d|0)==1){break ta}v[23588]=0;U(529,e+40|0,e+120|0,H|0);d=v[23588];v[23588]=0;if((d|0)==1){break sa}d=e+40|0;Ac(H,d);yb(d);yb(e+120|0);yb(f)}yb(k);break oa}i=P()|0;O()|0;break w}i=P()|0;O()|0;break pa}i=P()|0;O()|0;break ra}i=P()|0;O()|0;yb(e+120|0)}yb(f);break pa}i=P()|0;O()|0}yb(k);break w}Ba:{if(I>>>0<2){break Ba}i=0;if(!bc(v[e+596>>2])){break Ba}while(1){if(x[a+480188>>1]<=i>>>0){break Ba}d=v[e+596>>2];v[23588]=0;f=Q(155,b|0,bc(d)+(i<<2)|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break x}Ca:{if(!f){break Ca}v[23588]=0;f=S(279,b|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break x}v[23588]=0;f=Q(155,b|0,f|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break x}m=0;d=0;if(!f){break Ca}while(1){Da:{g=v[b+8>>2];f=v[b>>2];v[23588]=0;g=W(156,f|0,g|0,8)|0;f=v[23588];v[23588]=0;Ea:{Fa:{Ga:{if((f|0)!=1){if(!g){break Da}v[23588]=0;R(530,b|0,e+192|0);f=v[23588];v[23588]=0;if((f|0)==1){break Ga}f=bc(v[e+192>>2]);if(!f){break Da}switch((f&536870911)-1|0){case 1:break Ea;case 0:break Fa;default:continue}}i=P()|0;O()|0;break w}i=P()|0;O()|0;break w}m=bc(v[e+196>>2]);continue}d=bc(v[e+196>>2]);continue}break}if(!m|!d){break Ca}v[23588]=0;g=Q(155,b|0,m|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break y}if(!g){break Ca}v[23588]=0;U(413,b|0,((i<<5)+a|0)+480289|0,d|0);d=v[23588];v[23588]=0;if((d|0)==1){break y}}i=i+1|0;continue}}d=x[e+608>>1];v[23588]=0;s=Hb(d);R(225,G|0,J+s&65535);d=v[23588];v[23588]=0;if((d|0)==1){break z}y=h&16;r=J&65535;g=0;Ha:{Ia:{while(1){if((g|0)==(s|0)){fa=e,ga=Fi(v[E>>2]),v[fa+120>>2]=ga;g=wf(E);while(1){d=v[e+120>>2];if(!Hg(d,g)){i=1;d=bc(v[e+528>>2]);if(!d){break L}v[23588]=0;f=Q(155,b|0,d|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break z}if(!f){break L}J=s+J|0;au(E);break K}k=qo(d);h=Se(k);Ja:{Ka:{La:{Ma:{d=x[k>>1];if(!d){j=0;break Ma}v[23588]=0;f=Q(311,o|0,d-1&65535)|0;d=v[23588];v[23588]=0;if((d|0)==1){break Ja}j=x[k>>1];if(!f){break Ma}v[23588]=0;j=Q(360,o|0,j-1&65535)|0;d=v[23588];v[23588]=0;if((d|0)==1){break Ja}break La}if(x[h>>1]==((j&65535)+1|0)){break Ka}v[23588]=0;j=Q(359,G|0,1)|0;d=v[23588];v[23588]=0;if((d|0)==1){break Ja}if((j|0)==65535){break Ka}fa=cc(v[o>>2],x[k>>1]),ga=j,u[fa>>1]=ga}d=Yb(v[G>>2],j);ze(d,Lm(Te(Ne(e+192|0,12,Au(x[h>>1])),v[d+12>>2]-1|0)));s=(s&65535)>>>0>j>>>0?s:j+1|0}Kg(e+120|0);continue}break}i=P()|0;O()|0;break w}Na:{Oa:{if(!D){break Oa}d=v[e+936>>2];v[23588]=0;f=Q(155,b|0,bc(d)+(g<<2)|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break Ia}if(!f){break Oa}v[23588]=0;f=S(279,b|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break Ia}v[23588]=0;f=Q(155,b|0,f|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break Ia}if(!f){break Oa}V=Lb(e+56|0);v[23588]=0;Y=S(174,e|0)|0;d=v[23588];v[23588]=0;Pa:{Qa:{if((d|0)!=1){if(I){break Qa}v[23588]=0;R(531,b|0,e+192|0);d=v[23588];v[23588]=0;if((d|0)==1){break Na}u[e+104>>1]=w[e+192|0];Z=w[e+193|0]+1|0;f=48;break Pa}i=P()|0;O()|0;break A}v[23588]=0;n=t[e+870|0];R(532,b|0,e+176|0);d=v[23588];v[23588]=0;Ra:{Sa:{if((d|0)!=1){k=Hb(x[e+176>>1]);u[e+104>>1]=k;Z=Hb(x[e+178>>1])+1|0;d=bc(v[e+180>>2]);if(!d){break Ra}h=v[b+8>>2];v[23588]=0;Q(155,b|0,d|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break B}v[23588]=0;R(533,b|0,e+192|0);d=v[23588];v[23588]=0;if((d|0)==1){break B}d=v[e+196>>2];v[23588]=0;f=Q(155,b|0,bc(d)|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break B}if(!f){break Sa}d=v[e+200>>2];v[23588]=0;U(268,b|0,V|0,bc(d)|0);d=v[23588];v[23588]=0;if((d|0)!=1){break Sa}break B}break B}d=bc(v[e+208>>2]);Ta:{if(!d){break Ta}v[23588]=0;f=Q(155,b|0,d|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break B}if(!f){break Ta}v[23588]=0;f=S(279,b|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break B}v[23588]=0;f=Q(155,b|0,f|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break B}if(!f){break Ta}v[23588]=0;U(190,e+80|0,b|0,B(k,Z)|0);d=v[23588];v[23588]=0;if((d|0)==1){break B}f=e+80|0;d=jc(e+120|0,f);gd(Y,d);Ab(d);Ab(f)}v[23588]=0;Q(155,b|0,h|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break B}}f=n+(I>>>0<3?48:24)|0}v[23588]=0;k=g+r|0;h=W(226,G|0,k&65535,Z|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break B}Ua:{if(!h){break Ua}d=v[G>>2];v[23588]=0;A=Yb(d,k);R(281,A|0,V|0);d=v[23588];v[23588]=0;if((d|0)==1){break Ha}Ef(e+104|0,x[a+480188>>1]);C=0;p=x[e+104>>1];Va:while(1){if((C|0)==(Z|0)){break Ua}i=0;d=id(v[A>>2],v[v[A+48>>2]+12>>2],C,0);while(1){if((i&65535)>>>0>=p>>>0){C=C+1|0;continue Va}Wa:{if(!I){v[23588]=0;R(534,e+192|0,b|0);h=v[23588];v[23588]=0;if((h|0)!=1){m=w[e+192|0];n=e+192|0;h=Nc(n);t[d+1|0]=m>>>3&16|w[h|0]>>>4|m>>>1&32;k=w[h|0];fa=d,ga=w[Se(n)|0],t[fa+5|0]=ga;h=m&63;j=h?h+f|0:0;m=k&15;break Wa}break B}v[23588]=0;R(349,e+192|0,b|0);h=v[23588];v[23588]=0;Xa:{Ya:{if((h|0)!=1){h=e+192|0;l=Nc(h);m=Se(h);n=Li(h);v[23588]=0;k=S(206,Y|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break B}t[d+4|0]=k;k=w[e+192|0];h=k&127;if(!h){break Ya}j=f+h|0;break Xa}break B}j=0;if((k|0)!=128){break Xa}t[d|0]=254}t[d+1|0]=w[l|0]&63;m=w[m|0];t[d+5|0]=w[n|0]}if(j-1>>>0<=119){t[d|0]=j}F=(j|0)>84&ca|F;n=(q|0)!=0;k=(z|0)!=0;h=(y|0)!=0;l=jb-16|0;jb=l;t[d+3|0]=0;Za:{_a:{$a:{ab:{bb:{cb:{db:{eb:{fb:{gb:{hb:{ib:{jb:{kb:{lb:{mb:{nb:{ob:{pb:{qb:{rb:{sb:{tb:{ub:{m=m&255;switch(m-4|0){case 4:case 10:break Za;case 42:break $a;case 37:break ab;case 28:break bb;case 27:break cb;case 26:break db;case 25:break eb;case 24:break fb;case 23:break gb;case 22:break hb;case 21:break ib;case 20:break jb;case 18:break kb;case 17:break lb;case 16:break mb;case 14:break nb;case 13:break ob;case 12:break pb;case 11:break qb;case 9:break rb;case 8:break sb;case 5:break tb;case 0:break ub;default:break _a}}t[d+3|0]=5;k=w[d+5|0];t[l+15|0]=k>>>3;t[l+14|0]=15;h=w[Wb(l+15|0,l+14|0)|0];t[l+13|0]=k<<1&30;t[l+12|0]=15;fa=d,ga=w[Wb(l+13|0,l+12|0)|0]|h<<4,t[fa+5|0]=ga;break Za}if((w[d+5|0]-1&255)>>>0>19){break Za}t[d+3|0]=16;break Za}t[d+3|0]=13;k=w[d+5|0];vb:{if(!h){if(k>>>0>152){break vb}t[d+5|0]=B((k&240)>>>4|0,10)+(k&15);break Za}t[d+5|0]=(k&127)+1>>>1;break Za}t[d+3|0]=0;break Za}t[d+3|0]=11;break Za}h=w[d+5|0];if(!h){t[d+3|0]=14;break Za}if(h>>>0>240){break Za}t[d+3|0]=17;if(h>>>0<=2){t[d+5|0]=112;break Za}fa=d,ga=sk(+(BS(h,n,k,N)>>>0)/1e4),t[fa+5|0]=ga;break Za}t[d+3|0]=31;t[d+5|0]=w[d+5|0]|128;break Za}t[d+3|0]=19;t[l+11|0]=15;fa=d,ga=w[Wb(d+5|0,l+11|0)|0]|16,t[fa+5|0]=ga;break Za}t[d+3|0]=19;t[l+10|0]=15;fa=d,ga=w[Wb(d+5|0,l+10|0)|0]|32,t[fa+5|0]=ga;break Za}t[d+3|0]=5;h=w[d+5|0];t[l+9|0]=(h>>>4|0)+1;t[l+8|0]=15;fa=d,ga=h&15|w[Wb(l+9|0,l+8|0)|0]<<4,t[fa+5|0]=ga;break Za}t[d+3|0]=19;t[d+5|0]=w[d+5|0]&15|80;break Za}t[d+3|0]=19;t[l+7|0]=15;fa=d,ga=w[Wb(d+5|0,l+7|0)|0]|96,t[fa+5|0]=ga;break Za}t[d+3|0]=19;t[l+6|0]=15;fa=d,ga=w[Wb(d+5|0,l+6|0)|0]|192,t[fa+5|0]=ga;break Za}t[d+3|0]=10;break Za}t[d+3|0]=19;t[l+5|0]=15;fa=d,ga=w[Wb(d+5|0,l+5|0)|0]|160,t[fa+5|0]=ga;break Za}t[d+3|0]=19;t[l+4|0]=15;fa=d,ga=w[Wb(d+5|0,l+4|0)|0]|176,t[fa+5|0]=ga;break Za}h=(w[d+5|0]<<24)-16777216>>24;if((h|0)<0){break Za}t[d+5|0]=h;t[d+3|0]=31;break Za}t[d+3|0]=14;break Za}t[d+3|0]=19;t[l+3|0]=15;fa=d,ga=w[Wb(d+5|0,l+3|0)|0]|224,t[fa+5|0]=ga;break Za}h=w[d+5|0];if(h&240){t[d+3|0]=19;t[d+5|0]=h>>>4|208;break Za}if(!(h&15)){break Za}t[d+3|0]=19;t[d+5|0]=h|144;break Za}if(w[d+5|0]|w[d+4|0]){break Za}if(!_c(w[d|0])){break Za}t[d+5|0]=159;t[d+3|0]=20;break Za}h=w[d+4|0];if(!h){break Za}t[d+3|0]=44;fa=d,ga=Ll(Dc(((w[d+5|0]<<8&65280)>>>0)/(h>>>0)|0,0)),t[fa+5|0]=ga;break Za}h=w[d+5|0];if((h+16&255)>>>0>32){break Za}t[d+3|0]=9;fa=d,ga=sg(((h^128)<<3)-896|0),t[fa+5|0]=ga;break Za}if(m>>>0>15){break Za}Of(d,m,w[d+5|0])}jb=l+16|0;d=d+6|0;i=i+1|0;continue}}}Ab(Y);yb(V)}g=g+1|0;continue}break}break B}i=P()|0;O()|0;break w}break B}au(E);d=0;if(!i){break c}}Fj($,0);d=1;wb:{if(F&1){break wb}while(1){b=d&65535;if(b>>>0>x[a+480192>>1]){u[a+480192>>1]=0;break wb}c=((b<<2)+a|0)+900380|0;b=v[c>>2];if(b){Mb(cu(b))}v[c>>2]=0;d=d+1|0;continue}}xb:{if(!ea){break xb}v[23588]=0;c=Q(1,e+192|0,16335)|0;b=v[23588];v[23588]=0;yb:{if((b|0)!=1){b=v[a+1298464>>2];v[23588]=0;U(376,b|0,2,c|0);b=v[23588];v[23588]=0;if((b|0)==1){break yb}zb(c);break xb}i=P()|0;O()|0;break f}i=P()|0;O()|0;zb(c);break f}j=21619;zb:{Ab:{switch(aa-48|0){case 0:j=x[a+480188>>1]>4?17230:17216;break zb;case 1:j=17198;break zb;case 2:j=17180;break zb;case 3:break Ab;default:break zb}}j=17153}v[23588]=0;R(535,e+80|0,16768);b=v[23588];v[23588]=0;Bb:{Cb:{Db:{if((b|0)!=1){v[23588]=0;U(536,e+120|0,e+80|0,e+919|0);b=v[23588];v[23588]=0;if((b|0)==1){break Db}b=e+120|0;Ib(a+1298344|0,b);zb(b);ac(e+80|0);v[23588]=0;c=Q(1,b|0,12558)|0;b=v[23588];v[23588]=0;if((b|0)==1){break Cb}Ib(a+1298356|0,c);zb(c);v[23588]=0;R(136,a+1298368|0,j|0);b=v[23588];v[23588]=0;if((b|0)==1){break Bb}v[a+1298404>>2]=14;d=1;break c}i=P()|0;O()|0;break f}i=P()|0;O()|0;ac(e+80|0);break f}i=P()|0;O()|0;break f}i=P()|0;O()|0;break f}c=c+1|0;continue}}i=P()|0;O()|0;break f}i=P()|0;O()|0;Ab(Y)}yb(V);break w}i=P()|0;O()|0;break w}i=P()|0;O()|0;break w}i=P()|0;O()|0}au(E);break f}i=P()|0;O()|0;break f}i=P()|0;O()|0;break f}i=P()|0;O()|0;break f}A=1;if((d|0)!=7){break m}d=z+108|0;f=dA(d);while(1){if((d|0)!=(f|0)){fa=d,ga=Bl(w[d|0]-24|0),t[fa|0]=ga;d=d+1|0;continue}break}g=0}F=1;break l}g=0;Eb:{if(r|(q|0)<0){break Eb}n=z+108|0;j=7;Fb:while(1){if((j|0)==10){break Eb}k=B(j,12);h=B(j,-12)+72|0;d=0;while(1)if((d|0)==12){j=j+1|0;continue Fb}else{f=Kb(n,d+k|0);t[f|0]=h+w[f|0];d=d+1|0;continue}}}}v[23588]=0;R(537,_|0,e+192|0);d=v[23588];v[23588]=0;if((d|0)!=1){Gb:{d=w[e+196|0];if((d-1&255)>>>0<=15){t[z+31|0]=d;F=1}d=w[e+197|0];if((d<<24)-16777216>>24>=0){t[z+30|0]=d}d=0;Hb:{while(1){if((d|0)==(A|0)){if(!p){break j}if((q|0)>=0){break Hb}break j}v[23588]=0;h=B(d+y|0,104)+a|0;R(277,h+484380|0,8);f=v[23588];v[23588]=0;if((f|0)!=1){t[e+120|0]=w[e+198|0];t[e+56|0]=64;fa=h+484410|0,ga=w[Wb(e+120|0,e+56|0)|0]<<2,u[fa>>1]=ga;t[h+484416|0]=w[e+199|0];d=d+1|0;continue}break}break k}k=Zc(e+120|0,8,1,1,0);h=Hb(x[e+194>>1]);i=Hb(x[e+192>>1]);d=v[D>>2];v[23588]=0;j=S(160,d|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){d=pe(u[e+84>>1]);if(d&16){wd(k,16);j=j>>>1|0}if(d&32){Jo(k,3);j=j>>>1|0}if(d&64){cg(k,2)}j=g?(j>>>0)/((-1<<A^-1)>>>0)|0:j;m=h+i|0;d=0;while(1){if((d|0)==(A|0)){break j}g=B(d+y|0,104)+a|0;f=g+484380|0;v[f>>2]=j;v[23588]=0;W(219,k|0,f|0,D|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break Gb}i=i<<1;m=m<<1;if(h>>>0>=2){v[g+484388>>2]=m;v[g+484384>>2]=i;f=g+484414|0;u[f>>1]=x[f>>1]|2}d=d+1|0;j=j<<1;continue}}}}}i=P()|0;O()|0;Ab(D);break f}Ab(D);C=C+1|0;s=s+A|0;j=x[a+480192>>1];continue}}i=P()|0;O()|0;break e}i=P()|0;O()|0;break e}i=P()|0;O()|0}vc(M)}Ab(_);T(i|0);L()}d=0}vc(M)}Ab(_)}jb=e+976|0;return d|0}function bfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=C(0),k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,A=0,D=C(0),E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,V=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=C(0),ga=0,ha=0,ia=0,ka=0,la=0,ma=0;e=jb-688|0;jb=e;yc(b);a:{b:{c:{if(!ci(b,e+680|0)){break c}if(!AQ(e+680|0)){break c}if((Bo(b)|0)>=0){break c}if(!c){d=1;break c}Ad(a,16777216);d=a+480208|0;v[d>>2]=v[d>>2]|1681e4;vq(e+288|0,32);h=v[e+300>>2];d=a+1074320|0;v[d>>2]=v[e+296>>2];v[d+4>>2]=h;d=v[e+292>>2];v[a+1074312>>2]=v[e+288>>2];v[a+1074316>>2]=d;Zf(a+1074312|0,38);p=Sb(e+664|0);q=Sb(e+648|0);A=Sb(e+632|0);l=Sb(e+616|0);yg(b,4);i=a+480190|0;J=c&1;I=a+1298332|0;r=2500;H=!(c&2);F=a+1298464|0;d:{e:{f:{while(1){c=v[b+8>>2];d=v[b>>2];v[23588]=0;c=W(156,d|0,c|0,4)|0;d=v[23588];v[23588]=0;g:{h:{i:{j:{k:{l:{m:{if((d|0)!=1){n:{if(c){v[23588]=0;c=S(682,b|0)|0;d=v[23588];v[23588]=0;o:{if((d|0)==1){break o}n=4;d=0;p:{q:{r:{switch(c+21|0){case 20:v[23588]=0;c=S(279,b|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){d=c&65535;if(x[a+480188>>1]|d-1>>>0>126){continue}u[a+480188>>1]=c;la=a,ma=Xb(512/(d>>>0)|0,16,128),v[la+480228>>2]=ma;continue}c=P()|0;O()|0;break a;case 19:v[23588]=0;M=S(279,b|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break o}if(M>>>0<=1024){continue}break m;case 16:v[23588]=0;c=S(279,b|0)|0;h=v[23588];v[23588]=0;if((h|0)!=1){if((c&65535)==4){continue}break m}c=P()|0;O()|0;break a;case 15:v[23588]=0;c=S(279,b|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){v[e+288>>2]=c;v[e+184>>2]=800;la=a,ma=Pe(+y[Jb(e+288|0,e+184|0)>>2]*1.24*1e4),v[la+480204>>2]=ma;continue}c=P()|0;O()|0;break a;case 31:v[23588]=0;c=S(279,b|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break o}_=1;r=Cd(c,0,1e4);continue;case 32:case 33:v[23588]=0;c=S(279,b|0)|0;d=v[23588];v[23588]=0;s:{t:{if((d|0)!=1){_=1;if(!c){continue}v[23588]=0;d=Q(1,e+600|0,12467)|0;c=v[23588];v[23588]=0;if((c|0)==1){break t}c=v[F>>2];v[23588]=0;U(376,c|0,2,d|0);c=v[23588];v[23588]=0;if((c|0)==1){break s}zb(d);continue}c=P()|0;O()|0;break a}c=P()|0;O()|0;break a}c=P()|0;O()|0;zb(d);break a;case 14:v[23588]=0;Q(188,b|0,4)|0;c=v[23588];v[23588]=0;if((c|0)==1){break o}g=!x[i>>1]|g;continue;case 11:if(!J){break q}if(!oc(v[p>>2],v[p+4>>2])){break q}v[23588]=0;R(683,e+288|0,b|0);c=v[23588];v[23588]=0;if((c|0)!=1){if(v[p>>2]){Kc(p);c=v[p>>2];ko(p);Mb(c);la=Fb(p),ma=0,v[la>>2]=ma;v[p>>2]=0;v[p+4>>2]=0}c=e+288|0;v[p>>2]=v[c>>2];v[p+4>>2]=v[c+4>>2];d=Fb(c);la=Fb(p),ma=v[d>>2],v[la>>2]=ma;v[d>>2]=0;v[c>>2]=0;v[c+4>>2]=0;Di(c);continue}c=P()|0;O()|0;break a;case 3:case 4:case 10:h=zh(v[l>>2],v[l+4>>2]);d=x[i>>1];if(h>>>0<=d>>>0){continue}if((g|H)&1){break q}if(!Xh(d)){break q}d=d+1|0;u[i>>1]=d;s=Sb(e+584|0);v[23588]=0;n=S(174,e+560|0)|0;g=v[23588];v[23588]=0;u:{v:{w:{if((g|0)!=1){if((c|0)==-17){break w}if((c|0)!=-11){break v}v[23588]=0;c=S(279,b|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break u}v[23588]=0;U(190,e+184|0,b|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break u}c=e+184|0;g=jc(e+288|0,c);gd(n,g);Ab(g);break g}c=P()|0;O()|0;break d}v[23588]=0;R(684,e+288|0,b|0);c=v[23588];v[23588]=0;x:{if((c|0)!=1){c=e+288|0;g=Km(s,c);hc(c);re(e+528|0,v[g>>2],v[e+588>>2]);c=ee(e+520|0);v[23588]=0;g=v[c+4>>2];v[e+16>>2]=v[c>>2];v[e+20>>2]=g;c=Eg(328,e+536|0,v[e+528>>2],v[e+532>>2],e+16|0);g=v[23588];v[23588]=0;if((g|0)==1){break x}gd(n,c);break g}c=P()|0;O()|0;break e}c=P()|0;O()|0;break e}v[23588]=0;R(685,e+288|0,b|0);c=v[23588];v[23588]=0;y:{if((c|0)!=1){c=e+288|0;g=Km(s,c);hc(c);re(e+488|0,v[g>>2],v[e+588>>2]);c=ee(e+480|0);v[23588]=0;g=v[c+4>>2];v[e+8>>2]=v[c>>2];v[e+12>>2]=g;c=Eg(328,e+496|0,v[e+488>>2],v[e+492>>2],e+8|0);g=v[23588];v[23588]=0;if((g|0)==1){break y}gd(n,c);break g}c=P()|0;O()|0;break e}c=P()|0;O()|0;break e}c=P()|0;O()|0;break e;case 9:c=x[i>>1];if(!Xh(c)){continue}u[i>>1]=c+1;continue;case 8:if(!J){break q}if(!oc(v[A>>2],v[A+4>>2])){break q}v[23588]=0;R(686,e+288|0,b|0);c=v[23588];v[23588]=0;if((c|0)!=1){c=e+288|0;zQ(A,c);vc(c);continue}c=P()|0;O()|0;break a;case 7:if(!oc(v[l>>2],v[l+4>>2])){break q}v[23588]=0;R(687,e+288|0,b|0);c=v[23588];v[23588]=0;if((c|0)!=1){if(v[l>>2]){Kc(l);c=v[l>>2];Sz(l);Mb(c);la=Fb(l),ma=0,v[la>>2]=ma;v[l>>2]=0;v[l+4>>2]=0}c=e+288|0;v[l>>2]=v[c>>2];v[l+4>>2]=v[c+4>>2];d=Fb(c);la=Fb(l),ma=v[d>>2],v[la>>2]=ma;v[d>>2]=0;v[c>>2]=0;v[c+4>>2]=0;Ot(c);continue}c=P()|0;O()|0;break a;case 6:if(!J){break q}if(!oc(v[q>>2],v[q+4>>2])){break q}v[23588]=0;R(688,e+288|0,b|0);c=v[23588];v[23588]=0;if((c|0)!=1){if(v[q>>2]){Kc(q);c=v[q>>2];Mt(q);Mb(c);la=Fb(q),ma=0,v[la>>2]=ma;v[q>>2]=0;v[q+4>>2]=0}c=e+288|0;v[q>>2]=v[c>>2];v[q+4>>2]=v[c+4>>2];d=Fb(c);la=Fb(q),ma=v[d>>2],v[la>>2]=ma;v[d>>2]=0;v[c>>2]=0;v[c+4>>2]=0;Bm(c);continue}c=P()|0;O()|0;break a;case 17:case 18:break p;case 0:case 1:case 2:break q;case 5:break r;default:break m}}v[23588]=0;R(689,e+288|0,b|0);c=v[23588];v[23588]=0;if((c|0)==1){break n}z:{c=v[e+288>>2];d=v[e+292>>2];if(oc(c,d)){break z}v[23588]=0;X(337,I|0,c|0,ed(c,d)|0,1);c=v[23588];v[23588]=0;if((c|0)!=1){break z}c=P()|0;O()|0;hc(e+288|0);break a}hc(e+288|0);continue}v[23588]=0;n=S(279,b|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break o}}v[23588]=0;Q(188,b|0,n|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){continue}}c=P()|0;O()|0;break a}d=0;if(!x[a+480188>>1]|!M){break m}b=v[l>>2];c=v[l+4>>2];if(oc(b,c)){break m}if(J){if(oc(v[p>>2],v[p+4>>2])){break m}if(oc(v[A>>2],v[A+4>>2])){break m}if(oc(v[q>>2],v[q+4>>2])){break m}}b=zh(b,c);if(b>>>0>=256){v[23588]=0;R(690,l|0,255);b=v[23588];v[23588]=0;if((b|0)==1){break b}b=zh(v[l>>2],v[l+4>>2])}u[a+480192>>1]=b;m=a+480190|0;n=a+480192|0;la=m,ma=x[ke(i,n)>>1],u[la>>1]=ma;if(g&1){v[23588]=0;b=Q(1,e+584|0,16424)|0;c=v[23588];v[23588]=0;if((c|0)==1){break h}c=v[a+1298464>>2];v[23588]=0;U(376,c|0,2,b|0);c=v[23588];v[23588]=0;if((c|0)==1){break i}zb(b)}g=0;A:while(1){if((g|0)!=2){d=1;while(1){f=d&65535;if(f>>>0>x[n>>1]){g=g+1|0;continue A}B:{h=zm(v[l>>2],f-1|0);if(!w[h|0]|t[h+128|0]<0){break B}if((Kt(h)|0)==((g|0)!=1|0)){break B}C:{D:{E:{c=0;F:{if(!Kt(h)){break F}if(Hb(w[h+6|0]|w[h+7|0]<<8)){break F}if(Hb(w[h+14|0]|w[h+15|0]<<8)>>>0>20){break F}c=(Hb(w[h+18|0]|w[h+19|0]<<8)|0)==4}G:{H:{if(c){c=w[h+23|0];b=w[h+140|0];v[23588]=0;b=ja(691,h|0,a|0,(b&2)>>>1|0,(B(f,104)+a|0)+484380|0,r&65535)|0;k=v[23588];v[23588]=0;I:{J:{if((k|0)!=1){if(!b){break I}v[23588]=0;b=Q(55,e+416|0,10676)|0;k=v[23588];v[23588]=0;if((k|0)==1){break J}Cc(((f<<5)+a|0)+946304|0,b);yb(b);k=v[l>>2];b=d;if(zh(k,v[l+4>>2])>>>0<=c>>>0){break G}la=h,ma=w[h+143|0]+w[zm(k,c)+143|0]|0,t[la+143|0]=ma;break H}c=P()|0;O()|0;break a}c=P()|0;O()|0;break a}b=c+1|0;break G}c=0;K:{if(!Kt(h)){break K}if((Hb(w[h+6|0]|w[h+7|0]<<8)|0)!=1){break K}if((Hb(w[h+14|0]|w[h+15|0]<<8)|0)!=2){break K}c=(Hb(w[h+18|0]|w[h+19|0]<<8)|0)==10}b=d;if(!c){break G}rQ(e+288|0,h);b=Hb(x[e+308>>1]);if(b>>>0>=x[i>>1]){break H}v[23588]=0;c=S(681,e+184|0)|0;k=v[23588];v[23588]=0;if((k|0)==1){break E}k=x[e+324>>1];o=x[m>>1];v[23588]=0;s=B(b,104);b=a+484380|0;k=Hb(k);b=fa(692,e+288|0,(s+b|0)+104|0,(k>>>0<o>>>0?(b+B(k,104)|0)+104|0:c)|0,b+B(f,104)|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break D}if(!b){break H}v[23588]=0;b=Q(55,e+168|0,11173)|0;c=v[23588];v[23588]=0;if((c|0)==1){break C}Cc(((f<<5)+a|0)+946304|0,b);yb(b);t[h+139|0]=w[h+139|0]+12}b=d}v[23588]=0;b=b&65535;c=W(251,a|0,f|0,b|0)|0;f=v[23588];v[23588]=0;if((f|0)!=1){if(!c|b>>>0>x[i>>1]){break B}v[23588]=0;X(693,h|0,c|0,(B(b,104)+a|0)+484380|0,a|0);b=v[23588];v[23588]=0;if((b|0)!=1){break B}}c=P()|0;O()|0;break a}c=P()|0;O()|0;break a}c=P()|0;O()|0;break a}c=P()|0;O()|0;break a}d=d+1|0;continue}}break}I=Xf(e+152|0);s=Xf(e+136|0);b=uc(v[A>>2],v[A+4>>2]);$=B(x[a+480188>>1],M);aa=Cl((b>>>0)/($>>>0)|0);v[23588]=0;V=a+484344|0;R(225,V|0,aa|0);b=v[23588];v[23588]=0;if((b|0)==1){break k}ba=a+484376|0;Kc(Vb(v[a+484360>>2],w[ba|0]));b=x[a+480188>>1];v[23588]=0;F=Q(694,e+120|0,b|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break l}la=e,ma=Eb(v[q>>2]),v[la+64>>2]=ma;ga=a+902204|0;ha=Eb(v[q+4>>2]);ia=a+480208|0;while(1){L:{M:{N:{k=v[e+64>>2];if(!Ob(k,ha)){break N}b=pe((w[k+6|0]|w[k+7|0]<<8)<<16>>16);if((b|0)==1){break L}if((b&65535)==65535){break N}g=Hb(w[k|0]|w[k+1|0]<<8);b=v[p>>2];h=v[p+4>>2];c=qg(b,h);if(g>>>0>=c>>>0){break L}d=Hb(w[k+2|0]|w[k+3|0]<<8);if(d>>>0>c>>>0|!d|g>>>0>c-d>>>0){break L}c=b+(qg(b,h)<<5)|0;v[e+288>>2]=b;v[e+292>>2]=c-b>>5;b=v[e+288>>2];gc(e+96|0,b+(Hb(w[k|0]|w[k+1|0]<<8)<<5)|0,Hb(w[k+2|0]|w[k+3|0]<<8));O:{H=Vb(v[a+484360>>2],w[ba|0]);if(oc(v[H>>2],v[H+4>>2])){break O}v[23588]=0;R(522,H|0,65534);b=v[23588];v[23588]=0;if((b|0)!=1){break O}break M}b=v[e+96>>2];ka=ye(b,v[e+100>>2]);while(1){if((b|0)==(ka|0)){break L}c=pe(pe((w[k+8|0]|w[k+9|0]<<8)<<16>>16)+pe((w[b+16|0]|w[b+17|0]<<8)<<16>>16)<<16>>16);t[b+16|0]=c;t[b+17|0]=c>>>8;h=b;b=Sd(I);while(1){P:{c=0;if(!b){break P}d=b+14|0;if(!Gt(h,d)){c=1;if(!Gt(d,h)){break P}b=b+4|0}b=v[b>>2];continue}break}Q:{R:{S:{if(c){v[23588]=0;b=Q(695,I|0,h|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break M}E=x[b>>1];break S}E=0;if(!J){break S}b=w[h+12|0]|w[h+13|0]<<8;v[23588]=0;E=Q(359,V|0,Hb(b)|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break M}if((E|0)==65535){break L}v[23588]=0;b=Q(695,I|0,h|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break M}u[b>>1]=E;if(Hb(w[h+8|0]|w[h+9|0]<<8)>>>0>=aa>>>0){break R}if(Hb(w[h+10|0]|w[h+11|0]<<8)>>>0>=M>>>0){break R}m=Hb(w[h+14|0]|w[h+15|0]<<8);c=ym(Eb(v[A>>2]),B(Hb(w[h+8|0]|w[h+9|0]<<8),$));b=x[a+480188>>1];la=e,ma=ym(c,B(b,Hb(w[h+10|0]|w[h+11|0]<<8))),v[la+48>>2]=ma;N=0;v[e+32>>2]=0;o=tg(e+80|0);T:while(1){U:{d=Hb(w[h+12|0]|w[h+13|0]<<8);c=Yb(v[V>>2],E);if(d>>>0<=N>>>0){break U}n=0;Z=id(v[c>>2],v[v[c+48>>2]+12>>2],N,0);c=0;while(1){if((b&65535)>>>0<=n>>>0){N=N+1|0;continue T}b=Eb(v[A+4>>2]);d=v[e+48>>2];i=Ob(d,b)?d:e+32|0;b=Eb(v[A+4>>2]);if(Ob(v[e+48>>2],b)){xQ(e+48|0)}d=B(n,6)+Z|0;g=w[i+1|0];b=(g>>>0<85?g+25|0:-1)<<24>>24;r=0;f=v[l>>2];K=zh(f,v[l+4>>2]);G=w[i+3|0];V:{if(K>>>0<=G>>>0){break V}r=G+1|0;if(t[zm(f,G)+142|0]&1|(b|0)<0){break V}b=Bl(pe((w[h+16|0]|w[h+17|0]<<8)<<16>>16)+b<<24>>24)}W:{if(!w[d|0]|!(w[i+2|0]?1:G|(w[i|0]|(g|0)!=255))){break W}g=w[d+1|0];if(!g|g>>>0>K>>>0){break W}if(w[zm(f,g-1|0)+132|0]!=2){break W}io(d)}f=Nt(v[F>>2],n);X:{Y:{if(!(c&1)){g=w[i|0];break Y}c=w[o|0]|w[o+1|0]<<8|(w[o+2|0]<<16|w[o+3|0]<<24);t[d|0]=c;t[d+1|0]=c>>>8;t[d+2|0]=c>>>16;t[d+3|0]=c>>>24;c=w[o+4|0]|w[o+5|0]<<8;t[d+4|0]=c;t[d+5|0]=c>>>8;Z:{if(w[d+3|0]){break Z}g=w[f+21|0];c=w[Nt(v[F>>2],n-1|0)+21|0];if((g|0)==(c|0)){break Z}t[d+3|0]=21;t[f+21|0]=c;t[d+5|0]=c}c=0;g=w[i|0];if(!(g-24>>>0<2|(g|0)==9|!g&(w[i+2|0]+7&255)>>>0<2)){break X}}_:{$:{aa:{ba:{ca:{da:{switch(g|0){case 5:c=w[f+17|0];break ca;case 0:ea:{c=w[i+2|0];if(c>>>0>=201){g=0;fa:{switch(c-242|0){case 11:t[d+4|0]=1;t[d+2|0]=14;t[f+16|0]=0;break $;case 9:if(!w[d|0]){t[d|0]=w[f+17|0]}t[d+4|0]=1;t[d+2|0]=15;break $;case 8:if((m&255)>>>0<2){break $}m=m-1|0;break aa;case 7:if((m&255)==255){m=255;break $}m=m+1|0;break aa;case 6:t[f+17|0]=b;if(w[f+18|0]!=(r&255)){break $}t[d|0]=b;t[d+5|0]=255;t[d+3|0]=4;u[f+32>>1]=0;v[f+8>>2]=0;break $;case 5:t[d+5|0]=242;t[d+3|0]=2;break $;case 4:t[d+5|0]=242;t[d+3|0]=3;break $;case 3:t[d+5|0]=244;t[d+3|0]=2;break $;case 2:t[d+5|0]=244;t[d+3|0]=3;break $;case 1:t[d+5|0]=248;t[d+3|0]=2;break $;case 12:break ea;case 0:break fa;default:break $}}t[d+5|0]=248;t[d+3|0]=3;break $}g=0;K=t[i+1|0];if((K|0)<0&c>>>0>99){break $}if((K|0)>=0){t[f+17|0]=b;t[d|0]=b;t[f+18|0]=r;t[d+1|0]=r;u[f+32>>1]=0;v[f+8>>2]=0;c=w[i+2|0]}b=c&255;if(!b){break $}la=f,ma=sk(+(b>>>0)*.64),t[la+19|0]=ma;j=z[f>>2];v[f>>2]=0;g=j!=C(0);break $}t[d+4|0]=0;t[d+2|0]=14;t[f+16|0]=1;break $;case 1:v[f+4>>2]=0;z[f>>2]=C(w[i+2|0])*C(.0333000011742115);break _;case 2:v[f+4>>2]=0;z[f>>2]=C(w[i+2|0])*C(-.0333000011742115);break _;case 12:t[e+288|0]=15;t[e+116|0]=w[i+3|0]>>>3;b=w[Wb(e+288|0,e+116|0)|0];t[e+288|0]=15;t[e+116|0]=w[i+2|0]>>>3;la=f,ma=w[Wb(e+288|0,e+116|0)|0]|b<<4,t[la+24|0]=ma;break _;case 3:v[f+12>>2]=0;b=w[i+2|0];u[f+32>>1]=0;z[f+8>>2]=C(b>>>0)*C(.0333000011742115);break _;case 4:v[f+12>>2]=0;b=w[i+2|0];u[f+32>>1]=0;z[f+8>>2]=C(b>>>0)*C(-.0333000011742115);break _;case 15:if(!w[i+2|0]|(b|0)<0){break _}g=b-w[f+17|0]<<5;c=g>>31;c=(c^g)-c|0;v[e+288>>2]=c;t[f+17|0]=b;v[f+8>>2]=0;t[d|0]=b;t[d+3|0]=4;b=sg((c>>>0)/(w[i+2|0]<<1>>>0)|0);t[d+5|0]=b;t[f+27|0]=b;v[e+116>>2]=B(b,(m&255)-1|0);la=f,ma=c-v[sd(e+288|0,e+116|0)>>2]|0,u[la+32>>1]=ma;break _;case 13:t[e+288|0]=15;t[e+116|0]=w[i+3|0]>>>3;b=w[Wb(e+288|0,e+116|0)|0];t[e+288|0]=15;t[e+116|0]=w[i+2|0];la=f,ma=w[Wb(e+288|0,e+116|0)|0]|b<<4,t[la+23|0]=ma;break _;case 18:b=w[i+2|0]+w[f+17|0]&255;b=b?b>>>0<120?b:120:1;t[f+17|0]=b;t[d|0]=b;t[d+5|0]=255;t[d+3|0]=4;break ba;case 23:case 24:case 25:b=Sd(s);while(1){ga:{c=0;if(!b){break ga}g=b+13|0;if(!It(i,g)){c=1;if(!It(g,i)){break ga}b=b+4|0}b=v[b>>2];continue}break};if(c){t[d+3|0]=31;v[23588]=0;b=Q(696,s|0,i|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break M}t[d+5|0]=w[b|0];break _}b=v[Fb(s)>>2];if(b>>>0>127){break _}v[e+112>>2]=w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24);c=v[ia>>2];v[23588]=0;v[e+28>>2]=v[e+112>>2];c=W(697,e+28|0,ye(ga,b&255)|0,c|0)|0;g=v[23588];v[23588]=0;ha:{if((g|0)==1){break ha}if(!c){break _}t[d+3|0]=31;v[23588]=0;c=Q(696,s|0,i|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break ha}b=b|-128;t[c|0]=b;t[d+5|0]=b;ca=(w[i|0]&254)==24|ca;break _}break M;case 16:if(!w[i+2|0]){break _}t[d+3|0]=15;v[e+288>>2]=15;v[e+116>>2]=w[i+3|0]+1;la=d,ma=v[sd(e+288|0,e+116|0)>>2],t[la+5|0]=ma;u[f+30>>1]=B(w[i+2|0],w[i+3|0]+1|0);break _;case 9:t[d+3|0]=16;b=w[i+2|0];m=b?b:4;t[d+5|0]=m;break _;case 19:ia:{b=w[i+1|0];switch(b|0){case 0:case 4:break ia;default:break _}}g=128;g=(b|0)==4?w[i+3|0]:g;t[e+111|0]=g;t[e+288|0]=w[i+2|0];t[e+116|0]=100;b=e+288|0;r=e+116|0;c=w[Wb(b,r)|0];v[e+288>>2]=128;v[e+116>>2]=256-(g&255);g=v[sd(b,r)>>2];t[e+288|0]=128;b=w[Wb(b,e+111|0)|0];g=(B(c,g)|0)/128|0;r=g&255;if((r|0)!=w[f+20|0]){t[f+20|0]=g;t[d+3|0]=21;g=Dc(((B(r,w[f+19|0])+50&65535)>>>0)/100|0,0);t[f+21|0]=g;t[d+5|0]=g}if(w[i+1|0]!=4|(x[a+480188>>1]-1|0)<=(n|0)){break _}g=n+1|0;i=Nt(v[F>>2],g);b=B(b,c)>>>7|0;if(w[i+20|0]==(b&255)){break _}t[i+20|0]=b;b=B(g,6)+Z|0;t[b+3|0]=21;c=Dc(((B(w[f+20|0],w[f+19|0])+50&65535)>>>0)/100|0,0);t[f+21|0]=c;t[b+5|0]=c;break _;case 10:case 11:case 17:case 20:t[d+3|0]=0;break _;case 7:b=w[i+2|0];t[f+25|0]=0;t[f+26|0]=0;t[f+22|0]=b;break _;case 8:t[f+22|0]=w[f+22|0]+w[i+2|0];break _;case 14:t[f+25|0]=w[i+3|0];t[f+26|0]=w[i+2|0];break _;case 6:break da;default:break _}}t[f+18|0]=r;t[f+17|0]=b;t[d+1|0]=r;c=b}t[d|0]=c;if((b|0)>=0){t[f+18|0]=r;t[d+1|0]=r}if(w[i|0]==5){t[d+4|0]=1;t[d+2|0]=11}c=w[f+22|0];b=w[f+26|0];if(!(b?1:c|w[i+2|0])){break ba}if(b){da=(Ci(+x[f+28>>1]*.006135923151542565+4.71238898038469)+-1)*+(b>>>0)*.25}else{da=0}t[d+3|0]=44;la=d,ma=sk(da+ +(c+w[i+2|0]|0)),t[la+5|0]=ma}u[f+32>>1]=0;break _}t[d+5|0]=m;t[d+3|0]=16}b=Dc(((B(w[f+20|0],w[f+19|0])+50&65535)>>>0)/100|0,0);if(!(!g&w[f+21|0]==(b&255))){t[f+21|0]=b;t[d+5|0]=b;t[d+3|0]=21}if(n&1|t[i+1|0]<=0|(x[a+480188>>1]-1|0)<=(n|0)){break _}b=v[l>>2];if(zh(b,v[l+4>>2])>>>0<=G>>>0){break _}if(w[zm(b,G)+132|0]!=1){break _}g=n+1|0;b=B(g,6)+Z|0;c=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);t[b|0]=c;t[b+1|0]=c>>>8;t[b+2|0]=c>>>16;t[b+3|0]=c>>>24;c=w[d+4|0]|w[d+5|0]<<8;t[b+4|0]=c;t[b+5|0]=c>>>8;t[b+1|0]=w[b+1|0]+1;b=Nt(v[F>>2],g);t[b+19|0]=w[f+19|0];z[b>>2]=z[f>>2];z[b+4>>2]=z[f+4>>2];z[b+8>>2]=z[f+8>>2];z[b+12>>2]=z[f+12>>2];u[b+30>>1]=x[f+30>>1]}ja:{if(w[d|0]){t[f+16|0]=0;break ja}c=0;if(w[f+16|0]){break X}}ka:{if(!x[f+30>>1]){break ka}b=m&255;u[e+288>>1]=b;c=f+30|0;la=c,ma=x[ke(c,e+288|0)>>1]-b|0,u[la>>1]=ma;if(w[d+3|0]){break ka}t[d+3|0]=15;t[d+5|0]=0}j=z[f>>2];la:{if(j==C(0)){break la}b=m&255;j=C(C(j*C(b>>>0))+z[f+4>>2]);z[f+4>>2]=j;if(w[d+3|0]){break la}ma:{na:{oa:{pa:{if(b>>>0>=2){g=b-1|0;D=C(g|0);if(!(D<=j)){break pa}t[e+288|0]=15;la=e,ma=jh(C(j/D)),t[la+116|0]=ma;b=w[Wb(e+288|0,e+116|0)|0];z[f+4>>2]=j-C(B(b,g)|0);t[d+3|0]=22;c=b<<4;break ma}if(!(j>=C(1))){break oa}break na}if(j>=C(1)){break na}if(!(j<=C(1-b|0))){break oa}t[e+288|0]=15;la=e,ma=jh(C(C(-j)/D)),t[la+116|0]=ma;c=w[Wb(e+288|0,e+116|0)|0];z[f+4>>2]=j+C(B(g,c)|0);t[d+3|0]=22;break ma}if(!(j<=C(-1))){break la}t[e+288|0]=14;la=e,ma=jh(C(-j)),t[la+116|0]=ma;b=w[Wb(e+288|0,e+116|0)|0];z[f+4>>2]=j+C(b>>>0);t[d+3|0]=22;c=b|-16;break ma}t[e+288|0]=15;la=e,ma=jh(j),t[la+116|0]=ma;b=w[Wb(e+288|0,e+116|0)|0];z[f+4>>2]=j-C(b>>>0);t[d+3|0]=22;c=b<<4|15}t[d+5|0]=c}j=z[f+8>>2];qa:{if(j==C(0)){break qa}b=m&255;j=C(C(j*C(b>>>0))+z[f+12>>2]);z[f+12>>2]=j;ra:{if(!w[d+3|0]){sa:{ta:{if(b>>>0>=2){c=b-1|0;D=C(c|0);if(!(D<=j)){break ta}t[e+288|0]=223;la=e,ma=jh(C(j/D)),t[la+116|0]=ma;b=w[Wb(e+288|0,e+116|0)|0];z[f+12>>2]=j-C(B(b,c)|0);t[d+3|0]=2;t[d+5|0]=b;break qa}if(!(j>=C(1))){break sa}break ra}if(j>=C(1)){break ra}if(!(j<=C(1-b|0))){break sa}t[e+288|0]=223;la=e,ma=jh(C(C(-j)/D)),t[la+116|0]=ma;b=w[Wb(e+288|0,e+116|0)|0];z[f+12>>2]=j+C(B(b,c)|0);t[d+3|0]=3;t[d+5|0]=b;break qa}if(!(j<=C(-1))){break qa}t[e+288|0]=14;la=e,ma=jh(C(-j)),t[la+116|0]=ma;b=w[Wb(e+288|0,e+116|0)|0];z[f+12>>2]=j+C(b>>>0);t[d+3|0]=3;t[d+5|0]=b|240;break qa}if(w[d+2|0]|b>>>0<2){break qa}ea=C(j*C(.25));c=b-1|0;D=C(c|0);if(ea>=D){t[e+288|0]=9;la=e,ma=jh(C(j/D))>>>2|0,t[la+116|0]=ma;b=w[Wb(e+288|0,e+116|0)|0];z[f+12>>2]=j-C(B(b,c)<<2);t[d+2|0]=12;t[d+4|0]=b;break qa}if(!(C(1-b|0)>=ea)){break qa}t[e+288|0]=9;la=e,ma=jh(C(C(-j)/D))>>>2|0,t[la+116|0]=ma;b=w[Wb(e+288|0,e+116|0)|0];z[f+12>>2]=j+C(B(b,c)<<2);t[d+2|0]=13;t[d+4|0]=b;break qa}t[e+288|0]=15;la=e,ma=jh(j),t[la+116|0]=ma;b=w[Wb(e+288|0,e+116|0)|0];z[f+12>>2]=j-C(b>>>0);t[d+3|0]=2;t[d+5|0]=b|240}ua:{va:{wa:{xa:{ya:{za:{Aa:{b=w[d+3|0];switch(b|0){case 4:break ua;case 0:break Aa;default:break za}}Ba:{b=w[f+23|0];if(!b){b=w[f+24|0];if(b){break Ba}if(!x[f+32>>1]){break ua}c=f+32|0;break ya}t[d+3|0]=5;t[d+5|0]=b;if(!x[f+32>>1]){break ua}break xa}t[d+3|0]=8;t[d+5|0]=b;if(x[f+32>>1]){break xa}break ua}if(!x[f+32>>1]){break ua}c=f+32|0;if(b){break wa}}t[d+3|0]=4;break va}c=f+32|0}t[d+2|0]=11}u[e+288>>1]=B(w[f+27|0],(m&255)-1|0);la=f,ma=x[f+32>>1]-x[Vc(c,e+288|0)>>1]|0,u[la+32>>1]=ma}u[f+28>>1]=x[f+28>>1]+B(w[f+25|0],m&255)&1023;c=0;if(n&1){break X}b=w[f+18|0];if(!b){break X}g=v[l>>2];if(zh(g,v[l+4>>2])>>>0<b>>>0){break X}g=zm(g,b-1|0);if(!(w[g+142|0]&4)){break X}b=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);t[o|0]=b;t[o+1|0]=b>>>8;t[o+2|0]=b>>>16;t[o+3|0]=b>>>24;b=w[d+4|0]|w[d+5|0]<<8;t[o+4|0]=b;t[o+5|0]=b>>>8;c=1;b=w[e+81|0];if(!b|w[g+132|0]!=1){break X}t[e+81|0]=b+1}n=n+1|0;b=x[a+480188>>1];continue}}break}ze(c,Eh(Te(Ne(e+288|0,16,Hb(w[h+14|0]|w[h+15|0]<<8)&255),0)))}b=Dl(v[H>>2],v[H+4>>2]);la=e,ma=Hb(w[h+4|0]|w[h+5|0]<<8),u[la+288>>1]=ma;u[e+80>>1]=1;c=x[ke(e+288|0,e+80|0)>>1];v[23588]=0;X(698,H|0,b|0,c|0,E&65535);b=v[23588];v[23588]=0;if((b|0)==1){break Q}b=pe((w[k+8|0]|w[k+9|0]<<8)<<16>>16);b=pe(pe((w[h+16|0]|w[h+17|0]<<8)<<16>>16)-b<<16>>16);t[h+16|0]=b;t[h+17|0]=b>>>8}b=h+32|0;continue}break}break M}d=ca&1;if(d){v[23588]=0;g=a+906300|0;b=Ld(g,0);Y(284,b|0);c=v[23588];v[23588]=0;if((c|0)==1){break M}v[b+16>>2]=1299020115;v[b+20>>2]=1869112133;v[b+24>>2]=655376;v[b+28>>2]=0;v[e+288>>2]=0;h=b+48|0;c=e+288|0;wV(b+32|0,h,c);v[23588]=0;c=Q(55,c|0,9516)|0;f=v[23588];v[23588]=0;if((f|0)==1){break M}KB(h,c);yb(c);v[23588]=0;c=Q(55,e+96|0,9509)|0;h=v[23588];v[23588]=0;if((h|0)==1){break M}Ku(b+80|0,c);yb(c);v[23588]=0;b=Q(55,e+80|0,9501)|0;c=v[23588];v[23588]=0;if((c|0)==1){break M}KB(Ld(g,1)+48|0,b);yb(b)}b=0;while(1){if(x[a+480188>>1]>b>>>0){tB(a,b&65535);c=(b<<5)+a|0;t[c+480288|0]=d;u[c+480284>>1]=b<<8&256;b=b+1|0;continue}break}v[23588]=0;b=Q(1,e- -64|0,12017)|0;c=v[23588];v[23588]=0;Ca:{Da:{Ea:{if((c|0)!=1){Ib(a+1298344|0,b);zb(b);v[23588]=0;b=Q(1,e+48|0,12235)|0;c=v[23588];v[23588]=0;if((c|0)==1){break M}Ib(a+1298356|0,b);zb(b);if(_){break Ea}v[23588]=0;b=Q(1,e+32|0,12017)|0;c=v[23588];v[23588]=0;if((c|0)==1){break M}break Da}break M}if(zh(v[l>>2],v[l+4>>2])>>>0<=128){v[23588]=0;b=Q(1,e+32|0,9258)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break Da}break M}v[23588]=0;b=Q(1,e+32|0,14758)|0;c=v[23588];v[23588]=0;if((c|0)==1){break Ca}}Ib(a+1298368|0,b);zb(b);v[a+1298404>>2]=14;wQ(F);nQ(s);mQ(I);d=1;break m}}c=P()|0;O()|0;wQ(F);break j}eq(e- -64|0);continue}}c=P()|0;O()|0;break a}c=P()|0;O()|0;break a}Ot(l);vc(A);Bm(q);Di(p);break c}c=P()|0;O()|0;break j}c=P()|0;O()|0}nQ(s);mQ(I);break a}c=P()|0;O()|0;zb(b);break a}c=P()|0;O()|0;break a}Ab(c);v[23588]=0;c=d&65535;d=W(699,a|0,c|0,n|0)|0;g=v[23588];v[23588]=0;Fa:{Ga:{Ha:{Ia:{if((g|0)==1){break Ia}if(d){break Fa}v[23588]=0;d=W(700,a|0,c|0,n|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break Ia}if(d){break Fa}v[23588]=0;d=W(701,a|0,c|0,n|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break Ia}if(d){break Fa}v[23588]=0;d=Q(702,(B(c,104)+a|0)+484380|0,n|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break Ia}if(d){break Fa}v[23588]=0;d=Q(1,e+464|0,16130)|0;g=v[23588];v[23588]=0;if((g|0)==1){break Ha}g=v[F>>2];v[23588]=0;U(376,g|0,2,d|0);g=v[23588];v[23588]=0;if((g|0)==1){break Ga}zb(d);break Fa}c=P()|0;O()|0;break e}c=P()|0;O()|0;break e}c=P()|0;O()|0;zb(d);break e}Ja:{Ka:{La:{E=B(c,104)+a|0;if(w[E+484414|0]&64){d=x[i>>1];if(Xh(d)){break La}}d=v[l>>2];if(zh(d,v[l+4>>2])>>>0<=c>>>0){break Ka}if(w[zm(d,c)+132|0]!=2){break Ka}c=x[i>>1];if(!Xh(c)){break Ka}u[i>>1]=c+1;break Ka}c=d+1|0;u[i>>1]=c;G=B(c&65535,104)+a|0;o=G+484380|0;f=E+484380|0;d=v[f>>2];g=v[f+20>>2];Ma:{if(!Zd(d,g)){break Ma}h=x[f+34>>1];if((f|0)==(o|0)|(Kd(h)|0)!=2){break Ma}c=(f|0)==(o|0);if(!(Zd(v[o>>2],v[o+20>>2])?c:1)){break Ma}Zd(v[f>>2],v[f+20>>2]);if(!c){g=Jt(d,Zm(h))}h=v[f+20>>2];if(!(h?g:0)){if(!c){Cz(g)}break Ma}Na:{Oa:{switch(Zm(x[f+34>>1])-1|0){case 1:d=g;c=h;m=v[f+20>>2];k=v[f>>2];while(1){if(k){u[d>>1]=x[m>>1];u[c>>1]=x[m+2>>1];m=m+4|0;c=c+2|0;d=d+2|0;k=k-1|0;continue}break};break Na;case 0:break Oa;default:break Na}}d=g;c=h;m=v[f+20>>2];k=v[f>>2];while(1){if(k){t[d|0]=w[m|0];t[c|0]=w[m+1|0];m=m+2|0;c=c+1|0;d=d+1|0;k=k-1|0;continue}break}}d=jo(o,f);u[d+34>>1]=x[d+34>>1]&65471;v[o+20>>2]=g;g=jo(f,f);u[g+34>>1]=x[g+34>>1]&65471;v[f+20>>2]=h;h=a+1298224|0;c=a+1074992|0;while(1){if((c|0)!=(h|0)){f=v[c+104>>2];if(!((f|0)!=(d|0)&(f|0)!=(g|0))){v[c+88>>2]=v[c+88>>2]&-65}c=c+872|0;continue}break}tj(d,a);tj(g,a)}v[23588]=0;c=Q(55,e+448|0,6323)|0;d=v[23588];v[23588]=0;if((d|0)==1){break Ja}Be(G+484423|0,c);yb(c);v[23588]=0;c=Q(55,e+432|0,6226)|0;d=v[23588];v[23588]=0;if((d|0)==1){break f}Be(E+484423|0,c);yb(c)}Ab(n);hc(s);g=0;continue}break}c=P()|0;O()|0;break e}c=P()|0;O()|0}Ab(n)}hc(s);break a}jb=e+688|0;return d|0}c=P()|0;O()|0}Ot(l);vc(A);Bm(q);Di(p);T(c|0);L()}function Zt(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,S=0,V=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,fa=0,ga=0,ha=0,ka=0,la=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Ba=0,Ca=0,Da=0,Ea=C(0),Fa=0,Ga=0,Ha=0,Ia=C(0);i=jb-192|0;jb=i;$=Sb(a);q=i+160|0;t[q+26|0]=0;u[q+24>>1]=0;v[q+16>>2]=0;v[q+20>>2]=-1;v[q+8>>2]=-1;v[q+12>>2]=-1;v[q>>2]=0;v[q+4>>2]=0;M=v[d+16>>2];a=w[d+6|0];na=b+484360|0;e=v[na>>2];oa=(Fa=a,Ga=w[b+484376|0],Ha=rj(e,v[b+484364>>2])>>>0>a>>>0,Ha?Fa:Ga);a=oa&255;I=xj(e,a);v[23588]=0;r=Q(580,i+128|0,b|0)|0;e=v[23588];v[23588]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((e|0)!=1){l=v[r+4>>2];v[23588]=0;J=W(581,i+88|0,b|0,a|0)|0;a=v[23588];v[23588]=0;if((a|0)==1){break i}ca=c&7;h=v[d>>2];a=x[d+4>>1];while(1){e=a&65535;if(Qc(v[I>>2],v[I+4>>2])>>>0<=e>>>0){break g}v[23588]=0;e=Q(311,I|0,e|0)|0;n=v[23588];v[23588]=0;if((n|0)==1){break h}if(e){break g}a=a+1|0;h=0;continue}}k=P()|0;O()|0;break d}k=P()|0;O()|0;break e}k=P()|0;O()|0;v[d>>2]=h;u[d+4>>1]=a;break f}v[d>>2]=h;u[d+4>>1]=a;v[l+52>>2]=h;K=l+48|0;v[K>>2]=h;v[q+16>>2]=h;u[l+74>>1]=a;u[l+72>>1]=a;u[q+24>>1]=a;pa=ee(i+80|0);j:{if((ca|0)!=7){break j}a=jb-16|0;jb=a;e=a+8|0;Cb(e,pa,1);oo(e);jb=a+16|0;if((M|0)!=2){break j}a=v[I>>2];n=Qc(a,v[I+4>>2]);e=x[d+12>>1];if(n>>>0<=e>>>0){break j}n=v[b+484344>>2];f=v[b+484348>>2];a=x[cc(a,e)>>1];if(!xe(n,f,a)){break j}e=Yb(n,a);n=v[d+8>>2];if(y[e+12>>2]<=n>>>0){break j}a=0;k=id(v[e>>2],v[v[e+48>>2]+12>>2],n,0);e=x[b+480188>>1];n=v[r+8>>2];f=x[b+480192>>1];while(1){if((a|0)==(e|0)){break j}k:{l:{m:{n:{g=w[k|0];switch(g-253|0){case 1:case 2:break l;case 0:break n;default:break m}}if(f){break l}}if(!_c(g)){break k}if(vm(w[k+2|0],w[k+3|0])){break k}}Fa=af(n,a),Ga=-1,v[Fa>>2]=Ga}k=k+6|0;a=a+1|0;continue}}aa=c&1;if(aa){cO(l+223860|0)}V=l+74|0;wa=l+223872|0;xa=(M|0)!=3;N=l+80|0;ya=b+901692|0;za=b+902204|0;ga=l+44|0;ha=l+223860|0;ba=l+20|0;H=b+1074312|0;qa=l+616|0;da=32768;ra=A[d+8>>3];o(+ra);a=j(1)|0;Ba=j(0)|0;ka=a;_=b+480188|0;G=b+480180|0;la=b+484348|0;sa=(M|0)!=2;Ca=l+223884|0;ta=b+480192|0;Da=(ca|0)!=7;d=0;o:{p:{q:{r:{s:{t:while(1){n=ka;while(1){bO(i+16|0,v[G>>2],x[_>>1],l,p&1);if(!(!(A[r+24>>3]>=ra)|xa)){break p}g=w[i+16|0];a=65535;f=v[I>>2];h=Qc(f,v[I+4>>2]);e=x[l+72>>1];if(h>>>0>e>>>0){a=x[cc(f,e)>>1]}u[l+70>>1]=a;f=v[b+484344>>2];h=v[la>>2];k=a&65535;if(!(xe(f,h,k)|(k|0)==65535|sa)&(e|0)==(n&65535)){break p}u:{v:{while(1){a=a&65535;if(Af(f,h)>>>0>a>>>0){break u}k=x[l+72>>1];w:{x:{if((a|0)!=65535){e=v[I>>2];m=Qc(e,v[I+4>>2]);if(k>>>0<m>>>0){break x}}a=x[I+28>>1];if((k|0)==(a|0)){break u}e=v[I>>2];m=Qc(e,v[I+4>>2]);break w}a=k+1|0}u[l+72>>1]=a;k=65535;s=m;m=a&65535;if(s>>>0>m>>>0){k=x[cc(e,m)>>1]}u[l+74>>1]=a;u[l+70>>1]=k;y:{if(!xe(f,h,k&65535)){e=Up(i+16|0,qa);v[23588]=0;a=ja(582,J|0,a&65535,0,e|0,(g|0)!=0|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break y}if(a){break v}h=v[la>>2];f=v[b+484344>>2]}a=x[l+70>>1];continue}break}k=P()|0;O()|0;break f}if(M>>>0<=1){a=x[l+72>>1];v[q+8>>2]=0;u[q+20>>1]=a;if(!M){break u}}v[23588]=0;a=W(583,J|0,V|0,K|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break q}if(!a){break u}A[q>>3]=A[r+24>>3];v[23588]=0;R(584,$|0,q|0);a=v[23588];v[23588]=0;if((a|0)==1){break q}v[q+16>>2]=v[K>>2];u[q+24>>1]=x[V>>1];v[23588]=0;Y(585,r|0);a=v[23588];v[23588]=0;if((a|0)==1){break q}a=x[l+74>>1];u[l+72>>1]=a;Fa=l,Ga=x[cc(v[I>>2],a)>>1],u[Fa+70>>1]=Ga;v[l+52>>2]=v[l+48>>2]}if(x[V>>1]==65535){break o}a=v[b+484344>>2];e=x[l+70>>1];if(!xe(a,v[la>>2],e)){a=x[l+72>>1];if((a|0)==x[I+28>>1]){if(!M){break o}v[23588]=0;a=W(583,J|0,V|0,K|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break q}if(!a){break o}A[q>>3]=A[r+24>>3];v[23588]=0;R(584,$|0,q|0);a=v[23588];v[23588]=0;if((a|0)==1){break q}v[q+16>>2]=v[K>>2];u[q+24>>1]=x[V>>1];v[23588]=0;Y(585,r|0);a=v[23588];v[23588]=0;if((a|0)==1){break q}v[l+52>>2]=v[l+48>>2];continue}u[V>>1]=a+1;continue}f=v[K>>2];if(f>>>0>=y[Yb(a,e)+12>>2]){v[K>>2]=0;f=0}if(!(x[l+72>>1]!=(n&65535)|sa)&(f|0)==(Ba|0)){break p}a=0;if(!((M|0)==3|y[J+28>>2]<da>>>0)){v[r+24>>2]=0;v[r+28>>2]=2146435072;v[J+28>>2]=0;da=da>>>(da>>>0>256)|0;f=v[K>>2];a=1}e=x[l+72>>1];h=Up(i+16|0,qa);v[23588]=0;e=ja(582,J|0,e|0,f|0,h|0,(g|0)!=0|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break s}if((a|e)==1){if(M>>>0<=1){u[q+20>>1]=x[l+72>>1];v[q+8>>2]=v[l+48>>2];if(!M){break o}}v[23588]=0;a=W(583,J|0,V|0,K|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break r}if(!a){break o}A[q>>3]=A[r+24>>3];v[23588]=0;R(584,$|0,q|0);a=v[23588];v[23588]=0;if((a|0)==1){break r}v[q+16>>2]=v[K>>2];u[q+24>>1]=x[V>>1];v[23588]=0;Y(585,r|0);a=v[23588];v[23588]=0;if((a|0)==1){break r}v[l+52>>2]=v[l+48>>2];continue}u[q+22>>1]=x[l+72>>1];v[q+12>>2]=v[l+48>>2];aO(b,l,0);k=v[l+48>>2];e=Yb(v[b+484344>>2],x[l+70>>1]);if(k>>>0>=y[e+12>>2]){v[K>>2]=0;k=0}if(g){continue}break}a=0;k=id(v[e>>2],v[v[e+48>>2]+12>>2],k,0);Cb(i+16|0,H,77);g=Bb(v[v[i+16>>2]>>2],v[i+20>>2]);z:{while(1){if(x[_>>1]>a>>>0){A:{if(!(!$y(k)&(!g|!(w[((a<<5)+b|0)+480281|0]&4)))){io((l+B(a,872)|0)+1404|0);break A}if(fh(w[k|0])){B:{if(!Pd(w[Ca|0])){break B}e=w[k+1|0];if(e-251>>>0<5|!e){break B}f=w[k+5|0];p=w[k+3|0];h=gk(w[k+2|0],w[k+4|0]);n=i+16|0;t[n|0]=e-1;v[n+4>>2]=h&65535;v[23588]=0;e=Q(586,wa|0,n|0)|0;n=v[23588];v[23588]=0;if((n|0)==1){break z}Fa=e,Ia=C(C(gk(p,f)>>>0)/C(999)),z[Fa>>2]=Ia}io((l+B(a,872)|0)+1404|0);break A}e=l+B(a,872)|0;n=e+1408|0;f=w[k+4|0]|w[k+5|0]<<8;t[n|0]=f;t[n+1|0]=f>>>8;n=e+1404|0;f=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);t[n|0]=f;t[n+1|0]=f>>>8;t[n+2|0]=f>>>16;t[n+3|0]=f>>>24;C:{D:{E:{F:{switch(w[k+3|0]-16|0){case 0:h=w[k+5|0];break E;case 3:break C;case 4:break D;case 1:break F;default:break A}}Cb(i+16|0,H,5);if(!Bb(v[v[i+16>>2]>>2],v[i+20>>2])){break A}h=w[k+5|0];if(!h){break A}}_N(b,l,h&255);break A}n=e+1409|0;f=w[n|0];G:{if(!(f|!(v[G>>2]&16777250))){t[n|0]=w[e+1449|0];break G}t[e+1449|0]=f}e=w[k+5|0];n=e&240;if((n|0)!=224){if((n|0)!=96){break A}v[l+24>>2]=v[l+24>>2]+(e&15);break A}if(v[ba>>2]){break A}e=e&15;if(e?0:w[G|0]&2){break A}v[ba>>2]=e+1;break A}e=w[k+5|0];if((e&240)!=224){break A}v[ba>>2]=(e&15)+1}k=k+6|0;a=a+1|0;continue}break}n=il(l);v[i+16>>2]=1;a=v[Yc(ba,i+16|0)>>2];u[l+68>>1]=65535;v[l+60>>2]=-1;v[l+64>>2]=-1;D=n-1|0;a=n-a|0;F=B(a,1e4);k=0;while(1){if(x[_>>1]<=k>>>0){if(v[G>>2]==4&v[l+40>>2]==65535){break o}v[l+32>>2]=v[b+480216>>2];a=Yb(v[b+484344>>2],x[l+70>>1]);e=v[a+16>>2];if(ZN(e,v[a+20>>2])){v[l+32>>2]=e}f=YN(b,l);a=B(f,n);A[r+24>>3]=A[r+24>>3]+ +(a>>>0)/+y[b+24620>>2];v[l>>2]=a+v[l>>2];H:{I:{J:{if(Da){break J}k=0;fa=(d|0)!=0&(d|0)!=(f|0);while(1){if(x[_>>1]<=k>>>0){break J}F=af(v[r+8>>2],k);K:{if(v[F>>2]==-1){break K}m=l+B(k,872)|0;s=m+1404|0;S=v[m+1316>>2];if(!S){if($y(s)){break K}}a=m+1409|0;e=1;L:{M:{E=m+1407|0;switch(w[E|0]-4|0){case 0:case 2:break L;default:break M}}e=w[m+1406|0]==11}D=w[a|0];if(w[m+1405|0]){v[m+1276>>2]=0}g=m+616|0;h=D&15;p=0;N:{if(!_c(w[s|0])){break N}if(!(!e|!w[F+4|0])){_y(i+16|0,b,g,S,0);p=v[i+20>>2];v[m+624>>2]=v[i+16>>2];v[m+628>>2]=p}t[m+1418|0]=w[m+1415|0];S=m+1308|0;Z=v[S>>2];p=w[m+1419|0];if(p){Tp(b,g,p,e,1,1)}p=w[s|0];v[23588]=0;ia(587,b|0,g|0,p|0,e|0,1,0,65535);p=v[23588];v[23588]=0;if((p|0)==1){break I}D=D>>>4|0;XN(v[G>>2],x[_>>1],l,k&65535);ua=af(v[r+8>>2],k);t[ua+4|0]=1;F=w[E|0];O:{if(!((w[a|0]&240)!=208|(F-19&255)>>>0>1)){p=h;if(h>>>0<n>>>0){break O}}p=(F|0)==33?n>>>0>D>>>0?D:0:0}va=v[ba>>2];if(!(!(v[G>>2]&16777250)|(!p|va>>>0<2))){p=B(va-1|0,v[l+24>>2]+v[l+40>>2]|0)+p|0}if(!e){v[ua>>2]=0}P:{if((F|0)==9){break P}Q:{if((F|0)!=19){if((F|0)!=20|(D|0)!=8){break Q}break P}if((D|0)==8){break P}}if(w[m+1406|0]!=2){break N}}v[S>>2]=Z}R:{if(!_c(w[s|0])){Cb(i+16|0,H,114);if(!Bb(v[v[i+16>>2]>>2],v[i+20>>2])){break R}}S:{T:{U:{V:{e=w[E|0];switch(e-42|0){case 1:break S;case 0:break T;case 2:break U;default:break V}}if((e|0)!=10){break S}e=x[l+70>>1];D=v[l+48>>2];v[23588]=0;ea(588,b|0,g|0,k&65535,D|0,e|0);e=v[23588];v[23588]=0;if((e|0)!=1){break R}break H}F=Lka(w[a|0],0,v[m+692>>2],0);D=mb;e=D>>>8|0;Zn(b,g,Dc((D&255)<<24|F>>>8,e));break R}if(!v[m+720>>2]){break S}v[23588]=0;X(589,r|0,k&65535,d|0,-1);e=v[23588];v[23588]=0;if((e|0)==1){break H}VN(g,w[a|0]);p=v[l+40>>2]-1|0;break R}if(w[m+1406|0]!=15){break R}D=v[m+720>>2];if(!D){break R}e=w[m+1408|0];if(e>>>0>9){break R}W:{if(!e){e=v[m+1280>>2];break W}e=v[Db(D+68|0,e-1|0)>>2];v[m+1280>>2]=e}Zn(b,g,e)}X:{Y:{Z:{switch(w[s|0]-253|0){case 0:if(x[ta>>1]){break Y}break;case 1:case 2:break Y;default:break Z}}e=w[E|0];if(!((w[a|0]&240)!=192|(e-19&255)>>>0>1)&h>>>0<n>>>0){break Y}D=0;F=e&255;if((F|0)==33&(h|0)!=0&n>>>0>h+p>>>0){break Y}if((F|0)!=25){break X}}e=w[E|0];D=1}S=m+1304|0;F=e&255;_:{if((F|0)!=13){if(w[m+1406|0]!=1){break _}h=m+1408|0}else{h=a}v[S>>2]=w[h|0]<<2}$:{aa:{ba:{if(!v[m+720>>2]|D|F>>>0>45){break ba}Cb(i+16|0,pa,F);if(Bb(v[v[i+16>>2]>>2],v[i+20>>2])){break aa}e=w[E|0];if((e|0)!=19){break ba}h=w[a|0]&240;if((h|0)==16){break aa}e=19;if((h|0)==32){break aa}}if(!D){break $}}zP(g);Fa=af(v[r+8>>2],k),Ga=0,v[Fa>>2]=Ga;break K}if(fa){v[23588]=0;X(589,r|0,k&65535,d|0,-1);e=v[23588];v[23588]=0;if((e|0)==1){break H}e=w[E|0]}ca:{da:{ea:{fa:{ga:{e=e&255;if(e-6>>>0>=2){ha:{switch(e-19|0){case 1:break fa;case 0:break ga;default:break ha}}if(e-35>>>0<2){break da}if((e|0)==45){break ea}if((e|0)!=11){break ca}}if(!w[a|0]&v[G>>2]==1){break ca}e=m+1467|0;h=0;while(1){if((h|0)==(n|0)){break ca}t[e|0]=!h|w[e|0]&254;Yn(b,g,w[a|0]);h=h+1|0;continue}}e=w[a|0];a=e&15;if(!(v[G>>2]&1048580?1:a)){break ca}h=m+1467|0;t[h|0]=w[h|0]|1;e=e&240;if((e|0)!=176){if((e|0)!=160){break ca}Xn(b,g,a,0);break ca}Wn(b,g,a,0);break ca}ia:{ja:{ka:{a=w[a|0];switch(a-158|0){case 1:break ja;case 0:break ka;default:break ia}}v[23588]=0;X(589,r|0,k&65535,d|0,-1);a=v[23588];v[23588]=0;if((a|0)==1){break H}v[m+704>>2]=v[m+704>>2]&-129;break ca}v[23588]=0;X(589,r|0,k&65535,d|0,-1);a=v[23588];v[23588]=0;if((a|0)==1){break H}a=v[m+704>>2];v[m+704>>2]=a|128;if(v[g+4>>2]){break ca}e=v[m+692>>2];if(!e){break ca}if(!(Fa=_c(w[s|0]),Ga=1,Ha=a&2,Ha?Fa:Ga)){break ca}v[g>>2]=-1;v[g+4>>2]=e-1;break ca}if((a&240)!=112|a>>>0<115){break ca}wP(g,a,v[G>>2]);break ca}UN(g,w[a|0]);break ca}v[23588]=0;a=k&65535;X(589,r|0,a|0,d|0,-1);e=v[23588];v[23588]=0;if((e|0)==1){break H}TN(b,a,l,0)}h=m+1467|0;a=w[h|0]|1;t[h|0]=a;la:{ma:{na:{oa:{pa:{E=m+1406|0;switch(w[E|0]-3|0){case 11:break ma;case 0:case 1:break na;case 3:break oa;case 2:break pa;default:break la}}a=w[m+1408|0];Cb(i+16|0,H,41);Xn(b,g,a,Bb(v[v[i+16>>2]>>2],v[i+20>>2]));break la}a=w[m+1408|0];Cb(i+16|0,H,41);Wn(b,g,a,Bb(v[v[i+16>>2]>>2],v[i+20>>2]));break la}e=w[m+1408|0];qa:{if(e){break qa}Cb(i+16|0,H,41);e=0;if(!Bb(v[v[i+16>>2]>>2],v[i+20>>2])){break qa}e=w[m+1450|0];if(!e){break la}}e=w[E|0]==3?e<<4:e;a=0;while(1){if((a|0)==(n|0)){break la}t[h|0]=!a|w[h|0]&254;Yn(b,g,e&255);a=a+1|0;continue}}e=w[m+1408|0];if(e>>>0>1){break la}t[h|0]=a&247|!e<<3}if(w[h|0]&8){break K}a=1;ra:{sa:{ta:{e=w[s+3|0];if(e>>>0>28){break ta}g=1<<e;if(g&92){break ra}if(!(g&268959744)){break ta}if((w[s+5|0]-16&255)>>>0<32){break ra}break sa}if(e-38>>>0<4){break ra}}a=(w[s+2|0]-11&255)>>>0<3}if(a){e=af(v[r+8>>2],k);a=v[e>>2];v[e>>2]=a+n;v[23588]=0;X(589,r|0,k&65535,f|0,a+p|0);a=v[23588];v[23588]=0;if((a|0)!=1){break K}k=P()|0;O()|0;break f}a=af(v[r+8>>2],k);v[a>>2]=v[a>>2]+(n-p|0)}k=k+1|0;continue}}p=SN(b,l,I,0);d=f;continue t}k=P()|0;O()|0;break f}k=P()|0;O()|0;break f}g=l+B(k,872)|0;h=g+1404|0;ua:{if($y(h)){break ua}p=g+616|0;fa=g+1409|0;f=w[fa|0];S=g+1407|0;m=w[S|0];va:{wa:{if(!aa){break wa}s=w[h|0];e=s;E=g+1405|0;Z=w[E|0];if(Z){t[g+1415|0]=0;t[g+1419|0]=Z;Fa=af(v[r+8>>2],k),Ga=255,t[Fa+5|0]=Ga;e=w[h|0]}if(_c(e)){t[g+1415|0]=s;yP(p);e=w[h|0]}xa:{if(!(Fa=1,Ga=_c(e),Ha=w[E|0],Ha?Fa:Ga)){break xa}Z=g+1419|0;e=w[Z|0];ya:{if(!e){e=0;break ya}if(x[ta>>1]<e>>>0){break ya}E=v[((e<<2)+b|0)+900380>>2];if(!E|!(t[E+15|0]&1)){break ya}aq(p,v[E+8>>2],b);e=w[Z|0]}e=uq(b,s,e&255);if(!e){break xa}e=B(e,104)+b|0;if(!(w[e+484414|0]&32)){break xa}aq(p,x[e+484408>>1],b)}za:{Aa:{Ba:{e=w[g+1406|0];switch(e-1|0){case 1:break wa;case 2:case 3:break Aa;case 0:break Ba;default:break za}}Fa=af(v[r+8>>2],k),Ga=w[g+1408|0],t[Fa+5|0]=Ga;break wa}e=w[g+1408|0];if(!e){break wa}t[g+1450|0]=e;break wa}if((e|0)!=11){break wa}e=w[g+1408|0];if(!e){break wa}s=i+16|0;Zy(s,b,w[h+3|0],e,0);u[g+1384>>1]=x[i+16>>1];if(w[Se(s)|0]){break va}}Ca:{Da:{Ea:{Fa:{Ga:{switch(m-12|0){case 0:RN(b,l,k&65535);break Ca;case 2:e=QN(b,l,k&65535,f);if((e|0)==-1){break Ca}v[l+60>>2]=e;break Ca;case 5:Cb(i+16|0,H,5);if(Bb(v[v[i+16>>2]>>2],v[i+20>>2])){break Ca}h=B(Vn(b,x[l+70>>1],v[l+48>>2],k&65535,0),1e4);Ha:{if(!aa|!(v[G>>2]&16777250)){break Ha}if(h>>>0>=1e4){t[g+1451|0]=(h>>>0)/1e4;break Ha}h=B(w[g+1451|0],1e4)}Ia:{if(h>>>0>319999){break Ia}s=(h>>>0)/1e4|0;h=B(F,s&15);e=v[ga>>2];if((s&240)==16){h=e+h|0;break Ia}h=e-h|0;h=e>>>0<h>>>0?0:h}v[ga>>2]=h;e=v[b+8>>2];h=v[e+20>>2];e=v[e+24>>2];Cb(i+16|0,H,8);Po(ga,B(h,1e4),Bb(v[v[i+16>>2]>>2],v[i+20>>2])?255e4:B(e,1e4));break Ca;case 8:Ja:{switch((f&240)-144>>>4|0){case 0:if(f>>>0>145){break Ca}v[g+704>>2]=v[g+704>>2]&-257|((f|0)==145)<<8;break Ca;case 1:t[g+1452|0]=f&15;break Ca;case 2:break Fa;case 6:break Ja;default:break Ca}}t[g+1460|0]=f&15;break Ca;case 1:case 3:case 4:case 6:break Ca;case 7:break Ga;default:break Da}}e=f&240;if((e|0)==240){break Ea}if((e|0)!=96){break Ca}}Yy(b,l,p,f&15);break Ca}t[g+1460|0]=f&15;break Ca}if((m|0)!=28|(f&240)!=160){break Ca}Cb(i+16|0,H,58);if(Bb(v[v[i+16>>2]>>2],v[i+20>>2])){break Ca}t[g+1452|0]=f&15}if(!aa){break ua}Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{switch(m-2|0){case 0:if(!f){break Ka}Cb(i+16|0,H,90);if(!Bb(v[v[i+16>>2]>>2],v[i+20>>2])){t[g+1428|0]=f}t[g+1427|0]=f;break va;case 1:if(!f){break Ka}Cb(i+16|0,H,90);if(!Bb(v[v[i+16>>2]>>2],v[i+20>>2])){t[g+1427|0]=f}t[g+1428|0]=f;break va;case 2:if(!f){break Ka}u[g+1384>>1]=f;break va;case 8:if(!f){break Ka}v[g+1280>>2]=f<<8;break va;case 4:case 9:if(!f){break Ka}t[g+1425|0]=f;break va;case 11:Fa=af(v[r+8>>2],k),Ga=f,t[Fa+5|0]=Ga;break va;case 21:e=v[G>>2];f=f<<(!(e&59593760)&f<<24>>24>=0);h=f&255;if(h>>>0<=128){v[N>>2]=h<<1;break va}if(e&16777250){break va}v[N>>2]=256;break va;case 22:Cb(i+16|0,H,9);Ta:{if(Bb(v[v[i+16>>2]>>2],v[i+20>>2])){e=g+1433|0;if(f){t[e|0]=f;break Ta}f=w[e|0];break Ta}if(f){t[l+1433|0]=f;break Ta}f=w[l+1433|0]}e=f&240;h=f&15;Ua:{if(!(!e|(h|0)!=15)){f=e>>>4<<!(v[G>>2]&59593760);e=v[N>>2]+(f<<1)|0;break Ua}if(!(!h|(e|0)!=240)){f=h<<(v[G>>2]&59593760?1:2);e=v[N>>2]-f|0;break Ua}if(e){f=(f>>>3&30)<<!(v[G>>2]&59593760);e=v[N>>2]+B(a,f)|0;break Ua}f=h<<(v[G>>2]&59593760?1:2);e=v[N>>2]-B(a,f)|0}v[N>>2]=e;oe(N,0,256);break va;case 19:if(f>>>0>64){break va}v[g+1364>>2]=f;break va;case 20:e=g+1432|0;Va:{if(f){t[e|0]=f;break Va}f=w[e|0]}m=f&255;s=g+1364|0;e=v[s>>2];E=f&240;h=f&15;Wa:{if(!(!E|(h|0)!=15)){v[i+16>>2]=e+(m>>>4|0);break Wa}if(!(!h|(E|0)!=240)){v[i+16>>2]=e-h;break Wa}if(h){v[i+16>>2]=e-B(a,h);break Wa}v[i+16>>2]=e+B(a,m>>>4|0)}oe(i+16|0,0,64);v[s>>2]=v[i+16>>2];break va;case 7:um(b,p,f,8);break va;case 29:case 30:break La;case 25:break Ma;case 6:break Na;case 24:break Oa;case 3:break Pa;case 5:break Qa;case 18:break Ra;case 17:break Sa;default:break va}}if(f>>>0>15){break Ra}e=(f&1)<<14;m=x[_>>1];h=0;while(1){if((h|0)==(m|0)){break Ra}s=l+B(h,872)|0;v[s+704>>2]=(e|v[s+704>>2]&-16385)^16384;h=h+1|0;continue}}if((f&240)!=128){break va}um(b,p,f&15,4);break va}if(f){t[g+1425|0]=f}f=0}hl(p,f);break va}PN(b,p,f);break va}ON(p,f);break va}MN(p,f);break va}Xa:{if(f<<24>>24>=0){e=ye(ya,w[g+1460|0]);break Xa}e=ye(za,f&127)}h=w[fa|0];v[23588]=0;ma(590,b|0,l|0,k&65535,0,e|0,h|0);e=v[23588];v[23588]=0;if((e|0)!=1){break va}k=P()|0;O()|0;break f}f=0}Ya:{Za:{switch(w[g+1406|0]-2|0){case 0:um(b,p,w[g+1408|0],6);break Ya;case 5:Cb(i+16|0,H,53);e=w[g+1408|0];if(Bb(v[v[i+16>>2]>>2],v[i+20>>2])){t[g+1439|0]=e&15;break Ya}hl(p,e<<4);break Ya;case 6:break Za;default:break Ya}}hl(p,w[g+1408|0])}_a:{$a:{ab:{bb:{cb:{e=w[S|0];switch(e-5|0){case 1:break _a;case 3:break ab;case 0:case 2:break bb;default:break cb}}switch(e-26|0){case 1:break $a;case 0:break bb;default:break _a}}db:{if(v[G>>2]&16777248){e=n;if(!(w[b+480208|0]&4)){break db}}e=a}h=w[g+1439|0];Cb(i+16|0,H,21);g=g+1435|0;m=w[g|0];e=B(e,h);Fa=g,Ga=(Bb(v[v[i+16>>2]>>2],v[i+20>>2])?e<<2:e)+m|0,t[Fa|0]=Ga;break _a}eb:{if(v[G>>2]&16777248){e=n;if(!(w[b+480208|0]&4)){break eb}}e=a}h=w[g+1442|0];Cb(i+16|0,H,21);g=g+1436|0;m=w[g|0];e=B(e,h);Fa=g,Ga=(Bb(v[v[i+16>>2]>>2],v[i+20>>2])?e<<2:e)+m|0,t[Fa|0]=Ga;break _a}e=g+1437|0;t[e|0]=w[e|0]+B(D,w[g+1445|0]);KN(b,p)}Cb(i+16|0,H,78);if(!Bb(v[v[i+16>>2]>>2],v[i+20>>2])){break ua}e=f&255;if(!e){break ua}JN(p,e)}k=k+1|0;continue}}break}k=P()|0;O()|0;break f}k=P()|0;O()|0;break f}k=P()|0;O()|0;break f}k=P()|0;O()|0;break f}t[q+26|0]=1}fb:{if((ca|0)!=7){break fb}a=0;e=b+480188|0;while(1){if(x[e>>1]<=a>>>0){break fb}gb:{if(v[af(v[r+8>>2],a)>>2]==-1){break gb}v[23588]=0;X(589,r|0,a&65535,d|0,-1);n=v[23588];v[23588]=0;if((n|0)!=1){break gb}k=P()|0;O()|0;break f}a=a+1|0;continue}}if(w[q+26|0]){u[q+20>>1]=x[l+72>>1];v[q+8>>2]=v[l+48>>2]}A[q>>3]=A[r+24>>3];v[23588]=0;R(584,$|0,q|0);a=v[23588];v[23588]=0;if((a|0)!=1){if(!aa){break a}if(!(M?w[q+26|0]:1)){break c}n=Ly(i+48|0);if(Pd(w[ha+24|0])){vN(n,ha)}Xy(ha);a=tc(b+1074376|0,l,614);f=0;while(1){if((f|0)==256){Km(a+223848|0,l+223848|0);d=a+223860|0;f=w[d+24|0];e=l+223860|0;hb:{if((Pd(w[e+24|0])|0)==(f|0)){if(!f){break hb}f=ic(d);it(d,v[f>>2]);v[d>>2]=v[e>>2];v[d+4>>2]=v[e+4>>2];v[d+8>>2]=v[e+8>>2];ib:{if(!v[Fb(d)>>2]){v[d>>2]=f;break ib}v[v[f>>2]+8>>2]=f;f=ic(e);v[e>>2]=f;v[f>>2]=0;Fa=Fb(e),Ga=0,v[Fa>>2]=Ga}d=d+12|0;f=ic(d);ht(d,v[f>>2]);e=e+12|0;v[d>>2]=v[e>>2];v[d+4>>2]=v[e+4>>2];v[d+8>>2]=v[e+8>>2];jb:{if(!v[Fb(d)>>2]){v[d>>2]=f;break jb}v[v[f>>2]+8>>2]=f;d=ic(e);v[e>>2]=d;v[d>>2]=0;Fa=Fb(e),Ga=0,v[Fa>>2]=Ga}break hb}if(f){Xy(d);break hb}vN(d,e)}}else{d=B(f,872);Rp((d+a|0)+616|0,(d+l|0)+616|0);f=f+1|0;continue}break}Wy(a);a=0;v[b+1074400>>2]=0;t[b+1074476|0]=1;d=b+1074392|0;v[d>>2]=-2;v[d+4>>2]=0;v[b+1074428>>2]=v[b+1074424>>2];kb:{lb:{d=v[b+1298300>>2];if(!Ed(d)){break lb}v[23588]=0;Y(591,d|0);d=v[23588];v[23588]=0;if((d|0)!=1){break lb}break kb}while(1){if(x[b+480188>>1]<=a>>>0){a=$z(i+16|0);Fa=i,Ga=Fi(v[n+12>>2]),v[Fa+8>>2]=Ga;e=b+906300|0;p=wf(n+12|0);while(1){d=v[i+8>>2];if(!Hg(d,p)){mb:{p=250;d=a;nb:{while(1){if(p>>>0>=32){if(v[a>>2]){a=1;break nb}else{p=p-32|0;a=a+4|0;continue}}break}a=(v[d+28>>2]&67108863)!=0}if(!a){break mb}a=0;while(1){if((a|0)==250){break mb}Cb(i,d,a);ob:{if(!Bb(v[v[i>>2]>>2],v[i+4>>2])){break ob}f=v[Ld(e,a)>>2];g=v[v[f>>2]+180>>2];v[23588]=0;Y(g|0,f|0);f=v[23588];v[23588]=0;if((f|0)!=1){break ob}break kb}a=a+1|0;continue}}Fa=i,Ga=Fi(v[n>>2]),v[Fa>>2]=Ga;a=wf(n);while(1){d=v[i>>2];if(Hg(d,a)){d=vd(d);f=ic(d);Fa=Ld(e,w[d|0]),Ia=z[f>>2],z[Fa+144>>2]=Ia;Kg(i);continue}else{Sp(n);break b}}}f=vd(d);N=Fb(f);pb:{g=w[f|0];d=v[Ld(e,g)>>2];if(d){Cb(i,a,g);if(!Bb(v[v[i>>2]>>2],v[i+4>>2])){v[23588]=0;Q(592,a|0,g|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break pb}g=v[v[d>>2]+176>>2];v[23588]=0;R(g|0,d|0,-1);g=v[23588];v[23588]=0;if((g|0)==1){break pb}}Ea=z[N>>2];f=v[f+4>>2];g=v[v[d>>2]+44>>2];v[23588]=0;Aa(g|0,d|0,f|0,C(Ea));d=v[23588];v[23588]=0;if((d|0)==1){break pb}}Kg(i+8|0);continue}break}break kb}d=B(a,872)+b|0;e=w[d+1075791|0];if(e){t[d+1075794|0]=e}d=af(v[r+8>>2],a);if(!((ca|0)==7|w[d+5|0]==255)){t[i+16|0]=64;Fa=(B(a,872)+b|0)+1075680|0,Ga=w[Wb(d+5|0,i+16|0)|0]<<2,v[Fa>>2]=Ga}qb:{e=B(a,872)+b|0;d=v[e+1075096>>2];rb:{if(!d|!(w[d+35|0]&2)){break rb}f=v[b+1298300>>2];if(!Ed(f)){break rb}v[23588]=0;ka=f;f=a&65535;U(593,ka|0,f|0,d+68|0);d=v[23588];v[23588]=0;if((d|0)==1){break qb}d=v[b+1298300>>2];v[23588]=0;U(594,d|0,f|0,1);d=v[23588];v[23588]=0;if((d|0)==1){break qb}}v[e+1075008>>2]=0;a=a+1|0;continue}break}}k=P()|0;O()|0;Sp(n);break f}k=P()|0;O()|0}mt(J)}IN(r)}Di($);T(k|0);L()}if((c|0)==3){break b}v[b+1074416>>2]=v[b+480196>>2];v[b+1074420>>2]=v[b+480204>>2];v[b+1074456>>2]=v[b+480200>>2]}a=oa&255;if((a|0)==w[b+484376|0]){break a}Fj(na,a)}if(c&9){a=b+1298264|0;if(v[a>>2]){zO(a);b=v[a>>2];Vj(a);Mb(b);Fa=Fb(a),Ga=0,v[Fa>>2]=Ga;v[a>>2]=0;v[a+4>>2]=0}v[a>>2]=v[J>>2];v[a+4>>2]=v[J+4>>2];b=Fb(J);Fa=Fb(a),Ga=v[b>>2],v[Fa>>2]=Ga;v[b>>2]=0;v[J>>2]=0;v[J+4>>2]=0;a=a+12|0;c=ic(a);Wp(a,v[c>>2]);b=J+12|0;v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=v[b+8>>2];sb:{if(!v[Fb(a)>>2]){v[a>>2]=c;break sb}v[v[c>>2]+8>>2]=c;a=ic(b);v[b>>2]=a;v[a>>2]=0;Fa=Fb(b),Ga=0,v[Fa>>2]=Ga}}mt(J);IN(r);jb=i+192|0}function vS(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0,m=C(0),n=0,o=0,p=0,q=0,r=0,s=0,A=C(0),D=C(0),E=0,F=0,G=0,H=0,I=C(0),J=C(0),K=0,M=C(0),N=C(0),O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=C(0),_=C(0),$=0,ba=C(0),ca=C(0),da=0,ea=0,fa=C(0),ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0;U=jb-16|0;jb=U;a:{if(v[a+1420>>2]>=0){v[f>>2]=0;Q=v[a+1420>>2];d=(Q|0)>0?Q:0;while(1){if((d|0)!=(E|0)){v[(B(E,20)+a|0)+1436>>2]=0;E=E+1|0;continue}break}b:{c:{d:{if((Q|0)>3){break d}E=0;if((c|0)<4){break c}c=c-3|0;d=0;while(1){if((c|0)==(d|0)){break d}e:{f:{h=b+d|0;if(w[h|0]!=79){break f}if(Rb(h,93872,4)){break f}g=d+26|0;if((g|0)>=(c|0)){break e}j=d+27|0;i=b+g|0;f=w[i|0];if((j+f|0)>=(c|0)){break e}k=f+27|0;E=0;e=0;while(1)if((e|0)==(f|0)){e=0;while(1){f=22;if((E|0)!=22){e=jx(e,w[(d+E|0)+b|0]);E=E+1|0;continue}break}while(1){if((f|0)!=26){f=f+1|0;e=jx(e,0);continue}break}v[a+1420>>2]=Q+1;f=B(Q,20)+a|0;v[f+1432>>2]=e;v[f+1428>>2]=k-26;v[f+1424>>2]=w[h+22|0]|w[h+23|0]<<8|(w[h+24|0]<<16|w[h+25|0]<<24);e=w[(g+w[i|0]|0)+b|0]==255?-1:w[h+6|0]|w[h+7|0]<<8|(w[h+8|0]<<16|w[h+9|0]<<24);v[f+1436>>2]=g;v[f+1440>>2]=e;Q=v[a+1420>>2];if((Q|0)!=4){break f}Q=4;break d}else{k=w[(e+j|0)+b|0]+k|0;e=e+1|0;continue}}d=d+1|0;continue}break}c=d}d=0;g:while(1){i=(d|0)>(Q|0)?d:Q;while(1){if((d|0)==(i|0)){break b}E=0;f=B(d,20)+a|0;n=f+1428|0;h=v[n>>2];k=v[f+1436>>2];j=c-k|0;g=(h|0)<(j|0)?h:j;l=(g|0)>0?g:0;da=f+1432|0;e=v[da>>2];while(1){if((l|0)!=(E|0)){e=jx(e,w[(k+E|0)+b|0]);E=E+1|0;continue}break}v[n>>2]=h-g;v[da>>2]=e;if((h|0)<=(j|0)){h=e;e=f+1424|0;if((h|0)==v[e>>2]){v[a+1380>>2]=-1;v[a+992>>2]=0;v[a+1420>>2]=-1;b=v[(B(d,20)+a|0)+1440>>2];v[a+1060>>2]=b;v[a+1064>>2]=(b|0)!=-1;E=g+k|0;break c}f=Q-1|0;v[a+1420>>2]=f;f=B(f,20)+a|0;v[e+16>>2]=v[f+1440>>2];h=f+1432|0;g=v[h+4>>2];v[e+8>>2]=v[h>>2];v[e+12>>2]=g;f=f+1424|0;h=v[f+4>>2];v[e>>2]=v[f>>2];v[e+4>>2]=h;Q=v[a+1420>>2];continue g}else{d=d+1|0;continue}}}}c=E}break a}v[a+100>>2]=0;v[a+32>>2]=b;v[a+40>>2]=b+c;if(!lI(a)){v[f>>2]=0;c=0;break a}qa=U+12|0;da=jb-16|0;jb=da;v[a+1504>>2]=0;v[a+1508>>2]=0;h:{if(v[a+96>>2]){break h}i:{j:{k:{if(v[a+1380>>2]!=-1){break k}c=_e(a);if(v[a+96>>2]){break i}if((c|0)!=79){break j}if((_e(a)|0)!=103){break j}if((_e(a)|0)!=103){break j}if((_e(a)|0)!=83){break j}if(!kI(a)){break i}if(!(t[a+1375|0]&1)){break k}t[a+1376|0]=0;v[a+1384>>2]=0;dc(a,32);break i}k=gx(a);break i}dc(a,30)}if(!k){break h}if(nc(a,1)){dc(a,35);break h}s=da;l:{m:{if(!(v[a+84>>2]!=v[a+92>>2]?v[a+80>>2]:0)){c=nc(a,im(v[a+408>>2]-1|0));if((c|0)==-1|(c|0)>=v[a+408>>2]){break h}v[da+12>>2]=c;k=B(c,6)+a|0;if(!w[k+412|0]){h=v[a+112>>2];g=h>>1;break m}h=v[a+116>>2];g=h>>1;c=nc(a,1);j=nc(a,1);if(c|!w[k+412|0]){break m}v[U+4>>2]=h-v[a+112>>2]>>2;c=v[a+112>>2]+h>>2;break l}aa(6328,13110,3152,10684);L()}v[U+4>>2]=0;c=g}v[s+8>>2]=c;n:{if(!(!w[k+412|0]|j)){c=B(h,3);v[U+8>>2]=c-v[a+112>>2]>>2;h=c+v[a+112>>2]>>2;break n}v[U+8>>2]=g}v[da+4>>2]=h;h=1}if(h){E=v[U+4>>2];la=v[U+8>>2];ka=v[da+4>>2];O=jb-2368|0;jb=O;F=v[a+404>>2];oa=B(v[da+12>>2],6)+a|0;G=w[oa+413|0];R=F+B(G,40)|0;V=v[((w[oa+412|0]<<2)+a|0)+104>>2];ha=V>>1;sa=0-ha|0;o:{while(1){c=v[a+4>>2];if((c|0)>(n|0)){c=w[(v[R+4>>2]+B(n,3)|0)+2|0];P=(O+1344|0)+(n<<2)|0;v[P>>2]=0;h=w[(c+R|0)+9|0];if(!x[((h<<1)+a|0)+132>>1]){dc(a,21);c=0;break o}g=v[a+260>>2];p:{q:{if(!nc(a,1)){break q}c=2;k=v[((n<<2)+a|0)+996>>2];g=g+B(h,1596)|0;r=v[(w[g+1588|0]<<2)+72700>>2];h=im(r)-1|0;ta=k,ua=nc(a,h),u[ta>>1]=ua;ta=k,ua=nc(a,h),u[ta+2>>1]=ua;H=g+82|0;W=g+65|0;T=g+49|0;S=g+33|0;K=g+1|0;o=0;while(1){if(w[g|0]>o>>>0){p=w[o+K|0];q=w[p+T|0];l=-1<<q;X=w[p+S|0];r:{if(!q){i=0;break r}h=v[a+124>>2]+B(w[p+W|0],2096)|0;if(v[a+1396>>2]<=9){$k(a)}j=v[a+1392>>2];i=u[(h+((j&1023)<<1)|0)+36>>1];s:{if((i|0)>=0){s=j;i=i&65535;j=w[i+v[h+8>>2]|0];v[a+1392>>2]=s>>>j;j=v[a+1396>>2]-j|0;v[a+1396>>2]=(j|0)>0?j:0;i=(j|0)>=0?i:-1;break s}i=hm(a,h)}if(!w[h+23|0]){break r}i=v[v[h+2088>>2]+(i<<2)>>2]}ea=l^-1;h=c+X|0;while(1){if((c|0)!=(h|0)){l=0;j=u[(H+(p<<4)|0)+((i&ea)<<1)>>1];t:{if((j|0)<0){break t}j=v[a+124>>2]+B(j&65535,2096)|0;if(v[a+1396>>2]<=9){$k(a)}l=v[a+1392>>2];X=u[(j+((l&1023)<<1)|0)+36>>1];u:{if((X|0)>=0){s=l;X=X&65535;l=w[X+v[j+8>>2]|0];v[a+1392>>2]=s>>>l;l=v[a+1396>>2]-l|0;v[a+1396>>2]=(l|0)>0?l:0;l=(l|0)>=0?X:-1;break u}l=hm(a,j)}if(!w[j+23|0]){break t}l=v[v[j+2088>>2]+(l<<2)>>2]}i=i>>q;u[k+(c<<1)>>1]=l;c=c+1|0;continue}break}o=o+1|0;c=h;continue}break}if(v[a+1396>>2]==-1){break q}u[O+320>>1]=257;h=g+338|0;o=g+1088|0;c=2;while(1){l=v[g+1592>>2];if((l|0)<=(c|0)){c=0;while(1){if((c|0)>=(l|0)){break p}if(!w[(O+320|0)+c|0]){u[k+(c<<1)>>1]=65535;l=v[g+1592>>2]}c=c+1|0;continue}}else{j=c<<1;l=j+o|0;q=w[l|0];p=q<<1;i=x[p+h>>1];P=w[l+1|0];H=P<<1;W=u[k+p>>1];l=u[H+k>>1]-W|0;p=l>>31;i=(B((l^p)-p|0,x[h+j>>1]-i|0)|0)/(x[h+H>>1]-i|0)|0;l=W+((l|0)<0?0-i|0:i)|0;H=k+j|0;i=x[H>>1];v:{w:{if(i){j=O+320|0;t[j+P|0]=1;t[j+q|0]=1;t[c+j|0]=1;j=i<<16>>16;p=r-l|0;if((j|0)>=((l|0)>(p|0)?p:l)<<1){if((l|0)<(p|0)){break v}l=r+(i^-1)|0;break w}if(j&1){l=l-(j+1>>>1|0)|0;break w}l=(j>>1)+l|0;break w}t[(O+320|0)+c|0]=0}u[H>>1]=l}c=c+1|0;continue}}}v[P>>2]=1}n=n+1|0;continue}break}if(!(v[a+84>>2]!=v[a+92>>2]?v[a+80>>2]:0)){tc(O+320|0,O+1344|0,c<<2);g=x[R>>1];c=0;while(1){if((c|0)==(g|0)){c=F+B(G,40)|0}else{k=v[R+4>>2]+B(c,3)|0;h=w[k+1|0];l=O+1344|0;k=l+(w[k|0]<<2)|0;if(!(v[(h<<2)+l>>2]?v[k>>2]:0)){v[(O+1344|0)+(h<<2)>>2]=0;v[k>>2]=0}c=c+1|0;continue}break}X=c;i=0;while(1){x:{if(w[X+8|0]>i>>>0){l=0;c=v[a+4>>2];k=(c|0)>0?c:0;c=0;while(1){if((c|0)==(k|0)){break x}if(w[(v[R+4>>2]+B(c,3)|0)+2|0]==(i|0)){h=l+O|0;g=c<<2;y:{if(v[g+(O+1344|0)>>2]){g=0;n=1;break y}g=v[(a+g|0)+800>>2];n=0}t[h|0]=n;v[(O+256|0)+(l<<2)>>2]=g;l=l+1|0}c=c+1|0;continue}}if(!(v[a+84>>2]!=v[a+92>>2]?v[a+80>>2]:0)){k=(ha|0)>0?ha:0;h=x[R>>1];g=a+800|0;z:while(1){if((h|0)<=0){P=ha<<2;l=0;c=0;while(1){i=v[a+4>>2];if((i|0)<=(c|0)){while(1){if((i|0)>(l|0)){P=w[oa+412|0];R=V>>1;h=R<<2;X=v[a+92>>2];p=V>>3;W=V>>2;k=v[((l<<2)+a|0)+800>>2];c=R<<2;G=k+c|0;A:{if(v[a+80>>2]){j=Fn(a,h);break A}j=Od(h)}h=(j+c|0)-8|0;g=v[((P<<2)+a|0)+1068>>2];i=g;c=k;while(1){if((c|0)!=(G|0)){z[h+4>>2]=C(z[c>>2]*z[i>>2])-C(z[i+4>>2]*z[c+8>>2]);z[h>>2]=C(z[c>>2]*z[i+4>>2])+C(z[c+8>>2]*z[i>>2]);c=c+16|0;i=i+8|0;h=h-8|0;continue}break}c=((R<<2)+k|0)-12|0;while(1){if(h>>>0>=j>>>0){z[h+4>>2]=C(z[c>>2]*z[i+4>>2])-C(z[c+8>>2]*z[i>>2]);z[h>>2]=C(C(-z[c+8>>2])*z[i+4>>2])-C(z[i>>2]*z[c>>2]);c=c-16|0;i=i+8|0;h=h-8|0;continue}break}c=W<<2;o=c+k|0;h=c+j|0;i=(g+(R<<2)|0)-32|0;c=j;n=k;while(1){if(g>>>0<=i>>>0){m=z[c>>2];A=z[h>>2];D=z[h+4>>2];I=z[c+4>>2];z[o+4>>2]=D+I;z[o>>2]=z[h>>2]+z[c>>2];D=C(D-I);m=C(A-m);z[n+4>>2]=C(D*z[i+16>>2])-C(z[i+20>>2]*m);z[n>>2]=C(m*z[i+16>>2])+C(D*z[i+20>>2]);m=z[c+8>>2];A=z[h+8>>2];D=z[h+12>>2];I=z[c+12>>2];z[o+12>>2]=D+I;z[o+8>>2]=z[h+8>>2]+z[c+8>>2];D=C(D-I);m=C(A-m);z[n+12>>2]=C(D*z[i>>2])-C(z[i+4>>2]*m);z[n+8>>2]=C(m*z[i>>2])+C(D*z[i+4>>2]);c=c+16|0;h=h+16|0;n=n+16|0;o=o+16|0;i=i-32|0;continue}break}h=im(V);c=V>>4;n=R-1|0;i=0-p|0;hI(c,k,n,i,g);hI(c,k,n-W|0,i,g);H=V>>5;c=0-c|0;rp(H,k,n,c,g,16);rp(H,k,n-p|0,c,g,16);rp(H,k,n-(p<<1)|0,c,g,16);rp(H,k,n+B(p,-3)|0,c,g,16);c=h-4>>1;o=(c|0)>2?c:2;c=2;while(1){B:{C:{D:{if((c|0)==(o|0)){ea=h-7|0;break D}i=0;p=2<<c;p=(p|0)>0?p:0;r=8<<c;q=V>>c+4;F=V>>c+2;T=0-(F>>1)|0;while(1){if((i|0)==(p|0)){break C}rp(q,k,n-B(i,F)|0,T,g,r);i=i+1|0;continue}}while(1){E:{if((o|0)<(ea|0)){ma=32<<o;r=2<<o;T=8<<o;i=V>>o+6;Y=V>>o+2;$=0-(Y>>1)|0;h=n;c=g;while(1){if((i|0)<=0){break E}p=r;F=(h<<2)+k|0;q=F+($<<2)|0;S=B(T,12)+c|0;m=z[S>>2];K=(T<<3)+c|0;A=z[K>>2];s=(T<<2)+c|0;D=z[s>>2];I=z[S+4>>2];M=z[K+4>>2];Z=z[s+4>>2];_=z[c+4>>2];fa=z[c>>2];S=0-Y<<2;while(1){if((p|0)>0){K=q-4|0;N=z[K>>2];ba=z[F>>2];ca=z[q>>2];z[F>>2]=ba+ca;s=F-4|0;J=z[s>>2];z[s>>2]=J+z[K>>2];J=C(J-N);N=C(ba-ca);z[K>>2]=C(J*fa)+C(_*N);z[q>>2]=C(N*fa)-C(_*J);K=q-12|0;ba=z[K>>2];s=F-8|0;J=z[s>>2];ia=s;s=q-8|0;ca=z[s>>2];z[ia>>2]=J+ca;ga=F-12|0;N=z[ga>>2];z[ga>>2]=N+z[K>>2];N=C(N-ba);J=C(J-ca);z[K>>2]=C(N*D)+C(Z*J);z[s>>2]=C(J*D)-C(Z*N);K=q-20|0;ba=z[K>>2];s=F-16|0;J=z[s>>2];ia=s;s=q-16|0;ca=z[s>>2];z[ia>>2]=J+ca;ga=F-20|0;N=z[ga>>2];z[ga>>2]=N+z[K>>2];N=C(N-ba);J=C(J-ca);z[K>>2]=C(N*A)+C(M*J);z[s>>2]=C(J*A)-C(M*N);K=q-28|0;ba=z[K>>2];s=F-24|0;J=z[s>>2];ia=s;s=q-24|0;ca=z[s>>2];z[ia>>2]=J+ca;ga=F-28|0;N=z[ga>>2];z[ga>>2]=N+z[K>>2];N=C(N-ba);J=C(J-ca);z[K>>2]=C(N*m)+C(I*J);z[s>>2]=C(J*m)-C(I*N);p=p-1|0;q=q+S|0;F=F+S|0;continue}break}i=i-1|0;h=h-8|0;c=(ma<<2)+c|0;continue}}c=(n<<2)+k|0;i=c-(H<<6)|0;m=z[g+(V>>3<<2)>>2];fa=C(-m);while(1){if(c>>>0>i>>>0){M=z[c>>2];h=c-32|0;Z=z[h>>2];z[c>>2]=M+Z;g=c-4|0;A=z[g>>2];n=g;g=c-36|0;_=z[g>>2];z[n>>2]=A+_;n=c-8|0;D=z[n>>2];s=n;n=c-40|0;J=z[n>>2];z[s>>2]=D+J;p=c-12|0;I=z[p>>2];s=p;p=c-44|0;N=z[p>>2];z[s>>2]=I+N;z[h>>2]=M-Z;z[g>>2]=A-_;g=c-16|0;A=z[g>>2];s=g;g=c-48|0;ba=z[g>>2];z[s>>2]=A+ba;D=C(D-J);I=C(I-N);z[n>>2]=m*C(D+I);z[p>>2]=m*C(I-D);n=c-28|0;D=z[n>>2];p=c-60|0;I=z[p>>2];r=c-24|0;M=z[r>>2];o=c-56|0;Z=z[o>>2];q=c-20|0;_=z[q>>2];s=q;q=c-52|0;J=z[q>>2];z[s>>2]=_+J;z[r>>2]=M+Z;z[n>>2]=D+I;z[g>>2]=_-J;z[q>>2]=-C(A-ba);A=C(D-I);D=C(M-Z);z[o>>2]=m*C(A-D);z[p>>2]=C(D+A)*fa;gI(c);gI(h);c=c+-64|0;continue}break}p=R-4|0;h=j+(p<<2)|0;i=(j+(W<<2)|0)-16|0;c=v[((P<<2)+a|0)+1100>>2];while(1){if(i>>>0>=j>>>0){g=(x[c>>1]<<2)+k|0;z[h+12>>2]=z[g>>2];z[h+8>>2]=z[g+4>>2];z[i+12>>2]=z[g+8>>2];z[i+8>>2]=z[g+12>>2];g=(x[c+2>>1]<<2)+k|0;z[h+4>>2]=z[g>>2];z[h>>2]=z[g+4>>2];z[i+4>>2]=z[g+8>>2];z[i>>2]=z[g+12>>2];c=c+4|0;h=h-16|0;i=i-16|0;continue}break}c=v[((P<<2)+a|0)+1084>>2];i=j;h=i+(R<<2)|0;g=h;while(1){n=g-16|0;if(n>>>0>i>>>0){m=z[i+4>>2];r=g-4|0;A=z[r>>2];D=C(m-A);I=z[c+4>>2];m=C(m+A);A=z[i>>2];o=g-8|0;M=z[o>>2];Z=C(A-M);_=z[c>>2];fa=C(C(I*m)-C(Z*_));z[i+4>>2]=D+fa;A=C(A+M);m=C(C(I*Z)+C(m*_));z[i>>2]=A+m;z[r>>2]=fa-D;z[o>>2]=A-m;m=z[i+8>>2];A=z[n>>2];D=C(m+A);I=z[c+12>>2];m=C(m-A);A=z[i+12>>2];g=g-12|0;M=z[g>>2];Z=C(A+M);_=z[c+8>>2];fa=C(C(I*m)+C(Z*_));z[i+8>>2]=D+fa;A=C(A-M);m=C(C(I*Z)-C(m*_));z[i+12>>2]=A+m;z[n>>2]=D-fa;z[g>>2]=m-A;i=i+16|0;c=c+16|0;g=n;continue}break}i=v[((P<<2)+a|0)+1076>>2]+(R<<2)|0;c=(p<<2)+k|0;g=((V<<2)+k|0)-16|0;while(1){n=h-32|0;if(n>>>0>=j>>>0){m=z[h-8>>2];A=z[i-4>>2];D=z[i-8>>2];I=z[h-4>>2];M=C(C(m*A)-C(D*I));z[k>>2]=M;z[c+12>>2]=-M;m=C(C(D*C(-m))-C(A*I));z[G>>2]=m;z[g+12>>2]=m;m=z[h-16>>2];A=z[i-12>>2];D=z[i-16>>2];I=z[h-12>>2];M=C(C(m*A)-C(D*I));z[k+4>>2]=M;z[c+8>>2]=-M;m=C(C(D*C(-m))-C(A*I));z[G+4>>2]=m;z[g+8>>2]=m;m=z[h-24>>2];A=z[i-20>>2];D=z[i-24>>2];I=z[h-20>>2];M=C(C(m*A)-C(D*I));z[k+8>>2]=M;z[c+4>>2]=-M;m=C(C(D*C(-m))-C(A*I));z[G+8>>2]=m;z[g+4>>2]=m;m=z[n>>2];A=z[i-28>>2];i=i-32|0;D=z[i>>2];I=z[h-28>>2];M=C(C(m*A)-C(D*I));z[k+12>>2]=M;z[c>>2]=-M;m=C(C(D*C(-m))-C(A*I));z[G+12>>2]=m;z[g>>2]=m;g=g-16|0;c=c-16|0;G=G+16|0;k=k+16|0;h=n;continue}break}if(!v[a+80>>2]){Mb(j)}v[a+92>>2]=X;break B}o=o+1|0;continue}}c=c+1|0;continue}break}l=l+1|0;i=v[a+4>>2];continue}break}}else{h=c<<2;g=h+a|0;i=v[g+800>>2];F:{if(v[h+(O+320|0)>>2]){Tb(i,0,P);break F}F=v[g+996>>2];G:{h=w[(R+w[(v[R+4>>2]+B(c,3)|0)+2|0]|0)+9|0];if(!x[((h<<1)+a|0)+132>>1]){dc(a,21);break G}n=V>>1;p=v[a+260>>2]+B(h,1596)|0;H=p+338|0;W=p+838|0;k=B(w[p+1588|0],u[F>>1]);o=1;h=0;while(1){if(v[p+1592>>2]>(o|0)){g=w[o+W|0]<<1;j=u[g+F>>1];if((j|0)>=0){j=B(w[p+1588|0],j&65535);g=x[g+H>>1];if((g|0)!=(h|0)){q=j-k|0;r=g-h|0;G=(q|0)/(r|0)|0;H:{T=(g|0)<(n|0)?g:n;if((T|0)<=(h|0)){break H}s=q;q=q>>31;S=G>>31;S=((s^q)-q|0)-B(r,(S^G)-S|0)|0;K=q|1;q=i+(h<<2)|0;z[q>>2]=z[((k&255)<<2)+72720>>2]*z[q>>2];T=T-1|0;q=0;while(1){if((h|0)==(T|0)){break H}h=h+1|0;X=i+(h<<2)|0;q=q+S|0;ea=(q|0)<(r|0);k=(k+G|0)+(ea?0:K)|0;z[X>>2]=z[((k&255)<<2)+72720>>2]*z[X>>2];q=q-(ea?0:r)|0;continue}}h=g}k=j}o=o+1|0;continue}break}if((h|0)>=(n|0)){break G}g=(k<<2)+72720|0;while(1){if((h|0)==(n|0)){break G}k=i+(h<<2)|0;z[k>>2]=z[g>>2]*z[k>>2];h=h+1|0;continue}}}c=c+1|0;continue}break}jI(a);I:{if(w[a+1377|0]){v[a+1060>>2]=sa;t[a+1377|0]=0;v[a+1064>>2]=1;v[a+1412>>2]=V-ka;break I}c=v[a+1412>>2];if(!c){break I}h=la-E|0;if((h|0)<=(c|0)){v[a+1412>>2]=c-h;v[U+4>>2]=la;E=la;break I}E=c+E|0;v[U+4>>2]=E;v[a+1412>>2]=0}c=v[a+1064>>2];J:{K:{L:{M:{if(v[a+1388>>2]==v[a+1404>>2]){N:{if(!c|!(w[a+1375|0]&4)){break N}c=v[a+1408>>2];h=v[a+1060>>2];if(c>>>0>=h+(ka-E|0)>>>0){break N}h=c-h|0;c=(c>>>0<h>>>0?0:h)+E|0;c=(c|0)<(ka|0)?c:ka;v[qa>>2]=c;v[a+1060>>2]=c+v[a+1060>>2];break K}v[a+1064>>2]=1;c=v[a+1408>>2]+(E-ha|0)|0;break M}if(!c){break L}c=v[a+1060>>2]}v[a+1060>>2]=c+(la-E|0)}if(v[a+84>>2]!=v[a+92>>2]?v[a+80>>2]:0){break J}v[qa>>2]=ka}c=1;break o}aa(6328,13110,3451,5637);L()}h=h-1|0;c=v[R+4>>2]+B(h,3)|0;j=v[g+(w[c+1|0]<<2)>>2];i=v[g+(w[c|0]<<2)>>2];c=0;while(1){if((c|0)==(k|0)){continue z}n=c<<2;l=n+j|0;D=z[l>>2];n=i+n|0;m=z[n>>2];O:{if(m>C(0)){if(D>C(0)){A=C(m-D);break O}A=m;m=C(m+D);break O}if(D>C(0)){A=C(m+D);break O}A=m;m=C(m-D)}z[n>>2]=m;z[l>>2]=A;c=c+1|0;continue}}}aa(6328,13110,3335,5637);L()}W=O+256|0;n=0;q=jb-16|0;jb=q;G=v[a+4>>2];F=v[a+396>>2];o=w[(i+X|0)+24|0];p=F+B(o,24)|0;h=v[p+4>>2];ea=x[((o<<1)+a|0)+268>>1];c=ha<<((ea|0)==2);g=c>>>0>h>>>0?h:c;h=v[p>>2];P=(g-(c>>>0>h>>>0?h:c)>>>0)/y[p+8>>2]|0;k=P<<2;c=B(G,k+4|0);K=v[v[a+124>>2]+B(w[p+13|0],2096)>>2];ga=v[a+92>>2];P:{if(v[a+80>>2]){h=Fn(a,c);G=v[a+4>>2];break P}h=Od(c)}j=(l|0)>0?l:0;H=ha<<2;g=0;c=(G|0)>0?G:0;r=(G<<2)+h|0;while(1){if((c|0)!=(g|0)){v[(g<<2)+h>>2]=r;g=g+1|0;r=k+r|0;continue}break}k=h;c=0;while(1){if((c|0)!=(j|0)){if(!w[c+O|0]){Tb(v[W+(c<<2)>>2],0,H)}c=c+1|0;continue}break}Q:{if(!((l|0)==1|(ea|0)!=2)){c=0;while(1){R:{if((c|0)!=(j|0)){if(w[c+O|0]){break R}}else{c=j}if((c|0)==(l|0)){break Q}r=F+B(o,24)|0;G=(l|0)!=2;F=(l|0)<3;while(1){if((n|0)==8){break Q}S:{if(!G){h=0;o=0;while(1){if((o|0)>=(P|0)){break S}c=v[p>>2]+B(v[p+8>>2],o)|0;v[q+12>>2]=c&1;v[q+8>>2]=c>>1;c=0;if(!n){j=v[a+124>>2]+B(w[p+13|0],2096)|0;if(v[a+1396>>2]<=9){$k(a)}g=v[a+1392>>2];H=u[(j+((g&1023)<<1)|0)+36>>1];T:{if((H|0)>=0){s=g;H=H&65535;g=w[H+v[j+8>>2]|0];v[a+1392>>2]=s>>>g;g=v[a+1396>>2]-g|0;v[a+1396>>2]=(g|0)>0?g:0;g=(g|0)>=0?H:-1;break T}g=hm(a,j)}g=w[j+23|0]?v[v[j+2088>>2]+(g<<2)>>2]:g;if((g|0)==-1){break Q}v[v[k>>2]+(h<<2)>>2]=v[v[r+16>>2]+(g<<2)>>2]}while(1){if(!((c|0)>=(K|0)|(o|0)>=(P|0))){g=v[p+8>>2];j=u[(v[r+20>>2]+(w[v[v[k>>2]+(h<<2)>>2]+c|0]<<4)|0)+(n<<1)>>1];U:{if((j|0)>=0){if(iI(a,v[a+124>>2]+B(j&65535,2096)|0,W,2,q+12|0,q+8|0,ha,g)){break U}break Q}g=v[p>>2]+(g+B(g,o)|0)|0;v[q+8>>2]=g>>1;v[q+12>>2]=g&1}o=o+1|0;c=c+1|0;continue}break}h=h+1|0;continue}}if(F){break S}h=0;o=0;while(1){if((o|0)>=(P|0)){break S}g=v[p>>2]+B(v[p+8>>2],o)|0;c=(g|0)/(l|0)|0;v[q+12>>2]=g-B(c,l);v[q+8>>2]=c;c=0;if(!n){j=v[a+124>>2]+B(w[p+13|0],2096)|0;if(v[a+1396>>2]<=9){$k(a)}g=v[a+1392>>2];H=u[(j+((g&1023)<<1)|0)+36>>1];V:{if((H|0)>=0){s=g;H=H&65535;g=w[H+v[j+8>>2]|0];v[a+1392>>2]=s>>>g;g=v[a+1396>>2]-g|0;v[a+1396>>2]=(g|0)>0?g:0;g=(g|0)>=0?H:-1;break V}g=hm(a,j)}g=w[j+23|0]?v[v[j+2088>>2]+(g<<2)>>2]:g;if((g|0)==-1){break Q}v[v[k>>2]+(h<<2)>>2]=v[v[r+16>>2]+(g<<2)>>2]}while(1){if(!((c|0)>=(K|0)|(o|0)>=(P|0))){g=v[p+8>>2];j=u[(v[r+20>>2]+(w[v[v[k>>2]+(h<<2)>>2]+c|0]<<4)|0)+(n<<1)>>1];W:{if((j|0)>=0){if(!iI(a,v[a+124>>2]+B(j&65535,2096)|0,W,l,q+12|0,q+8|0,ha,g)){break Q}break W}g=v[p>>2]+(g+B(g,o)|0)|0;j=(g|0)/(l|0)|0;v[q+8>>2]=j;v[q+12>>2]=g-B(j,l)}o=o+1|0;c=c+1|0;continue}break}h=h+1|0;continue}}n=n+1|0;continue}}c=c+1|0;continue}}ma=F+B(o,24)|0;l=0;while(1){if((l|0)==8){break Q}n=0;T=0;X:while(1){if((n|0)<(P|0)){h=0;c=0;Y:{if(l){break Y}while(1){if((c|0)==(j|0)){break Y}if(!w[c+O|0]){r=v[a+124>>2]+B(w[p+13|0],2096)|0;if(v[a+1396>>2]<=9){$k(a)}g=v[a+1392>>2];o=u[(r+((g&1023)<<1)|0)+36>>1];Z:{if((o|0)>=0){s=g;o=o&65535;g=w[o+v[r+8>>2]|0];v[a+1392>>2]=s>>>g;g=v[a+1396>>2]-g|0;v[a+1396>>2]=(g|0)>0?g:0;g=(g|0)>=0?o:-1;break Z}g=hm(a,r)}g=w[r+23|0]?v[v[r+2088>>2]+(g<<2)>>2]:g;if((g|0)==-1){break Q}v[v[k+(c<<2)>>2]+(T<<2)>>2]=v[v[ma+16>>2]+(g<<2)>>2]}c=c+1|0;continue}}while(1){_:{$:{if((h|0)>=(K|0)){break $}c=0;if((n|0)>=(P|0)){break $}while(1){if((c|0)==(j|0)){break _}aa:{if(w[c+O|0]){break aa}g=c<<2;r=u[(v[ma+20>>2]+(w[v[v[g+k>>2]+(T<<2)>>2]+h|0]<<4)|0)+(l<<1)>>1];if((r|0)<0){break aa}G=v[a+124>>2]+B(r&65535,2096)|0;Y=v[g+W>>2];S=v[p+8>>2];H=v[p>>2]+B(S,n)|0;ba:{ca:{if(ea){F=0;while(1){g=1;if((F|0)>=(S|0)){break ba}$=Y+(H<<2)|0;g=S-F|0;o=0;m=C(0);da:{s=fI(a,G);if((s|0)<0){break da}r=v[G>>2];g=(g|0)>(r|0)?r:g;s=B(r,s);if(w[G+22|0]){r=0;g=(g|0)>0?g:0;o=1;while(1){if((g|0)==(r|0)){break da}ja=$+(r<<2)|0;m=C(m+z[v[G+28>>2]+(r+s<<2)>>2]);z[ja>>2]=z[ja>>2]+m;r=r+1|0;m=C(m+z[G+12>>2]);continue}}r=0;g=(g|0)>0?g:0;o=1;while(1){if((g|0)==(r|0)){break da}ja=$+(r<<2)|0;z[ja>>2]=z[ja>>2]+C(z[v[G+28>>2]+(r+s<<2)>>2]+C(0));r=r+1|0;continue}}if(!o){break ca}g=v[G>>2];H=g+H|0;F=g+F|0;continue}}F=0;r=(S|0)/v[G>>2]|0;s=(r|0)>0?r:0;ja=Y+(H<<2)|0;g=1;while(1){if((F|0)==(s|0)){break ba}o=F+H|0;Y=F<<2;F=F+1|0;ia=Y+ja|0;Y=S-o|0;$=0;m=C(0);ea:{na=fI(a,G);if((na|0)<0){break ea}o=0;$=v[G>>2];Y=(Y|0)>($|0)?$:Y;Y=(Y|0)>0?Y:0;na=B($,na);$=1;while(1){if((o|0)==(Y|0)){break ea}ra=(B(o,r)<<2)+ia|0;A=C(m+z[v[G+28>>2]+(o+na<<2)>>2]);z[ra>>2]=z[ra>>2]+A;m=w[G+22|0]?A:m;o=o+1|0;continue}}if($){continue}break}}g=0}if(!g){break Q}}c=c+1|0;continue}}T=T+1|0;continue X}n=n+1|0;h=h+1|0;continue}}break}l=l+1|0;continue}}if(!v[a+80>>2]){Mb(k)}v[a+92>>2]=ga;jb=q+16|0;i=i+1|0;continue}}aa(6328,13110,3302,5637);L()}jb=O+2368|0}else{c=0}jb=da+16|0;if(!c){fa:{ga:{ha:{c=v[a+100>>2];switch(c-32|0){case 0:break ga;case 3:break ha;default:break fa}}v[a+100>>2]=0;while(1){if(ta=0,ua=(vh(a)|0)!=-1,va=v[a+96>>2],va?ta:ua){continue}break}v[f>>2]=0;c=v[a+32>>2]-b|0;break a}if(v[a+992>>2]){break fa}v[a+100>>2]=0;while(1){if(ta=0,ua=(vh(a)|0)!=-1,va=v[a+96>>2],va?ta:ua){continue}break}v[f>>2]=0;c=v[a+32>>2]-b|0;break a}v[a+1420>>2]=0;v[a+992>>2]=0;v[a+1504>>2]=0;v[a+1508>>2]=0;v[a+1412>>2]=0;v[a+1416>>2]=0;t[a+1377|0]=0;v[a+1064>>2]=0;v[a+100>>2]=c;v[f>>2]=0;c=1;break a}g=v[U+12>>2];j=v[U+4>>2];h=v[U+8>>2];ia:{ja:{k=v[a+992>>2];if(k){i=k<<1;ka:{if((i|0)==v[a+112>>2]){c=a+1092|0}else{c=0;if((i|0)!=v[a+116>>2]){break ka}c=a+1096|0}c=v[c>>2]}if(!c){break ja}n=(k|0)>0?k:0;while(1){if(v[a+4>>2]>(Q|0)){i=(Q<<2)+a|0;E=0;while(1){if((n|0)!=(E|0)){l=v[i+800>>2]+(j+E<<2)|0;s=l;A=z[l>>2];l=E<<2;z[s>>2]=C(A*z[l+c>>2])+C(z[l+v[i+928>>2]>>2]*z[c+(k+(E^-1)<<2)>>2]);E=E+1|0;continue}break}Q=Q+1|0;continue}break}Q=v[a+992>>2]}v[a+992>>2]=g-h;k=(g|0)<(h|0);i=(k?h:g)-h|0;while(1){if(v[a+4>>2]>(pa|0)){c=(pa<<2)+a|0;E=0;while(1){if((i|0)!=(E|0)){z[v[c+928>>2]+(E<<2)>>2]=z[v[c+800>>2]+(h+E<<2)>>2];E=E+1|0;continue}break}pa=pa+1|0;continue}break}if(!Q){break ja}c=(k?g:h)-j|0;v[a+1416>>2]=c+v[a+1416>>2];break ia}c=0}h=c;v[U+12>>2]=c;c=0;g=v[a+4>>2];k=(g|0)>0?g:0;while(1){if((c|0)!=(k|0)){i=(c<<2)+a|0;v[i+864>>2]=v[i+800>>2]+(j<<2);c=c+1|0;continue}break}if(d){v[d>>2]=g}v[f>>2]=h;v[e>>2]=a+864;c=v[a+32>>2]-b|0}jb=U+16|0;return c}function tga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;d=jb-1760|0;jb=d;yc(b);f=jb-16|0;jb=f;h=d+1632|0;RR(f+8|0,h);g=v[f+12>>2];k=b;mc(f,v[b>>2],v[b+8>>2],v[f+8>>2],v[f+12>>2]);b=v[f+4>>2];if((b|0)==(g|0)){Zb(k,v[f+12>>2])}jb=f+16|0;b=(b|0)==(g|0);if(!b){QR(h)}a:{if(!b){break a}if(!SR(d+1632|0)){break a}if(!Pb(v[k>>2],v[k+8>>2],Dc(256,0))){break a}b:{if(!c){break b}Ad(a,1048576);$f(a);b=jb-16|0;jb=b;e=xc(b,4233);$c(d+1376|0,e);zb(e);jb=b+16|0;b=x[d+1640>>1];v[d+160>>2]=b>>>8;v[23588]=0;v[d+16>>2]=b&255;R(433,d+88|0,d+16|0);b=v[23588];v[23588]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{if((b|0)!=1){v[23588]=0;X(419,d+272|0,d+1376|0,d+160|0,d+88|0);b=v[23588];v[23588]=0;if((b|0)==1){break m}b=d+272|0;Ib(a+1298344|0,b);zb(b);e=d+88|0;zb(e);f=d+1376|0;ac(f);g=xc(b,15090);Ib(a+1298356|0,g);zb(g);Me(e,2,d+1642|0);Ec(f,e);v[23588]=0;U(11,b|0,8,f|0);b=v[23588];v[23588]=0;if((b|0)==1){break i}b=d+272|0;Ib(a+1298368|0,b);zb(b);e=d+1376|0;yb(e);v[a+1298404>>2]=8;aA(e,2,d+1674|0);Ec(b,e);Ac(a+1298308|0,b);yb(b);u[a+480188>>1]=x[d+1744>>1];f=w[d+1748|0];v[a+480204>>2]=125e4;v[a+480208>>2]=32792;G=a,H=Cd(f,1,31),v[G+480196>>2]=H;u[a+480192>>1]=x[d+1754>>1];u[a+480190>>1]=x[d+1756>>1];f=Cd(w[d+1749|0],1,32);v[a+480216>>2]=f;v[a+480228>>2]=96;v[a+480232>>2]=48;v[a+480220>>2]=f<<2;ev(k,e);f=a+484360|0;g=a+484376|0;Vq(Vb(v[f>>2],w[g|0]),e,x[d+1738>>1],65535,65535);Ue(Vb(v[f>>2],w[g|0]),x[d+1740>>1]);p=Rg(k);$d(b,k,p?274:0);A=jc(d+1352|0,b);Ab(b);v[23588]=0;b=S(157,k|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break k}v[23588]=0;U(190,d+272|0,k|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break k}b=d+272|0;s=jc(d+1328|0,b);Ab(b);b=a+480188|0;o=x[b>>1];if(p){u[b>>1]=o+8}z=c&1;if(!z){break j}v[23588]=0;R(225,a+484344|0,x[d+1742>>1]);b=v[23588];v[23588]=0;if((b|0)!=1){break j}g=P()|0;O()|0;break e}g=P()|0;O()|0;break l}g=P()|0;O()|0;zb(d+88|0)}ac(d+1376|0);break c}g=P()|0;O()|0;break d}q=a+484344|0;C=a+480188|0;g=0;while(1){n:{o:{p:{q:{r:{s:{if(x[d+1742>>1]<=r>>>0){b=x[d+1746>>1];if((b-2&65535)>>>0>=4998){break q}if(!(g&1)){break s}i=0;b=Hc(((b>>>1|0)+11025e5>>>0)/(b>>>0)|0,0);break r}v[23588]=0;b=S(194,k|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break f}v[d+160>>2]=b;v[23588]=0;b=S(157,k|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break g}v[23588]=0;U(190,d+88|0,k|0,b+1&-2);b=v[23588];v[23588]=0;if((b|0)==1){break g}b=d+88|0;m=jc(d+272|0,b);Ab(b);wc(d+160|0,1024);if(!z){break o}l=v[d+160>>2];if(!l){break o}v[23588]=0;b=W(226,q|0,r&65535,l|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){if(!b){break o}h=0;e=0;if(t[d+1750|0]&1){break p}t:while(1){if((h|0)==(l|0)){break o}e=0;b=Yb(v[q>>2],r);b=Cf(v[b>>2],v[v[b+48>>2]+12>>2],h);while(1){if((e|0)==(o|0)){h=h+1|0;continue t}v[23588]=0;R(601,m|0,d+88|0);f=v[23588];v[23588]=0;if((f|0)!=1){g=PR(b+B(e,6)|0,d+88|0)|g;e=e+1|0;continue}break}break}break h}break h}i=2;b=Pe(2646e3/+(B(b,B(v[a+480216>>2],v[a+480196>>2]))>>>0)*1e4)}t[a+480224|0]=i;v[a+480204>>2]=b}h=a+480188|0;b=x[h>>1];v[23588]=0;t[d+272|0]=0;r=W(602,d+1312|0,b|0,d+272|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){i=a+1298320|0;l=a+1298332|0;n=a+484348|0;m=0;u:{v:{w:{x:{y:{z:{while(1){b=v[s+8>>2];e=v[s>>2];v[23588]=0;b=W(156,e|0,b|0,8)|0;e=v[23588];v[23588]=0;A:{if((e|0)!=1){if(b){break A}f=a+906300|0;g=v[r>>2];h=0;i=a+480188|0;while(1){e=x[i>>1];if(e>>>0<=h>>>0){v[d+264>>2]=0;v[d+268>>2]=0;v[d+256>>2]=0;v[d+260>>2]=0;v[d+248>>2]=0;v[d+252>>2]=0;v[d+240>>2]=0;v[d+244>>2]=0;B:{C:{if(!p){break C}e=0;v[23588]=0;R(603,A|0,d+272|0);b=v[23588];v[23588]=0;if((b|0)==1){break B}while(1){if((e|0)==8){e=0;v[23588]=0;h=Q(218,d+224|0,x[d+272>>1])|0;b=v[23588];v[23588]=0;if((b|0)!=1){D:{E:{F:{G:{while(1){if(x[d+272>>1]<=e>>>0){v[23588]=0;l=W(604,d+208|0,x[d+1742>>1],26924)|0;b=v[23588];v[23588]=0;if((b|0)==1){break E}j=a+484376|0;z=a+484348|0;C=a+480188|0;f=0;break F}v[23588]=0;b=S(194,k|0)|0;f=v[23588];v[23588]=0;if((f|0)!=1){v[23588]=0;U(190,d+160|0,k|0,b<<5);b=v[23588];v[23588]=0;if((b|0)==1){break G}f=d+160|0;b=jc(d+88|0,f);gd(Og(v[h>>2],e),b);Ab(b);e=e+1|0;Ab(f);continue}break}g=P()|0;O()|0;break D}g=P()|0;O()|0;break D}while(1){if(x[d+1738>>1]<=f>>>0){nd(l);Uc(h);break C}H:{g=d+f|0;e=w[g+290|0];if(e>>>0>=x[d+272>>1]){break H}b=x[cc(v[Vb(v[a+484360>>2],w[j|0])>>2],f)>>1];if(b>>>0>=x[d+1742>>1]){break H}I:{i=cc(v[l>>2],b);n=x[i>>1];J:{if((n|0)==65535){u[i>>1]=e;break J}if((e|0)==(n|0)){break J}v[23588]=0;e=Q(605,q|0,b|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break I}if((e|0)==65535){break J}G=cc(v[Vb(v[a+484360>>2],w[j|0])>>2],f),H=e,u[G>>1]=H;b=e}if(!xe(v[a+484344>>2],v[z>>2],b)){break H}p=Og(v[h>>2],w[g+290|0]);yc(p);e=v[p>>2];v[23588]=0;e=S(160,e|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break I}D=e>>>5|0;i=0;K:while(1){e=Yb(v[q>>2],b);if(y[e+12>>2]<=i>>>0){break H}g=0;e=id(v[e>>2],v[v[e+48>>2]+12>>2],i,x[C>>1]-8&65535);while(1){if((g|0)==8){i=i+1|0;continue K}Ej(d+88|0);n=x[d+92>>1];t[e+4|0]=n;t[e+5|0]=n>>>8;n=v[d+88>>2];t[e|0]=n;t[e+1|0]=n>>>8;t[e+2|0]=n>>>16;t[e+3|0]=n>>>24;L:{if(i>>>0>=D>>>0){break L}v[23588]=0;Q(606,p|0,d+88|0)|0;n=v[23588];v[23588]=0;if((n|0)==1){break I}if(t[d+88|0]>=0){break L}t[e|0]=61;t[e+1|0]=w[(d+256|0)+(g<<1)|0];n=w[d+88|0]&31;t[d+160|0]=n;if(n){vf(d+160|0,15);t[e+3|0]=20;t[e+5|0]=w[d+160|0]|208}t[e+2|0]=1;t[e+4|0]=w[d+89|0]+3>>>2}e=e+6|0;g=g+1|0;continue}}}g=P()|0;O()|0;nd(l);break D}f=f+1|0;continue}}g=P()|0;O()|0}Uc(h);break u}g=P()|0;O()|0;break u}f=e<<1;g=f+(d+256|0)|0;b=x[a+480192>>1]+1&65535;h=x[v[a+8>>2]+58>>1];while(1){M:{N:{i=b&65535;if(i>>>0<=h>>>0){if(v[((i<<2)+a|0)+900380>>2]){break N}}else{b=65535}b=b&65535;break M}b=b+1|0;continue}break}u[g>>1]=b;h=f+(d+240|0)|0;f=x[(d+f|0)+274>>1];u[h>>1]=f;O:{if((b|0)!=65535){v[23588]=0;b=W(251,a|0,b|0,f+1&65535)|0;f=v[23588];v[23588]=0;P:{Q:{if((f|0)!=1){if(!b){break O}v[23588]=0;R(286,d+160|0,4478);f=v[23588];v[23588]=0;if((f|0)==1){break Q}v[23588]=0;v[d+16>>2]=e+1;U(607,d+88|0,d+160|0,d+16|0);f=v[23588];v[23588]=0;if((f|0)==1){break P}f=b+492|0;b=d+88|0;Cc(f,b);yb(b);_b(d+160|0);break O}g=P()|0;O()|0;break u}g=P()|0;O()|0;break u}g=P()|0;O()|0;_b(d+160|0);break u}u[g>>1]=0}e=e+1|0;continue}}R:{S:{b=x[d+1750>>1]|x[d+1752>>1]<<16;if(!(b&2)){break S}b=(((b&8?x[a+480188>>1]:o)&65535)+(x[d+1640>>1]>591?m:0)|0)+(b>>>4&1)|0;f=0;T:while(1){e=0;if(x[d+1742>>1]<=f>>>0){break S}while(1){U:{if((b|0)!=(e|0)){g=v[k+8>>2];h=v[k>>2];v[23588]=0;g=W(156,h|0,g|0,4)|0;h=v[23588];v[23588]=0;if((h|0)==1){break R}if(g){break U}}f=f+1|0;continue T}v[23588]=0;R(608,x[d+1640>>1],k|0);g=v[23588];v[23588]=0;if((g|0)==1){break R}e=e+1|0;continue}}}v[23588]=0;q=Q(218,d+192|0,255)|0;b=v[23588];v[23588]=0;if((b|0)!=1){n=a+480208|0;f=0;while(1){V:{b=f;W:{if((b|0)==255){m=$z(d+88|0);l=$z(d+160|0);g=0;while(1){X:{Y:{Z:{if((g|0)==256){h=0;break Z}v[23588]=0;R(609,k|0,d+272|0);b=v[23588];v[23588]=0;if((b|0)==1){break Y}v[23588]=0;b=S(157,k|0)|0;e=v[23588];v[23588]=0;_:{$:{aa:{if((e|0)!=1){v[23588]=0;U(190,d+16|0,k|0,b|0);e=v[23588];v[23588]=0;if((e|0)==1){break aa}e=d+16|0;h=jc(d- -64|0,e);Ab(e);if(x[d+1756>>1]>g>>>0){e=d+48|0;Me(e,2,d+272|0);v[23588]=0;R(222,d+16|0,e|0);e=v[23588];v[23588]=0;if((e|0)==1){break _}e=d+16|0;Cc(((g<<5)+a|0)+946336|0,e);yb(e)}if(!b){break X}if(x[d+1756>>1]>g>>>0){break $}break X}g=P()|0;O()|0;break W}g=P()|0;O()|0;break W}v[23588]=0;b=B(g+1|0,104)+a|0;e=b+484380|0;R(277,e|0,32);f=v[23588];v[23588]=0;ba:{ca:{da:{if((f|0)!=1){Ko(e);v[23588]=0;R(610,h|0,d+16|0);f=v[23588];v[23588]=0;if((f|0)==1){break _}f=v[d+16>>2];v[e>>2]=f;v[b+484404>>2]=v[d+20>>2];if(w[d+24|0]>=2){i=b+484414|0;u[i>>1]=x[i>>1]|1;f=f>>>1|0;v[e>>2]=f}if(w[d+25|0]>=2){i=b+484414|0;u[i>>1]=x[i>>1]|64;v[e>>2]=f>>>1}i=2;switch(w[d+27|0]-1|0){case 0:break ca;case 1:break da;default:break ba}}break _}i=6}e=b+484414|0;u[e>>1]=x[e>>1]|i}v[b+484384>>2]=v[d+28>>2];v[b+484388>>2]=v[d+32>>2];u[b+484410>>1]=x[d+36>>1]>>>7;e=w[d+38|0];ea:{if((e|0)==128){e=b+484414|0;f=x[e>>1]|256;u[e>>1]=f;break ea}u[b+484408>>1]=(e<<24>>24)+128;f=x[b+484414>>1]}i=b+484414|0;u[i>>1]=f|32;t[b+484416|0]=w[d+39|0];e=w[d+26|0];if(e&2){b=d+48|0;Cb(b,l,g);oo(b);e=w[d+26|0]}if(e&5){u[i>>1]=x[i>>1]|16384}if(!(e&8)){break X}b=d+48|0;Cb(b,m,g);oo(b);e=0;while(1){if((e|0)==8){break X}b=e<<1;fa:{if(x[b+(d+240|0)>>1]!=(g|0)){break fa}b=v[((x[b+(d+256|0)>>1]<<2)+a|0)+900380>>2];if(!b){break fa}t[b+14|0]=0}e=e+1|0;continue}}g=P()|0;O()|0;Ab(h);break W}while(1){ga:{ha:{if(x[d+1754>>1]<=h>>>0){if(!(c&2)){break ha}e=a+1298404|0;f=a+1298464|0;g=0;ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{while(1){if(x[a+480190>>1]<=g>>>0){break ha}g=g+1|0;c=B(g,104)+a|0;h=c+484380|0;b=c+484416|0;Al(h,(+(t[b|0]-49|0)+ +t[c+484417|0]*-.0078125)/-12);u[b>>1]=0;b=x[c+484414>>1];if(!(b&16384)){b=Zc(d+272|0,b&1?16:8,b&64?3:1,0,11);v[23588]=0;W(219,b|0,h|0,k|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){continue}g=P()|0;O()|0;break W}v[23588]=0;h=S(157,k|0)|0;b=v[23588];v[23588]=0;qa:{if((b|0)==1){break qa}v[23588]=0;Q(188,k|0,12)|0;b=v[23588];v[23588]=0;if((b|0)==1){break qa}b=Lb(d+272|0);v[23588]=0;U(268,k|0,b|0,h|0);h=v[23588];v[23588]=0;if((h|0)==1){break pa}Be(c+484423|0,b);v[23588]=0;R(374,d- -64|0,16382);c=v[23588];v[23588]=0;if((c|0)==1){break oa}v[d+12>>2]=g;c=v[e>>2];v[23588]=0;U(11,d+48|0,c|0,b|0);c=v[23588];v[23588]=0;if((c|0)==1){break na}v[23588]=0;X(419,d+16|0,d- -64|0,d+12|0,d+48|0);c=v[23588];v[23588]=0;if((c|0)==1){break ma}c=v[f>>2];v[23588]=0;U(376,c|0,2,d+16|0);c=v[23588];v[23588]=0;if((c|0)==1){break la}zb(d+16|0);zb(d+48|0);ac(d- -64|0);yb(b);continue}break}g=P()|0;O()|0;break W}g=P()|0;O()|0;break ia}g=P()|0;O()|0;break ia}g=P()|0;O()|0;break ja}g=P()|0;O()|0;break ka}g=P()|0;O()|0;zb(d+16|0)}zb(d+48|0)}ac(d- -64|0)}yb(b);break W}b=v[Og(v[q>>2],h)>>2];v[23588]=0;b=S(160,b|0)|0;e=v[23588];v[23588]=0;ra:{sa:{if((e|0)!=1){if(!b){h=h+1|0;continue}b=Og(v[q>>2],h);yc(b);v[23588]=0;R(611,b|0,d+272|0);b=v[23588];v[23588]=0;if((b|0)==1){break sa}i=Sb(d+16|0);v[23588]=0;U(612,k|0,i|0,x[d+272>>1]);b=v[23588];v[23588]=0;if((b|0)==1){break ra}h=h+1|0;b=v[((h<<2)+a|0)+900380>>2];if(!b|w[b+34|0]){break ga}v[b+4>>2]=32;e=0;du(b,0);n=b+108|0;j=b+236|0;while(1){if((e|0)==96){break ga}f=w[(d+e|0)+274|0];ta:{if(f>>>0>=x[d+272>>1]){break ta}g=af(v[i>>2],f);p=e+12|0;z=cc(j,p);f=w[g|0];o=f+1|0;u[z>>1]=o;if(f>>>0>=x[a+480190>>1]){break ta}f=B(o,104)+a|0;t[f+484418|0]=w[d+370|0]&3;t[f+484419|0]=w[d+371|0];t[f+484420|0]=w[d+372|0];t[f+484421|0]=w[d+373|0];u[f+484412>>1]=w[g+1|0]<<1;t[f+484417|0]=w[g+2|0];f=o-1|0;Cb(d- -64|0,m,f);if(Bb(v[v[d+64>>2]>>2],v[d+68>>2])){t[b+14|0]=0}Cb(d- -64|0,l,f);if(!Bb(v[v[d+64>>2]>>2],v[d+68>>2])){break ta}G=Kb(n,p),H=61,t[G|0]=H}e=e+1|0;continue}}g=P()|0;O()|0;break W}g=P()|0;O()|0;break W}g=P()|0;O()|0;qe(i);break W}Uc(q);hc(r);Ab(s);Ab(A);break b}qe(i);continue}}g=P()|0;O()|0;break W}Ab(h);g=g+1|0;continue}}v[23588]=0;R(609,k|0,d+160|0);e=v[23588];v[23588]=0;ua:{va:{wa:{xa:{if((e|0)!=1){v[23588]=0;e=S(157,k|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break xa}v[23588]=0;e=(e|0)==32?428:e;h=e?x[d+1640>>1]>513?e+4|0:e:e;U(190,d+88|0,k|0,h|0);e=v[23588];v[23588]=0;if((e|0)==1){break wa}g=d+88|0;e=jc(d+272|0,g);i=je(d+16|0,gd(Og(v[q>>2],b),e));Ab(e);f=b+1|0;Ab(g);if(b>>>0>=x[d+1754>>1]){break V}v[23588]=0;b=f&65535;g=W(251,a|0,b|0,b|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break va}break ua}g=P()|0;O()|0;break W}g=P()|0;O()|0;break W}g=P()|0;O()|0;break W}if(!g){break V}b=d+88|0;Me(b,2,d+160|0);v[23588]=0;R(222,d+272|0,b|0);b=v[23588];v[23588]=0;ya:{if((b|0)!=1){b=d+272|0;Cc(g+492|0,b);yb(b);if(!h){break V}v[23588]=0;R(611,i|0,d+272|0);b=v[23588];v[23588]=0;if((b|0)!=1){m=3;h=0;if(x[d+1640>>1]<513){l=0;break ya}v[23588]=0;l=S(194,i|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break ua}if(x[d+1640>>1]<514){break ya}v[23588]=0;m=S(157,i|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break ya}break ua}break ua}break ua}v[g>>2]=x[d+374>>1];t[g+16|0]=w[(x[d+376>>1]&3)+26926|0];t[g+17|0]=w[(w[d+377|0]&3)+26926|0];t[g+18|0]=w[(x[d+376>>1]>>>12&3)+26930|0];while(1){za:{Aa:{if((h|0)==4){if(!(t[g+60|0]&1|w[g+16|0]==3)){v[g>>2]=32767}Lj(g,127,1);Kj(g,0,1);if(!l){break V}v[23588]=0;R(613,i|0,d+88|0);b=v[23588];v[23588]=0;if((b|0)==1){break ua}if(l&2){Lj(g,aB(v[n>>2],+x[d+90>>1]),1);Kj(g,w[d+92|0],1)}t[g+25|0]=w[d+89|0]==1;if(!(l&4)){break V}t[g+31|0]=w[d+95|0]+1;b=t[d+96|0];t[g+34|0]=b+1;if((b|0)<0){t[g+30|0]=w[d+103|0]+1}if(!w[d+100|0]){break Aa}h=g+108|0;e=0;while(1){if((e|0)==128){break Aa}b=e+1|0;v[d+64>>2]=b+t[d+100|0];LR(d- -64|0);G=Kb(h,e),H=v[d+64>>2],t[G|0]=H;e=b;continue}}if(!(m&1)){break za}v[23588]=0;R(614,i|0,d+88|0);b=v[23588];v[23588]=0;Ba:{if((b|0)!=1){b=Gh(g,w[h+26934|0]);Ca:{if((h|0)!=3){e=w[d+88|0];o=w[b+12|0]&-17;break Ca}e=w[d+88|0];o=e<<4&16|w[b+12|0]&-17}t[b+12|0]=e>>>1&2|(e<<1&4|(o&248|e&1));t[d+64|0]=w[d+89|0];t[d+48|0]=16;e=w[Wb(d- -64|0,d+48|0)|0];v[23588]=0;R(291,b|0,e|0);e=v[23588];v[23588]=0;if((e|0)==1){break Ba}e=w[d+90|0];t[b+15|0]=e;t[b+16|0]=e;t[b+13|0]=w[d+91|0];t[b+14|0]=w[d+92|0];e=0;o=v[b>>2];j=_d(o,v[b+4>>2]);while(1){if((e|0)==(j|0)){break za}p=Db(o,e);b=(d+88|0)+(e<<2)|0;u[p>>1]=w[b+8|0]|w[b+9|0]<<8;G=p,H=Cd(w[b+10|0]|w[b+11|0]<<8,0,64),t[G+2|0]=H;e=e+1|0;continue}}break ua}break ua}du(g,0);break V}h=h+1|0;m=m>>>1|0;continue}}g=P()|0;O()|0;Ab(i)}Uc(q);break u}Ab(i);continue}}g=P()|0;O()|0;break u}g=P()|0;O()|0;break u}g=P()|0;O()|0;break u}else{b=t[Kb(g,h)|0];Da:{if((b|0)<=(h|0)|(b|0)>=(e|0)){break Da}b=w[((b<<5)+a|0)+480288|0];if(!b){break Da}e=((h<<5)+a|0)+480288|0;l=w[e|0];if(!l){t[e|0]=b;break Da}e=l-1|0;while(1){l=Ld(f,e&255);e=Ym(v[l+28>>2]);if((e|0)!=255){continue}break}b=b-1&255;v[l+28>>2]=b>>>0<250?b+128|0:0}h=h+1|0;continue}}}g=P()|0;O()|0;break u}v[23588]=0;f=S(157,s|0)|0;b=v[23588];v[23588]=0;Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{if((b|0)!=1){v[23588]=0;b=S(157,s|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break Ma}v[23588]=0;U(190,d+272|0,s|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break Ma}e=d+272|0;b=jc(d+88|0,e);Ab(e);if((f|0)==4674381){break Ia}if((f|0)==5068115){break Ha}if((f|0)==726487106){break La}if((f|0)==844387158){break Ga}e=0;if((f|0)==1280004692){break Ka}if((f|0)==1314144592){break Ja}if((f|0)!=1397445204){break Fa}v[23588]=0;e=S(194,b|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break w}e=e>>>0<256?48:e>>>8|0;v[a+480228>>2]=e;v[a+480232>>2]=e>>>1;e=0;while(1){if(x[h>>1]<=e>>>0){break Fa}v[23588]=0;f=Q(615,b|0,d+272|0)|0;j=v[23588];v[23588]=0;if((j|0)==1){break z}if(f){u[((e<<5)+a|0)+480286>>1]=x[d+272>>1]>>>10;G=Kb(v[r>>2],e),H=w[d+275|0],t[G|0]=H}e=e+1|0;continue}}g=P()|0;O()|0;break u}g=P()|0;O()|0;break u}if(g&1){break Fa}t[a+480224|0]=2;v[23588]=0;E=+la(616,b|0);e=v[23588];v[23588]=0;if((e|0)==1){break Ea}if(!(E>1e-8)){break Fa}G=a,H=Pe(2646e3/(E*+(B(v[a+480216>>2],v[a+480196>>2])>>>0))*1e4),v[G+480204>>2]=H;break Fa}while(1){Na:{if(x[h>>1]<=e>>>0){break Fa}f=v[b>>2];v[23588]=0;f=W(156,f|0,v[d+96>>2],1)|0;j=v[23588];v[23588]=0;if((j|0)==1){break y}if(!f){break Fa}f=Lb(d+272|0);v[23588]=0;U(350,b|0,f|0,-1);j=v[23588];v[23588]=0;if((j|0)!=1){j=d+16|0;bg(j,3,Lc(f),Gb(f));v[23588]=0;R(222,d+160|0,j|0);j=v[23588];v[23588]=0;if((j|0)==1){break Na}j=d+160|0;Gl(((e<<5)+a|0)+480289|0,j);yb(j);yb(f);e=e+1|0;continue}}break}g=P()|0;O()|0;yb(f);break v}while(1){if(x[d+1742>>1]<=e>>>0){break Fa}f=v[b>>2];v[23588]=0;f=W(156,f|0,v[d+96>>2],1)|0;j=v[23588];v[23588]=0;if((j|0)==1){break x}if(!f){break Fa}if(!Qm(v[a+484344>>2],v[n>>2],e&65535)){break Fa}f=Lb(d+272|0);v[23588]=0;U(350,b|0,f|0,-1);j=v[23588];v[23588]=0;Oa:{if((j|0)==1){break Oa}j=v[q>>2];v[23588]=0;R(281,Yb(j,e)|0,f|0);j=v[23588];v[23588]=0;if((j|0)==1){break Oa}yb(f);e=e+1|0;continue}break}g=P()|0;O()|0;yb(f);break v}v[23588]=0;Q(188,b|0,1)|0;e=v[23588];v[23588]=0;if((e|0)==1){break w}v[23588]=0;e=S(202,b|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break w}v[23588]=0;X(331,l|0,b|0,e|0,2);e=v[23588];v[23588]=0;if((e|0)!=1){break Fa}break w}v[23588]=0;Q(617,b|0,d+16|0)|0;e=v[23588];v[23588]=0;Pa:{if((e|0)!=1){e=Lb(d+272|0);v[23588]=0;U(350,b|0,e|0,-1);f=v[23588];v[23588]=0;if((f|0)==1){break Pa}if(xq(e,12534)){v[23588]=0;U(11,d+160|0,8,e|0);f=v[23588];v[23588]=0;if((f|0)==1){break Pa}f=d+160|0;Ib(i,f);zb(f)}yb(e);break Fa}g=P()|0;O()|0;break v}g=P()|0;O()|0;yb(e);break v}v[23588]=0;m=S(157,b|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break w}}Ab(b);continue}break}g=P()|0;O()|0;break v}g=P()|0;O()|0;break v}g=P()|0;O()|0;break v}g=P()|0;O()|0;break v}g=P()|0;O()|0}Ab(b)}hc(r);break e}g=P()|0;O()|0;break e}while(1){b=v[m>>2];v[23588]=0;b=W(156,b|0,v[d+280>>2],1)|0;f=v[23588];v[23588]=0;Qa:{if((f|0)!=1){if(!b){break o}v[23588]=0;i=S(206,m|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break h}n=0;if((i|0)!=255){break Qa}v[23588]=0;n=S(206,m|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){v[23588]=0;i=S(206,m|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break Qa}}break h}break h}if(i&127){b=Yb(v[q>>2],r);f=id(v[b>>2],v[v[b+48>>2]+12>>2],e,h&65535);Ru(d+88|0);if(i&1){v[23588]=0;b=S(206,m|0)|0;j=v[23588];v[23588]=0;if((j|0)==1){break n}t[d+88|0]=b}if(i&2){v[23588]=0;b=S(206,m|0)|0;j=v[23588];v[23588]=0;if((j|0)==1){break n}t[d+89|0]=b}if(i&4){v[23588]=0;b=S(206,m|0)|0;j=v[23588];v[23588]=0;if((j|0)==1){break n}t[d+90|0]=b}if(i&8){v[23588]=0;b=S(206,m|0)|0;j=v[23588];v[23588]=0;if((j|0)==1){break n}t[d+91|0]=b}if(i&16){v[23588]=0;b=S(206,m|0)|0;j=v[23588];v[23588]=0;if((j|0)==1){break n}t[d+92|0]=b}if(i&32){v[23588]=0;b=S(206,m|0)|0;j=v[23588];v[23588]=0;if((j|0)==1){break n}t[d+93|0]=b}if(i&64){v[23588]=0;b=S(206,m|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break n}t[d+94|0]=b}D=PR(f,d+88|0);v[d+16>>2]=n;v[d+64>>2]=l+(e^-1);F=v[Jb(d+16|0,d- -64|0)>>2];i=0;b=f;while(1){if((i|0)!=(F|0)){b=B(x[C>>1],6)+b|0;j=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);t[b|0]=j;t[b+1|0]=j>>>8;t[b+2|0]=j>>>16;t[b+3|0]=j>>>24;j=w[f+4|0]|w[f+5|0]<<8;t[b+4|0]=j;t[b+5|0]=j>>>8;i=i+1|0;continue}break}g=g|D}e=(e+n|0)+1|0;while(1){if(e>>>0>=l>>>0){h=h+1|0;e=e-l|0;continue}break}if(o>>>0>(h&65535)>>>0){continue}break}}Ab(m);r=r+1|0;continue}break}break h}g=P()|0;O()|0;yb(d+1376|0);break c}g=P()|0;O()|0;Ab(m);break e}g=P()|0;O()|0;break e}g=P()|0;O()|0}Ab(s)}Ab(A)}T(g|0);L()}e=1}jb=d+1760|0;return e|0}function mja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;d=jb-1184|0;jb=d;yc(b);e=jb-16|0;jb=e;g=d+944|0;ZT(e+8|0,g);m=v[e+12>>2];mc(e,v[b>>2],v[b+8>>2],v[e+8>>2],v[e+12>>2]);j=v[e+4>>2];if((j|0)==(m|0)){Zb(b,v[e+12>>2])}jb=e+16|0;e=(j|0)==(m|0);if(!e){YT(g)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{if(!e){break o}if(!$T(d+944|0)){break o}if(!Pb(v[b>>2],v[b+8>>2],Dc(_T(v[d+948>>2]),mb))){break o}if(!c){f=1;break o}Ad(a,16777216);$f(a);e=a+480208|0;v[e>>2]=v[e>>2]|16809984;f=d+480|0;vq(f,32);m=v[d+492>>2];e=a+1074320|0;v[e>>2]=v[d+488>>2];v[e+4>>2]=m;e=v[d+484>>2];v[a+1074312>>2]=v[d+480>>2];v[a+1074316>>2]=e;Nb(Nb(a+1074312|0,57,w[d+947|0]>5),114,1);e=xo(d+904|0);H=e,I=Cd(w[d+1144|0],1,31),v[H+8>>2]=I;H=e,I=Cd(w[d+1145|0],1,12),v[H+4>>2]=I;H=e,I=Hb(x[d+1146>>1]),v[H>>2]=I;DB(a+1298408|0,e);u[a+480188>>1]=32;e=d+376|0;XT(e,3,d+1148|0);m=d+56|0;Ec(m,e);v[23588]=0;U(11,f|0,1,m|0);e=v[23588];v[23588]=0;p:{q:{if((e|0)!=1){e=d+480|0;Ib(a+1298368|0,e);zb(e);yb(d+56|0);r:{if(w[d+947|0]<=5){Rf(d+56|0,3927);break r}e=jb-16|0;jb=e;f=xc(e,3996);$c(d+56|0,f);zb(f);jb=e+16|0}v[23588]=0;U(362,d+480|0,d+56|0,w[d+947|0]);e=v[23588];v[23588]=0;if((e|0)==1){break q}e=d+480|0;Ib(a+1298344|0,e);zb(e);f=d+56|0;ac(f);m=xc(e,15094);Ib(a+1298356|0,m);zb(m);v[a+1298404>>2]=12;Me(f,3,d+952|0);Ec(e,f);Ac(a+1298308|0,e);yb(e);v[a+480228>>2]=256;v[a+480200>>2]=384/(x[a+480188>>1]+3>>>0);if(w[d+947|0]>5){break p}H=d,I=Hb(x[d+1172>>1]),u[H+480>>1]=I;u[d+56>>1]=1;e=d+480|0;f=d+56|0;H=a,I=x[ke(e,f)>>1],v[H+480196>>2]=I;H=d,I=Hb(x[d+1174>>1]),u[H+480>>1]=I;u[d+56>>1]=1;H=a,I=B(x[ke(e,f)>>1],1e4),v[H+480204>>2]=I;H=d,I=Dc(((Hb(x[d+1176>>1])<<8)+2047>>>0)/4095|0,0),v[H+480>>2]=I;v[d+56>>2]=256;H=a,I=v[Jb(e,f)>>2],v[H+480200>>2]=I;H=d,I=Hb(x[d+1178>>1]),u[H+480>>1]=I;Ef(e,127);f=0;e=x[d+480>>1];while(1){if((e|0)==(f|0)){break p}H=d,I=Dc(((Gj(b)<<8)+2047>>>0)/4095|0,0),u[H+56>>1]=I;u[d+376>>1]=256;H=((f<<5)+a|0)+480284|0,I=x[Vc(d+56|0,d+376|0)>>1],u[H>>1]=I;f=f+1|0;continue}}a=P()|0;O()|0;yb(d+56|0);break a}a=P()|0;O()|0;ac(d+56|0);break a}cd(b,bc(v[d+948>>2]));m=je(d+880|0,b);v[23588]=0;R(366,d+864|0,m|0);b=v[23588];v[23588]=0;s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{if((b|0)!=1){v[23588]=0;U(367,d+480|0,d+864|0,1346458707);b=v[23588];v[23588]=0;if((b|0)==1){break H}v[23588]=0;b=W(156,v[d+480>>2],v[d+488>>2],2)|0;e=v[23588];v[23588]=0;if((e|0)==1){break K}if(!b){break I}v[23588]=0;b=S(271,d+480|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break K}if((b-1&65535)>>>0>126){break I}u[a+480188>>1]=b;b=d+480|0;Ab(b);v[23588]=0;U(367,b|0,d+864|0,1397706311);b=v[23588];v[23588]=0;if((b|0)!=1){break L}a=P()|0;O()|0;break c}a=P()|0;O()|0;break b}v[23588]=0;b=W(156,v[d+480>>2],v[d+488>>2],2)|0;e=v[23588];v[23588]=0;if((e|0)==1){break G}if(!b){break I}v[23588]=0;b=S(271,d+480|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break G}u[d+56>>1]=b;b=w[a+484376|0];e=v[a+484360>>2];v[23588]=0;f=S(271,d+480|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break G}Ue(Vb(e,b),f);v[23588]=0;b=S(202,d+480|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break G}Ef(d+56|0,Cl(b>>>1|0));b=w[a+484376|0];e=v[a+484360>>2];v[23588]=0;U(274,Vb(e,b)|0,d+480|0,x[d+56>>1]);b=v[23588];v[23588]=0;if((b|0)==1){break G}b=d+480|0;Ab(b);v[23588]=0;U(367,b|0,d+864|0,1480806221);b=v[23588];v[23588]=0;if((b|0)!=1){break J}a=P()|0;O()|0;break c}a=P()|0;O()|0;Ab(d+480|0);break c}v[23588]=0;b=W(156,v[d+480>>2],v[d+488>>2],3)|0;e=v[23588];v[23588]=0;if((e|0)!=1){if(b){break F}b=160;while(1){M:{f=b;if(!b){f=0;break M}b=f-1|0;if(w[(d+b|0)+984|0]==32){continue}}break}v[23588]=0;X(337,a+1298332|0,d+984|0,f|0,4);b=v[23588];v[23588]=0;if((b|0)!=1){break E}break D}break D}Ab(d+480|0);f=0;break s}a=P()|0;O()|0;break c}a=P()|0;O()|0;Ab(d+480|0);break c}v[23588]=0;b=S(271,d+480|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){v[23588]=0;X(331,a+1298332|0,d+480|0,b|0,4);b=v[23588];v[23588]=0;if((b|0)!=1){break E}}break D}b=d+480|0;Ab(b);v[23588]=0;U(367,b|0,d+864|0,1413697073);b=v[23588];v[23588]=0;if((b|0)==1){break C}v[23588]=0;b=S(206,d+480|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break A}if(b){break B}v[23588]=0;b=Q(155,d+480|0,2648)|0;e=v[23588];v[23588]=0;if((e|0)==1){break A}if(!b){break B}f=0;v[23588]=0;b=S(279,d+480|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break A}while(1){if((f|0)==32){break B}e=((f<<5)+a|0)+480280|0;v[e>>2]=v[e>>2]&-1025|!(b>>>f&1)<<10;f=f+1|0;continue}}a=P()|0;O()|0;Ab(d+480|0);break c}a=P()|0;O()|0;break c}b=d+480|0;Ab(b);v[23588]=0;U(367,b|0,d+864|0,1413697074);b=v[23588];v[23588]=0;if((b|0)==1){break z}v[23588]=0;b=W(156,v[d+480>>2],v[d+488>>2],12)|0;e=v[23588];v[23588]=0;if((e|0)==1){break y}N:{if(!b){break N}v[23588]=0;R(368,d+56|0,d+480|0);b=v[23588];v[23588]=0;if((b|0)==1){break y}b=d+56|0;e=Se(b);f=ic(b);g=WT(b);j=Fb(b);n=VT(b);e=B(Cd(Hb(w[e|0]|w[e+1|0]<<8),32,999),1e4);b=Lka(Hb(w[f|0]|w[f+1|0]<<8),0,1e4,0)+32768|0;f=mb;f=b>>>0<32768?f+1|0:f;H=a,I=e+((Dc((f&65535)<<16|b>>>16,f>>>16|0)>>>0)%1e4|0)|0,v[H+480204>>2]=I;H=a,I=Cd(Hb(w[g|0]|w[g+1|0]<<8),1,255),v[H+480196>>2]=I;b=16/(Cd(Hb(w[n|0]|w[n+1|0]<<8),1,16)>>>0)|0;v[a+480216>>2]=b;H=a,I=B(Cd(Hb(w[j|0]|w[j+1|0]<<8),1,16),b),v[H+480220>>2]=I;if(!Hb(x[d+56>>1])){break N}v[23588]=0;b=S(271,d+480|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break y}e=a+480208|0;v[e>>2]=v[e>>2]&-17|!b<<4}b=d+480|0;Ab(b);v[23588]=0;U(367,b|0,d+864|0,1414942540);b=v[23588];v[23588]=0;if((b|0)==1){break x}v[23588]=0;b=W(156,v[d+480>>2],v[d+488>>2],2)|0;e=v[23588];v[23588]=0;if((e|0)==1){break v}if(!b){break w}v[23588]=0;b=S(271,d+480|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break v}u[d+56>>1]=b;u[d+376>>1]=x[a+480188>>1];b=x[Vc(d+56|0,d+376|0)>>1];f=0;while(1){if((b|0)==(f|0)){break w}v[23588]=0;e=S(271,d+480|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break v}u[d+56>>1]=e;u[d+376>>1]=4096;H=((f<<5)+a|0)+480286|0,I=x[Vc(d+56|0,d+376|0)>>1]>>>6&255,u[H>>1]=I;f=f+1|0;continue}}a=P()|0;O()|0;Ab(d+480|0);break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;Ab(d+480|0);break c}a=P()|0;O()|0;break c}Ab(d+480|0);v[23588]=0;U(367,d+56|0,d+864|0,1296652368);b=v[23588];v[23588]=0;if((b|0)==1){break u}v[23588]=0;b=W(156,v[d+56>>2],v[d+64>>2],56)|0;e=v[23588];v[23588]=0;if((e|0)==1){break d}if(!b){break t}v[23588]=0;R(369,d+56|0,d+480|0);b=v[23588];v[23588]=0;if((b|0)==1){break d}if((Hb(x[d+514>>1])|0)!=4){break t}if((Hb(x[d+528>>1])|0)!=257){break t}H=d,I=Hb(x[d+520>>1]),u[H+376>>1]=I;u[d+848>>1]=16384;e=x[Vc(d+376|0,d+848|0)>>1];b=e>>>24|0;e=(e<<8)+2048|0;b=e>>>0<2048?b+1|0:b;H=a,I=Dc((b&4095)<<20|e>>>12,b>>>12|0),v[H+480200>>2]=I;g=a+480188|0;f=0;while(1){if(Hb(x[d+518>>1])>>>0<=(f&65535)>>>0){break t}v[23588]=0;R(370,d+56|0,d+376|0);b=v[23588];v[23588]=0;if((b|0)==1){break d}O:{if(w[d+376|0]){break O}b=Hb(x[d+378>>1]);if(b>>>0>=x[g>>1]){break O}b=(b<<5)+a|0;H=b+480284|0,I=Dc(((Hb(x[d+382>>1])<<8)+2047>>>0)/4095|0,0),u[H>>1]=I;h=b+480286|0;e=Hb(x[d+380>>1]);b=e>>>26|0;e=(e<<6)+2048|0;b=e>>>0<2048?b+1|0:b;H=h,I=Dc((b&4095)<<20|e>>>12,b>>>12|0)&255,u[H>>1]=I}f=f+1|0;continue}}a=P()|0;O()|0;Ab(d+480|0);break c}a=P()|0;O()|0;break c}b=d+56|0;Ab(b);v[23588]=0;U(371,b|0,d+864|0,1396788530);b=v[23588];v[23588]=0;if((b|0)==1){break e}H=d,I=Eb(v[d+56>>2]),v[H+800>>2]=I;f=c&2;j=d+480|2;n=Eb(v[d+60>>2]);g=a+480190|0;l=a+1298464|0;P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{while(1){e=v[d+800>>2];if(!Ob(e,n)){b=d+56|0;Uc(b);v[23588]=0;U(371,b|0,d+864|0,1396788560);b=v[23588];v[23588]=0;if((b|0)==1){break f}H=d,I=Eb(v[d+56>>2]),v[H+832>>2]=I;j=d+480|2;n=Eb(v[d+60>>2]);e=a+480190|0;break P}v[23588]=0;b=Q(372,e|0,d+480|0)|0;k=v[23588];v[23588]=0;if((k|0)==1){break R}Z:{_:{if(!b){break _}b=Hb(x[d+480>>1]);if((b-4e3&65535)>>>0<61537){break _}if(Hb(x[d+528>>1])>>>0>1){break _}if(Hb(x[d+510>>1])>>>0>1){break _}if(b>>>0>x[g>>1]){u[g>>1]=b}v[23588]=0;k=B(b,104)+a|0;b=k+484380|0;R(373,d+480|0,b|0);h=v[23588];v[23588]=0;$:{aa:{ba:{if((h|0)==1){break ba}h=d+848|0;Hi(h,3,j);v[23588]=0;R(222,d+376|0,h|0);h=v[23588];v[23588]=0;if((h|0)==1){break aa}h=d+376|0;Cc(((Hb(x[d+480>>1])<<5)+a|0)+946304|0,h);yb(h);if(!f){break _}h=x[d+554>>1]|x[d+556>>1]<<16;v[23588]=0;h=Q(155,e|0,bc(h)-8|0)|0;p=v[23588];v[23588]=0;if((p|0)==1){break ba}if(!h){break _}if(Hb(x[d+510>>1])){break $}h=d+376|0;Zc(h,(Hb(w[d+512|0]|w[d+513|0]<<8)|0)==8?8:16,(Hb(w[d+516|0]|w[d+517|0]<<8)|0)==1?1:2,!Hb(w[d+514|0]|w[d+515|0]<<8),0);v[23588]=0;W(219,h|0,b|0,e|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break $}a=P()|0;O()|0;break Q}a=P()|0;O()|0;break Q}a=P()|0;O()|0;break Q}b=Lb(d+376|0);h=x[d+530>>1];v[23588]=0;U(268,e|0,b|0,Hb(h)|0);e=v[23588];v[23588]=0;if((e|0)==1){break T}Be(k+484423|0,b);if((Hb(x[d+510>>1])|0)==1){v[23588]=0;R(374,d+832|0,16382);e=v[23588];v[23588]=0;if((e|0)==1){break Z}v[23588]=0;U(11,d+816|0,0,b|0);e=v[23588];v[23588]=0;if((e|0)==1){break Y}v[23588]=0;X(375,d+848|0,d+832|0,x[d+480>>1],d+816|0);e=v[23588];v[23588]=0;if((e|0)==1){break X}e=v[l>>2];v[23588]=0;U(376,e|0,2,d+848|0);e=v[23588];v[23588]=0;if((e|0)==1){break W}zb(d+848|0);zb(d+816|0);ac(d+832|0)}yb(b)}Mf(d+800|0);continue}break}a=P()|0;O()|0;break S}a=P()|0;O()|0;break U}a=P()|0;O()|0;break V}a=P()|0;O()|0;zb(d+848|0)}zb(d+816|0)}ac(d+832|0);break S}a=P()|0;O()|0}yb(b);break Q}a=P()|0;O()|0}Uc(d+56|0);break c}ca:{while(1){da:{g=v[d+832>>2];if(!Ob(g,n)){Uc(d+56|0);v[23588]=0;U(371,d+848|0,d+864|0,1447382614);b=v[23588];v[23588]=0;if((b|0)!=1){break ca}a=P()|0;O()|0;break c}v[23588]=0;b=Q(377,g|0,d+480|0)|0;l=v[23588];v[23588]=0;if((l|0)==1){break da}ea:{fa:{if(!b){break fa}b=Hb(x[d+480>>1]);if((b-4e3&65535)>>>0<61537){break fa}if(Hb(x[d+534>>1])){break fa}if(b>>>0>x[e>>1]){u[e>>1]=b}v[23588]=0;b=(B(b,104)+a|0)+484380|0;R(378,d+480|0,b|0);l=v[23588];v[23588]=0;if((l|0)==1){break da}l=d+848|0;Hi(l,3,j);v[23588]=0;R(222,d+376|0,l|0);l=v[23588];v[23588]=0;if((l|0)==1){break da}l=d+376|0;Cc(((Hb(x[d+480>>1])<<5)+a|0)+946304|0,l);yb(l);if(!f){break fa}l=x[d+510>>1];k=d+376|0;Zc(k,(Hb(x[d+514>>1])|0)==8?8:16,Hb(l)&1?2:1,1,0);v[23588]=0;W(219,k|0,b|0,g|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break ea}}Mf(d+832|0);continue}}break}a=P()|0;O()|0;Uc(d+56|0);break c}v[23588]=0;U(371,d+832|0,d+864|0,1413828182);b=v[23588];v[23588]=0;if((b|0)==1){break h}v[23588]=0;U(371,d+816|0,d+864|0,1346719318);b=v[23588];v[23588]=0;if((b|0)==1){break j}v[23588]=0;U(371,d+800|0,d+864|0,1229869908);b=v[23588];v[23588]=0;if((b|0)==1){break l}H=d,I=Eb(v[d+800>>2]),v[H+24>>2]=I;n=d+426|0;l=d+376|2;k=d+480|2;h=Eb(v[d+804>>2]);p=a+480190|0;q=a+480208|0;while(1){ga:{ha:{ia:{ja:{g=v[d+24>>2];if(!Ob(g,h)){Uc(d+800|0);v[23588]=0;U(371,d+376|0,d+864|0,1346458692);b=v[23588];v[23588]=0;if((b|0)!=1){break ja}a=P()|0;O()|0;break k}v[23588]=0;b=Q(379,g|0,d+480|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break n}if(!b){break ga}if(Hb(x[d+510>>1])){break ga}b=x[d+480>>1];v[23588]=0;e=W(251,a|0,Hb(b)|0,0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break n}if(!e){break ga}b=Hb(x[d+480>>1]);if(b>>>0>x[a+480192>>1]){u[a+480192>>1]=b}b=d+376|0;Hi(b,3,k);v[23588]=0;R(222,d+56|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break ia}b=d+56|0;Cc(e+492|0,b);yb(b);t[e+33|0]=2;if((pe(u[d+514>>1])|0)>0){t[e+15|0]=w[e+15|0]|1;f=pe(u[d+514>>1]);b=f>>>24|0;j=(f<<8&-256)+2047|0;f=b&255;H=e,I=Dc(Oka(j,j>>>0<2047?f+1|0:f,4095,0),mb),v[H+8>>2]=I}j=e+108|0;i=e+236|0;b=0;while(1){ka:{v[d+56>>2]=128;v[d+376>>2]=128;f=b&255;if(f>>>0>=y[Jb(d+56|0,d+376|0)>>2]){v[23588]=0;R(380,d+56|0,e|0);b=v[23588];v[23588]=0;if((b|0)==1){break ka}H=d,I=Fi(v[d+56>>2]),v[H+376>>2]=I;f=wf(d+56|0);while(1){b=v[d+376>>2];if(Ob(b,f)){b=x[qo(b)>>1];if(!(!b|b>>>0>x[p>>1])){H=(B(b,104)+a|0)+484410|0,I=Hb(x[d+512>>1]),u[H>>1]=I}Kg(d+376|0);continue}break}qu(d+56|0);Lj(e,127,1);Kj(e,0,1);b=Hb(x[d+530>>1]);if(!b){v[e>>2]=0;b=x[d+516>>1];v[23588]=0;X(381,e|0,0,Hb(b)|0,d+848|0);b=v[23588];v[23588]=0;if((b|0)==1){break n}b=x[d+520>>1];v[23588]=0;X(381,e|0,1,Hb(b)|0,d+816|0);b=v[23588];v[23588]=0;if((b|0)==1){break n}b=x[d+518>>1];v[23588]=0;X(381,e|0,2,Hb(b)|0,d+832|0);b=v[23588];v[23588]=0;if((b|0)!=1){break ga}break n}v[23588]=0;U(382,g|0,d+376|0,((b|0)==1?98:102)|0);b=v[23588];v[23588]=0;la:{ma:{na:{if((b|0)!=1){b=Hb(x[d+376>>1]);j=b&1;if(!j){break ha}f=b&24;if(f){break na}f=0;break ma}a=P()|0;O()|0;break m}if((f|0)!=8){break la}f=1}t[e+25|0]=f}oa:{pa:{qa:{ra:{if(!(b&2)){break ra}v[23588]=0;b=W(383,d+360|0,l|0,24)|0;f=v[23588];v[23588]=0;if((f|0)==1){break qa}v[23588]=0;z=+la(384,b|0);f=v[23588];v[23588]=0;if((f|0)==1){break pa}yb(b);if(!(z>20)){break ra}Lj(e,aB(v[q>>2],z),1)}if(Hb(x[d+376>>1])&4){break oa}break ha}a=P()|0;O()|0;break m}a=P()|0;O()|0;yb(b);break m}v[23588]=0;b=W(383,d+344|0,n|0,24)|0;f=v[23588];v[23588]=0;sa:{if((f|0)!=1){v[23588]=0;z=+la(384,b|0);f=v[23588];v[23588]=0;if((f|0)==1){break sa}yb(b);Kj(e,sk(z*127/24),1);break ha}a=P()|0;O()|0;break m}a=P()|0;O()|0;yb(b);break m}else{o=(d+480|0)+(f<<1)|0;H=cc(i,f),I=w[o+52|0],u[H>>1]=I;f=Kb(j,f);H=f,I=Bl(t[o+53|0]+w[f|0]|0),t[H|0]=I;b=b+1|0;continue}}break}a=P()|0;O()|0;break m}b=v[d+380>>2];e=v[d+376>>2];v[23588]=0;g=a+484344|0;R(225,g|0,Bf(e,b)&65535);b=v[23588];v[23588]=0;ta:{if((b|0)!=1){v[d+48>>2]=v[a+480204>>2];v[d+40>>2]=v[a+480196>>2];H=d,I=Eb(v[d+376>>2]),v[H+8>>2]=I;o=c&1;b=d+56|0;r=b|4;A=b|2;C=b|1;D=Eb(v[d+380>>2]);E=a+480188|0;while(1){ua:{va:{wa:{xa:{ya:{za:{b=v[d+8>>2];if(!Ob(b,D)){v[23588]=0;U(367,d+56|0,d+864|0,1414414669);b=v[23588];v[23588]=0;if((b|0)!=1){break za}a=P()|0;O()|0;break ta}if(!o){break ua}c=v[b+8>>2];e=v[b>>2];v[23588]=0;c=W(156,e|0,c|0,24)|0;e=v[23588];v[23588]=0;if((e|0)==1){break ya}if(!c){break ua}v[23588]=0;j=S(271,b|0)|0;c=v[23588];v[23588]=0;Aa:{Ba:{Ca:{Da:{if((c|0)!=1){t[d+496|0]=0;v[d+488>>2]=0;v[d+492>>2]=0;v[d+480>>2]=0;v[d+484>>2]=0;v[23588]=0;R(385,b|0,d+480|0);c=v[23588];v[23588]=0;if((c|0)==1){break Da}v[23588]=0;p=S(271,b|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break Ca}v[23588]=0;n=S(271,b|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break Ba}v[23588]=0;l=S(271,b|0)|0;c=v[23588];v[23588]=0;Ea:{if((c|0)==1){break Ea}c=v[b+8>>2];e=v[b>>2];v[23588]=0;c=W(156,e|0,c|0,B(B(l,n),5)|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break Ea}if(!(c&p>>>0<2)){break ua}v[23588]=0;c=W(226,g|0,j|0,n|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break Ea}if(!c){break ua}c=v[g>>2];v[23588]=0;R(386,Yb(c,j)|0,d+480|0);c=v[23588];v[23588]=0;if((c|0)!=1){break Aa}}a=P()|0;O()|0;break ta}a=P()|0;O()|0;break ta}a=P()|0;O()|0;break ta}a=P()|0;O()|0;break ta}a=P()|0;O()|0;break ta}t[d+24|0]=0;c=de(d+56|0,0,d+24|0);v[23588]=0;c=W(363,d+800|0,l|0,c|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break va}e=0;Fa:while(1){if((e|0)==(n|0)){nd(c);break ua}f=0;k=Yb(v[g>>2],j);F=Cf(v[k>>2],v[v[k+48>>2]+12>>2],e);while(1){if((f|0)==(l|0)){e=e+1|0;continue Fa}h=tg(d+56|0);q=x[E>>1];v[23588]=0;R(387,b|0,d+24|0);k=v[23588];v[23588]=0;Ga:{if((k|0)==1){break Ga}k=B(f,6)+F|0;i=h;h=f>>>0<q>>>0;q=h?k:i;i=w[d+24|0];if((i-1&255)>>>0<=119){i=i+1|0;t[q|0]=i;H=cc(v[c>>2],f),I=i,t[H|0]=I}i=w[d+25|0];if(i){t[(h?k+1|0:C)|0]=i;H=cc(v[c>>2],f),I=i,t[H+1|0]=I}i=w[d+28|0];if(i){t[(h?k+2|0:A)|0]=1;t[(h?k+4|0:r)|0]=p?i-16|0:i>>>2|0}k=w[d+947|0];h=w[d+27|0];i=w[d+26|0];s=cc(v[c>>2],f);G=w[s+1|0];s=w[s|0];v[23588]=0;Ca(365,a|0,q|0,i|0,h|0,k|0,s|0,G|0,d+48|0,d+40|0);k=v[23588];v[23588]=0;if((k|0)==1){break Ga}f=f+1|0;continue}break}break}a=P()|0;O()|0;nd(c);break ta}v[23588]=0;b=W(156,v[d+56>>2],v[d+64>>2],38)|0;c=v[23588];v[23588]=0;if((c|0)!=1){if(!b){break wa}v[23588]=0;b=S(271,d+56|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break xa}c=d+480|4;e=a+480188|0;f=0;Ha:{while(1){if(b>>>0<=(f&65535)>>>0){break wa}v[23588]=0;g=W(156,v[d+56>>2],v[d+64>>2],36)|0;j=v[23588];v[23588]=0;Ia:{if((j|0)!=1){if(g){break Ia}break wa}break xa}v[23588]=0;R(388,d+56|0,d+480|0);g=v[23588];v[23588]=0;if((g|0)!=1){Ja:{if(Hb(x[d+480>>1])){break Ja}if(Hb(x[d+482>>1])>>>0>=x[e>>1]){break Ja}g=d+8|0;Me(g,3,c);v[23588]=0;R(222,d+24|0,g|0);g=v[23588];v[23588]=0;if((g|0)==1){break Ha}g=d+24|0;Gl(((Hb(x[d+482>>1])<<5)+a|0)+480289|0,g);yb(g)}f=f+1|0;continue}break}break xa}break xa}break xa}a=P()|0;O()|0;break ta}a=P()|0;O()|0;Ab(d+56|0);break ta}Ab(d+56|0);Uc(d+376|0);Uc(d+816|0);Uc(d+832|0);Uc(d+848|0);f=1;break s}a=P()|0;O()|0;break ta}Mf(d+8|0);continue}}a=P()|0;O()|0}Uc(d+376|0);break k}a=P()|0;O()|0;break m}f=0;while(1){if(w[d+477|0]<=f>>>0){break ga}v[23588]=0;R(389,g|0,d+56|0);b=v[23588];v[23588]=0;Ka:{La:{if((b|0)!=1){v[d+8>>2]=33620480;H=d,I=(Hb(x[d+516>>1])|0)!=0,t[H+48|0]=I;H=d,I=(Hb(x[d+518>>1])|0)!=0,t[H+49|0]=I;H=d,I=(Hb(x[d+520>>1])|0)!=0,t[H+50|0]=I;H=d,I=j&(Hb(x[d+522>>1])|0)!=0,t[H+51|0]=I;if(!w[(d+48|0)+f|0]|f>>>0>3){break Ka}b=(f|0)!=3;if(!b&(t[e+100|0]&1)){break Ka}v[23588]=0;i=w[(d+8|0)+f|0];U(390,d+56|0,e|0,i|0);o=v[23588];v[23588]=0;if((o|0)==1){break La}if(!b){t[e+100|0]=w[e+100|0]|16}Ma:{switch(i|0){case 0:if(Hb(x[d+68>>1])&1){b=Hb(x[d+66>>1])&32767}else{b=0}v[e>>2]=b;break Ka;case 2:break Ma;default:break Ka}}if(!(Hb(x[d+68>>1])&2)){break Ka}H=d,I=Hb(x[d+62>>1]),u[H+40>>1]=I;u[d+46>>1]=1;b=x[ke(d+40|0,d+46|0)>>1];i=Ll(Dc(((Hb(x[d+58>>1])<<6|48)>>>0)/100|0,0));H=d,I=Hb(x[d+60>>1]),u[H+40>>1]=I;u[d+46>>1]=1;o=sg(256/x[ke(d+40|0,d+46|0)>>1]|0);r=x[d+480>>1];A=x[d+64>>1];v[23588]=0;s=Hb(r);r=Hb(A);ma(391,a|0,s|0,w[(r>>>0<6?r:0)+26592|0],255/(b>>>0)|0,i|0,o|0);b=v[23588];v[23588]=0;if((b|0)!=1){break Ka}a=P()|0;O()|0;break m}a=P()|0;O()|0;break m}a=P()|0;O()|0;break m}f=f+1|0;continue}}Mf(d+24|0);continue}}Yd(d+864|0);Ab(m)}jb=d+1184|0;return f|0}a=P()|0;O()|0}Uc(d+800|0);break k}a=P()|0;O()|0}Uc(d+816|0);break i}a=P()|0;O()|0}Uc(d+832|0);break g}a=P()|0;O()|0}Uc(d+848|0);break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;Ab(d+56|0)}Yd(d+864|0)}Ab(m)}T(a|0);L()}function kaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,Q=0,R=0,S=0,U=0,V=0,X=0,Y=0,Z=0,_=0,$=0,ba=0,ca=0;m=jb-1168|0;jb=m;yc(b);a:{if(!tr(b,m+1144|0)){break a}if(!_L(m+1144|0)){break a}if(v[m+1152>>2]!=(Vg(v[b>>2])|0)){break a}if(v[m+1160>>2]!=(cf(b)|0)){break a}if(!c){h=1;break a}d=m+1088|0;Tb(d,0,56);o=-2;b:{if(!d){break b}v[d+44>>2]=0;v[d+48>>2]=0;v[d+52>>2]=0;v[d+20>>2]=0;v[d+24>>2]=0;v[d+8>>2]=0;o=v[d+32>>2];if(!o){v[d+32>>2]=1088;o=1088}if(!v[d+36>>2]){v[d+36>>2]=1089}e=nb[o|0](v[d+40>>2],1,43784)|0;o=-4;if(!e){break b}v[d+28>>2]=e;v[e+43780>>2]=1;v[e+10992>>2]=0;v[e+10996>>2]=0;v[e>>2]=0;v[e+11008>>2]=15;v[e+11e3>>2]=1;v[e+11004>>2]=0;o=0}if(o){break a}h=v[m+1160>>2];v[m+1084>>2]=h;I=v[m+1164>>2];R=sB(m+1072|0,I);c:{d:{while(1){if(!(!h|!I|(g|0)==1)){v[m+32>>2]=1024;g=m+32|0;S=v[Jb(g,m+1084|0)>>2];d=gc(m+40|0,m+48|0,S);h=v[d+4>>2];d=v[d>>2];v[23588]=0;Nk(165,g,b,d,h);g=v[23588];v[23588]=0;if((g|0)==1){break d}d=m+48|0;g=d;h=S;e=_^-1;while(1){if(h>>>0<4){while(1){if(h){e=v[(((w[g|0]^e)&255)<<2)+63136>>2]^e>>>8;h=h-1|0;g=g+1|0;continue}break}_=e^-1}else{e=v[(((w[g|0]^e)&255)<<2)+63136>>2]^e>>>8;e=e>>>8^v[(((e^w[g+1|0])&255)<<2)+63136>>2];e=e>>>8^v[(((e^w[g+2|0])&255)<<2)+63136>>2];e=e>>>8^v[(((e^w[g+3|0])&255)<<2)+63136>>2];h=h-4|0;g=g+4|0;continue}break}v[m+1092>>2]=S;v[m+1088>>2]=d;v[m+1104>>2]=I;v[m+1100>>2]=v[R>>2]+$;D=jb-16|0;jb=D;g=-2;p=m+1088|0;e:{if(!p){break e}i=v[p+28>>2];if(!i){break e}ca=v[p+4>>2];v[i+11e3>>2]=0;f:{if(v[i+43780>>2]<0){break f}if(v[i+11004>>2]){break e}h=v[i+11008>>2];g=0;v[i+11004>>2]=0;d=v[i+10996>>2];if(!d){V=(h|0)>0?11:10;G=i+11012|0;e=v[p+4>>2];k=v[i+10992>>2];while(1){v[D+12>>2]=e;v[D+8>>2]=32768-k;C=v[p>>2];d=0;e=0;o=0;H=0;J=0;U=0;X=0;Y=jb-144|0;jb=Y;g:{h:{K=k+G|0;if(K>>>0>=G>>>0){E=v[D+8>>2]+K|0;r=E-G|0;Z=(G^-1)+E|0;if(!(r&Z)){break h}}v[D+8>>2]=0;v[D+12>>2]=0;n=-3;break g}q=v[D+12>>2];A=q+C|0;M=v[i+60>>2];s=v[i+40>>2];g=v[i+36>>2];z=v[i+32>>2];h=v[i+56>>2];f=v[i+4>>2];n=-1;j=C;l=K;i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{k=v[i>>2];switch(k|0){case 36:break k;case 39:break n;case 10:break o;case 35:break p;case 17:break q;case 21:break r;case 34:break s;case 42:break w;case 41:break x;case 53:break y;case 52:break z;case 51:break A;case 38:break B;case 27:break C;case 26:break D;case 25:break E;case 24:break F;case 23:break G;case 18:break H;case 16:break I;case 14:break J;case 11:break K;case 9:break L;case 7:break M;case 6:break N;case 3:break O;case 37:break P;case 32:break Q;case 5:break R;case 2:break S;case 1:break T;case 0:break U;default:break j}}v[i+28>>2]=1;h=0;v[i+8>>2]=0;v[i+12>>2]=0;v[i+16>>2]=1;s=0;g=0;z=0;f=0;if(V&1){break T}break v}if((q|0)<=0){v[i>>2]=1;break m}v[i+8>>2]=w[C|0];j=C+1|0}if(j>>>0>=A>>>0){v[i>>2]=2;n=1;break i}g=w[j|0];v[i+12>>2]=g;q=1;e=v[i+8>>2];if(!(((g|e<<8)>>>0)%31|g&32)){q=(e&15)!=8}j=j+1|0;k=36;g=256<<(e>>>4);if(g>>>0>32768|g>>>0>r>>>0){break l}g=0;if(q){break l}break v}if((q|0)<=0){v[i>>2]=5;break m}U=f+8|0;j=C+1|0;h=w[C|0]<<f|h;d=2;break v}if((q|0)<=0){v[i>>2]=32;break m}f=f+8|0;j=C+1|0;break u}k=37;break k}d=1;break v}d=4;break v}d=3;break v}d=7;break v}d=9;break v}d=10;break v}d=11;break v}d=12;break v}d=13;break v}d=14;break v}d=15;break v}d=16;break v}d=17;break v}d=8;break v}d=5;break v}d=6;break v}d=18;break v}k=2;break t}k=1;break t}V:while(1){W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{switch(d|0){case 0:if(f>>>0>2){break Ba}d=1;continue;case 3:break za;case 2:break Aa;case 1:break Ca;case 9:break fa;case 10:break ga;case 11:break ha;case 12:break ia;case 13:break ja;case 14:break ka;case 15:break la;case 16:break ma;case 17:break na;case 8:break ta;case 7:break ua;case 6:break va;case 5:break wa;case 4:break ya;default:break oa}}while(1){if(j>>>0>=A>>>0){v[i>>2]=3;n=1;break i}h=w[j|0]<<f|h;j=j+1|0;f=f+8|0;if(f>>>0<3){continue}break}}d=h&7;v[i+20>>2]=d;k=d>>>1|0;v[i+24>>2]=k;f=f-3|0;h=h>>>3|0;if(d>>>0>=2){break sa}U=f;break pa}f=U&-8;h=h>>>(U&7)|0;g=0;d=0;break ra}if(j>>>0<A>>>0){break xa}v[i>>2]=7;n=1;break i}while(1){if(j>>>0>=A>>>0){v[i>>2]=6;n=1;break i}h=w[j|0]<<f|h;d=f>>>0>4294967287;j=j+1|0;f=f+8|0;if(d){continue}break}d=1;break ra}t[(g+i|0)+10528|0]=w[j|0];j=j+1|0;d=2;break ra}while(1){if(j>>>0>=A>>>0){v[i>>2]=51;n=1;break i}h=w[j|0]<<f|h;d=f>>>0>4294967287;j=j+1|0;f=f+8|0;if(d){continue}break}break Z}if(l>>>0<E>>>0){t[l|0]=z;g=g-1|0;l=l+1|0;break _}n=2;k=52;break k}if(l>>>0<E>>>0){break qa}n=2;k=9;break k}if(j>>>0<A>>>0){d=E-l|0;e=A-j|0;d=d>>>0<e>>>0?d:e;d=d>>>0<g>>>0?d:g;g=g-d|0;l=tc(l,j,d)+d|0;j=d+j|0;break Y}v[i>>2]=38;n=1;break i}e=0;Da:{switch(k-1|0){case 0:v[i+44>>2]=288;v[i+48>>2]=32;d=i+3552|0;v[d>>2]=84215045;v[d+4>>2]=84215045;d=i+3560|0;v[d>>2]=84215045;v[d+4>>2]=84215045;d=i+3568|0;v[d>>2]=84215045;v[d+4>>2]=84215045;d=i+3576|0;v[d>>2]=84215045;v[d+4>>2]=84215045;d=i- -64|0;k=0;while(1){e=144;if((k|0)==144){while(1){k=256;if((e|0)==256){while(1){e=280;if((k|0)==280){while(1){if((e|0)==288){break ca}t[d|0]=8;e=e+1|0;d=d+1|0;continue}}else{t[d|0]=7;k=k+1|0;d=d+1|0;continue}}}else{t[d|0]=9;e=e+1|0;d=d+1|0;continue}}}else{t[d|0]=8;k=k+1|0;d=d+1|0;continue}};case 2:break o;default:break Da}}d=0;break ea}while(1){Ea:{Fa:{Ga:{Ha:{Ia:{switch(d|0){case 0:if(g>>>0>3){break Ha}if(!f){f=0;d=3;continue V}if(f>>>0>7){break Fa}d=4;continue V;case 1:t[(g+i|0)+10528|0]=h;f=f-8|0;h=h>>>8|0;break Ea;default:break Ia}}g=g+1|0;break Ga}g=x[i+10528>>1];if((g|0)==(x[i+10530>>1]^65535)){break _}break n}d=0;continue}d=1;continue}d=2;continue}}d=8;continue}d=2;continue}if(l>>>0>=E>>>0){n=2;k=53;break k}t[l|0]=w[(M-z&Z)+G|0];l=l+1|0;M=M+1|0;d=7;break $}while(1){if(j>>>0>=A>>>0){v[i>>2]=27;n=1;break i}h=w[j|0]<<f|h;j=j+1|0;f=f+8|0;if(s>>>0>f>>>0){continue}break}d=6;break $}if(j>>>0>=A>>>0){v[i>>2]=26;n=1;break i}h=w[j|0]<<f|h;j=j+1|0;f=f+8|0;d=4;if(f>>>0<15){break $}d=5;break $}while(1){if(j>>>0>=A>>>0){v[i>>2]=25;n=1;break i}h=w[j|0]<<f|h;j=j+1|0;f=f+8|0;if(s>>>0>f>>>0){continue}break}d=3;break $}if(l>>>0>=E>>>0){n=2;k=24;break k}t[l|0]=g;l=l+1|0;break aa}if(j>>>0>=A>>>0){v[i>>2]=23;n=1;break i}h=w[j|0]<<f|h;j=j+1|0;f=f+8|0;d=0;if(f>>>0<15){break $}d=1;break $}while(1){if(j>>>0>=A>>>0){v[i>>2]=18;n=1;break i}h=w[j|0]<<f|h;j=j+1|0;f=f+8|0;if(s>>>0>f>>>0){continue}break}X=z-16|0;d=3;break ba}if(j>>>0>=A>>>0){v[i>>2]=16;n=1;break i}h=w[j|0]<<f|h;j=j+1|0;f=f+8|0;d=1;if(f>>>0<15){break ba}d=2;break ba}while(1){if(j>>>0>=A>>>0){v[i>>2]=14;n=1;break i}h=w[j|0]<<f|h;j=j+1|0;f=f+8|0;if(f>>>0<3){continue}break}d=1;break da}d=g+21600|0;while(1){if(j>>>0>=A>>>0){v[i>>2]=11;n=1;break i}h=w[j|0]<<f|h;j=j+1|0;f=f+8|0;J=t[d|0];if(f>>>0<J>>>0){continue}break}e=g;d=1}while(1){Ja:{Ka:{La:{if(!d){if(e>>>0>2){break La}g=e;J=t[e+21600|0];if(J>>>0<=f>>>0){break Ja}d=9;continue V}g=e<<2;v[(g+i|0)+44>>2]=v[g+64672>>2]+((-1<<J^-1)&h);e=e+1|0;f=f-J|0;h=h>>>J|0;break Ka}g=0;Tb(i+7040|0,0,288);d=0;break da}d=0;continue}d=1;continue}}while(1){Ma:{Na:{Oa:{if(!d){if(y[i+52>>2]<=g>>>0){break Oa}if(f>>>0>2){break Ma}d=10;continue V}t[(w[g+64688|0]+i|0)+7040|0]=h&7;g=g+1|0;f=f-3|0;h=h>>>3|0;break Na}v[i+52>>2]=19;break ca}d=0;continue}d=1;continue}}H=v[i+24>>2];d=0}while(1){Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{switch(d|0){case 0:d=0;if((H|0)<0){break aa}N=Tb(Y,0,64);e=B(H,3488)+i|0;Tb(e+352|0,0,3200);ba=e- -64|0;F=v[i+24>>2];e=v[((F<<2)+i|0)+44>>2];while(1){if((d|0)!=(e|0)){k=(w[d+ba|0]<<2)+N|0;v[k>>2]=v[k>>2]+1;d=d+1|0;continue}break};v[N+64>>2]=0;v[N+68>>2]=0;r=0;d=1;k=0;while(1){if((d|0)!=16){q=d<<2;d=d+1|0;q=v[q+N>>2];k=q+k<<1;v[(N- -64|0)+(d<<2)>>2]=k;r=q+r|0;continue}break};Q=0;q=-1;if((k|0)!=65536&r>>>0>=2){break p}while(1){if(e>>>0>Q>>>0){r=w[Q+ba|0];Ya:{if(!r){break Ya}d=(N- -64|0)+(r<<2)|0;k=v[d>>2];v[d>>2]=k+1;d=0;e=r;while(1){if(e){d=k&1|d<<1;k=k>>>1|0;e=e-1|0;continue}break}if(r>>>0<=10){e=1<<r;k=r<<9|Q;r=B(H,3488)+i|0;while(1){if(d>>>0>1023){break Ya}u[(r+(d<<1)|0)+352>>1]=k;d=d+e|0;continue}}F=B(H,3488)+i|0;k=F+((d&1023)<<1)|0;e=u[k+352>>1];Za:{if(e){k=q;q=e;break Za}u[k+352>>1]=q;k=q-2|0}d=d>>>9|0;while(1){d=d>>>1|0;e=d&1;if(r>>>0>=12){e=(F+(e+(q^-1)<<1)|0)+2400|0;q=u[e>>1];if(!q){u[e>>1]=k;q=k;k=k-2|0}r=r-1|0;continue}break}u[((B(H,3488)+i|0)+(e+(q^-1)<<1)|0)+2400>>1]=Q;q=k}Q=Q+1|0;F=v[i+24>>2];e=v[((F<<2)+i|0)+44>>2];continue}break};d=0;if((F|0)!=2){break Qa}break Ua;case 1:d=u[(((h&1023)<<1)+i|0)+7328>>1];_a:{if((d|0)>=0){if(d>>>0<512|d>>9>>>0>f>>>0){break _a}break Ta}if(f>>>0<11){break _a}e=10;while(1){d=u[(((h>>>e&1)+(d^-1)<<1)+i|0)+9376>>1];if((d|0)<0){k=e+2|0;e=e+1|0;if(f>>>0>=k>>>0){continue}}break}if((d|0)>=0){break Ta}}d=11;continue V;case 2:e=u[(((h&1023)<<1)+i|0)+7328>>1];if((e|0)>=0){break Wa}d=10;while(1){k=h>>>d|0;d=d+1|0;e=u[(((k&1)+(e^-1)<<1)+i|0)+9376>>1];if((e|0)<0){continue}break};z=e&65535;break Va;default:break Xa}}d=t[X+17809|0]+((-1<<s^-1)&h)|0;f=f-s|0;h=h>>>s|0;e=g+i|0;Tb(e+10532|0,(z|0)==16?w[e+10531|0]:0,d);d=d+g|0;break Ua}d=e>>9;z=e&511}f=f-d|0;h=h>>>d|0;if(z>>>0>15){break Sa}t[(g+i|0)+10532|0]=z;d=g+1|0}e=v[i+48>>2];g=v[i+44>>2];k=e+g|0;if(k>>>0<=d>>>0){break Ra}if(f>>>0<=14){if((A-j|0)<=1){g=d;d=1;continue}h=w[j|0]<<f|h|w[j+1|0]<<f+8;j=j+2|0;f=f+16|0}g=d}d=2;continue}if(!((z|0)!=16|g)){g=0;z=16;break q}X=z-16|0;s=t[z+21575|0];if(s>>>0<=f>>>0){break Pa}d=12;continue V}if((d|0)!=(k|0)){g=d;break r}k=i+10532|0;tc(i- -64|0,k,g);tc(i+3552|0,g+k|0,e);F=v[i+24>>2];g=d}H=F-1|0;v[i+24>>2]=H;d=0;continue}d=3;continue}}o=h;d=2}$a:while(1){ab:{bb:{cb:{db:{eb:{fb:{gb:{hb:{ib:{jb:{kb:{lb:{mb:{nb:{ob:{switch(d|0){case 0:d=u[(((h&1023)<<1)+i|0)+352>>1];pb:{if((d|0)>=0){if(d>>>0<512|d>>9>>>0>f>>>0){break pb}break ab}if(f>>>0<11){break pb}e=10;while(1){d=u[(((h>>>e&1)+(d^-1)<<1)+i|0)+2400>>1];if((d|0)<0){k=e+2|0;e=e+1|0;if(f>>>0>=k>>>0){continue}}break}if((d|0)>=0){break ab}}d=13;continue V;case 1:e=u[(((h&1023)<<1)+i|0)+352>>1];if((e|0)>=0){break nb}d=10;while(1){g=h>>>d|0;d=d+1|0;e=u[(((g&1)+(e^-1)<<1)+i|0)+2400>>1];if((e|0)<0){continue}break};g=e&65535;break mb;case 3:break db;case 4:break eb;case 5:break ib;case 6:break jb;case 2:break ob;default:break kb}}while(1){d=A-j|0;if(!((E-l|0)>1&(d|0)>=4)){if(f>>>0>14){h=o;break ab}if((d|0)<=1){h=o;d=0;continue $a}h=w[j|0]<<f|o|w[j+1|0]<<f+8;f=f+16|0;j=j+2|0;break ab}if(f>>>0>14){k=j}else{o=(w[j|0]|w[j+1|0]<<8)<<f|o;f=f+16|0;k=j+2|0}g=u[(((o&1023)<<1)+i|0)+352>>1];qb:{if((g|0)<0){d=10;while(1){h=o>>>d|0;d=d+1|0;g=u[(((h&1)+(g^-1)<<1)+i|0)+2400>>1];if((g|0)<0){continue}break}g=g&65535;break qb}d=g>>9}f=f-d|0;h=o>>>d|0;if(g&256){j=k;break lb}if(!(f>>>0>14)){h=(w[k|0]|w[k+1|0]<<8)<<f|h;k=k+2|0;f=f+16|0}r=f;j=k;e=u[(((h&1023)<<1)+i|0)+352>>1];rb:{if((e|0)<0){d=10;while(1){o=h>>>d|0;d=d+1|0;e=u[(((o&1)+(e^-1)<<1)+i|0)+2400>>1];if((e|0)<0){continue}break}e=e&65535;break rb}d=e>>9}t[l|0]=g;f=r-d|0;o=h>>>d|0;if(!(e&256)){t[l+1|0]=e;l=l+2|0;continue}break}l=l+1|0;h=o;g=e;break lb}d=e>>9;g=e&511}f=f-d|0;h=h>>>d|0;if(g>>>0>255){break lb}d=14;continue V}e=g&511;g=256;if((e|0)==256){break X}d=e-257<<2;g=v[d+64160>>2];s=0;if(e-285>>>0<4294967276){break cb}s=v[d+64288>>2];if(s>>>0>f>>>0){d=15;continue V}d=3;continue}if(!g){o=h;g=-1;break gb}g=g-1|0;d=18;continue V}f=f-s|0;o=h>>>s|0;z=((-1<<s^-1)&h)+z|0;break hb}e=u[(((h&1023)<<1)+i|0)+3840>>1];sb:{if((e|0)<0){d=10;while(1){k=h>>>d|0;d=d+1|0;e=u[(((k&1)+(e^-1)<<1)+i|0)+5888>>1];if((e|0)<0){continue}break}e=e&65535;break sb}d=e>>9;e=e&511}f=f-d|0;h=h>>>d|0;d=e<<2;z=v[d+64416>>2];s=0;if(e-30>>>0<4294967270){o=h;break hb}s=v[d+64544>>2];if(s>>>0<=f>>>0){break fb}d=17;continue V}M=l-G|0;d=(M-z&Z)+G|0;if((d>>>0<l>>>0?l:d)+g>>>0>E>>>0){h=o;d=7;continue}while(1){if(g>>>0>=3){t[l|0]=w[d|0];t[l+1|0]=w[d+1|0];t[l+2|0]=w[d+2|0];g=g-3|0;d=d+3|0;l=l+3|0;continue}break}if(!g){g=0;break gb}t[l|0]=w[d|0];if((g|0)!=1){t[l+1|0]=w[d+1|0]}l=g+l|0}d=2;continue}d=6;continue}d=u[(((h&1023)<<1)+i|0)+3840>>1];tb:{if((d|0)>=0){if(d>>>0<512|d>>9>>>0>f>>>0){break tb}break bb}if(f>>>0<11){break tb}e=10;while(1){d=u[(((h>>>e&1)+(d^-1)<<1)+i|0)+5888>>1];if((d|0)<0){k=e+2|0;e=e+1|0;if(f>>>0>=k>>>0){continue}}break}if((d|0)>=0){break bb}}d=16;continue V}f=f-s|0;g=((-1<<s^-1)&h)+g|0;h=h>>>s|0}if(f>>>0>14){break bb}if((A-j|0)<=1){d=4;continue}h=w[j|0]<<f|h|w[j+1|0]<<f+8;f=f+16|0;j=j+2|0}d=5;continue}d=1;continue}}if(!g|!f){break Y}if(f>>>0>7){break Z}d=5;continue}f=f-8|0;z=h&255;h=h>>>8|0;d=6;continue}if(g){break W}g=0}if(t[i+20|0]&1){break u}d=0;continue}d=7;continue}}h=0;d=f>>>3|0;e=j-C|0;e=e>>>0>j>>>0?0:e;d=d>>>0<e>>>0?d:e;if((f&-8)==d<<3){j=j-d|0;e=0;d=0;f=0;if(!(V&1)){break s}k=0;break t}aa(6842,13088,2797,6852);L()}while(1){ub:{vb:{wb:{xb:{yb:{zb:{switch(k|0){case 0:if(e>>>0>3){g=e;f=d;break s}f=0;if(d){break yb}g=e;k=1;continue;case 1:break zb;default:break xb}}if(j>>>0<A>>>0){break vb}v[i>>2]=42;n=1;break i}g=e;f=d;if(d>>>0>7){break wb}k=2;continue}while(1){if(j>>>0>=A>>>0){v[i>>2]=41;n=1;break i}h=w[j|0]<<f|h;e=f>>>0>4294967287;j=j+1|0;d=f+8|0;f=d;if(e){continue}break}e=g}k=h&255;h=h>>>8|0;d=d-8|0;break ub}k=w[j|0];j=j+1|0;e=g;d=f}v[i+16>>2]=v[i+16>>2]<<8|k;e=e+1|0;k=0;continue}}n=0;k=34;break k}k=21;break k}k=17;break k}k=35;break k}k=10;break k}k=39;break k}n=1;break i}g=1}v[i>>2]=k}d=f>>>3|0;e=j-C|0;e=e>>>0>j>>>0?0:e;d=d>>>0<e>>>0?d:e;j=j-d|0;f=f-(d<<3)|0}v[i+4>>2]=f;v[i+60>>2]=M;v[i+40>>2]=s;v[i+36>>2]=g;v[i+32>>2]=z;v[i+56>>2]=(((f&63)>>>0>=32?0:-1<<f)^-1)&h;v[D+12>>2]=j-C;h=l-K|0;v[D+8>>2]=h;if((n|0)<0){break g}f=(h>>>0)%5552|0;g=v[i+28>>2];e=g>>>16|0;k=g&65535;while(1){j=0;if(h){d=K;while(1){if((j|7)>>>0<f>>>0){g=w[d|0]+k|0;o=g+w[d+1|0]|0;q=o+w[d+2|0]|0;r=q+w[d+3|0]|0;l=r+w[d+4|0]|0;z=l+w[d+5|0]|0;C=z+w[d+6|0]|0;k=C+w[d+7|0]|0;e=k+(C+(z+(l+(r+(q+(o+(e+g|0)|0)|0)|0)|0)|0)|0)|0;d=d+8|0;j=j+8|0;continue}break}j=f&8184;while(1){if((f|0)!=(j|0)){j=j+1|0;k=w[d|0]+k|0;e=k+e|0;d=d+1|0;continue}break}h=h-f|0;e=(e>>>0)%65521|0;k=(k>>>0)%65521|0;K=f+K|0;f=5552;continue}break}g=e<<16|k;v[i+28>>2]=g;if(n){break g}n=0;if(!(V&1)){break g}n=(g|0)==v[i+16>>2]?0:-2}jb=Y+144|0;v[i+43780>>2]=n;g=v[D+12>>2];v[p>>2]=g+v[p>>2];v[p+4>>2]=v[p+4>>2]-g;v[p+8>>2]=g+v[p+8>>2];v[p+48>>2]=v[i+28>>2];g=v[D+8>>2];v[i+10996>>2]=g;d=v[p+16>>2];d=d>>>0>g>>>0?g:d;tc(v[p+12>>2],v[i+10992>>2]+G|0,d);v[p+12>>2]=d+v[p+12>>2];v[p+16>>2]=v[p+16>>2]-d;v[p+20>>2]=d+v[p+20>>2];h=v[i+10996>>2];v[i+10996>>2]=h-d;k=d+v[i+10992>>2]&32767;v[i+10992>>2]=k;if((n|0)<0){break f}if(!((n|0)!=1|ca)){g=-5;break e}if(n){g=0;e=v[p+4>>2];if(!e|!v[p+16>>2]){break e}if((d|0)==(h|0)){continue}break e}break}g=(d|0)==(h|0);break e}h=v[p+16>>2];d=d>>>0<h>>>0?d:h;tc(v[p+12>>2],(v[i+10992>>2]+i|0)+11012|0,d);v[p+12>>2]=d+v[p+12>>2];v[p+16>>2]=v[p+16>>2]-d;v[p+20>>2]=d+v[p+20>>2];h=v[i+10996>>2];v[i+10996>>2]=h-d;v[i+10992>>2]=d+v[i+10992>>2]&32767;if(v[i+43780>>2]){break e}g=(d|0)==(h|0);break e}g=-3}jb=D+16|0;h=v[m+1084>>2]-S|0;v[m+1084>>2]=h;d=I+$|0;I=v[m+1104>>2];$=d-I|0;continue}break}b=m+1088|0;Ab:{if(!b){break Ab}d=v[b+28>>2];if(!d){break Ab}nb[v[b+36>>2]](v[b+40>>2],d);v[b+28>>2]=0}h=0;Bb:{Cb:{if(!(v[m+1156>>2]!=(_|0)|I|(g|0)!=1)){re(m+24|0,v[R>>2],v[R+4>>2]);b=ee(m+16|0);v[23588]=0;g=v[b+4>>2];v[m+8>>2]=v[b>>2];v[m+12>>2]=g;b=Eg(540,m+48|0,v[m+24>>2],v[m+28>>2],m+8|0);g=v[23588];v[23588]=0;if((g|0)==1){break Cb}v[23588]=0;h=W(870,a|0,b|0,c|0)|0;a=v[23588];v[23588]=0;if((a|0)==1){break Bb}Ab(b)}hc(R);break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;Ab(b);break c}a=P()|0;O()|0}hc(R);T(a|0);L()}jb=m+1168|0;return h|0}function Pga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=C(0),y=0,A=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=C(0),Q=0,R=C(0),S=0,U=0,X=0,Y=0,$=0,aa=0,ba=0,ca=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=C(0),ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=C(0);p=jb-11360|0;jb=p;yc(c);a:{while(1){b:{if(!Pb(v[c>>2],v[c+8>>2],4)){break b}e=p+16|0;d=jb-16|0;jb=d;c:{if(!Pb(v[c>>2],v[c+8>>2],3)){f=0;while(1){if((f|0)!=3){Ch(e+f|0);f=f+1|0;continue}break}break c}xv(d+8|0,e);td(d,c,v[d+8>>2],v[d+12>>2])}jb=d+16|0;d:{e:{if(!Rb(e,14993,3)){e=p+4648|0;d=jb-16|0;jb=d;f:{if(!Pb(v[c>>2],v[c+8>>2],7)){f=0;while(1){if((f|0)!=7){Ch(e+f|0);f=f+1|0;continue}break}break f}Eo(d+8|0,e);td(d,c,v[d+8>>2],v[d+12>>2])}jb=d+16|0;H=0;i=3;while(1){if((i|0)==7){break d}e=w[(p+4648|0)+i|0];if(e&128){break e}i=i+1|0;H=e|H<<7;continue}}g:{if(Rb(p+16|0,14152,3)){break g}if(!cS(c,13474)){break g}Zb(c,Bg(c)+16|0);continue}if(!Rb(p+16|0,30222,3)){continue}if(!Rb(p+16|0,30226,3)){continue}if(!w[p+16|0]){yg(c,2);continue}if(KP(p+16|0)){break b}}i=0;break a}Zb(c,H);continue}break}yc(c);e=p+11336|0;MA(e,c);ca=v[p+11336>>2];Y=Ie(e);X=Sb(p+11320|0);c=p+4648|0;Tb(c,0,6668);gz(c);c=p+4640|0;v[c>>2]=0;v[c+4>>2]=0;c=p+4632|0;v[c>>2]=0;v[c+4>>2]=0;v[p+4624>>2]=0;v[p+4628>>2]=0;H=0;c=0;h:{while(1){d=Hc(ca,ea);aa=p+16|0;I=p+4624|0;e=0;n=jb-17168|0;jb=n;v[n+17164>>2]=0;i:{j:{E=p+4648|0;k:{if(w[E+6152|0]!=255|(d|0)<5){break k}if(!tp(E+6152|0,Y)){break k}i=ox(w[Y+1|0],w[Y+2|0],v[E+6148>>2])+sp(Y)|0;v[n+17164>>2]=i;if((d|0)==(i|0)){i=d;break j}l:{if((d|0)>=(i+4|0)){if(tp(Y,i+Y|0)){break l}}v[n+17164>>2]=0;break k}if(i){break j}}f=Y;J=Tb(E,0,6668)+6148|0;$=n+17164|0;i=0;j=0;D=d-4|0;q=(D|0)>0?D:0;while(1){m:{n:{o:{p:{if((i|0)==(q|0)){i=d;break p}if(!sI(f)){break n}h=ox(w[f+1|0],w[f+2|0],v[J>>2]);e=h+sp(f)|0;g=4;o=i+4|0;q:{while(1){if(!(g>>>0>2303|h)){if((D|0)<=((g<<1)+i|0)){break q}h=0;m=f+g|0;r:{if(!tp(f,m)){break r}k=g-sp(f)|0;y=sp(m)+k|0;if((d|0)<(y+(g+o|0)|0)){break r}if(!tp(f,m+y|0)){break r}v[J>>2]=k;h=k;e=g}g=g+1|0;continue}break}if(!h|(d|0)<(e+i|0)){break q}y=d-i|0;g=0;A=0;while(1){s:{t:{if((A|0)!=10){k=(A|0)!=0;F=g;g=f+g|0;g=(F+ox(w[g+1|0],w[g+2|0],h)|0)+sp(g)|0;if((y|0)<(g+4|0)){break s}if(tp(f,f+g|0)){break t}k=0}else{k=1}break s}A=A+1|0;continue}break}if(!k){break q}j=e;break p}if((e|0)!=(d|0)|i){break o}i=0;j=d}v[$>>2]=j;e=i;break m}v[J>>2]=0}f=f+1|0;i=i+1|0;continue}break}i=v[n+17164>>2];if((d|0)>=(e+i|0)?i:0){break j}v[I>>2]=e;A=0;break i}d=e+Y|0;v[E+6152>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[I+4>>2]=e;v[I>>2]=e+i;v[I+8>>2]=w[d+3|0]>191?1:2;qa=I,ra=vI(w[d+1|0],w[d+2|0]),v[qa+12>>2]=ra;v[I+16>>2]=4-(w[d+1|0]>>>1&3);qa=I,ra=nx(w[d+1|0],w[d+2|0]),v[qa+20>>2]=ra;if(!aa){A=mx(w[d+1|0]);break i}uI(n+17152|0,d+4|0,i-4|0);if(!(t[d+1|0]&1)){ge(n+17152|0,16)}u:{if(v[I+16>>2]==3){A=0;m=n+17152|0;ja=n+3740|0;e=ja;f=0;g=w[d+1|0];i=B((g>>>3&1)+(g>>>4&1)|0,3)+(w[d+2|0]>>>2&3)|0;j=i-((i|0)!=0)|0;$=d;d=w[d+3|0]>191?1:2;v:{if(g&8){i=ge(m,9);d=d<<1;f=ge(m,d+7|0);break v}i=ge(m,d|8)>>>d|0}g=B(j,40);q=g+65008|0;o=g+65328|0;y=B(j,23)+64816|0;l=-1;h=0;w:{while(1){j=w[$+3|0];k=ge(m,12);u[e+4>>1]=k;g=ge(m,9);u[e+6>>1]=g;if((g&65535)>>>0>288){break w}g=j>>>0>191?f<<4:f;qa=e,ra=ge(m,8),t[qa+10|0]=ra;f=ge(m,w[$+1|0]&8?4:9);t[e+13|0]=22;t[e+14|0]=0;v[e>>2]=y;u[e+8>>1]=f;x:{if(ge(m,1)){f=ge(m,2);t[e+11|0]=f;if(!(f&255)){break w}f=ge(m,1);u[e+18>>1]=65287;t[e+12|0]=f;if(w[e+11|0]==2){y:{if(!(f&255)){v[e>>2]=q;t[e+18|0]=8;j=39;f=0;break y}v[e>>2]=o;j=30;f=w[$+1|0]&8?8:6}t[e+14|0]=j;t[e+13|0]=f;g=g&3855}f=ge(m,10);qa=e,ra=ge(m,3),t[qa+21|0]=ra;qa=e,ra=ge(m,3),t[qa+22|0]=ra;qa=e,ra=ge(m,3),t[qa+23|0]=ra;f=f<<5;break x}t[e+11|0]=0;t[e+12|0]=0;f=ge(m,15);qa=e,ra=ge(m,4),t[qa+18|0]=ra;j=ge(m,3);t[e+20|0]=255;t[e+19|0]=j}t[e+17|0]=f&31;t[e+15|0]=f>>>10;t[e+16|0]=f>>>5&31;h=(k&65535)+h|0;z:{if(w[$+1|0]&8){f=ge(m,1);break z}f=x[e+8>>1]>499}t[e+24|0]=f;qa=e,ra=ge(m,1),t[qa+25|0]=ra;f=ge(m,1);t[e+27|0]=g>>>12&15;t[e+26|0]=f;e=e+28|0;f=g<<4;d=d-1|0;if(d){continue}break}l=(v[m+4>>2]+h|0)>(v[m+8>>2]+(i<<3)|0)?-1:i}if(!((l|0)<0|v[n+17156>>2]>v[n+17160>>2])){h=n+17152|0;i=v[h+4>>2];f=v[h+8>>2];d=n+912|0;g=v[E+6144>>2];e=g-l|0;j=(g|0)<(l|0)?g:l;g=tc(d+12|0,(((e|0)>0?e:0)+E|0)+6156|0,j);e=(f-i|0)/8|0;tc(g+j|0,v[h>>2]+(v[h+4>>2]/8|0)|0,e);uI(d,g,e+j|0);A:{i=v[E+6144>>2]>=(l|0);if(!i){break A}ma=E+2304|0;na=n+8620|0;oa=n+3852|0;while(1){if((w[$+1|0]&8?2:1)>>>0<=A>>>0){break A}pa=Tb(oa,0,4608);d=v[I+8>>2];K=B(B(d,A),28)+ja|0;e=0;ka=(d|0)>0?d:0;G=n+912|0;y=G+7548|0;ba=E+6152|0;while(1){if((e|0)!=(ka|0)){o=B(e,28)+K|0;J=x[o+4>>1];D=v[G+4>>2];d=(G+B(e,39)|0)+16156|0;h=y;q=e;j=jb-48|0;jb=j;ia=w[o+25|0];l=B(!w[o+13|0]+(w[o+14|0]!=0)|0,28)+65648|0;B:{if(w[ba+1|0]&8){e=w[o+27|0];g=w[x[o+8>>1]+65744|0];f=g&3;t[j+47|0]=f;t[j+46|0]=f;f=g>>>2|0;t[j+45|0]=f;t[j+44|0]=f;break B}e=(w[ba+3|0]&16)>>>4&(q|0)!=0;g=e?12:0;r=x[o+8>>1]>>>e|0;while(1){if((r|0)>=0){e=3;f=1;while(1){if((e|0)>=0){k=w[(e+g|0)+65760|0];t[(j+44|0)+e|0]=((r|0)/(f|0)|0)%(k|0);e=e-1|0;f=B(f,k);continue}break}g=g+4|0;r=r-f|0;continue}break}l=g+l|0;e=-16}g=d;f=j;m=f+44|0;r=0;while(1){C:{D:{E:{if((r|0)==4){break E}Q=w[l+r|0];if(!Q){break E}if(e&8){tc(f,g,Q);break D}fa=w[m+r|0];if(!fa){Tb(f,0,Q);Tb(g,0,Q);break D}d=(e|0)>=0?-1:-1<<fa^-1;k=0;while(1){if((k|0)==(Q|0)){break D}M=ge(G,fa);t[g+k|0]=(d|0)==(M|0)?-1:M;t[f+k|0]=M;k=k+1|0;continue}}t[f+2|0]=0;t[f|0]=0;t[f+1|0]=0;break C}e=e<<1;r=r+1|0;f=f+Q|0;g=g+Q|0;continue}break}F:{f=w[o+14|0];if(f){e=2-ia|0;m=w[o+23|0]<<e;k=w[o+22|0]<<e;g=w[o+21|0]<<e;d=w[o+13|0];e=0;while(1){if(e>>>0>=f>>>0){break F}M=j+(e+d|0)|0;t[M|0]=g+w[M|0];t[M+1|0]=k+w[M+1|0];t[M+2|0]=m+w[M+2|0];e=e+3|0;continue}}if(!w[o+24|0]){break F}e=0;while(1){if((e|0)==10){break F}d=e+j|0;t[d+11|0]=w[d+11|0]+w[e+65784|0];e=e+1|0;continue}}d=ia+1|0;e=0;s=lx(C(2048),((((w[ba+3|0]&224)==96)<<1)-w[o+10|0]|0)+258|0);while(1){if(w[o+13|0]+(f&255)>>>0>e>>>0){qa=(e<<2)+h|0,sa=lx(s,w[e+j|0]<<d),z[qa>>2]=sa;e=e+1|0;f=w[o+14|0];continue}break}jb=j+48|0;k=(G+B(q,2304)|0)+2940|0;ia=D+J|0;s=C(0);e=v[G+4>>2];f=v[G>>2]+((e|0)/8|0)|0;d=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);g=(d<<24|d<<8&16711680|(d>>>8&65280|d>>>24))<<(e&7);l=e|-8;r=f+4|0;S=v[o>>2];U=x[o+6>>1];e=0;while(1){G:{H:{if((U|0)>0){j=e+1|0;e=e+o|0;d=w[e+15|0];fa=(u[(d<<1)+70208>>1]<<1)+65824|0;ga=w[e+18|0];if(d>>>0>=16){M=w[d+70272|0];m=32-M|0;while(1){J=w[S|0]>>>1|0;D=(J|0)>(U|0)?U:J;s=z[h>>2];while(1){e=g>>>27|0;d=5;while(1){e=u[fa+(e<<1)>>1];if((e|0)<0){g=g<<d;f=e&7;e=(g>>>32-f|0)-(e>>3)|0;l=d+l|0;d=f;continue}break}f=e&65535;e=f>>>8|0;l=e+l|0;g=g<<e;d=0;while(1){if((d|0)!=2){F=f&15;I:{if((F|0)==15){l=l+M|0;e=g<<M;while(1){if((l|0)>=0){e=w[r|0]<<l|e;r=r+1|0;l=l-8|0;continue}break}F=(g>>>m|0)+15|0;g=F;J:{if((g|0)<=128){N=z[(g<<2)+70368>>2];break J}ha=g<<3;Q=g;g=g>>>0<1024;ha=g?ha:Q;Q=ha<<1&64;R=C(C((ha&63)-Q|0)/C(Q+(ha&-64)|0));N=C((g?C(16):C(256))*C(C(C(R*C(C(R*C(.2222222238779068))+C(1.3333333730697632)))+C(1))*z[(Q+ha>>6<<2)+70368>>2]))}N=C(C(s*N)*C(e>>31|1));break I}e=g;N=C(s*z[(((e>>>27&16|F)^16)<<2)+70304>>2])}z[k>>2]=N;f=f>>>4|0;k=k+4|0;d=d+1|0;g=(F|0)!=0;l=g+l|0;g=e<<g;continue}break}while(1){if((l|0)>=0){g=w[r|0]<<l|g;r=r+1|0;l=l-8|0;continue}break}D=D-1|0;if(D){continue}break}h=h+4|0;S=S+1|0;U=U-J|0;if((U|0)<=0){break H}e=(ga|0)>0;ga=ga-1|0;if(e){continue}break}break H}while(1){m=w[S|0]>>>1|0;F=(m|0)>(U|0)?U:m;s=z[h>>2];while(1){e=g>>>27|0;d=5;while(1){e=u[fa+(e<<1)>>1];if((e|0)<0){g=g<<d;f=e&7;e=(g>>>32-f|0)-(e>>3)|0;l=d+l|0;d=f;continue}break}d=e&65535;e=d>>>8|0;l=e+l|0;g=g<<e;e=0;while(1){if((e|0)!=2){f=d&15;z[k>>2]=s*z[(((f|g>>>27&16)^16)<<2)+70304>>2];d=d>>>4|0;k=k+4|0;e=e+1|0;f=(f|0)!=0;l=f+l|0;g=g<<f;continue}break}while(1){if((l|0)>=0){g=w[r|0]<<l|g;r=r+1|0;l=l-8|0;continue}break}F=F-1|0;if(F){continue}break}h=h+4|0;S=S+1|0;U=U-m|0;if((U|0)<=0){break H}e=(ga|0)>0;ga=ga-1|0;if(e){continue}break}break H}d=1-U|0;while(1){K:{f=w[o+26|0]?70192:70160;e=w[f+(g>>>28|0)|0];if(!(e&8)){e=w[f+((g<<4>>>32-(e&3))+(e>>>3)|0)|0]}f=e&7;l=f+l|0;if((ia|0)<((l+(r-v[G>>2]<<3)|0)-24|0)){break K}d=d-1|0;if(!d){d=w[S|0];if(d>>>0<2){break K}S=S+1|0;s=z[h>>2];h=h+4|0;d=d>>>1|0}g=g<<f;if(e&128){z[k>>2]=(g|0)<0?C(-s):s;l=l+1|0;g=g<<1}if(e&64){z[k+4>>2]=(g|0)<0?C(-s):s;l=l+1|0;g=g<<1}d=d-1|0;if(!d){d=w[S|0];if(d>>>0<2){break K}S=S+1|0;s=z[h>>2];h=h+4|0;d=d>>>1|0}if(e&32){z[k+8>>2]=(g|0)<0?C(-s):s;l=l+1|0;g=g<<1}if(e&16){z[k+12>>2]=(g|0)<0?C(-s):s;l=l+1|0;g=g<<1}while(1){if((l|0)>=0){g=w[r|0]<<l|g;r=r+1|0;l=l-8|0;continue}break}k=k+16|0;continue}break}v[G+4>>2]=ia;break G}e=j;continue}break}e=q+1|0;continue}break}e=w[E+6155|0];L:{if(e&16){D=jb-16|0;jb=D;e=G+2940|0;g=e+2304|0;q=v[K>>2];o=w[K+14|0];f=o+w[K+13|0]|0;d=0;m=D+4|0;v[m+8>>2]=-1;v[m>>2]=-1;v[m+4>>2]=-1;while(1){if((d|0)!=(f|0)){y=d+q|0;j=w[y|0];h=0;M:{while(1){if(h>>>0>=j>>>0){break M}k=h<<2;if(z[k+g>>2]==C(0)){h=h+2|0;if(z[(k|4)+g>>2]==C(0)){continue}}break}v[m+((d>>>0)%3<<2)>>2]=d;j=w[y|0]}d=d+1|0;g=(j<<2)+g|0;continue}break}if(w[K+13|0]){g=v[D+4>>2];d=v[D+8>>2];g=(d|0)<(g|0)?g:d;d=v[D+12>>2];d=(d|0)<(g|0)?g:d;v[D+12>>2]=d;v[D+8>>2]=d;v[D+4>>2]=d}m=G+16195|0;j=o?3:1;g=f-j|0;h=0;while(1){if((h|0)!=(j|0)){f=g+h|0;d=f-j|0;if((d|0)<=v[(D+4|0)+(h<<2)>>2]){d=w[ba+1|0]<<28>>31&3}else{d=w[d+m|0]}t[f+m|0]=d;h=h+1|0;continue}break}q=v[K>>2];o=D+4|0;y=u[K+36>>1]&1;g=0;k=w[ba+1|0]&8?7:64;while(1){j=g+q|0;d=w[j|0];if(d){f=w[ba+3|0]&32;N:{O:{if(v[o+((g>>>0)%3<<2)>>2]>=(g|0)){break O}h=w[g+m|0];if(h>>>0>=k>>>0){break O}N=f?C(1.4142135381698608):C(1);P:{if(w[ba+1|0]&8){f=h<<3;s=z[f+70900>>2];R=z[f+70896>>2];break P}R=lx(C(1),h+1>>>1<<y);f=h&1;s=f?C(1):R;R=f?R:C(1)}R=C(N*R);s=C(N*s);h=0;while(1){if((d|0)!=(h|0)){f=(h<<2)+e|0;N=z[f>>2];z[f+2304>>2]=N*s;z[f>>2]=N*R;h=h+1|0;continue}break}break N}if(!f){break N}rI(e,d)}g=g+1|0;e=(w[j|0]<<2)+e|0;continue}break}jb=D+16|0;break L}if((e&224)!=96){break L}rI(G+2940|0,576)}k=G+7708|0;e=0;while(1){if((e|0)!=(ka|0)){d=w[E+6153|0];q=(w[K+12|0]!=0)<<1<<((B((d>>>3&1)+(d>>>4&1)|0,3)+(w[E+6154|0]>>>2&3)|0)==2);j=(G+B(e,2304)|0)+2940|0;g=j;if(w[K+14|0]){r=v[K>>2]+w[K+13|0]|0;h=((G+B(e,2304)|0)+B(q,72)|0)+2940|0;d=h;f=k;while(1){o=w[r|0];if(o){y=o<<1;l=0;while(1){if((l|0)!=(o|0)){z[f>>2]=z[d>>2];z[f+4>>2]=z[(o<<2)+d>>2];z[f+8>>2]=z[(y<<2)+d>>2];d=d+4|0;l=l+1|0;f=f+12|0;continue}break}r=r+3|0;d=(y<<2)+d|0;continue}break}tc(h,k,f-k|0);f=q-1|0}else{f=31}while(1){d=0;if((f|0)>0){while(1){if((d|0)!=8){y=d<<2;h=y+g|0;la=z[h+72>>2];F=h;N=z[y+70960>>2];R=z[y+70992>>2];h=(17-d<<2)+g|0;s=z[h>>2];z[F+72>>2]=C(la*N)-C(R*s);z[h>>2]=C(la*R)+C(s*N);d=d+1|0;continue}break}g=g+72|0;f=f-1|0;continue}break}d=j;f=B(e,1152)+E|0;g=w[K+11|0];if(q){qI(d,f,71024,q);f=B(q,36)+f|0;d=B(q,72)+d|0}Q:{if((g|0)==2){h=32-q|0;m=jb-80|0;jb=m;q=m|8;o=m|4;while(1){if((h|0)>0){y=tc(m,d,72);g=v[f+20>>2];v[d+16>>2]=v[f+16>>2];v[d+20>>2]=g;g=v[f+12>>2];v[d+8>>2]=v[f+8>>2];v[d+12>>2]=g;g=v[f+4>>2];v[d>>2]=v[f>>2];v[d+4>>2]=g;g=f+24|0;kx(y,d+24|0,g);kx(o,d+48|0,g);kx(q,f,g);d=d+72|0;f=f+36|0;h=h-1|0;continue}break}jb=m+80|0;break Q}qI(d,f,B((g|0)==3,72)+71024|0,32-q|0)}h=0;f=j+72|0;while(1){d=1;if(h>>>0<=31){while(1){if(d>>>0<=17){g=(d<<2)+f|0;z[g>>2]=-z[g>>2];d=d+2|0;continue}break}f=f+144|0;h=h+2|0;continue}break}K=K+28|0;e=e+1|0;continue}break}tI(ma,pa,18,v[I+8>>2],aa,na);A=A+1|0;aa=B(v[I+8>>2],1152)+aa|0;continue}}g=n+912|0;d=v[g+8>>2]>>>3|0;e=v[g+4>>2]+7>>>3|0;j=d-e|0;f=(j|0)<511?j:511;if((j|0)>0){gj(E+6156|0,(g+(j>>>0>511?d-511|0:e)|0)+12|0,f)}v[E+6144>>2]=f;break u}gz(E);break i}q=n+17152|0;f=0;g=0;h=0;A=0;R:{S:{T:{e=d;d=w[d+3|0];i=d>>>6|0;switch(i-1|0){case 2:break R;case 0:break T;default:break S}}g=(d>>>2&12)+4|0;break R}g=32}k=w[e+1|0];U:{if((k&6)==6){i=72428;d=32;break U}if(!(k&8)){i=72431;d=30;break U}d=w[e+2|0];j=d>>>2&3;d=nx(k,d)>>>((i|0)!=3)|0;d=d?d:192;if(d>>>0<=55){i=72452;d=(j|0)==2?12:8;break U}i=72440;d=d>>>0>95?(j|0)!=1?30:27:27}t[n+768|0]=d;t[n+769|0]=(d|0)>(g|0)?g:d;d=i;j=72336;while(1){g=w[n+768|0];if(g>>>0<=f>>>0){f=0;while(1){j=g<<1&510;if(j>>>0>f>>>0){i=f+n|0;V:{if(!w[i+770|0]){d=6;break V}d=2;if((w[e+1|0]&6)==6){break V}d=ge(q,2);g=w[n+768|0]}t[i+834|0]=d;f=f+1|0;continue}break}g=n+770|0;o=n+834|0;e=n;f=0;while(1){if((f|0)!=(j|0)){d=w[g|0];i=d?19>>>w[f+o|0]&3|4:0;g=g+1|0;y=B(d,3)-6|0;s=C(0);d=4;while(1){if(d){if(d&i){k=ge(q,6);h=(k|0)/3|0;s=C(z[(y+(B(h,-3)+k|0)<<2)+72464>>2]*C(2097152>>>h|0))}z[e>>2]=s;d=d>>>1|0;e=e+4|0;continue}break}f=f+1|0;continue}break}f=w[n+769|0];e=w[n+768|0];e=e>>>0<f>>>0?f:e;while(1){if((e|0)!=(f|0)){t[((f<<1)+n|0)+771|0]=0;f=f+1|0;continue}break}}else{if((f|0)==(A|0)){j=w[d|0]+72336|0;A=w[d+2|0]+f|0;h=w[d+1|0];d=d+3|0}k=f<<1;g=w[ge(q,h)+j|0];t[(k+n|0)+770|0]=g;i=w[n+769|0];if(i>>>0>f>>>0){g=w[ge(q,h)+j|0];i=w[n+769|0]}t[((k|1)+n|0)+770|0]=i?g:0;f=f+1|0;continue}break}i=0;d=Tb(n+3852|0,0,4608);q=E+2304|0;o=n+8620|0;A=0;W:{while(1){if((A|0)==3){break W}y=d+(i<<2)|0;D=n+17152|0;j=0;J=v[I+16>>2]|1;m=(J|0)>0?J:0;l=576;while(1){if((j|0)!=4){f=y+(B(j,J)<<2)|0;g=0;while(1){if(w[n+768|0]<<1>>>0>g>>>0){X:{k=w[(g+n|0)+770|0];if(!k){break X}if(k>>>0<=16){h=(-1<<k-1)+1|0;e=0;while(1){if((e|0)==(m|0)){break X}qa=(e<<2)+f|0,sa=C(ge(D,k)+h|0),z[qa>>2]=sa;e=e+1|0;continue}}e=2<<k-17;h=ge(D,(e-(e>>>3|0)|0)+3|0);k=e>>>1|0;$=e|1;e=0;while(1){if((e|0)==(m|0)){break X}F=h;h=(h>>>0)/($>>>0)|0;z[(e<<2)+f>>2]=F-(k+B($,h)|0)|0;e=e+1|0;continue}}g=g+1|0;f=(l<<2)+f|0;l=18-l|0;continue}break}j=j+1|0;continue}break}i=(J<<2)+i|0;if((i|0)==12){j=(A<<2)+n|0;e=d;i=w[n+769|0];f=d+B(i,72)|0;tc(f+2304|0,f,B(w[n+768|0]-i|0,72));g=0;while(1){if(w[n+768|0]>g>>>0){f=0;while(1){if((f|0)!=12){i=(f<<2)+e|0;z[i>>2]=z[j>>2]*z[i>>2];i=i+2304|0;z[i>>2]=z[j+12>>2]*z[i>>2];f=f+1|0;continue}break}j=j+24|0;e=e+72|0;g=g+1|0;continue}break}tI(q,d,12,v[I+8>>2],aa,o);Tb(d,0,4608);aa=B(v[I+8>>2],768)+aa|0;i=0}A=A+1|0;if(v[n+17156>>2]<=v[n+17160>>2]){continue}break}gz(E);A=0;break i}i=1}A=B(mx(w[E+6153|0]),i)}jb=n+17168|0;e=v[p+4624>>2];if((e|0)<0|!e&(A|0)!=0|!(e|A)){break h}Y:{if(e){e=v[p+4636>>2];if((e|0)!=(H|0)?H:0){break h}d=v[p+4632>>2];if((d|0)!=(c|0)?c:0){break h}if(d-3>>>0<4294967294|(e|0)<=0){break Y}v[p+12>>2]=0;qa=p,ra=Hc(ca,ea),v[qa+8>>2]=ra;c=v[Ij(p+4624|0,p+12|0,p+8|0)>>2];v[p+12>>2]=0;qa=p,ra=Hc(ca,ea),v[qa+8>>2]=ra;Y=c+Y|0;c=ca;f=v[Ij(p+4624|0,p+12|0,p+8|0)>>2];ca=c-f|0;ea=ea-((f>>31)+(c>>>0<f>>>0)|0)|0;Z:{if(!A){break Z}v[23588]=0;c=p+16|0;W(574,X|0,c|0,c+(B(d,A)<<1)|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break Z}H=V(92948)|0;if((O()|0)==(da(92948)|0)){_(H|0)|0;v[23588]=0;Z(18);f=v[23588];v[23588]=0;H=e;c=d;if((f|0)!=1){break h}H=P()|0;O()|0}nd(X);Tc(p+11336|0);T(H|0);L()}H=e;c=d}if((Qc(v[X>>2],v[X+4>>2])>>>0)/(c>>>0)>>>0>268435456){break h}if(!!ca&(ea|0)>=0|(ea|0)>0){continue}break h}break}H=e;c=d}i=0;_:{if(!H|!c){break _}d=v[X>>2];e=v[X+4>>2];if(oc(d,e)){break _}if((Qc(d,e)>>>0)/(c>>>0)>>>0>268435456){break _}rt(a,b);e=B(b,104)+a|0;d=e+484380|0;qa=d,ra=(Qc(v[X>>2],v[X+4>>2])>>>0)/(c>>>0)|0,v[qa>>2]=ra;a=e+484414|0;b=x[a>>1];u[a>>1]=(c|0)==2?b|65:b&65470|1;Ng(d);a=e+484400|0;i=Zd(v[d>>2],v[a>>2]);if(!i){break _}_n(Eb(v[X>>2]),Eb(v[X+4>>2]),v[a>>2]);i=Zd(v[d>>2],v[d+20>>2])}nd(X);Tc(p+11336|0)}jb=p+11360|0;return i|0}function qA(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=C(0),A=0,E=0,F=0,G=0,I=C(0),J=0,K=0,M=0,N=0,O=C(0);r=jb-1520|0;jb=r;e=r+8|0;M=Tb(e,0,1512),N=-1,v[M+1420>>2]=N;t[r+56|0]=1;v[r+48>>2]=a+b;v[r+40>>2]=a;l=jb-1024|0;jb=l;t[e+1377|0]=1;a:{if(!os(e)){break a}b=w[e+1375|0];if(!(b&2)){dc(e,34);break a}if(b&4){dc(e,34);break a}if(b&1){dc(e,34);break a}if(v[e+1116>>2]!=1){dc(e,34);break a}b=w[e+1120|0];if((b|0)!=30){b:{if((b|0)!=64){break b}if(!hx(e,l+1018|0,6)|w[l+1018|0]!=102|(w[l+1019|0]!=105|w[l+1020|0]!=115)){break b}if(w[l+1021|0]!=104|w[l+1022|0]!=101|w[l+1023|0]!=97){break b}if((_e(e)|0)!=100){break b}if(_e(e)){break b}dc(e,38);break a}dc(e,34);break a}if((_e(e)|0)!=1){dc(e,34);break a}if(!hx(e,l+1018|0,6)){dc(e,10);break a}if(!fx(l+1018|0)){dc(e,34);break a}if(fj(e)){dc(e,34);break a}b=_e(e);v[e+4>>2]=b;if(!b){dc(e,34);break a}if(b>>>0>=17){dc(e,5);break a}b=fj(e);v[e>>2]=b;if(!b){dc(e,34);break a}fj(e);fj(e);fj(e);b=_e(e);j=b>>>4|0;v[e+116>>2]=1<<j;g=b&15;v[e+112>>2]=1<<g;if(g-14>>>0<=4294967287){dc(e,20);break a}if((b<<24)+536870912>>24>=0){dc(e,20);break a}c:{if(g>>>0>j>>>0){dc(e,20);break c}if(!(_e(e)&1)){dc(e,34);break c}if(!os(e)){break a}if(!gx(e)){break a}if(!ix(e)){break a}if((vh(e)|0)==3){while(1){if((f|0)!=6){M=(l+1018|0)+f|0,N=vh(e),t[M|0]=N;f=f+1|0;continue}break}if(!fx(l+1018|0)){dc(e,20);break c}b=ex(e);f=fe(e,b+1|0);v[e+20>>2]=f;if(f){f=0;g=(b|0)>0?b:0;while(1){if((f|0)!=(g|0)){j=vh(e);t[v[e+20>>2]+f|0]=j;f=f+1|0;continue}break}t[b+v[e+20>>2]|0]=0;b=ex(e);v[e+28>>2]=0;v[e+24>>2]=b;d:{if((b|0)<=0){break d}b=fe(e,b<<2);v[e+28>>2]=b;if(b){break d}dc(e,3);break c}while(1){e:{f:{if(v[e+24>>2]>(h|0)){b=ex(e);f=fe(e,b+1|0);g=h<<2;v[g+v[e+28>>2]>>2]=f;if(!v[g+v[e+28>>2]>>2]){break f}f=0;j=(b|0)>0?b:0;while(1){if((f|0)==(j|0)){break e}i=vh(e);t[v[g+v[e+28>>2]>>2]+f|0]=i;f=f+1|0;continue}}if(!(vh(e)&1)){dc(e,20);break c}eI(e,w[e+1376|0]);t[e+1376|0]=0;while(1){b=ix(e);eI(e,b);t[e+1376|0]=0;if(b){continue}break}f=0;if(!gx(e)){break a}if(!lI(e)){if(v[e+100>>2]!=21){break a}v[e+100>>2]=20;break a}b=0;while(1){if((b|0)!=256){j=b<<24;g=0;while(1){if((g|0)!=8){j=j>>31&79764919^j<<1;g=g+1|0;continue}break}v[(b<<2)+463232>>2]=j;b=b+1|0;continue}break}if((vh(e)|0)==5){while(1){if((f|0)!=6){M=(l+1018|0)+f|0,N=vh(e),t[M|0]=N;f=f+1|0;continue}break}if(!fx(l+1018|0)){dc(e,20);break c}b=nc(e,8)+1|0;v[e+120>>2]=b;b=fe(e,B(b,2096));v[e+124>>2]=b;if(!b){dc(e,3);break c}Tb(b,0,B(v[e+120>>2],2096));g:{h:{while(1){i:{if(v[e+120>>2]>(E|0)){b=v[e+124>>2];if((nc(e,8)&255)!=66){dc(e,20);break c}if((nc(e,8)&255)!=67){dc(e,20);break c}if((nc(e,8)&255)!=86){dc(e,20);break c}g=b+B(E,2096)|0;M=g,N=nc(e,8)&255|nc(e,8)<<8,v[M>>2]=N;M=g,N=nc(e,8)&255|(nc(e,8)<<8&65280|nc(e,8)<<16),v[M+4>>2]=N;k=g+4|0;f=0;m=nc(e,1);if(!m){f=nc(e,1)}t[g+23|0]=f;h=v[k>>2];if(v[g>>2]){b=h;break i}b=0;if(!h){break i}dc(e,20);break c}b=nc(e,6)+1&255;f=0;j:{while(1){if((b|0)==(f|0)){break j}f=f+1|0;if(!nc(e,16)){continue}break}dc(e,20);break c}b=nc(e,6)+1|0;v[e+128>>2]=b;b=fe(e,B(b,1596));v[e+260>>2]=b;k:{if(b){E=0;k=0;l:while(1){if(v[e+128>>2]<=(k|0)){break k}b=nc(e,16);u[((k<<1)+e|0)+132>>1]=b;b=b&65535;if(b>>>0>=2){dc(e,20);break c}if(!b){b=v[e+260>>2]+B(k,1596)|0;M=b,N=nc(e,8),t[M|0]=N;M=b,N=nc(e,16),u[M+2>>1]=N;M=b,N=nc(e,16),u[M+4>>1]=N;M=b,N=nc(e,6),t[M+6|0]=N;M=b,N=nc(e,8),t[M+7|0]=N;j=nc(e,4)+1|0;t[b+8|0]=j;h=b+9|0;f=0;while(1){if((j&255)>>>0>f>>>0){M=f+h|0,N=nc(e,8),t[M|0]=N;f=f+1|0;j=w[b+8|0];continue}break}dc(e,4);break c}f=v[e+260>>2]+B(k,1596)|0;b=nc(e,5);t[f|0]=b;m=f+1|0;j=0;g=-1;while(1)if((b&255)>>>0<=j>>>0){h=g+1|0;g=f+82|0;i=f+65|0;o=f+49|0;n=f+33|0;b=0;while(1){if((b|0)!=(h|0)){M=b+n|0,N=nc(e,3)+1|0,t[M|0]=N;q=b+o|0;p=nc(e,2);t[q|0]=p;j=0;m:{if(!(p&255)){break m}p=nc(e,8);t[b+i|0]=p;if(v[e+120>>2]>(p&255)){break m}dc(e,20);break c}n:{while(1){if(1<<w[q|0]<=(j|0)){break n}p=nc(e,8)-1|0;u[(g+(b<<4)|0)+(j<<1)>>1]=p;j=j+1|0;if(v[e+120>>2]>p<<16>>16){continue}break}dc(e,20);break c}b=b+1|0;continue}break}g=2;M=f,N=nc(e,2)+1|0,t[M+1588|0]=N;b=nc(e,4);v[f+1592>>2]=2;h=0;u[f+338>>1]=0;t[f+1589|0]=b;u[f+340>>1]=1<<b;b=f+338|0;i=0;while(1){if(w[f|0]>i>>>0){o=n+w[i+m|0]|0;j=0;while(1){if(w[o|0]>j>>>0){g=nc(e,w[f+1589|0]);u[b+(v[f+1592>>2]<<1)>>1]=g;g=v[f+1592>>2]+1|0;v[f+1592>>2]=g;j=j+1|0;continue}break}i=i+1|0;continue}break}while(1){if((g|0)>(h|0)){g=x[b+(h<<1)>>1];j=(l+16|0)+(h<<2)|0;u[j+2>>1]=h;u[j>>1]=g;h=h+1|0;g=v[f+1592>>2];continue}break}dI(l+16|0,g,1090);g=v[f+1592>>2];h=((g|0)>1?g:1)-1|0;j=0;o:{while(1){if((h|0)==(j|0)){h=f+838|0;j=0;break o}i=l+16|0;n=x[i+(j<<2)>>1];j=j+1|0;if((n|0)!=x[i+(j<<2)>>1]){continue}break}dc(e,20);break c}while(1){if((g|0)>(j|0)){t[h+j|0]=w[((l+16|0)+(j<<2)|0)+2|0];j=j+1|0;g=v[f+1592>>2];continue}break}q=f+1088|0;j=2;while(1){if((g|0)>(j|0)){v[l+12>>2]=0;v[l+8>>2]=0;g=0;p=(j|0)>0?j:0;i=b+(j<<1)|0;m=65536;n=-1;while(1){if((g|0)!=(p|0)){o=b+(g<<1)|0;h=x[o>>1];if(!((n|0)>=(h|0)|x[i>>1]<=h>>>0)){v[l+12>>2]=g;h=x[o>>1];n=h}if(!((h|0)>=(m|0)|x[i>>1]>=h>>>0)){v[l+8>>2]=g;m=x[o>>1]}g=g+1|0;continue}break}h=q+(j<<1)|0;t[h|0]=v[l+12>>2];t[h+1|0]=v[l+8>>2];j=j+1|0;g=v[f+1592>>2];continue}break}E=(g|0)>(E|0)?g:E;k=k+1|0;continue l}else{b=nc(e,4);t[j+m|0]=b;b=b&255;g=(b|0)>(g|0)?b:g;j=j+1|0;b=w[f|0];continue}}}dc(e,3);break c}b=nc(e,6)+1|0;v[e+264>>2]=b;b=fe(e,B(b,24));v[e+396>>2]=b;if(!b){dc(e,3);break c}k=0;Tb(b,0,B(v[e+264>>2],24));p:{q:{r:{while(1){if(v[e+264>>2]>(k|0)){b=v[e+396>>2];h=nc(e,16);u[((k<<1)+e|0)+268>>1]=h;if((h&65535)>>>0>=3){dc(e,20);break c}g=b+B(k,24)|0;M=g,N=nc(e,24),v[M>>2]=N;b=nc(e,24);v[g+4>>2]=b;if(b>>>0<y[g>>2]){dc(e,20);break c}M=g,N=nc(e,24)+1|0,v[M+8>>2]=N;M=g,N=nc(e,6)+1|0,t[M+12|0]=N;b=nc(e,8);t[g+13|0]=b;if(v[e+120>>2]<=(b&255)){break r}f=0;while(1){b=w[g+12|0];if(b>>>0>f>>>0){h=(l+16|0)+f|0;b=nc(e,3);if(nc(e,1)){i=nc(e,5)}else{i=0}t[h|0]=b+(i<<3);f=f+1|0;continue}break}b=fe(e,b<<4);v[g+20>>2]=b;if(!b){break q}h=0;while(1){if(w[g+12|0]>h>>>0){b=w[(l+16|0)+h|0];f=0;while(1){if((f|0)!=8){s:{if(b>>>f&1){j=nc(e,8);m=f<<1;i=h<<4;u[m+(i+v[g+20>>2]|0)>>1]=j;if(v[e+120>>2]>u[m+(i+v[g+20>>2]|0)>>1]){break s}dc(e,20);break c}u[(v[g+20>>2]+(h<<4)|0)+(f<<1)>>1]=65535}f=f+1|0;continue}break}h=h+1|0;continue}break}h=fe(e,v[(v[e+124>>2]+B(w[g+13|0],2096)|0)+4>>2]<<2);v[g+16>>2]=h;if(!h){dc(e,3);break c}b=0;Tb(h,0,v[(v[e+124>>2]+B(w[g+13|0],2096)|0)+4>>2]<<2);while(1){h=v[e+124>>2]+B(w[g+13|0],2096)|0;if(v[h+4>>2]>(b|0)){f=v[h>>2];j=fe(e,f);h=b<<2;v[h+v[g+16>>2]>>2]=j;j=b;if(v[h+v[g+16>>2]>>2]){while(1){if((f|0)>0){f=f-1|0;t[f+v[h+v[g+16>>2]>>2]|0]=(j|0)%w[g+12|0];j=(j|0)/w[g+12|0]|0;continue}break}b=b+1|0;continue}else{dc(e,3);break c}}break}k=k+1|0;continue}break}b=nc(e,6)+1|0;v[e+400>>2]=b;b=fe(e,B(b,40));v[e+404>>2]=b;if(!b){dc(e,3);break c}Tb(b,0,B(v[e+400>>2],40));i=0;while(1){if(v[e+400>>2]>(i|0)){b=v[e+404>>2];if(nc(e,16)){dc(e,20);break c}h=b+B(i,40)|0;b=fe(e,B(v[e+4>>2],3));v[h+4>>2]=b;if(!b){dc(e,3);break c}if(nc(e,1)){b=nc(e,4)+1|0}else{b=1}t[h+8|0]=b;t:{if(nc(e,1)){b=nc(e,8)+1|0;u[h>>1]=b;f=0;g=v[e+4>>2];if((g|0)<(b&65535)){dc(e,20);break c}while(1){if(x[h>>1]<=f>>>0){break t}g=nc(e,im(g-1|0));b=B(f,3);t[b+v[h+4>>2]|0]=g;g=nc(e,im(v[e+4>>2]-1|0));t[(b+v[h+4>>2]|0)+1|0]=g;g=v[e+4>>2];b=b+v[h+4>>2]|0;j=w[b|0];if((g|0)<=(j|0)){dc(e,20);break c}b=w[b+1|0];if((b|0)>=(g|0)){dc(e,20);break c}f=f+1|0;if((b|0)!=(j|0)){continue}break}dc(e,20);break c}u[h>>1]=0}if(nc(e,2)){dc(e,20);break c}g=0;b=0;f=0;u:{if(w[h+8|0]>=2){while(1){if(v[e+4>>2]<=(b|0)){break u}f=nc(e,4);j=B(b,3);t[(j+v[h+4>>2]|0)+2|0]=f;b=b+1|0;if(w[(j+v[h+4>>2]|0)+2|0]<w[h+8|0]){continue}break}dc(e,20);break c}while(1){if(v[e+4>>2]<=(f|0)){break u}t[(v[h+4>>2]+B(f,3)|0)+2|0]=0;f=f+1|0;continue}}v:{while(1){if(w[h+8|0]<=g>>>0){break v}nc(e,8);b=g+h|0;M=b,N=nc(e,8),t[M+9|0]=N;f=nc(e,8);t[b+24|0]=f;if(v[e+128>>2]<=w[b+9|0]){dc(e,20);break c}g=g+1|0;if(v[e+264>>2]>(f&255)){continue}break}dc(e,20);break c}i=i+1|0;continue}break}M=e,N=nc(e,6)+1|0,v[M+408>>2]=N;h=e+412|0;j=0;w:{while(1){if(v[e+408>>2]<=(j|0)){break w}b=h+B(j,6)|0;M=b,N=nc(e,1),t[M|0]=N;M=b,N=nc(e,16),u[M+2>>1]=N;M=b,N=nc(e,16),u[M+4>>1]=N;f=nc(e,8);t[b+1|0]=f;if(x[b+2>>1]){dc(e,20);break c}if(x[b+4>>1]){dc(e,20);break c}j=j+1|0;if(v[e+400>>2]>(f&255)){continue}break}dc(e,20);break c}jI(e);v[e+992>>2]=0;h=E<<1;f=0;while(1){if(v[e+4>>2]>(f|0)){b=(f<<2)+e|0;M=b,N=fe(e,v[e+116>>2]<<2),v[M+800>>2]=N;M=b,N=fe(e,v[e+116>>2]<<1&2147483646),v[M+928>>2]=N;g=fe(e,h);v[b+996>>2]=g;j=v[b+800>>2];if(g?!j|!v[b+928>>2]:1){dc(e,3);break c}Tb(j,0,v[e+116>>2]<<2);f=f+1|0;continue}break}f=0;if(!cI(e,0,v[e+112>>2])){break a}if(!cI(e,1,v[e+116>>2])){break a}v[e+104>>2]=v[e+112>>2];h=v[e+116>>2];v[e+108>>2]=h;b=v[e+264>>2];i=(b|0)>0?b:0;b=(h|0)/2|0;g=0;while(1){if((f|0)!=(i|0)){j=v[e+396>>2]+B(f,24)|0;k=v[j+4>>2];n=b>>>0>k>>>0?k:b;k=v[j>>2];j=(n-(b>>>0>k>>>0?k:b)>>>0)/y[j+8>>2]|0;g=(g|0)<(j|0)?j:g;f=f+1|0;continue}break}b=h<<1&2147483646;h=B(v[e+4>>2],(g<<2)+4|0);b=b>>>0>h>>>0?b:h;v[e+12>>2]=b;x:{if(!v[e+80>>2]){break x}h=v[e+92>>2];if((h|0)!=v[e+84>>2]){break p}if(h>>>0>=(b+v[e+88>>2]|0)+1512>>>0){break x}dc(e,3);break c}y:{if(v[e+1380>>2]==-1){v[e+52>>2]=w[e+48|0]?0:v[e+32>>2]-v[e+36>>2]|0;break y}v[e+52>>2]=0}f=1;break a}dc(e,20);break c}dc(e,3);break c}aa(7304,13110,4196,8789);L()}z:{if(f&255){j=Fn(e,b);break z}j=fe(e,b);v[g+8>>2]=j}if(!j){dc(e,3);break c}i=0;A:{if(!m){f=0;while(1){b=v[k>>2];if((f|0)>=(b|0)){break A}B:{C:{if(w[g+23|0]){if(!nc(e,1)){break C}}b=nc(e,5)+1|0;t[f+j|0]=b;if((b&255)!=32){i=i+1|0;break B}dc(e,20);break c}t[f+j|0]=255}f=f+1|0;continue}}h=nc(e,5);f=0;while(1){b=v[k>>2];if((f|0)>=(b|0)){break A}m=nc(e,im(b-f|0));h=h+1|0;if((h|0)>=32){dc(e,20);break c}b=f+m|0;if((b|0)>v[k>>2]){dc(e,20);break c}else{Tb(f+j|0,h,m);f=b;continue}}}D:{E:{F:{if(w[g+23|0]){if(b>>2>(i|0)){break F}if(v[e+16>>2]<(b|0)){v[e+16>>2]=b;b=v[k>>2]}b=fe(e,b);v[g+8>>2]=b;if(!b){dc(e,3);break c}tc(b,j,v[k>>2]);ej(e,j,v[k>>2]);j=v[g+8>>2];t[g+23|0]=0;b=v[k>>2]}h=0;i=(b|0)>0?b:0;f=0;while(1){if((f|0)!=(i|0)){h=((w[f+j|0]-11&255)>>>0<244)+h|0;f=f+1|0;continue}break}v[g+2092>>2]=h;b=fe(e,b<<2);v[g+32>>2]=b;if(b){m=g+2092|0;f=0;break E}dc(e,3);break c}v[g+2092>>2]=i;m=g+2092|0;G:{if(!i){f=0;h=0;break G}b=fe(e,i);v[g+8>>2]=b;if(!b){dc(e,3);break c}b=Fn(e,v[m>>2]<<2);v[g+32>>2]=b;if(!b){dc(e,3);break c}f=Fn(e,v[m>>2]<<2);if(!f){break D}b=v[k>>2];h=v[m>>2]}b=(h<<3)+b|0;if(b>>>0<=y[e+16>>2]){break E}v[e+16>>2]=b}n=v[k>>2];b=0;h=jb-128|0;jb=h;o=Tb(h,0,128);h=(n|0)>0?n:0;while(1){H:{I:{if((b|0)!=(h|0)){if(w[b+j|0]==255){break I}h=b}if((h|0)==(n|0)){b=1;if(!v[g+2092>>2]){break H}aa(15698,13110,1103,7548);L()}b=h+j|0;i=w[b|0];if(i>>>0<32){aI(g,0,h,0,i,f);q=1;i=w[b|0]+1|0;b=1;J:{while(1){if((b|0)==(i|0)){K:while(1){L:{b=1;h=h+1|0;if((n|0)<=(h|0)){break H}F=h+j|0;i=w[F|0];if((i|0)==255){continue}b=i;if(b>>>0>=32){break L}while(1){if((b|0)<=0){b=0;break H}G=o+(b<<2)|0;p=v[G>>2];if(!p){b=b-1|0;continue}break}v[G>>2]=0;aI(g,gm(p),h,q,i,f);q=q+1|0;i=w[F|0];if((i|0)==(b|0)){continue}while(1){if((b|0)>=(i|0)){continue K}F=o+(i<<2)|0;if(v[F>>2]){break J}v[F>>2]=p+(1<<32-i);i=i-1|0;continue}}break}}else{v[o+(b<<2)>>2]=1<<32-b;b=b+1|0;continue}break}aa(15196,13110,1118,7548);L()}aa(15742,13110,1133,7548);L()}aa(15203,13110,1104,7548);L()}b=b+1|0;continue}break}jb=o+128|0;if(!b){if(w[g+23|0]){ej(e,f,0)}dc(e,20);break c}b=v[m>>2];if(b){b=fe(e,(b<<2)+4|0);v[g+2084>>2]=b;if(!b){dc(e,3);break c}b=fe(e,(v[m>>2]<<2)+4|0);v[g+2088>>2]=b;if(!b){dc(e,3);break c}v[g+2088>>2]=b+4;v[b>>2]=-1;b=0;i=0;M:{N:{O:{if(w[g+23|0]){while(1){i=v[g+2092>>2];if((i|0)<=(b|0)){break O}h=b<<2;M=h+v[g+2084>>2]|0,N=gm(v[h+v[g+32>>2]>>2]),v[M>>2]=N;b=b+1|0;continue}}while(1){if(v[g+4>>2]>(b|0)){if($H(w[g+23|0],w[b+j|0])){M=v[g+2084>>2]+(i<<2)|0,N=gm(v[v[g+32>>2]+(b<<2)>>2]),v[M>>2]=N;i=i+1|0}b=b+1|0;continue}break}if(v[g+2092>>2]!=(i|0)){break N}}dI(v[g+2084>>2],i,1091);v[v[g+2084>>2]+(v[g+2092>>2]<<2)>>2]=-1;h=0;b=v[g+(w[g+23|0]?2092:4)>>2];p=(b|0)>0?b:0;P:{while(1){if((h|0)!=(p|0)){b=h;i=w[g+23|0];b=i?v[(b<<2)+f>>2]:b;F=w[b+j|0];Q:{if(!$H(i,F)){break Q}G=h<<2;n=gm(v[G+v[g+32>>2]>>2]);b=v[g+2092>>2];i=0;while(1){if((b|0)>=2){o=b>>>1|0;J=o+i|0;q=n>>>0<y[v[g+2084>>2]+(J<<2)>>2];b=q?o:b-o|0;i=q?i:J;continue}break}b=i<<2;if((n|0)!=v[b+v[g+2084>>2]>>2]){break P}if(w[g+23|0]){v[b+v[g+2088>>2]>>2]=v[f+G>>2];t[v[g+8>>2]+i|0]=F;break Q}v[b+v[g+2088>>2]>>2]=h}h=h+1|0;continue}break}break M}aa(12151,13110,1230,9932);L()}aa(7489,13110,1200,9932);L()}}if(w[g+23|0]){ej(e,f,v[m>>2]<<2);ej(e,v[g+32>>2],v[m>>2]<<2);ej(e,j,v[k>>2]);v[g+32>>2]=0}i=g;b=0;f=0;while(1){if((b|0)!=1024){u[(i+(b<<1)|0)+36>>1]=65535;b=b+1|0;continue}break}b=v[i+(w[i+23|0]?2092:4)>>2];b=(b|0)<32767?b:32767;h=(b|0)>0?b:0;while(1){if((f|0)!=(h|0)){R:{if(w[v[i+8>>2]+f|0]>10){break R}S:{if(w[i+23|0]){b=gm(v[v[i+2084>>2]+(f<<2)>>2]);break S}b=v[v[i+32>>2]+(f<<2)>>2]}while(1){if(b>>>0>1023){break R}u[(i+(b<<1)|0)+36>>1]=f;b=(1<<w[v[i+8>>2]+f|0])+b|0;continue}}f=f+1|0;continue}break}b=nc(e,4);t[i+21|0]=b;b=b&255;if(b>>>0>=3){dc(e,20);break c}if(b){M=i,O=bI(nc(e,32)),z[M+12>>2]=O;M=i,O=bI(nc(e,32)),z[M+16>>2]=O;M=i,N=nc(e,4)+1|0,t[M+20|0]=N;M=i,N=nc(e,1),t[M+22|0]=N;f=v[i>>2];h=v[k>>2];T:{if(w[i+21|0]==1){A=H(Es(+C(C(zp(+C(h|0)))/C(f|0))));U:{if(D(A)<2147483648){b=~~A;break U}b=-2147483648}A=+(f|0);K=H(ak(+C(C(b|0)+C(1)),A));V:{if(D(K)<2147483648){f=~~K;break V}f=-2147483648}b=((f|0)<=(h|0))+b|0;s=C(b|0);if(ak(+C(s+C(1)),A)<=+(h|0)){f=-1}else{A=H(ak(+s,A));W:{if(D(A)<2147483648){f=~~A;break W}f=-2147483648}f=(f|0)>(h|0)?-1:b}if((f|0)>=0){break T}dc(e,20);break c}f=B(f,h)}v[i+24>>2]=f;if(!f){dc(e,20);break c}n=Fn(e,f<<1);if(!n){break h}f=0;while(1){j=v[i+24>>2];if((j|0)>(f|0)){b=nc(e,w[i+20|0]);if((b|0)==-1){ej(e,n,v[i+24>>2]<<1);dc(e,20);break c}else{u[n+(f<<1)>>1]=b;f=f+1|0;continue}}break}X:{Y:{if(w[i+21|0]==1){o=w[i+23|0];Z:{if(o){f=v[m>>2];if(f){break Z}break X}f=v[k>>2]}b=fe(e,B(v[i>>2],f)<<2);v[i+28>>2]=b;if(!b){ej(e,n,v[i+24>>2]<<1);dc(e,3);break c}h=0;b=v[(o?m:k)>>2];m=(b|0)>0?b:0;q=i+2088|0;s=C(0);while(1){if((h|0)==(m|0)){break Y}g=h;g=o?v[v[q>>2]+(g<<2)>>2]:g;j=v[i>>2];f=0;b=1;while(1){if((f|0)<(j|0)){I=C(s+C(C(C(x[n+(((g>>>0)/(b>>>0)>>>0)%y[i+24>>2]<<1)>>1])*z[i+16>>2])+z[i+12>>2]));z[v[i+28>>2]+(B(h,j)+f<<2)>>2]=I;s=w[i+22|0]?I:s;f=f+1|0;j=v[i>>2];if((f|0)>=(j|0)){continue}k=v[i+24>>2];Lka(k,0,b,0);if(mb){ej(e,n,k<<1);dc(e,20);break c}else{b=B(b,k);continue}}break}h=h+1|0;continue}}b=fe(e,j<<2);v[i+28>>2]=b;if(!b){break g}f=0;s=C(0);while(1){j=v[i+24>>2];if((j|0)<=(f|0)){break X}I=C(s+C(C(C(x[n+(f<<1)>>1])*z[i+16>>2])+z[i+12>>2]));z[v[i+28>>2]+(f<<2)>>2]=I;s=w[i+22|0]?I:s;f=f+1|0;continue}}t[i+21|0]=2;j=v[i+24>>2]}ej(e,n,j<<1)}E=E+1|0;continue}break}dc(e,3);break c}dc(e,3);break c}ej(e,n,v[i+24>>2]<<1);dc(e,3);break c}dc(e,20);break c}dc(e,3);break c}t[b+v[v[e+28>>2]+(h<<2)>>2]|0]=0;h=h+1|0;continue}}dc(e,3);break c}dc(e,20)}f=0}jb=l+1024|0;_:{$:{if(!f){v[d>>2]=v[r+104>>2]?1:v[r+108>>2];break $}b=fe(r+8|0,1512);if(b){M=c,N=v[tc(b,r+8|0,1512)+32>>2]-a|0,v[M>>2]=N;v[d>>2]=0;break _}}nI(r+8|0);b=0}jb=r+1520|0;return b}function TG(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,u=0,x=0,z=0,A=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,O=0;s=jb-48|0;jb=s;a:{if(c>>>0<=2){c=c<<2;I=v[c+79532>>2];J=v[c+79520>>2];while(1){c=v[b+4>>2];b:{if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break b}c=rd(b)}if(Vk(c)){continue}break}o=1;c:{d:{switch(c-43|0){case 0:case 2:break d;default:break c}}o=(c|0)==45?-1:1;c=v[b+4>>2];if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break c}c=rd(b)}e:{f:{while(1){if(t[g+4955|0]==(c|32)){g:{if(g>>>0>6){break g}c=v[b+4>>2];if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break g}c=rd(b)}g=g+1|0;if((g|0)!=8){continue}break f}break}if((g|0)!=3){if((g|0)==8){break f}if(!d|g>>>0<4){break e}if((g|0)==8){break f}}c=v[b+116>>2];if((c|0)>0|(c|0)>=0){v[b+4>>2]=v[b+4>>2]-1}if(!d|g>>>0<4){break f}c=(c|0)<0;while(1){if(!c){v[b+4>>2]=v[b+4>>2]-1}g=g-1|0;if(g>>>0>3){continue}break}}i=jb-16|0;jb=i;l=(p(C(C(o|0)*C(N))),j(2));b=l&2147483647;h:{if(b-8388608>>>0<=2130706431){r=b<<25;c=(b>>>7|0)+1065353216|0;break h}r=l<<25;c=l>>>7|2147418112;if(b>>>0>=2139095040){break h}r=0;c=0;if(!b){break h}c=b;b=E(b);Kf(i,c,0,0,0,b+81|0);k=v[i>>2];h=v[i+4>>2];r=v[i+8>>2];c=v[i+12>>2]^65536|16265-b<<16}v[s>>2]=k;v[s+4>>2]=h;v[s+8>>2]=r;v[s+12>>2]=l&-2147483648|c;jb=i+16|0;k=v[s+8>>2];h=v[s+12>>2];i=v[s>>2];l=v[s+4>>2];break a}i:{j:{k:{if(g){break k}g=0;while(1){if(t[g+9928|0]!=(c|32)){break k}l:{if(g>>>0>1){break l}c=v[b+4>>2];if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break l}c=rd(b)}g=g+1|0;if((g|0)!=3){continue}break}break j}m:{switch(g|0){case 0:n:{if((c|0)!=48){break n}g=v[b+4>>2];o:{if((g|0)!=v[b+104>>2]){v[b+4>>2]=g+1;g=w[g|0];break o}g=rd(b)}if((g&-33)==88){g=d;c=0;f=jb-432|0;jb=f;p:{q:{d=v[b+4>>2];if((d|0)!=v[b+104>>2]){v[b+4>>2]=d+1;c=w[d|0];break q}d=0;break p}d=1}while(1){r:{s:{t:{u:{v:{w:{x:{y:{if(!d){c=rd(b);break y}if((c|0)!=48){l=1073676288;if((c|0)==46){break w}break v}d=v[b+4>>2];if((d|0)==v[b+104>>2]){break x}n=1;v[b+4>>2]=d+1;c=w[d|0]}d=1;continue}n=1;break s}c=v[b+4>>2];z:{if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break z}c=rd(b)}if((c|0)==48){break u}F=1}break t}while(1){c=r;r=c-1|0;u=u-!c|0;F=1;c=v[b+4>>2];A:{if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break A}c=rd(b)}if((c|0)==48){continue}break}n=1}while(1){e=c|32;B:{C:{M=c-48|0;if(M>>>0<10){break C}if(!((c|0)==46|e-97>>>0<6)){d=c;break r}d=46;if((c|0)!=46){break C}if(F){break r}F=1;r=k;u=h;break B}c=(c|0)>57?e-87|0:M;D:{if((h|0)<=0&k>>>0<=7|(h|0)<0){x=c+(x<<4)|0;break D}if(!h&k>>>0<=28){ah(f+48|0,c);Id(f+32|0,G,H,i,l,0,0,0,1073414144);G=v[f+32>>2];H=v[f+36>>2];i=v[f+40>>2];l=v[f+44>>2];Id(f+16|0,v[f+48>>2],v[f+52>>2],v[f+56>>2],v[f+60>>2],G,H,i,l);Fg(f,v[f+16>>2],v[f+20>>2],v[f+24>>2],v[f+28>>2],m,q,A,D);A=v[f+8>>2];D=v[f+12>>2];m=v[f>>2];q=v[f+4>>2];break D}if(!c|z){break D}Id(f+80|0,G,H,i,l,0,0,0,1073610752);Fg(f- -64|0,v[f+80>>2],v[f+84>>2],v[f+88>>2],v[f+92>>2],m,q,A,D);A=v[f+72>>2];D=v[f+76>>2];z=1;m=v[f+64>>2];q=v[f+68>>2]}c=k+1|0;h=c?h:h+1|0;k=c;n=1}c=v[b+4>>2];if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0]}else{c=rd(b)}continue}}d=0;continue}break}E:{if(!n){c=v[b+116>>2];F:{G:{if((c|0)>0|(c|0)>=0){c=v[b+4>>2];v[b+4>>2]=c-1;if(!g){break G}v[b+4>>2]=c-2;if(!F){break F}v[b+4>>2]=c-3;break F}if(g){break F}}ki(b,0,0)}Ui(f+96|0,+(o|0)*0);m=v[f+96>>2];q=v[f+100>>2];c=v[f+108>>2];b=v[f+104>>2];break E}if((h|0)<=0&k>>>0<=7|(h|0)<0){i=k;l=h;while(1){x=x<<4;c=i+1|0;l=c?l:l+1|0;i=c;if((c|0)!=8|l){continue}break}}H:{I:{J:{if((d&-33)==80){i=SG(b,g);c=mb;l=c;if(i|(c|0)!=-2147483648){break H}if(g){c=v[b+116>>2];if((c|0)>0|(c|0)>=0){break J}break I}m=0;q=0;ki(b,0,0);c=0;b=0;break E}i=0;l=0;if(v[b+116>>2]<0){break H}}v[b+4>>2]=v[b+4>>2]-1}i=0;l=0}if(!x){Ui(f+112|0,+(o|0)*0);m=v[f+112>>2];q=v[f+116>>2];c=v[f+124>>2];b=v[f+120>>2];break E}b=F?r:k;h=(F?u:h)<<2|b>>>30;b=i+(b<<2)|0;d=h+l|0;d=b>>>0<i>>>0?d+1|0:d;k=b-32|0;h=d-(b>>>0<32)|0;b=h;if(k>>>0>0-I>>>0&(b|0)>=0|(b|0)>0){v[116064]=68;ah(f+160|0,o);Id(f+144|0,v[f+160>>2],v[f+164>>2],v[f+168>>2],v[f+172>>2],-1,-1,-1,2147418111);Id(f+128|0,v[f+144>>2],v[f+148>>2],v[f+152>>2],v[f+156>>2],-1,-1,-1,2147418111);m=v[f+128>>2];q=v[f+132>>2];c=v[f+140>>2];b=v[f+136>>2];break E}b=I-226|0;c=b>>31;if((h|0)>=(c|0)&b>>>0<=k>>>0|(c|0)<(h|0)){if((x|0)>=0){while(1){Fg(f+416|0,m,q,A,D,0,0,0,-1073807360);c=US(m,q,A,D,1073610752);b=(c|0)<0;Fg(f+400|0,m,q,A,D,b?m:v[f+416>>2],b?q:v[f+420>>2],b?A:v[f+424>>2],b?D:v[f+428>>2]);b=k;k=b-1|0;h=h-!b|0;A=v[f+408>>2];D=v[f+412>>2];m=v[f+400>>2];q=v[f+404>>2];x=x<<1|(c|0)>=0;if((x|0)>=0){continue}break}}d=h-((I>>31)+(k>>>0<I>>>0)|0)|0;b=(k-I|0)+32|0;d=b>>>0<32?d+1|0:d;c=b>>>0<J>>>0&(d|0)<=0|(d|0)<0?(b|0)>0?b:0:J;K:{if((c|0)>=113){ah(f+384|0,o);r=v[f+392>>2];u=v[f+396>>2];G=v[f+384>>2];H=v[f+388>>2];h=0;b=0;break K}Ui(f+352|0,Uj(1,144-c|0));ah(f+336|0,o);G=v[f+336>>2];H=v[f+340>>2];r=v[f+344>>2];u=v[f+348>>2];VG(f+368|0,v[f+352>>2],v[f+356>>2],v[f+360>>2],v[f+364>>2],G,H,r,u);K=v[f+376>>2];L=v[f+380>>2];h=v[f+372>>2];b=v[f+368>>2]}c=!(x&1)&((Gm(m,q,A,D,0,0,0,0)|0)!=0&(c|0)<32);on(f+320|0,c+x|0);Id(f+304|0,G,H,r,u,v[f+320>>2],v[f+324>>2],v[f+328>>2],v[f+332>>2]);d=b;Fg(f+272|0,v[f+304>>2],v[f+308>>2],v[f+312>>2],v[f+316>>2],b,h,K,L);b=c;Id(f+288|0,G,H,r,u,b?0:m,b?0:q,b?0:A,b?0:D);Fg(f+256|0,v[f+288>>2],v[f+292>>2],v[f+296>>2],v[f+300>>2],v[f+272>>2],v[f+276>>2],v[f+280>>2],v[f+284>>2]);Lx(f+240|0,v[f+256>>2],v[f+260>>2],v[f+264>>2],v[f+268>>2],d,h,K,L);b=v[f+240>>2];c=v[f+244>>2];d=v[f+248>>2];h=v[f+252>>2];if(!Gm(b,c,d,h,0,0,0,0)){v[116064]=68}UG(f+224|0,b,c,d,h,k);m=v[f+224>>2];q=v[f+228>>2];c=v[f+236>>2];b=v[f+232>>2];break E}v[116064]=68;ah(f+208|0,o);Id(f+192|0,v[f+208>>2],v[f+212>>2],v[f+216>>2],v[f+220>>2],0,0,0,65536);Id(f+176|0,v[f+192>>2],v[f+196>>2],v[f+200>>2],v[f+204>>2],0,0,0,65536);m=v[f+176>>2];q=v[f+180>>2];c=v[f+188>>2];b=v[f+184>>2]}v[s+16>>2]=m;v[s+20>>2]=q;v[s+24>>2]=b;v[s+28>>2]=c;jb=f+432|0;k=v[s+24>>2];h=v[s+28>>2];i=v[s+16>>2];l=v[s+20>>2];break a}if(v[b+116>>2]<0){break n}v[b+4>>2]=v[b+4>>2]-1}g=b;f=o;x=d;d=0;o=0;e=jb-8976|0;jb=e;K=I+J|0;L=0-K|0;L:{M:{while(1){if((c|0)!=48){N:{if((c|0)!=46){break L}b=v[g+4>>2];if((b|0)==v[g+104>>2]){break N}v[g+4>>2]=b+1;c=w[b|0];break M}}else{b=v[g+4>>2];if((b|0)!=v[g+104>>2]){d=1;v[g+4>>2]=b+1;c=w[b|0]}else{d=1;c=rd(g)}continue}break}c=rd(g)}n=1;if((c|0)!=48){break L}while(1){b=k;k=b-1|0;h=h-!b|0;b=v[g+4>>2];O:{if((b|0)!=v[g+104>>2]){v[g+4>>2]=b+1;c=w[b|0];break O}c=rd(g)}if((c|0)==48){continue}break}d=1}v[e+784>>2]=0;P:{Q:{b=(c|0)==46;m=c-48|0;R:{S:{T:{U:{if(b|m>>>0<=9){while(1){V:{if(b&1){if(!n){k=i;h=l;n=1;break V}b=!d;break U}b=i+1|0;l=b?l:l+1|0;i=b;if((o|0)<=2044){F=(c|0)==48?F:i;b=(e+784|0)+(o<<2)|0;if(z){m=(B(v[b>>2],10)+c|0)-48|0}v[b>>2]=m;d=1;c=z+1|0;b=(c|0)==9;z=b?0:c;o=b+o|0;break V}if((c|0)==48){break V}v[e+8960>>2]=v[e+8960>>2]|1;F=18396}b=v[g+4>>2];W:{if((b|0)!=v[g+104>>2]){v[g+4>>2]=b+1;c=w[b|0];break W}c=rd(g)}b=(c|0)==46;m=c-48|0;if(b|m>>>0<10){continue}break}}k=n?k:i;h=n?h:l;if(!(!d|(c&-33)!=69)){m=SG(g,x);b=mb;q=b;X:{if(m|(b|0)!=-2147483648){break X}if(!x){break R}m=0;q=0;if(v[g+116>>2]<0){break X}v[g+4>>2]=v[g+4>>2]-1}if(!d){break S}h=h+q|0;b=k+m|0;h=b>>>0<m>>>0?h+1|0:h;k=b;break Q}b=!d;if((c|0)<0){break T}}if(v[g+116>>2]<0){break T}v[g+4>>2]=v[g+4>>2]-1}if(!b){break Q}}v[116064]=28}i=0;l=0;ki(g,0,0);c=0;b=0;break P}b=v[e+784>>2];if(!b){Ui(e,+(f|0)*0);i=v[e>>2];l=v[e+4>>2];c=v[e+12>>2];b=v[e+8>>2];break P}if(!((k|0)!=(i|0)|(h|0)!=(l|0)|(i>>>0>9&(l|0)>=0|(l|0)>0)|(b>>>J|0?(J|0)<=30:0))){ah(e+48|0,f);on(e+32|0,b);Id(e+16|0,v[e+48>>2],v[e+52>>2],v[e+56>>2],v[e+60>>2],v[e+32>>2],v[e+36>>2],v[e+40>>2],v[e+44>>2]);i=v[e+16>>2];l=v[e+20>>2];c=v[e+28>>2];b=v[e+24>>2];break P}if(k>>>0>(I|0)/-2>>>0&(h|0)>=0|(h|0)>0){v[116064]=68;ah(e+96|0,f);Id(e+80|0,v[e+96>>2],v[e+100>>2],v[e+104>>2],v[e+108>>2],-1,-1,-1,2147418111);Id(e- -64|0,v[e+80>>2],v[e+84>>2],v[e+88>>2],v[e+92>>2],-1,-1,-1,2147418111);i=v[e+64>>2];l=v[e+68>>2];c=v[e+76>>2];b=v[e+72>>2];break P}b=I-226|0;c=k>>>0<b>>>0;b=b>>31;if(c&(h|0)<=(b|0)|(b|0)>(h|0)){v[116064]=68;ah(e+144|0,f);Id(e+128|0,v[e+144>>2],v[e+148>>2],v[e+152>>2],v[e+156>>2],0,0,0,65536);Id(e+112|0,v[e+128>>2],v[e+132>>2],v[e+136>>2],v[e+140>>2],0,0,0,65536);i=v[e+112>>2];l=v[e+116>>2];c=v[e+124>>2];b=v[e+120>>2];break P}if(z){if((z|0)<=8){b=(e+784|0)+(o<<2)|0;g=v[b>>2];while(1){g=B(g,10);z=z+1|0;if((z|0)!=9){continue}break}v[b>>2]=g}o=o+1|0}Y:{n=k;if((F|0)>(k|0)|(F|0)>8|(k|0)>17){break Y}if((n|0)==9){ah(e+192|0,f);on(e+176|0,v[e+784>>2]);Id(e+160|0,v[e+192>>2],v[e+196>>2],v[e+200>>2],v[e+204>>2],v[e+176>>2],v[e+180>>2],v[e+184>>2],v[e+188>>2]);i=v[e+160>>2];l=v[e+164>>2];c=v[e+172>>2];b=v[e+168>>2];break P}if((n|0)<=8){ah(e+272|0,f);on(e+256|0,v[e+784>>2]);Id(e+240|0,v[e+272>>2],v[e+276>>2],v[e+280>>2],v[e+284>>2],v[e+256>>2],v[e+260>>2],v[e+264>>2],v[e+268>>2]);ah(e+224|0,v[(0-n<<2)+79520>>2]);GP(e+208|0,v[e+240>>2],v[e+244>>2],v[e+248>>2],v[e+252>>2],v[e+224>>2],v[e+228>>2],v[e+232>>2],v[e+236>>2]);i=v[e+208>>2];l=v[e+212>>2];c=v[e+220>>2];b=v[e+216>>2];break P}b=(J+B(n,-3)|0)+27|0;c=v[e+784>>2];if(c>>>b|0?(b|0)<=30:0){break Y}ah(e+352|0,f);on(e+336|0,c);Id(e+320|0,v[e+352>>2],v[e+356>>2],v[e+360>>2],v[e+364>>2],v[e+336>>2],v[e+340>>2],v[e+344>>2],v[e+348>>2]);ah(e+304|0,v[(n<<2)+79448>>2]);Id(e+288|0,v[e+320>>2],v[e+324>>2],v[e+328>>2],v[e+332>>2],v[e+304>>2],v[e+308>>2],v[e+312>>2],v[e+316>>2]);i=v[e+288>>2];l=v[e+292>>2];c=v[e+300>>2];b=v[e+296>>2];break P}while(1){c=o;o=c-1|0;if(!v[(e+784|0)+(o<<2)>>2]){continue}break}b=(n|0)%9|0;Z:{if(!b){z=0;b=0;break Z}z=0;d=(n|0)<0?b+9|0:b;_:{if(!c){b=0;c=0;break _}k=v[(0-d<<2)+79520>>2];l=1e9/(k|0)|0;m=0;g=0;b=0;while(1){h=m;i=(e+784|0)+(g<<2)|0;o=v[i>>2];m=(o>>>0)/(k>>>0)|0;h=h+m|0;v[i>>2]=h;h=!h&(b|0)==(g|0);b=h?b+1&2047:b;n=h?n-9|0:n;m=B(l,o-B(k,m)|0);g=g+1|0;if((g|0)!=(c|0)){continue}break}if(!m){break _}v[(e+784|0)+(c<<2)>>2]=m;c=c+1|0}n=(n-d|0)+9|0}while(1){o=(e+784|0)+(b<<2)|0;g=(n|0)<36;$:{while(1){aa:{if(g){break aa}if((n|0)!=36){break $}if(y[o>>2]<=10384592){break aa}n=36;break $}d=c+2047|0;m=0;while(1){i=d&2047;x=(e+784|0)+(i<<2)|0;d=v[x>>2];l=d>>>3|0;h=d<<29;k=h+m|0;d=l;d=h>>>0>k>>>0?d+1|0:d;h=d;if(!h&k>>>0<1000000001){m=0}else{m=Oka(k,h,1e9,0);d=Lka(m,mb,-1e9,-1)+k|0;k=d}v[x>>2]=k;c=(i|0)!=(c-1&2047)?c:(b|0)==(i|0)?c:k?c:i;d=i-1|0;if((b|0)!=(i|0)){continue}break}z=z-29|0;if(!m){continue}break}b=b-1&2047;if((c|0)==(b|0)){d=e+784|0;k=d+((c+2046&2047)<<2)|0;c=c-1&2047;v[k>>2]=v[k>>2]|v[d+(c<<2)>>2]}n=n+9|0;v[(e+784|0)+(b<<2)>>2]=m;continue}break}ba:{ca:while(1){k=c+1&2047;l=(e+784|0)+((c-1&2047)<<2)|0;while(1){h=(n|0)>45?9:1;da:{while(1){d=b;g=0;ea:{while(1){fa:{b=d+g&2047;if((b|0)==(c|0)){break fa}b=v[(e+784|0)+(b<<2)>>2];i=v[(g<<2)+79472>>2];if(b>>>0<i>>>0){break fa}if(b>>>0>i>>>0){break ea}g=g+1|0;if((g|0)!=4){continue}}break}if((n|0)!=36){break ea}k=0;h=0;g=0;i=0;l=0;while(1){b=d+g&2047;if((b|0)==(c|0)){c=c+1&2047;v[((c<<2)+e|0)+780>>2]=0}on(e+768|0,v[(e+784|0)+(b<<2)>>2]);Id(e+752|0,k,h,i,l,0,0,1342177280,1075633366);Fg(e+736|0,v[e+752>>2],v[e+756>>2],v[e+760>>2],v[e+764>>2],v[e+768>>2],v[e+772>>2],v[e+776>>2],v[e+780>>2]);i=v[e+744>>2];l=v[e+748>>2];k=v[e+736>>2];h=v[e+740>>2];g=g+1|0;if((g|0)!=4){continue}break}ah(e+720|0,f);Id(e+704|0,k,h,i,l,v[e+720>>2],v[e+724>>2],v[e+728>>2],v[e+732>>2]);i=v[e+712>>2];l=v[e+716>>2];k=0;h=0;m=v[e+704>>2];q=v[e+708>>2];x=z+113|0;o=x-I|0;n=(o|0)<(J|0);b=n?(o|0)>0?o:0:J;if((b|0)<=112){break da}break ba}z=h+z|0;b=c;if((d|0)==(b|0)){continue}break}o=1e9>>>h|0;m=-1<<h^-1;g=0;b=d;while(1){i=g;g=(e+784|0)+(d<<2)|0;x=v[g>>2];i=i+(x>>>h|0)|0;v[g>>2]=i;i=!i&(b|0)==(d|0);b=i?b+1&2047:b;n=i?n-9|0:n;g=B(o,m&x);d=d+1&2047;if((d|0)!=(c|0)){continue}break}if(!g){continue}if((b|0)!=(k|0)){v[(e+784|0)+(c<<2)>>2]=g;c=k;continue ca}v[l>>2]=v[l>>2]|1;continue}break}break}Ui(e+656|0,Uj(1,225-b|0));VG(e+688|0,v[e+656>>2],v[e+660>>2],v[e+664>>2],v[e+668>>2],m,q,i,l);G=v[e+696>>2];H=v[e+700>>2];A=v[e+688>>2];D=v[e+692>>2];Ui(e+640|0,Uj(1,113-b|0));uP(e+672|0,m,q,i,l,v[e+640>>2],v[e+644>>2],v[e+648>>2],v[e+652>>2]);k=v[e+672>>2];h=v[e+676>>2];r=v[e+680>>2];u=v[e+684>>2];Lx(e+624|0,m,q,i,l,k,h,r,u);Fg(e+608|0,A,D,G,H,v[e+624>>2],v[e+628>>2],v[e+632>>2],v[e+636>>2]);i=v[e+616>>2];l=v[e+620>>2];m=v[e+608>>2];q=v[e+612>>2]}g=d+4&2047;ga:{if((g|0)==(c|0)){break ga}g=v[(e+784|0)+(g<<2)>>2];ha:{if(g>>>0<=499999999){if(!g&(d+5&2047)==(c|0)){break ha}Ui(e+496|0,+(f|0)*.25);Fg(e+480|0,k,h,r,u,v[e+496>>2],v[e+500>>2],v[e+504>>2],v[e+508>>2]);r=v[e+488>>2];u=v[e+492>>2];k=v[e+480>>2];h=v[e+484>>2];break ha}if((g|0)!=5e8){Ui(e+592|0,+(f|0)*.75);Fg(e+576|0,k,h,r,u,v[e+592>>2],v[e+596>>2],v[e+600>>2],v[e+604>>2]);r=v[e+584>>2];u=v[e+588>>2];k=v[e+576>>2];h=v[e+580>>2];break ha}O=+(f|0);if((d+5&2047)==(c|0)){Ui(e+528|0,O*.5);Fg(e+512|0,k,h,r,u,v[e+528>>2],v[e+532>>2],v[e+536>>2],v[e+540>>2]);r=v[e+520>>2];u=v[e+524>>2];k=v[e+512>>2];h=v[e+516>>2];break ha}Ui(e+560|0,O*.75);Fg(e+544|0,k,h,r,u,v[e+560>>2],v[e+564>>2],v[e+568>>2],v[e+572>>2]);r=v[e+552>>2];u=v[e+556>>2];k=v[e+544>>2];h=v[e+548>>2]}if((b|0)>111){break ga}uP(e+464|0,k,h,r,u,0,0,0,1073676288);if(Gm(v[e+464>>2],v[e+468>>2],v[e+472>>2],v[e+476>>2],0,0,0,0)){break ga}Fg(e+448|0,k,h,r,u,0,0,0,1073676288);r=v[e+456>>2];u=v[e+460>>2];k=v[e+448>>2];h=v[e+452>>2]}Fg(e+432|0,m,q,i,l,k,h,r,u);Lx(e+416|0,v[e+432>>2],v[e+436>>2],v[e+440>>2],v[e+444>>2],A,D,G,H);i=v[e+424>>2];l=v[e+428>>2];m=v[e+416>>2];q=v[e+420>>2];ia:{if((-2-K|0)>=(x&2147483647)){break ia}v[e+408>>2]=i;v[e+412>>2]=l&2147483647;v[e+400>>2]=m;v[e+404>>2]=q;Id(e+384|0,m,q,i,l,0,0,0,1073610752);d=US(v[e+400>>2],v[e+404>>2],v[e+408>>2],v[e+412>>2],1081081856);c=(d|0)<0;i=c?i:v[e+392>>2];l=c?l:v[e+396>>2];m=c?m:v[e+384>>2];q=c?q:v[e+388>>2];z=((d|0)>=0)+z|0;if((Gm(k,h,r,u,0,0,0,0)|0)!=0&(c?n:n&(b|0)!=(o|0))?0:(L|0)>=(z+110|0)){break ia}v[116064]=68}UG(e+368|0,m,q,i,l,z);i=v[e+368>>2];l=v[e+372>>2];c=v[e+380>>2];b=v[e+376>>2]}v[s+40>>2]=b;v[s+44>>2]=c;v[s+32>>2]=i;v[s+36>>2]=l;jb=e+8976|0;k=v[s+40>>2];h=v[s+44>>2];i=v[s+32>>2];l=v[s+36>>2];break a;case 3:break j;default:break m}}c=v[b+116>>2];if((c|0)>0|(c|0)>=0){v[b+4>>2]=v[b+4>>2]-1}break i}ja:{c=v[b+4>>2];ka:{if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break ka}c=rd(b)}if((c|0)==40){g=1;break ja}h=2147450880;if(v[b+116>>2]<0){break a}v[b+4>>2]=v[b+4>>2]-1;break a}while(1){c=v[b+4>>2];la:{if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break la}c=rd(b)}if(!(!(c-48>>>0<10|c-65>>>0<26|(c|0)==95)&c-97>>>0>=26)){g=g+1|0;continue}break}h=2147450880;if((c|0)==41){break a}c=v[b+116>>2];if((c|0)>0|(c|0)>=0){v[b+4>>2]=v[b+4>>2]-1}ma:{if(d){if(g){break ma}break a}break i}while(1){g=g-1|0;if((c|0)>0|(c|0)>=0){v[b+4>>2]=v[b+4>>2]-1}if(g){continue}break}break a}v[116064]=28;ki(b,0,0)}h=0}v[a>>2]=i;v[a+4>>2]=l;v[a+8>>2]=k;v[a+12>>2]=h;jb=s+48|0}function Ofa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0;d=jb-384|0;jb=d;yc(b);a:{if(!uo(b,d+368|0)){break a}if(!uR(d+368|0)){break a}q=je(d+344|0,b);o=Sb(d+328|0);b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{if(!c){v[23588]=0;R(637,d+40|0,q|0);b=v[23588];v[23588]=0;if((b|0)==1){break z}break B}v[23588]=0;R(638,d+40|0,q|0);b=v[23588];v[23588]=0;if((b|0)==1){break A}}b=d+40|0;Tt(o,b);Yd(b);v[23588]=0;U(639,b|0,o|0,1413891155);b=v[23588];v[23588]=0;C:{D:{if((b|0)!=1){v[23588]=0;e=Q(640,d+40|0,14081)|0;b=v[23588];v[23588]=0;if((b|0)==1){break D}Ab(d+40|0);if(!c){break b}if(!(e^1)){break C}break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;Ab(d+40|0);break c}v[23588]=0;R(246,a|0,4194304);b=v[23588];v[23588]=0;if((b|0)==1){break d}v[a+480208>>2]=12;v[23588]=0;U(639,d+304|0,o|0,1280592212);b=v[23588];v[23588]=0;if((b|0)==1){break e}v[23588]=0;b=S(160,v[d+304>>2])|0;e=v[23588];v[23588]=0;if((e|0)==1){break g}v[23588]=0;U(444,d+304|0,a+1298308|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break g}i=a+484360|0;j=a+484376|0;Kc(Vb(v[i>>2],w[j|0]));k=Sb(d+288|0);t[d+287|0]=0;v[23588]=0;U(641,d+272|0,o|0,1196314451);b=v[23588];v[23588]=0;if((b|0)==1){break i}A=d,C=Eb(v[d+272>>2]),v[A+264>>2]=C;p=d+252|0;r=Eb(v[d+276>>2]);E:{F:{while(1){b=v[d+264>>2];if(!Ob(b,r)){break F}l=je(d+40|0,b);v[23588]=0;e=Q(642,l|0,d+24|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break E}b=1;if(!(!e|w[d+33|0]!=1)){A=a,C=Cd(w[d+34|0],x[a+480188>>1],127),u[A+480188>>1]=C;v[23588]=0;h=S(643,d+208|0)|0;b=v[23588];v[23588]=0;G:{H:{I:{J:{K:{if((b|0)!=1){b=d+192|0;pf(b,d+24|0,9,1);v[23588]=0;R(222,d+160|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break K}b=d+8|0;gc(b,p,10);e=b;b=d+160|0;Ml(e,b);yb(b);b=Vb(v[a+484360>>2],w[j|0]);if(oc(v[b>>2],v[b+4>>2])){break H}v[23588]=0;b=S(272,i|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break J}if((b|0)!=255){break I}b=2;break G}b=P()|0;O()|0;break k}b=P()|0;O()|0;break l}b=P()|0;O()|0;break l}b=Vb(v[a+484360>>2],w[j|0])}v[23588]=0;U(5,d+160|0,5,p|0);e=v[23588];v[23588]=0;if((e|0)==1){break n}v[23588]=0;R(273,b|0,d+160|0);b=v[23588];v[23588]=0;if((b|0)==1){break o}zb(d+160|0);v[23588]=0;R(638,d+192|0,l|0);b=v[23588];v[23588]=0;if((b|0)==1){break p}A=d,C=Eb(v[d+192>>2]),v[A+184>>2]=C;n=Eb(v[d+196>>2]);L:{M:{while(1){b=v[d+184>>2];if(!Ob(b,n)){b=0;if(x[d+244>>1]==65535|x[d+246>>1]==65535){break L}b=w[j|0];e=v[a+484360>>2];v[23588]=0;Y(644,Vb(e,b)|0);b=v[23588];v[23588]=0;if((b|0)!=1){v[23588]=0;R(645,k|0,h|0);e=v[23588];v[23588]=0;b=0;if((e|0)!=1){break L}}b=P()|0;O()|0;break m}zo(d+160|0,b);Yh(d+8|0,v[b>>2],v[b+4>>2]);e=1;N:{g=v[d+8>>2];O:{if((g|0)!=1212960847){b=0;if((g|0)!=1312903248){break O}while(1){if(x[a+480188>>1]<=b>>>0){break O}v[23588]=0;g=W(156,v[d+160>>2],v[d+168>>2],2)|0;f=v[23588];v[23588]=0;if((f|0)!=1){if(!g){break O}v[23588]=0;R(260,d+136|0,d+160|0);g=v[23588];v[23588]=0;P:{Q:{R:{S:{if((g|0)!=1){switch(w[d+136|0]){case 4:break Q;case 2:break R;case 0:break S;default:break P}}break q}g=Nc(d+136|0);A=Kb(v[h>>2],b),C=w[g|0]^128,t[A|0]=C;g=d+144|0;Cb(g,v[d+232>>2],b);Ye(g,0);break P}A=Kb(v[h>>2],b),C=128,t[A|0]=C;g=d+144|0;Cb(g,v[d+232>>2],b);Ye(g,1);break P}A=Kb(v[h>>2],b),C=128,t[A|0]=C;g=d+144|0;Cb(g,v[d+232>>2],b);Ye(g,0)}b=b+1|0;continue}break}break q}if(y[d+12>>2]<9){break O}b=0;v[23588]=0;Q(188,d+160|0,2)|0;e=v[23588];v[23588]=0;g=65535;if((e|0)==1){break N}while(1){T:{v[23588]=0;e=W(156,v[d+160>>2],v[d+168>>2],1)|0;f=v[23588];v[23588]=0;U:{V:{W:{X:{Y:{Z:{_:{$:{if((f|0)!=1){if(!e){break T}v[23588]=0;f=S(206,d+160|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break q}e=0;switch(f|0){case 0:break T;case 14:break V;case 13:break W;case 12:break X;case 8:break Y;case 7:break Z;case 4:break _;case 1:break $;default:break O}}break q}e=Vb(v[a+484360>>2],w[j|0]);if(x[d+244>>1]==65535){A=d,C=Dl(v[e>>2],v[e+4>>2]),u[A+244>>1]=C}e=Dl(v[e>>2],v[e+4>>2]);v[23588]=0;u[d+246>>1]=e;e=Q(646,d+160|0,d+287|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break q}aa:{ba:{switch(e-254|0){case 1:e=65535;break aa;case 0:break ba;default:break aa}}e=65534}f=w[j|0];m=v[a+484360>>2];v[23588]=0;R(522,Vb(m,f)|0,e|0);e=v[23588];v[23588]=0;if((e|0)==1){break q}g=(g&65535)==65535?b:g;break U}v[23588]=0;e=S(194,d+160|0)|0;f=v[23588];v[23588]=0;ca:{da:{if((f|0)!=1){if(e>>>0>=(g&65535)>>>0){break da}e=x[d+248>>1];break ca}break q}e=e-g|0;u[d+248>>1]=e}Ue(Vb(v[a+484360>>2],w[j|0]),e&65535);break U}v[23588]=0;e=S(206,d+160|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break q}t[d+251|0]=e;break U}v[23588]=0;e=S(206,d+160|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break q}t[d+250|0]=e;break U}v[23588]=0;f=Q(617,d+160|0,d+144|0)|0;m=v[23588];v[23588]=0;if((m|0)!=1){if(w[d+144|0]|!f|(w[d+146|0]|w[d+145|0]!=255)){break O}if(w[d+147|0]|w[d+148|0]!=1){break O}if(!w[d+149|0]){break U}break O}break q}v[23588]=0;R(534,d+152|0,d+160|0);e=v[23588];v[23588]=0;ea:{fa:{ga:{ha:{if((e|0)!=1){m=Nc(d+152|0);e=v[h>>2];z=ed(e,v[d+212>>2]);f=w[d+152|0];if(z>>>0<=f>>>0){break U}switch(w[Se(d+152|0)|0]){case 4:break fa;case 2:break ga;case 0:break ha;default:break ea}}break q}A=Kb(e,f),C=w[m|0]^128,t[A|0]=C;e=d+144|0;Cb(e,v[d+232>>2],w[d+152|0]);Ye(e,0);break ea}A=Kb(e,f),C=128,t[A|0]=C;e=d+144|0;Cb(e,v[d+232>>2],w[d+152|0]);Ye(e,1);break ea}A=Kb(e,f),C=128,t[A|0]=C;e=d+144|0;Cb(e,v[d+232>>2],w[d+152|0]);Ye(e,0)}ia:{if(s){break ia}s=0;e=v[k+4>>2];if(!gq(v[k>>2],e)){break U}f=e-56|0;e=w[d+152|0];if(w[Kb(v[f>>2],e)|0]!=w[Kb(v[h>>2],e)|0]){break ia}Cb(d+144|0,v[f+24>>2],e);e=Bb(v[v[d+144>>2]>>2],v[d+148>>2]);Cb(d+136|0,v[d+232>>2],w[d+152|0]);if((Bb(v[v[d+136>>2]>>2],v[d+140>>2])|0)==(e|0)){break U}}s=1;break U}v[23588]=0;R(260,d+144|0,d+160|0);e=v[23588];v[23588]=0;if((e|0)==1){break q}e=v[d+220>>2];m=ed(e,v[d+224>>2]);f=w[d+144|0];if(m>>>0<=f>>>0){break U}m=Nc(d+144|0);A=Kb(e,f),C=(w[m|0]>>>2|0)+1|0,t[A|0]=C}b=b+1|0;continue}break}e=1}Ab(d+160|0);if(!e){break M}Mm(d+184|0);continue}break}break q}b=1}Yd(d+192|0)}St(h)}Ab(l);if(!b){Mf(d+264|0);continue}break}e=0;if((b|0)!=2){break w}}e=0;Fj(i,0);b=v[k>>2];if(oc(b,v[k+4>>2])){break w}if(!(c&2)){break x}v[23588]=0;U(641,d+160|0,o|0,1347244868);b=v[23588];v[23588]=0;if((b|0)==1){break y}A=d,C=Eb(v[d+160>>2]),v[A+8>>2]=C;e=a+480190|0;g=d+53|0;h=d+57|0;j=Eb(v[d+164>>2]);l=w[d+287|0];while(1){b=v[d+8>>2];if(!Ob(b,j)){Uc(d+160|0);b=v[k>>2];break x}ja:{ka:{la:{if(!l){v[23588]=0;f=Q(647,b|0,d+40|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break ka}if(!f){break ja}f=x[d+92>>1];i=f+1|0;u[d+144>>1]=i;if(f>>>0>3998){break la}A=a,C=x[ke(e,d+144|0)>>1],u[A+480190>>1]=C;v[23588]=0;R(648,d+40|0,(B(i&65535,104)+a|0)+484380|0);f=v[23588];v[23588]=0;if((f|0)==1){break ka}f=d+24|0;tR(f,g);v[23588]=0;R(222,d+192|0,f|0);f=v[23588];v[23588]=0;if((f|0)!=1){f=d+192|0;Cc(((x[d+144>>1]<<5)+a|0)+946304|0,f);yb(f);break la}break ka}v[23588]=0;f=Q(649,b|0,d+40|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break ka}if(!f){break ja}f=x[d+96>>1];i=f+1|0;u[d+144>>1]=i;if(f>>>0>3998){break la}A=a,C=x[ke(e,d+144|0)>>1],u[A+480190>>1]=C;v[23588]=0;R(650,d+40|0,(B(i&65535,104)+a|0)+484380|0);f=v[23588];v[23588]=0;if((f|0)==1){break ka}f=d+24|0;tR(f,h);v[23588]=0;R(222,d+192|0,f|0);f=v[23588];v[23588]=0;if((f|0)==1){break ka}f=d+192|0;Cc(((x[d+144>>1]<<5)+a|0)+946304|0,f);yb(f)}f=x[d+144>>1];if((f-1&65535)>>>0>3998){break ja}i=Zc(d+40|0,8,1,0,2);v[23588]=0;W(219,i|0,(B(f,104)+a|0)+484380|0,b|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break ja}}b=P()|0;O()|0;Uc(d+160|0);break j}Mf(d+8|0);continue}}b=P()|0;O()|0;break k}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break j}b=Yz(b,0);v[a+480196>>2]=w[b+43|0];v[a+480204>>2]=B(w[b+42|0],1e4);Ue(Vb(v[a+484360>>2],w[a+484376|0]),x[b+40>>1]);b=0;while(1){if(x[a+480188>>1]>b>>>0){e=(b<<5)+a|0;g=e+480280|0;df(g);h=Yz(v[k>>2],0);A=e+480286|0,C=w[Kb(v[h+12>>2],b)|0],u[A>>1]=C;A=e+480284|0,C=w[Kb(v[h>>2],b)|0],u[A>>1]=C;Cb(d+40|0,v[h+24>>2],b);A=g,C=v[g>>2]&-257|(Bb(v[v[d+40>>2]>>2],v[d+44>>2])?256:0),v[A>>2]=C;b=b+1|0;continue}break}v[23588]=0;b=Q(1,d+192|0,(w[d+287|0]?17096:16969)|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break r}Ib(a+1298344|0,b);zb(b);v[23588]=0;b=Q(1,d+24|0,10087)|0;e=v[23588];v[23588]=0;if((e|0)==1){break s}Ib(a+1298356|0,b);zb(b);v[a+1298404>>2]=5;e=1;if(!(c&1)|!x[a+480188>>1]){break w}v[23588]=0;U(641,d+8|0,o|0,1146045008);b=v[23588];v[23588]=0;if((b|0)==1){break t}b=v[d+12>>2];c=v[d+8>>2];v[23588]=0;l=a+484344|0;R(225,l|0,Bf(c,b)&65535);b=v[23588];v[23588]=0;if((b|0)==1){break v}A=d,C=Eb(v[d+8>>2]),v[A+144>>2]=C;r=Eb(v[d+12>>2]);while(1){j=v[d+144>>2];if(!Ob(j,r)){ma:{na:{b=v[k>>2];e=v[k+4>>2];if(gq(b,e)>>>0<2){break na}j=a+484348|0;g=0;while(1){if(gq(b,e)>>>0<=g>>>0){break na}i=v[a+484344>>2];n=v[j>>2];h=xj(v[a+484360>>2],g&255);m=v[h>>2];c=Yz(b,g);f=x[c+36>>1];if(xe(i,n,x[cc(m,f)>>1])){v[23588]=0;e=Q(360,h|0,f|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break ma}oa:{if(!s){break oa}b=0;while(1){if(x[a+480188>>1]<=b>>>0){break oa}Cb(d+40|0,v[c+24>>2],b);f=Bb(v[v[d+40>>2]>>2],v[d+44>>2]);h=Yb(v[l>>2],e);pa:{if(f){ze(h,Eh(vo(Te(Ne(d+40|0,20,145),0),b&65535)));break pa}ze(h,Eh(vo(Te(Ne(d+40|0,9,w[Kb(v[c>>2],b)|0]),0),b&65535)))}b=b+1|0;continue}}b=d+40|0;ze(Yb(v[l>>2],e),Eh(Te(Ne(b,16,w[c+43|0]),0)));ze(Yb(v[l>>2],e),Eh(Te(Ne(b,17,w[c+42|0]),0)));e=v[k+4>>2];b=v[k>>2]}g=g+1|0;continue}}Uc(d+8|0);e=1;break w}b=P()|0;O()|0;break u}b=v[j>>2];v[23588]=0;b=S(160,b|0)|0;c=v[23588];v[23588]=0;qa:{ra:{sa:{ta:{ua:{va:{wa:{if((c|0)==1){break wa}v[23588]=0;c=S(157,j|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break wa}if((b|0)!=(c|0)){break qa}b=v[j>>2];v[23588]=0;b=Q(651,b|0,8)|0;c=v[23588];v[23588]=0;if((c|0)==1){break wa}if(!b){break qa}v[23588]=0;i=Q(646,j|0,d+287|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break ra}v[23588]=0;p=S(194,j|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break sa}v[23588]=0;b=W(226,l|0,i|0,p|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break sa}if(!b){break qa}f=0;while(1){if((f|0)==(p|0)){break qa}b=Yb(v[l>>2],i);c=Cf(v[b>>2],v[v[b+48>>2]+12>>2],f);v[23588]=0;b=S(194,j|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break va}xa:{if(b>>>0>=3){v[23588]=0;U(190,d+160|0,j|0,b-2|0);b=v[23588];v[23588]=0;if((b|0)==1){break ta}b=d+160|0;h=jc(d+40|0,b);Ab(b);while(1){b=v[h>>2];v[23588]=0;b=W(156,b|0,v[d+48>>2],3)|0;e=v[23588];v[23588]=0;if((e|0)==1){break xa}if(b){v[23588]=0;R(260,d+160|0,h|0);b=v[23588];v[23588]=0;ya:{za:{Aa:{Ba:{if((b|0)!=1){u[d+136>>1]=x[a+480188>>1]-1;A=d,C=w[Nc(d+160|0)|0],u[A+264>>1]=C;e=x[Vc(d+136|0,d+264|0)>>1];g=c+B(e,6)|0;b=t[d+160|0];if((b|0)>=0){break ya}v[23588]=0;b=S(206,h|0)|0;n=v[23588];v[23588]=0;if((n|0)==1){break ua}if(w[d+287|0]){break Aa}if((b|0)!=255){break Ba}b=254;break za}break ua}if(b>>>0>128){break za}b=(B(b>>>4|0,12)+(b&15)|0)+13|0;break za}b=b>>>0<85?b+36|0:b}t[g|0]=b;b=w[d+160|0]}if(b&64){v[23588]=0;b=S(206,h|0)|0;n=v[23588];v[23588]=0;if((n|0)==1){break ua}t[g+1|0]=b+1;b=w[d+160|0]}if(b&32){v[23588]=0;b=S(206,h|0)|0;n=v[23588];v[23588]=0;if((n|0)==1){break ua}t[d+136|0]=b;t[g+2|0]=1;t[d+264|0]=127;A=g,C=w[Wb(d+136|0,d+264|0)|0]+1>>>1|0,t[A+4|0]=C;b=w[d+160|0]}if(!(b&16)){continue}v[23588]=0;R(260,d+136|0,h|0);b=v[23588];v[23588]=0;Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{cb:{db:{eb:{fb:{gb:{hb:{if((b|0)!=1){b=w[Nc(d+136|0)|0];t[g+5|0]=b;switch(w[d+136|0]-1|0){case 72:break Da;case 71:break Ea;case 70:break Fa;case 61:break Ga;case 60:break Ha;case 53:break Ia;case 52:break Ja;case 51:break Ka;case 50:break Ma;case 43:break Na;case 42:break Oa;case 41:break Pa;case 40:break Qa;case 31:break Ra;case 30:break Sa;case 23:break Ta;case 22:break Ua;case 21:break Va;case 20:break Wa;case 18:break Xa;case 17:break Ya;case 15:break Za;case 16:break _a;case 14:break $a;case 13:break ab;case 12:break bb;case 11:break cb;case 10:break db;case 3:break eb;case 2:break fb;case 1:break gb;case 0:break hb;default:break Ca}}break ua}t[(c+B(e,6)|0)+3|0]=11;if(w[d+287|0]){t[g+5|0]=b<<4|15;continue}t[g+5|0]=b<<3|15;continue}t[(c+B(e,6)|0)+3|0]=11;if(w[d+287|0]){t[g+5|0]=b<<4;continue}t[g+5|0]=b<<3&240;continue}t[(c+B(e,6)|0)+3|0]=11;if(w[d+287|0]){t[g+5|0]=b|240;continue}t[g+5|0]=b>>>1|240;continue}t[(c+B(e,6)|0)+3|0]=11;if(w[d+287|0]){t[g+5|0]=b&15;continue}if(b>>>0<=1){t[g+5|0]=b|240;continue}t[g+5|0]=b>>>1&15;continue}t[(c+B(e,6)|0)+3|0]=2;A=g,C=Rt(b,w[d+287|0])|240,t[A+5|0]=C;continue}t[(c+B(e,6)|0)+3|0]=2;A=g,C=Rt(b,w[d+287|0]),t[A+5|0]=C;continue}t[(c+B(e,6)|0)+3|0]=3;A=g,C=Rt(b,w[d+287|0])|240,t[A+5|0]=C;continue}t[(c+B(e,6)|0)+3|0]=3;A=g,C=Rt(b,w[d+287|0]),t[A+5|0]=C;continue}t[(c+B(e,6)|0)+3|0]=4;if(w[d+287|0]){continue}t[g+5|0]=(b&252)>>>2;continue}t[(c+B(e,6)|0)+3|0]=20;t[g+5|0]=b&1|16;continue}t[(c+B(e,6)|0)+3|0]=6;t[g+5|0]=b&240;continue}t[(c+B(e,6)|0)+3|0]=6;t[g+5|0]=(b&240)>>>4;continue}t[(c+B(e,6)|0)+3|0]=20;continue}t[(c+B(e,6)|0)+3|0]=5;continue}t[(c+B(e,6)|0)+3|0]=20;t[g+5|0]=b&15|48;continue}t[(c+B(e,6)|0)+3|0]=7;t[g+5|0]=b|240;continue}t[(c+B(e,6)|0)+3|0]=7;continue}t[(c+B(e,6)|0)+3|0]=8;continue}t[(c+B(e,6)|0)+3|0]=20;t[g+5|0]=b&15|64;continue}t[(c+B(e,6)|0)+3|0]=10;v[23588]=0;b=S(206,h|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){break La}break ua}t[(c+B(e,6)|0)+3|0]=15;continue}t[(c+B(e,6)|0)+3|0]=20;t[g+5|0]=b&15|192;continue}t[(c+B(e,6)|0)+3|0]=20;t[g+5|0]=b&15|208;continue}t[(c+B(e,6)|0)+3|0]=12;b=(b&254)>>>1|0}t[g+5|0]=b;v[23588]=0;Q(188,h|0,1)|0;b=v[23588];v[23588]=0;if((b|0)!=1){continue}break ua}t[(c+B(e,6)|0)+3|0]=14;t[g+5|0]=0;continue}t[(c+B(e,6)|0)+3|0]=20;t[g+5|0]=b&15|176;continue}t[(c+B(e,6)|0)+3|0]=20;t[g+5|0]=b&15|224;continue}t[(c+B(e,6)|0)+3|0]=16;continue}t[(c+B(e,6)|0)+3|0]=17;continue}t[(c+B(e,6)|0)+3|0]=1;continue}t[(c+B(e,6)|0)+3|0]=20;t[g+5|0]=b&15|32;continue}t[(c+B(e,6)|0)+3|0]=20;t[g+5|0]=b&15|128;continue}t[(c+B(e,6)|0)+3|0]=0;continue}break}Ab(h)}f=f+1|0;continue}break}break ua}b=P()|0;O()|0;break u}b=P()|0;O()|0;break u}b=P()|0;O()|0;Ab(h);break u}b=P()|0;O()|0;break u}b=P()|0;O()|0;break u}b=P()|0;O()|0;break u}Mf(d+144|0);continue}}Uc(d+272|0);sR(k);Ab(d+304|0);break b}b=P()|0;O()|0}Uc(d+8|0);break j}b=P()|0;O()|0;break j}b=P()|0;O()|0;break j}b=P()|0;O()|0;break j}b=P()|0;O()|0;Ab(d+160|0);break m}b=P()|0;O()|0;break l}b=P()|0;O()|0;zb(d+160|0);break l}b=P()|0;O()|0;break l}Yd(d+192|0)}St(h)}Ab(l)}Uc(d+272|0);break h}b=P()|0;O()|0}sR(k);break f}b=P()|0;O()|0}Ab(d+304|0);break c}b=P()|0;O()|0;break c}b=P()|0;O()|0}Yd(o);Ab(q);T(b|0);L()}Yd(o);Ab(q)}jb=d+384|0;return e|0}function Iha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;d=jb-480|0;jb=d;yc(b);h=d+472|0;e=Nu(b,h);if(!e){VS(h)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(!e){break k}if(!WS(d+472|0)){break k}if(!c){A=1;break k}H=je(d+448|0,b);v[23588]=0;R(493,d+432|0,H|0);b=v[23588];v[23588]=0;l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{if((b|0)!=1){v[23588]=0;U(494,d+408|0,d+432|0,20041);b=v[23588];v[23588]=0;if((b|0)==1){break u}v[23588]=0;e=S(178,v[d+408>>2])|0;b=v[23588];v[23588]=0;if((b|0)==1){break m}if(!e){break l}v[23588]=0;e=Q(495,d+408|0,d+312|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break m}if(!e){break l}v[23588]=0;R(246,a|0,16384);b=v[23588];v[23588]=0;if((b|0)==1){break m}v[a+480208>>2]=8;v[23588]=0;e=W(264,a+1074312|0,9,1)|0;b=v[23588];v[23588]=0;if((b|0)==1){break m}v[23588]=0;e=W(264,e|0,114,1)|0;b=v[23588];v[23588]=0;if((b|0)==1){break m}v[23588]=0;e=Q(265,e|0,21)|0;b=v[23588];v[23588]=0;if((b|0)==1){break m}v[23588]=0;Q(265,e|0,30)|0;b=v[23588];v[23588]=0;if((b|0)==1){break m}v[23588]=0;e=Q(1,d+296|0,8240)|0;b=v[23588];v[23588]=0;if((b|0)==1){break r}Ib(a+1298344|0,e);zb(e);v[23588]=0;e=Q(1,d+280|0,10672)|0;b=v[23588];v[23588]=0;if((b|0)==1){break q}Ib(a+1298356|0,e);zb(e);v[23588]=0;g=Q(1,d+264|0,17466)|0;b=v[23588];v[23588]=0;if((b|0)==1){break p}e=15016;b=w[d+476|0];switch(b-16|0){case 1:break n;case 0:break t;default:break s}}f=P()|0;O()|0;break a}f=P()|0;O()|0;break b}e=14997;break n}if(!b){break o}e=21619;break n}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}e=13174}v[23588]=0;h=Q(1,d+248|0,e|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break e}v[23588]=0;U(2,d+208|0,g|0,h|0);b=v[23588];v[23588]=0;if((b|0)==1){break f}e=d+208|0;Ib(a+1298368|0,e);zb(e);zb(h);zb(g);v[a+1298404>>2]=5;b=d+96|0;Me(b,3,d+312|0);v[23588]=0;R(222,e|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break g}b=d+208|0;Ac(a+1298308|0,b);yb(b);b=d+232|0;Cj(b,3,d+344|0);v[23588]=0;R(222,d+96|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break h}v[23588]=0;U(11,d+208|0,5,d+96|0);b=v[23588];v[23588]=0;if((b|0)==1){break i}b=d+208|0;Ib(a+1298320|0,b);zb(b);yb(d+96|0);v[a+480200>>2]=w[d+368|0]+1;I=a,J=Cd(w[d+369|0],1,255),v[I+480196>>2]=J;I=a,J=B(Cd(w[d+370|0],4,255),1e4),v[I+480204>>2]=J;h=v[a+484360>>2];e=a+484376|0;b=w[e|0];v[23588]=0;ea(340,Vb(h,b)|0,d+408|0,x[d+364>>1],65535,65535);b=v[23588];v[23588]=0;if((b|0)==1){break m}Ue(Vb(v[a+484360>>2],w[e|0]),x[d+366>>1]);u[a+480188>>1]=0;b=0;while(1){if((b|0)==32){v[23588]=0;U(494,d+208|0,d+432|0,17741);b=v[23588];v[23588]=0;if((b|0)!=1){b=d+208|0;h=gd(d+408|0,b);Ab(b);b=v[h>>2];v[23588]=0;e=S(160,b|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break m}v[23588]=0;X(331,a+1298332|0,h|0,e|0,0);b=v[23588];v[23588]=0;if((b|0)==1){break m}v[23588]=0;U(494,d+208|0,d+432|0,21321);b=v[23588];v[23588]=0;if((b|0)!=1){b=d+208|0;j=gd(h,b);Ab(b);b=v[j>>2];v[23588]=0;e=S(178,b|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break m}v:{w:{if(e){v[23588]=0;U(494,d+208|0,d+432|0,16723);b=v[23588];v[23588]=0;if((b|0)==1){break v}v[23588]=0;g=S(206,j|0)|0;b=v[23588];v[23588]=0;x:{if((b|0)!=1){h=c&2;i=a+480190|0;while(1){if(g>>>0<=(n&255)>>>0){break x}v[23588]=0;r=S(206,j|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break w}if(!r){break x}e=v[j+8>>2];b=v[j>>2];v[23588]=0;e=W(156,b|0,e|0,56)|0;b=v[23588];v[23588]=0;if((b|0)==1){break w}if(!e){break x}if(r>>>0>x[i>>1]){u[i>>1]=r}v[23588]=0;p=B(r,104)+a|0;A=p+484380|0;R(277,A|0,0);b=v[23588];v[23588]=0;if((b|0)==1){break w}to(A);v[23588]=0;U(314,j|0,((r<<5)+a|0)+946304|0,32);b=v[23588];v[23588]=0;if((b|0)==1){break w}v[23588]=0;R(317,j|0,p+484423|0);b=v[23588];v[23588]=0;if((b|0)==1){break w}y:{if(w[d+476|0]<=15){v[23588]=0;f=S(194,j|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break y}break w}v[23588]=0;f=S(157,j|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break w}}v[p+484404>>2]=f<<1;v[23588]=0;e=S(157,j|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break w}v[A>>2]=e;v[23588]=0;e=S(157,j|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break w}l=p+484384|0;v[l>>2]=e;v[23588]=0;e=S(157,j|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break w}F=p+484388|0;v[F>>2]=e;if(e){b=p+484414|0;u[b>>1]=x[b>>1]|2;v[F>>2]=e+v[l>>2]}v[23588]=0;e=S(206,j|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break w}if(w[d+476|0]<=15){u[p+484410>>1]=e}v[23588]=0;r=S(206,j|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break w}b=p+484414|0;e=x[b>>1];o=8;if(r&1){e=e|1;u[b>>1]=e;v[A>>2]=v[A>>2]>>>1;v[l>>2]=v[l>>2]>>>1;v[F>>2]=v[F>>2]>>>1;o=16}u[b>>1]=e&65531|r<<1&4;b=Zc(d+96|0,o,1,0,((r&12)!=0)<<3);z:{if(!h){break z}v[23588]=0;W(219,b|0,A|0,d+208|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break z}break w}n=n+1|0;continue}}break w}Ab(d+208|0)}v[23588]=0;U(494,d+208|0,d+432|0,18761);b=v[23588];v[23588]=0;A:{if((b|0)!=1){b=d+208|0;k=gd(j,b);Ab(b);b=v[k>>2];v[23588]=0;e=S(178,b|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break m}if(!e){break A}s=Sb(d+96|0);y=Sb(d+232|0);z=Sb(d+192|0);v[23588]=0;U(494,d+168|0,d+432|0,17750);b=v[23588];v[23588]=0;B:{if((b|0)==1){break B}b=v[d+180>>2];e=d- -64|0;v[e>>2]=v[d+176>>2];v[e+4>>2]=b;v[d+72>>2]=v[d+184>>2];v[23588]=0;b=v[d+172>>2];v[d+56>>2]=v[d+168>>2];v[d+60>>2]=b;R(496,d+56|0,s|0);b=v[23588];v[23588]=0;if((b|0)==1){break B}v[23588]=0;U(494,d+144|0,d+432|0,17744);b=v[23588];v[23588]=0;if((b|0)==1){break B}b=v[d+156>>2];v[d+40>>2]=v[d+152>>2];v[d+44>>2]=b;v[d+48>>2]=v[d+160>>2];v[23588]=0;b=v[d+148>>2];v[d+32>>2]=v[d+144>>2];v[d+36>>2]=b;R(496,d+32|0,y|0);b=v[23588];v[23588]=0;if((b|0)==1){break B}v[23588]=0;U(494,d+120|0,d+432|0,17734);b=v[23588];v[23588]=0;if((b|0)==1){break B}b=v[d+132>>2];v[d+16>>2]=v[d+128>>2];v[d+20>>2]=b;v[d+24>>2]=v[d+136>>2];v[23588]=0;b=v[d+124>>2];v[d+8>>2]=v[d+120>>2];v[d+12>>2]=b;R(496,d+8|0,z|0);b=v[23588];v[23588]=0;if((b|0)==1){break B}v[23588]=0;p=S(206,k|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break B}j=d+208|1;A=a+480190|0;o=0;while(1){if(p>>>0<=(o&255)>>>0){lo(z);lo(y);lo(s);break A}v[23588]=0;R(260,d+80|0,k|0);b=v[23588];v[23588]=0;C:{if((b|0)!=1){E=Nc(d+80|0);D:{E:{if(!w[d+80|0]){break E}h=v[k+8>>2];e=v[k>>2];b=w[E|0];v[23588]=0;e=W(156,e|0,h|0,B(b,14)+32|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break B}if(!e){break E}v[23588]=0;m=W(251,a|0,w[d+80|0],0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break B}if(m){break D}}b=w[E|0];v[23588]=0;Q(188,k|0,B(b,14)+32|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break C}break B}v[23588]=0;U(314,k|0,m+492|0,32);b=v[23588];v[23588]=0;if((b|0)==1){break B}l=m+88|0;F=m+68|0;r=m+48|0;i=m+236|0;b=0;n=0;while(1){if(w[E|0]<=(n&255)>>>0){break C}v[23588]=0;R(497,k|0,d+208|0);e=v[23588];v[23588]=0;if((e|0)==1){break B}e=w[d+208|0];F:{if(!e|e>>>0>x[A>>1]){break F}if(w[j|0]>=129){t[j|0]=128}while(1){e=b&255;g=w[d+209|0];if(e>>>0>g>>>0){e=v[s+4>>2];b=v[s>>2];v[23588]=0;X(498,r|0,w[d+211|0],b|0,e|0);b=v[23588];v[23588]=0;if((b|0)==1){break B}e=v[y+4>>2];b=v[y>>2];v[23588]=0;X(498,F|0,w[d+213|0],b|0,e|0);b=v[23588];v[23588]=0;if((b|0)==1){break B}e=v[z+4>>2];b=v[z>>2];v[23588]=0;X(498,l|0,w[d+221|0],b|0,e|0);b=v[23588];v[23588]=0;if((b|0)==1){break B}v[m>>2]=x[d+214>>1]+1>>>1;e=w[d+208|0];G:{if(w[d+211|0]&64){u[(B(e,104)+a|0)+484410>>1]=w[d+210|0];break G}b=(B(e,104)+a|0)+484414|0;u[b>>1]=x[b>>1]|32768}u[d+118>>1]=w[d+212|0]<<1;u[d+116>>1]=254;C=B(e,104)+a|0;I=C+484408|0,J=x[Vc(d+118|0,d+116|0)>>1],u[I>>1]=J;t[C+484418|0]=w[(w[d+219|0]&3)+26660|0];e=C+484419|0;G=w[d+218|0];t[e|0]=G;h=w[d+217|0]+3>>>2|0;t[C+484420|0]=h;t[C+484421|0]=w[d+216|0];b=g+1|0;if(G){g=Ll(Dc(((h<<8|G>>>1)>>>0)/(G>>>0)|0,0))}else{g=255}t[e|0]=g;if(!(w[d+213|0]&64)){break F}e=C+484414|0;u[e>>1]=x[e>>1]|32}else{I=cc(i,e),J=w[d+208|0],u[I>>1]=J;b=b+1|0;continue}break}}n=n+1|0;continue}}break B}o=o+1|0;continue}}f=P()|0;O()|0;lo(z);lo(y);lo(s);break c}f=P()|0;O()|0;break c}A=1;s=Sb(d+232|0);H:{if(!(c&1)){break H}v[23588]=0;U(494,d+208|0,d+432|0,21076);b=v[23588];v[23588]=0;I:{J:{K:{L:{M:{N:{if((b|0)!=1){g=gd(k,d+208|0);b=v[g>>2];v[23588]=0;c=S(178,b|0)|0;b=v[23588];v[23588]=0;O:{P:{Q:{if((b|0)!=1){Ab(d+208|0);if(!c){break O}v[23588]=0;e=S(194,g|0)|0;c=v[23588];v[23588]=0;b=1;if((c|0)==1){break Q}v[23588]=0;h=e+1|0;R(499,s|0,h|0);c=v[23588];v[23588]=0;if((c|0)==1){break Q}while(1){if((b|0)==(h|0)){break O}v[23588]=0;e=S(194,g|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break P}v[23588]=0;U(190,d+96|0,g|0,e|0);c=v[23588];v[23588]=0;if((c|0)==1){break P}c=d+96|0;e=jc(d+208|0,c);gd(Og(v[s>>2],b),e);Ab(e);b=b+1|0;Ab(c);continue}}f=P()|0;O()|0;Ab(d+208|0);break I}f=P()|0;O()|0;break I}f=P()|0;O()|0;break I}v[23588]=0;U(494,d+208|0,d+432|0,16720);b=v[23588];v[23588]=0;if((b|0)==1){break K}k=gd(g,d+208|0);b=v[k>>2];v[23588]=0;c=S(178,b|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break L}Ab(d+208|0);if(!c){break N}v[23588]=0;G=S(206,k|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break J}o=0;R:{S:{T:while(1){U:{if(G>>>0<=(o&65535)>>>0){v[23588]=0;Q(155,k|0,1)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break U}break J}n=32;V:{if(w[d+476|0]<16){break V}v[23588]=0;R(500,k|0,d+208|0);b=v[23588];v[23588]=0;if((b|0)==1){break R}n=w[d+208|0];if(n>>>0<=x[a+480188>>1]|n>>>0>32){break V}u[a+480188>>1]=n}b=0;while(1){h=b&65535;if(h>>>0>=n>>>0){o=o+1|0;continue T}v[23588]=0;e=S(194,k|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break S}if(!(!e|h>>>0>31|h>>>0<x[a+480188>>1])){u[a+480188>>1]=b+1}b=b+1|0;continue}}break}v[23588]=0;z=a+484344|0;R(225,z|0,G|0);b=v[23588];v[23588]=0;if((b|0)==1){break J}F=d+208|2;m=0;while(1){if((m|0)==(G|0)){break N}C=Lb(d+96|0);W:{if(w[d+476|0]<16){j=32;h=64;break W}v[23588]=0;R(500,k|0,d+208|0);b=v[23588];v[23588]=0;if((b|0)==1){break M}c=w[d+209|0];j=w[d+208|0];b=d+80|0;pf(b,F,16,3);v[23588]=0;R(222,d+192|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break M}b=d+192|0;Ac(C,b);yb(b);h=c+1|0}v[23588]=0;c=W(226,z|0,m&65535,h|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break M}X:{if(!c){v[23588]=0;Q(188,k|0,j<<1)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break X}break M}b=v[z>>2];v[23588]=0;R(281,Yb(b,m)|0,C|0);b=v[23588];v[23588]=0;if((b|0)==1){break M}r=h-1|0;p=0;while(1){E=p&65535;if(E>>>0>=j>>>0){break X}v[23588]=0;c=S(194,k|0)|0;b=v[23588];v[23588]=0;Y:{if((b|0)!=1){if(!c){break Y}b=v[s>>2];if(Bf(b,v[s+4>>2])>>>0<=c>>>0|E>>>0>=x[a+480188>>1]){break Y}D=Og(b,c);yc(D);c=0;Z:while(1){e=c;if(h>>>0<=e>>>0){break Y}c=v[D+8>>2];b=v[D>>2];v[23588]=0;c=W(156,b|0,c|0,1)|0;b=v[23588];v[23588]=0;_:{$:{aa:{ba:{ca:{if((b|0)!=1){if(!c){break Y}b=Yb(v[z>>2],m);b=id(v[b>>2],v[v[b+48>>2]+12>>2],e,E);v[23588]=0;g=S(206,D|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break M}f=g>>>2|0;switch((g&3)-1|0){case 2:break $;case 1:break aa;case 0:break ba;default:break ca}}break M}c=(e+f|0)+1|0;continue}c=0;if(!e){continue}c=Yb(v[z>>2],m);i=id(v[c>>2],v[v[c+48>>2]+12>>2],e-1|0,E);while(1){c=w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24);t[b|0]=c;t[b+1|0]=c>>>8;t[b+2|0]=c>>>16;t[b+3|0]=c>>>24;c=w[i+4|0]|w[i+5|0]<<8;t[b+4|0]=c;t[b+5|0]=c>>>8;c=e+1|0;if((e|0)==(r|0)){continue Z}b=B(x[a+480188>>1],6)+b|0;g=f&255;e=c;f=f-1|0;if(g){continue}break}continue}if(e>>>0<=f>>>0){break _}c=Yb(v[z>>2],m);g=id(v[c>>2],v[v[c+48>>2]+12>>2],f,E);c=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);t[b|0]=c;t[b+1|0]=c>>>8;t[b+2|0]=c>>>16;t[b+3|0]=c>>>24;c=w[g+4|0]|w[g+5|0]<<8;t[b+4|0]=c;t[b+5|0]=c>>>8;break _}if(f&1){v[23588]=0;g=S(206,D|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break M}t[b|0]=g>>>0>120?-1:g}if(f&2){v[23588]=0;g=S(206,D|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break M}t[b+1|0]=g}n=0;c=0;da:{if(f&4){v[23588]=0;c=S(206,D|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break da}}o=0;if(f&8){v[23588]=0;i=S(206,D|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break da}n=i&15;o=i>>>4|0}l=0;i=0;if(f&16){v[23588]=0;i=S(206,D|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break da}}if(f&32){v[23588]=0;l=S(206,D|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break da}}g=c;q=jb-32|0;jb=q;c=q+24|0;RS(c,n,i);y=Nc(c);c=q+16|0;RS(c,((o-1&255)>>>0<6?o+15|0:o)&255,l);l=Nc(c);ea:{fa:{ga:{if(w[q+24|0]==10){i=w[l|0];c=w[y|0]&15;t[y|0]=c?-1:i;c=i|c<<8;f=w[q+16|0];if((f|0)!=10){break ga}f=0;t[q+16|0]=0;break ga}if(w[q+16|0]!=10){break fa}c=w[l|0]&15;t[l|0]=c?-1:0;c=c<<8;f=w[q+24|0]}if(c-256>>>0>4294967038){break fa}if(Ji(f)>>>0>=Ji(10)>>>0){break fa}t[b+5|0]=c;t[b+2|0]=15;t[b+3|0]=10;t[b+4|0]=c>>>8;break ea}if(g){t[b+2|0]=1;t[b+4|0]=g+2>>>2}Uu(q+24|0,y,q+16|0,l);c=w[q+16|0];ha:{ia:{i=w[q+24|0];if(i){if((i|0)==20|(i|0)!=(c&255)){break ia}c=i}break ha}if(!(c&255)){t[b+5|0]=w[y|0];t[b+3|0]=i;break ea}if(!g){Ao(q+8|0,b,i,w[y|0],c&255,w[l|0]);break ea}if(Ji(i)>>>0>Ji(c&255)>>>0){t[b+5|0]=w[y|0];t[b+3|0]=i;break ea}}t[b+5|0]=w[l|0];t[b+3|0]=c}jb=q+32|0;break _}break M}c=e+1|0;continue}}break M}p=p+1|0;continue}}yb(C);m=m+1|0;continue}}f=P()|0;O()|0;break I}f=P()|0;O()|0;break I}f=P()|0;O()|0;break I}v[23588]=0;U(494,d+208|0,d+432|0,20048);b=v[23588];v[23588]=0;ja:{ka:{if((b|0)!=1){h=gd(k,d+208|0);b=v[h>>2];v[23588]=0;c=S(178,b|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break ka}Ab(d+208|0);if(!c){break H}e=a+484348|0;while(1){if(!Af(v[a+484344>>2],v[e>>2])){break H}c=v[h+8>>2];b=v[h>>2];v[23588]=0;c=W(156,b|0,c|0,16)|0;b=v[23588];v[23588]=0;if((b|0)==1){break ja}if(!c){break H}v[23588]=0;R(385,h|0,d+208|0);b=v[23588];v[23588]=0;if((b|0)!=1){b=v[a+484344>>2];v[23588]=0;R(386,Yb(b,0)|0,d+208|0);b=v[23588];v[23588]=0;if((b|0)!=1){continue}}break}f=P()|0;O()|0;break I}f=P()|0;O()|0;break I}f=P()|0;O()|0;Ab(d+208|0);break I}f=P()|0;O()|0;break I}f=P()|0;O()|0;yb(C);break I}f=P()|0;O()|0;Ab(d+208|0);break I}f=P()|0;O()|0;break I}f=P()|0;O()|0}Uc(s);break c}Uc(s);break l}f=P()|0;O()|0;Ab(d+208|0);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}i=(b<<5)+a|0;g=i+480280|0;df(g);h=t[(b+d|0)+371|0];e=h<<1&254;u[i+480284>>1]=(e|0)==254?256:e;la:{if((h|0)<0){v[g>>2]=v[g>>2]|1024;break la}u[a+480188>>1]=b+1}v[23588]=0;R(501,d+408|0,i+480289|0);e=v[23588];v[23588]=0;if((e|0)==1){break j}b=b+1|0;continue}}f=P()|0;O()|0;break c}Ab(d+408|0);Yd(d+432|0);Ab(H)}jb=d+480|0;return A|0}f=P()|0;O()|0;break c}f=P()|0;O()|0;yb(d+96|0);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;zb(h);break d}f=P()|0;O()|0}zb(g)}Ab(d+408|0)}Yd(d+432|0)}Ab(H);T(f|0);L()}function Oja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;d=jb-240|0;jb=d;yc(b);e=jb-16|0;jb=e;h=d+216|0;zu(e+8|0,h);g=v[e+12>>2];mc(e,v[b>>2],v[b+8>>2],v[e+8>>2],v[e+12>>2]);j=v[e+4>>2];if((j|0)==(g|0)){Zb(b,v[e+12>>2])}jb=e+16|0;e=(g|0)==(j|0);if(!e){zU(h)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(!e){break n}if(!AU(d+216|0)){break n}if(!c){f=1;break n}Ad(a,1024);$f(a);v[a+480208>>2]=v[a+480208>>2]|12;Zf(a+1074312|0,21);e=Hb(x[d+232>>1]);if(e){v[a+480204>>2]=B(e,1e4)}e=Hb(x[d+230>>1]);if(e){v[a+480196>>2]=e}if(!w[d+226|0]){nh(a,1)}MB(b,a+1298308|0,bc(v[d+220>>2])-14|0);b=je(d+112|0,b);v[23588]=0;R(338,d+200|0,b|0);e=v[23588];v[23588]=0;o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{if((e|0)!=1){Ab(b);v[23588]=0;U(339,d+112|0,d+200|0,1395544366);b=v[23588];v[23588]=0;if((b|0)==1){break s}v[23588]=0;b=S(275,v[d+112>>2])|0;e=v[23588];v[23588]=0;if((e|0)==1){break y}if(!b){break r}v[23588]=0;b=S(271,d+112|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break y}v[23588]=0;e=S(271,d+112|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break y}v[23588]=0;Q(188,d+112|0,4)|0;f=v[23588];v[23588]=0;if((f|0)==1){break y}f=a+484376|0;g=w[f|0];h=v[a+484360>>2];v[23588]=0;ea(340,Vb(h,g)|0,d+112|0,b|0,65535,65535);b=v[23588];v[23588]=0;if((b|0)==1){break y}Ue(Vb(v[a+484360>>2],w[f|0]),e);b=d+112|0;Ab(b);v[23588]=0;U(339,b|0,d+200|0,1346458708);b=v[23588];v[23588]=0;if((b|0)==1){break x}v[23588]=0;e=S(275,v[d+112>>2])|0;b=v[23588];v[23588]=0;if((b|0)==1){break w}f=0;b=0;if(!e){break t}v[23588]=0;e=S(271,d+112|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break w}u[a+480188>>1]=e;if((e-33&65535)>>>0<65504){break t}v[23588]=0;b=S(271,d+112|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break w}v[23588]=0;R(225,a+484344|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break w}b=0;v[23588]=0;o=S(279,d+112|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break w}switch(o-841887796|0){case 1:break t;case 0:case 2:break u;default:break v}}e=P()|0;O()|0;Ab(b);break a}e=P()|0;O()|0;Ab(d+112|0);break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;Ab(d+112|0);break b}if(o){break t}}b=1}Ab(d+112|0);if(!b){break o}v[23588]=0;U(339,d+176|0,d+200|0,1398157625);b=v[23588];v[23588]=0;if((b|0)==1){break d}v[23588]=0;b=S(275,v[d+176>>2])|0;e=v[23588];v[23588]=0;if((e|0)==1){break c}if(!b){break q}v[23588]=0;Q(188,d+176|0,2)|0;b=v[23588];v[23588]=0;if((b|0)==1){break c}v[23588]=0;b=S(279,d+176|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break c}G=a,H=Pe((+(b>>>0)*2.3283064365386963e-10+ +(y[a+480204>>2]/1e4>>>0))*1e4),v[G+480204>>2]=H;b=0;v[23588]=0;Q(341,d+176|0,d+112|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break c}f=x[a+480188>>1];while(1){if((b|0)!=32&(b|0)!=(f|0)){G=d,H=Hb(x[(d+112|0)+(b<<1)>>1]),v[G+48>>2]=H;v[d+32>>2]=180;e=v[sd(d+48|0,d+32|0)>>2]-90|0;g=e>>31;G=((b<<5)+a|0)+480284|0,H=Hc(Mka(e<<7|45,g<<7|e>>>25,90,0),mb)+128|0,u[G>>1]=H;b=b+1|0;continue}else{z:{v[23588]=0;Q(188,d+176|0,16)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break z}break c}}break}v[23588]=0;b=W(156,v[d+176>>2],v[d+184>>2],2)|0;e=v[23588];v[23588]=0;if((e|0)==1){break c}A:{if(b){v[23588]=0;b=S(271,d+176|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break A}u[d+48>>1]=b;u[d+32>>1]=256;G=a,H=x[Vc(d+48|0,d+32|0)>>1],v[G+480200>>2]=H}v[23588]=0;Q(188,d+176|0,128)|0;b=v[23588];v[23588]=0;if((b|0)==1){break c}v[23588]=0;b=Q(341,d+176|0,d+48|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){if(!b){break q}e=x[a+480188>>1];b=0;while(1)if((b|0)!=32&(b|0)!=(e|0)){G=d,H=Hb(x[(d+48|0)+(b<<1)>>1]),v[G+32>>2]=H;v[d+16>>2]=128;G=((b<<5)+a|0)+480286|0,H=v[sd(d+32|0,d+16|0)>>2]/2&255,u[G>>1]=H;b=b+1|0;continue}else{v[a+480228>>2]=v[a+480228>>2]<<1;break q}}break c}break c}e=P()|0;O()|0;break b}Ab(d+112|0);break p}Ab(d+176|0);v[23588]=0;U(339,d+112|0,d+200|0,1413830740);b=v[23588];v[23588]=0;B:{C:{if((b|0)!=1){v[23588]=0;b=S(275,v[d+112>>2])|0;e=v[23588];v[23588]=0;if((e|0)==1){break e}if(!b){break B}v[23588]=0;R(342,d+112|0,d+48|0);b=v[23588];v[23588]=0;if((b|0)==1){break e}if((Hb(x[d+58>>1])|0)!=65535){break C}v[23588]=0;Q(188,d+112|0,1)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break C}break e}e=P()|0;O()|0;break b}v[23588]=0;b=S(202,d+112|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break e}v[23588]=0;X(331,a+1298332|0,d+112|0,b|0,2);b=v[23588];v[23588]=0;if((b|0)==1){break e}}Ab(d+112|0);v[23588]=0;U(339,d+48|0,d+200|0,1229869908);b=v[23588];v[23588]=0;if((b|0)==1){break h}v[23588]=0;b=S(275,v[d+48>>2])|0;e=v[23588];v[23588]=0;if((e|0)==1){break l}if(b){D:{v[23588]=0;b=S(271,d+48|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break i}E:{F:{b=b<<16>>16;f=b&32767;if(f>>>0>3999){break F}v[23588]=0;e=W(156,v[d+48>>2],v[d+56>>2],B(f,(b>>>14&2)+50|0)|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break g}if(!e){break F}u[a+480190>>1]=f;g=a+480190|0;h=d+130|0;j=(b|0)>=0;b=1;G:{H:{I:{J:{while(1){if(f>>>0<(b&65535)>>>0){v[23588]=0;b=S(271,d+48|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){break G}break g}K:{if(j){p=b}else{v[23588]=0;e=S(271,d+48|0)|0;m=v[23588];v[23588]=0;if((m|0)==1){break K}p=e+1|0}u[d+16>>1]=p;v[23588]=0;R(343,d+48|0,d+112|0);e=v[23588];v[23588]=0;if((e|0)==1){break J}e=x[d+16>>1];if((e-4e3&65535)>>>0>=61537){G=a,H=x[ke(g,d+16|0)>>1],u[G+480190>>1]=H;m=x[d+234>>1]|x[d+236>>1]<<16;v[23588]=0;X(344,d+112|0,(B(e,104)+a|0)+484380|0,bc(m)|0,o|0);e=v[23588];v[23588]=0;if((e|0)==1){break I}e=d+32|0;Hl(e,2,h);v[23588]=0;R(222,d+176|0,e|0);e=v[23588];v[23588]=0;if((e|0)==1){break H}e=d+176|0;Cc(((x[d+16>>1]<<5)+a|0)+946304|0,e);yb(e)}b=b+1|0;continue}break}e=P()|0;O()|0;break f}e=P()|0;O()|0;break f}e=P()|0;O()|0;break f}e=P()|0;O()|0;break f}if((b|0)!=4){break E}u[d+112>>1]=x[a+480190>>1];u[d+176>>1]=255;h=a+480192|0;b=d+176|0;G=h,H=x[Vc(d+112|0,b)>>1],u[G>>1]=H;v[23588]=0;U(339,b|0,d+200|0,1229278806);b=v[23588];v[23588]=0;if((b|0)==1){break j}L:{M:while(1){v[23588]=0;b=W(156,v[d+48>>2],v[d+56>>2],15)|0;e=v[23588];v[23588]=0;if((e|0)==1){break L}if(b){v[23588]=0;R(345,d+48|0,d+32|0);b=v[23588];v[23588]=0;if((b|0)==1){break k}b=Hb(x[d+32>>1]);if(b>>>0>=x[h>>1]){continue}e=B(b,104)+a|0;t[e+484524|0]=w[d+40|0];f=w[d+39|0];t[e+484523|0]=255;t[e+484525|0]=f;v[23588]=0;b=b+1&65535;e=W(251,a|0,b|0,b|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break k}if(!e){continue}G=d,H=Hb(w[d+37|0]|w[d+38|0]<<8),u[G+112>>1]=H;u[d+16>>1]=4095;G=e,H=x[Vc(d+112|0,d+16|0)>>1],v[G>>2]=H;b=w[d+35|0];if((b|0)==255){continue}v[23588]=0;b=Q(155,d+176|0,B(b,34)+2|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break k}if(!b){continue}v[23588]=0;R(346,d+176|0,d+112|0);b=v[23588];v[23588]=0;if((b|0)==1){break k}t[e+60|0]=w[e+60|0]|1;b=x[d+112>>1];v[d+20>>2]=16;v[d+24>>2]=240;G=d,H=Hb(b),v[G+16>>2]=H;b=JB(d+16|0);v[23588]=0;R(291,e+48|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break k}g=v[e+52>>2];f=v[e+48>>2];b=0;while(1){j=_d(f,g);if(j>>>0<=b>>>0){b=w[d+36|0];if((b|0)!=255){t[e- -64|0]=b;t[e+63|0]=b;t[e+60|0]=w[e+60|0]|4}if(oc(f,g)){continue M}b=j-1|0;t[e+62|0]=b;t[e+61|0]=b;t[e+60|0]=w[e+60|0]|2;continue M}else{t[d+16|0]=64;j=(d+112|0)+(b<<1)|0;t[d+12|0]=w[j+2|0];m=Wb(d+16|0,d+12|0);i=Db(f,b);t[i+2|0]=w[m|0];u[i>>1]=w[j+3|0];b=b+1|0;continue}}}break}Ab(d+176|0);break D}break k}Ab(d+48|0);break p}}}Ab(d+48|0);v[23588]=0;U(347,d+176|0,d+200|0,1145131092);b=v[23588];v[23588]=0;if((b|0)==1){break m}G=d,H=Eb(v[d+176>>2]),v[G+16>>2]=H;m=a+484344|0;A=c&1;q=d+48|4;C=Eb(v[d+180>>2]);r=(o|0)!=841887798;s=a+480188|0;D=(o|0)!=841887796;while(1){N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{g=v[d+16>>2];if(!Ob(g,C)){Uc(d+176|0);v[23588]=0;U(339,d+112|0,d+200|0,1346458702);b=v[23588];v[23588]=0;if((b|0)!=1){break _}e=P()|0;O()|0;break b}v[23588]=0;Q(188,g|0,4)|0;b=v[23588];v[23588]=0;if((b|0)!=1){v[23588]=0;i=S(271,g|0)|0;b=v[23588];v[23588]=0;$:{if((b|0)!=1){v[23588]=0;j=S(271,g|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break P}j=r?j:(j>>>0)/y[a+480196>>2]|0;if(!A|i>>>0>255){break N}v[23588]=0;b=W(226,m|0,i|0,j|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break P}if(b){break $}break N}e=P()|0;O()|0;break O}if(!r){h=0;v[23588]=0;Q(188,g|0,4)|0;b=v[23588];v[23588]=0;if((b|0)==1){break P}while(1){z=h&65535;if(z>>>0>=x[s>>1]){break N}v[23588]=0;b=S(271,g|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break Z}v[23588]=0;U(190,d+48|0,g|0,b+(b&1)&65535);b=v[23588];v[23588]=0;if((b|0)==1){break Q}b=d+48|0;f=jc(d+112|0,b);Ab(b);v[d+48>>2]=0;v[d+52>>2]=0;e=0;aa:{while(1){b=v[f>>2];v[23588]=0;b=W(156,b|0,v[d+120>>2],6)|0;k=v[23588];v[23588]=0;if((k|0)==1){break aa}k=v[d+48>>2];if(b&k>>>0<j>>>0){b=Yb(v[m>>2],i);b=id(v[b>>2],v[v[b+48>>2]+12>>2],k,z);v[23588]=0;R(348,d+32|0,f|0);k=v[23588];v[23588]=0;ba:{ca:{if((k|0)!=1){k=d+32|0;l=Nc(k);E=Se(k);F=Li(k);p=ic(k);n=t[d+32|0];if((n-1&255)>>>0>95){break ca}t[b|0]=n+13;if(!v[d+52>>2]){break ba}t[b+3|0]=19;v[d+12>>2]=15;G=b,H=w[sd(q,d+12|0)|0]|208,t[G+5|0]=H;break ba}break R}if((n|0)>=0){break ba}if(v[d+52>>2]){t[b+3|0]=19;v[d+12>>2]=15;G=b,H=w[sd(q,d+12|0)|0]|192,t[G+5|0]=H;break ba}t[b|0]=254}if(w[l|0]){t[b+2|0]=1;t[d+12|0]=64;G=b,H=w[Wb(l,d+12|0)|0],t[G+4|0]=H}l=w[E|0];if(l){t[b+1|0]=l}l=w[F|0];n=w[p|0];if(l|n){Of(b,l,n)}l=d+48|0;b=w[k+5|0];if(b&128){v[23588]=0;k=S(206,f|0)|0;n=v[23588];v[23588]=0;if((n|0)==1){break R}b=k|b<<8&32512}e=b+e|0;yB(l,e,v[a+480196>>2]);continue}break}Ab(f);h=h+1|0;continue}break}break R}h=0;b=Yb(v[m>>2],i);b=id(v[b>>2],v[v[b+48>>2]+12>>2],0,0);da:while(1){f=0;if((h|0)==(j|0)){break N}while(1){if(x[s>>1]<=(f&65535)>>>0){h=h+1|0;continue da}v[23588]=0;R(349,d+48|0,g|0);e=v[23588];v[23588]=0;if((e|0)!=1){t[d+12|0]=0;ea:{if(!D){e=v[d+48>>2];v[d+112>>2]=e;i=d+112|0;k=Nc(i);l=Se(i);n=Li(i);if(e<<24>>24>0){t[b|0]=(B((e&240)>>>4|0,12)+(e&15)|0)+12}e=w[k|0];if(e>>>0>=4){t[b+2|0]=1;t[b+4|0]=(e>>>2|0)-1;e=w[k|0]}t[b+1|0]=e<<4&48|w[l|0]>>>4;i=w[l|0]&15;t[d+12|0]=i;e=w[n|0];t[b+5|0]=e;break ea}e=v[d+48>>2];v[d+8>>2]=e;v[d+4>>2]=e;e=d+32|0;xu(e,d+4|0,b);i=d+112|0;qB(i,d+12|0,b+5|0);pB(i,e);G=b,H=w[b+1|0]|w[Kb(d+48|0,0)|0]&48,t[G+1|0]=H;e=w[b+5|0];i=w[d+12|0]}Of(b,i,e&255);e=w[b+3|0];fa:{if(e>>>0>11){break fa}e=1<<e;ga:{if(!(e&2240)){if(!(e&12)){break fa}if(!w[b+5|0]){break ga}break fa}e=w[b+5|0];i=e&240;if(i){t[b+5|0]=i;break fa}if(e){break fa}}t[b+3|0]=0}b=b+6|0;f=f+1|0;continue}break}break}e=P()|0;O()|0;break O}e=P()|0;O()|0;break O}v[23588]=0;b=S(275,v[d+112>>2])|0;e=v[23588];v[23588]=0;ha:{ia:{ja:{ka:{la:{if((e|0)!=1){if(b){f=Lb(d+48|0);e=a+484348|0;b=0;ma:{while(1){na:{v[23588]=0;g=W(156,v[d+112>>2],v[d+120>>2],1)|0;h=v[23588];v[23588]=0;if((h|0)==1){break na}if(!g){break ma}if(Af(v[a+484344>>2],v[e>>2])>>>0<=b>>>0){break ma}v[23588]=0;U(350,d+112|0,f|0,32);g=v[23588];v[23588]=0;if((g|0)==1){break na}g=v[m>>2];v[23588]=0;R(281,Yb(g,b)|0,f|0);g=v[23588];v[23588]=0;if((g|0)==1){break na}b=b+1|0;continue}break}e=P()|0;O()|0;yb(f);break la}yb(f)}b=d+112|0;Ab(b);v[23588]=0;U(339,b|0,d+200|0,1414679374);b=v[23588];v[23588]=0;if((b|0)==1){break ka}v[23588]=0;b=S(275,v[d+112>>2])|0;e=v[23588];v[23588]=0;if((e|0)==1){break T}if(!b){break ha}f=Lb(d+48|0);e=a+480188|0;b=0;while(1){v[23588]=0;g=W(156,v[d+112>>2],v[d+120>>2],1)|0;h=v[23588];v[23588]=0;if((h|0)==1){break ja}if(!(g&x[e>>1]>b>>>0)){break ia}v[23588]=0;U(350,d+112|0,f|0,32);g=v[23588];v[23588]=0;if((g|0)==1){break ja}Gl(((b<<5)+a|0)+480289|0,f);b=b+1|0;continue}}e=P()|0;O()|0}Ab(d+112|0);break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;yb(f);break S}yb(f)}b=d+112|0;Ab(b);v[23588]=0;U(347,b|0,d+200|0,1145129300);b=v[23588];v[23588]=0;if((b|0)==1){break U}G=d,H=Eb(v[d+112>>2]),v[G+48>>2]=H;e=c&2;f=Eb(v[d+116>>2]);g=a+480190|0;oa:{pa:{qa:{ra:{sa:{ta:{while(1){b=v[d+48>>2];if(!Ob(b,f)){Uc(d+112|0);b=Lb(d+48|0);if((o|0)!=841887798){break sa}v[23588]=0;c=Q(1,d+112|0,9450)|0;e=v[23588];v[23588]=0;if((e|0)==1){break ta}Ib(b,c);zb(c);break ra}v[23588]=0;c=S(271,b|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break V}ua:{if(!(!e|c>>>0>=x[g>>1])){c=B(c,104)+a|0;h=x[c+484518>>1];h=Zc(d+176|0,h&1?16:8,h&64?2:1,1,0);v[23588]=0;W(219,h|0,c+484484|0,b|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break ua}}Mf(d+48|0);continue}break}break V}e=P()|0;O()|0;break W}v[23588]=0;U(339,d+112|0,d+200|0,1447383635);c=v[23588];v[23588]=0;va:{wa:{xa:{ya:{za:{if((c|0)!=1){v[23588]=0;c=S(275,v[d+112>>2])|0;e=v[23588];v[23588]=0;if((e|0)==1){break qa}if(!c){break wa}v[23588]=0;c=S(279,d+112|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break za}v[23588]=0;R(266,d+32|0,4295);e=v[23588];v[23588]=0;if((e|0)==1){break ya}v[d+16>>2]=c>>>4;v[23588]=0;v[d+12>>2]=c&15;X(351,d+176|0,d+32|0,d+16|0,d+12|0);c=v[23588];v[23588]=0;if((c|0)==1){break xa}c=d+176|0;Ib(b,c);zb(c);ac(d+32|0);break va}e=P()|0;O()|0;break W}e=P()|0;O()|0;break X}e=P()|0;O()|0;break X}e=P()|0;O()|0;ac(d+32|0);break X}v[23588]=0;c=Q(1,d+176|0,8469)|0;e=v[23588];v[23588]=0;if((e|0)==1){break Y}Ib(b,c);zb(c)}Ab(d+112|0)}v[23588]=0;c=Q(1,d+32|0,8469)|0;e=v[23588];v[23588]=0;if((e|0)==1){break pa}Ib(a+1298344|0,c);zb(c);v[23588]=0;c=Q(1,d+16|0,10083)|0;e=v[23588];v[23588]=0;if((e|0)==1){break oa}Ib(a+1298356|0,c);zb(c);Ib(a+1298368|0,b);v[a+1298404>>2]=14;zb(b);f=1;break o}e=P()|0;O()|0;break X}e=P()|0;O()|0;break W}e=P()|0;O()|0;break W}e=P()|0;O()|0;break O}e=P()|0;O()|0}Ab(d+112|0)}zb(b);break b}e=P()|0;O()|0;Uc(d+112|0);break b}e=P()|0;O()|0;break b}e=P()|0;O()|0}Ab(d+112|0);break b}e=P()|0;O()|0;Ab(f);break O}e=P()|0;O()|0;break O}e=P()|0;O()|0}Uc(d+176|0);break b}Mf(d+16|0);continue}}f=0}Yd(d+200|0)}jb=d+240|0;return f|0}e=P()|0;O()|0;break b}e=P()|0;O()|0;break f}e=P()|0;O()|0;Ab(d+176|0);break f}e=P()|0;O()|0;break f}e=P()|0;O()|0;break f}e=P()|0;O()|0;break b}e=P()|0;O()|0}Ab(d+48|0);break b}e=P()|0;O()|0;Ab(d+112|0);break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;Ab(d+176|0)}Yd(d+200|0)}T(e|0);L()}function IV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;d=jb-464|0;jb=d;yc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{if(!ci(b,d+456|0)){break F}if(!OB(d+456|0)){break F}if(!c){p=1;break F}q=je(d+432|0,b);v[23588]=0;R(261,d+416|0,q|0);b=v[23588];v[23588]=0;G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{if((b|0)!=1){v[23588]=0;U(262,d+240|0,d+416|0,1229866575);b=v[23588];v[23588]=0;if((b|0)==1){break da}v[23588]=0;p=Q(263,d+240|0,d+400|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break fa}Ab(d+240|0);if(!p){break G}v[23588]=0;R(246,a|0,524288);b=v[23588];v[23588]=0;ga:{if((b|0)==1){break ga}$f(a);v[a+480208>>2]=12;H=a+480188|0,I=Cd(Hb(x[d+408>>1]),1,127),u[H>>1]=I;H=d,I=Hb(x[d+400>>1]),u[H+240>>1]=I;u[d+344>>1]=255;H=a+480192|0,I=x[Vc(d+240|0,d+344|0)>>1],u[H>>1]=I;H=d,I=Hb(x[d+402>>1]),u[H+240>>1]=I;u[d+344>>1]=3999;H=a+480190|0,I=x[Vc(d+240|0,d+344|0)>>1],u[H>>1]=I;v[23588]=0;b=W(264,a+1074312|0,6,1)|0;e=v[23588];v[23588]=0;if((e|0)==1){break ga}v[23588]=0;b=Q(265,b|0,21)|0;e=v[23588];v[23588]=0;if((e|0)==1){break ga}v[23588]=0;Q(265,b|0,13)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break ea}}b=P()|0;O()|0;break b}b=P()|0;O()|0;break a}b=P()|0;O()|0;Ab(d+240|0);break b}v[23588]=0;b=Q(1,d+384|0,9242)|0;e=v[23588];v[23588]=0;if((e|0)==1){break c}Ib(a+1298344|0,b);zb(b);v[23588]=0;b=Q(1,d+368|0,10267)|0;e=v[23588];v[23588]=0;if((e|0)==1){break d}Ib(a+1298356|0,b);zb(b);v[23588]=0;R(266,d+344|0,4339);b=v[23588];v[23588]=0;if((b|0)==1){break e}v[23588]=0;R(267,d+320|0,d+456|4);b=v[23588];v[23588]=0;if((b|0)==1){break g}v[23588]=0;R(267,d+296|0,d+456|5);b=v[23588];v[23588]=0;if((b|0)==1){break i}v[23588]=0;X(111,d+240|0,d+344|0,d+320|0,d+296|0);b=v[23588];v[23588]=0;if((b|0)==1){break j}b=d+240|0;Ib(a+1298368|0,b);zb(b);zb(d+296|0);zb(d+320|0);b=d+344|0;ac(b);v[a+1298404>>2]=14;v[23588]=0;U(262,b|0,d+416|0,1312902469);b=v[23588];v[23588]=0;if((b|0)==1){break k}v[23588]=0;b=S(160,v[d+344>>2])|0;e=v[23588];v[23588]=0;if((e|0)==1){break m}v[23588]=0;g=a+1298308|0;U(268,d+344|0,g|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break m}v[23588]=0;U(262,d+320|0,d+416|0,1397706311);b=v[23588];v[23588]=0;if((b|0)==1){break n}h=a+484360|0;e=a+484376|0;Kc(Vb(v[h>>2],w[e|0]));k=Hb(x[d+404>>1]);ha:{ia:{while(1){if(k>>>0<=(f&65535)>>>0){break ha}v[23588]=0;b=W(156,v[d+320>>2],v[d+328>>2],46)|0;j=v[23588];v[23588]=0;ja:{if((j|0)!=1){if(!b){break ha}v[23588]=0;R(269,d+320|0,d+240|0);b=v[23588];v[23588]=0;if((b|0)!=1){if(!Qe(g)){break ja}v[23588]=0;R(270,g|0,d+240|0);b=v[23588];v[23588]=0;if((b|0)!=1){break ja}}b=P()|0;O()|0;break o}b=P()|0;O()|0;break o}v[23588]=0;j=S(271,d+320|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break ca}b=Vb(v[a+484360>>2],w[e|0]);if(!oc(v[b>>2],v[b+4>>2])){v[23588]=0;b=S(272,h|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break ca}if((b|0)==255){break ha}b=Vb(v[a+484360>>2],w[e|0])}v[23588]=0;U(5,d+296|0,14,d+240|0);i=v[23588];v[23588]=0;if((i|0)!=1){v[23588]=0;R(273,b|0,d+296|0);b=v[23588];v[23588]=0;if((b|0)==1){break ia}zb(d+296|0);b=w[e|0];i=v[a+484360>>2];v[23588]=0;U(274,Vb(i,b)|0,d+320|0,j|0);b=v[23588];v[23588]=0;if((b|0)==1){break ca}f=f+1|0;continue}break}b=P()|0;O()|0;break o}b=P()|0;O()|0;zb(d+296|0);break o}Fj(h,0);v[23588]=0;U(262,d+296|0,d+416|0,1229869908);b=v[23588];v[23588]=0;if((b|0)==1){break ba}v[23588]=0;b=S(275,v[d+296>>2])|0;f=v[23588];v[23588]=0;if((f|0)==1){break p}ka:{if(!b){break ka}g=a+480192|0;f=1;la:{while(1){b=f&65535;if(b>>>0>x[g>>1]){v[23588]=0;U(262,d+216|0,d+416|0,1447382614);b=v[23588];v[23588]=0;if((b|0)!=1){break la}break p}v[23588]=0;R(276,d+296|0,d+240|0);e=v[23588];v[23588]=0;if((e|0)==1){break p}e=x[d+270>>1];v[23588]=0;b=W(251,a|0,b|0,Hb(e)|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break p}ma:{na:{if(!b){break na}if(Hb(x[d+270>>1])>>>0>3999){break na}e=d+128|0;LB(e,2,d+240|0);v[23588]=0;R(222,d+152|0,e|0);e=v[23588];v[23588]=0;if((e|0)==1){break ma}e=d+152|0;Cc(b+492|0,e);yb(e);h=d+128|0;LB(h,2,d+240|0);v[23588]=0;R(222,e|0,h|0);e=v[23588];v[23588]=0;if((e|0)==1){break p}e=d+152|0;Cc(((Hb(x[d+270>>1])<<5)+a|0)+946304|0,e);yb(e);v[b>>2]=0;H=b,I=pe(u[d+286>>1])+128&65535,v[H+8>>2]=I;wc(b+8|0,256);t[b+15|0]=w[b+15|0]|1;b=x[d+270>>1];v[23588]=0;b=B(Hb(b),104)+a|0;R(277,b+484380|0,0);e=v[23588];v[23588]=0;if((e|0)==1){break p}H=d,I=Hb(x[d+272>>1]),u[H+152>>1]=I;u[d+128>>1]=64;H=b+484410|0,I=x[Vc(d+152|0,d+128|0)>>1]<<2,u[H>>1]=I;H=b+484404|0,I=bc(x[d+274>>1]|x[d+276>>1]<<16),v[H>>2]=I;e=bc(x[d+282>>1]|x[d+284>>1]<<16);if(!e){break na}h=Hb(x[d+288>>1]);if(!(h&3)){break na}k=e;e=bc(x[d+278>>1]|x[d+280>>1]<<16);v[b+484388>>2]=k+e;v[b+484384>>2]=e;b=b+484414|0;e=x[b>>1];u[b>>1]=e|2;if(!(h&2)){break na}u[b>>1]=e|6}f=f+1|0;continue}break}break p}b=v[d+228>>2];v[d+32>>2]=v[d+224>>2];v[d+36>>2]=b;v[d+40>>2]=v[d+232>>2];v[23588]=0;b=v[d+220>>2];v[d+24>>2]=v[d+216>>2];v[d+28>>2]=b;X(278,d+24|0,0,a|0,0);b=v[23588];v[23588]=0;if((b|0)==1){break p}v[23588]=0;U(262,d+192|0,d+416|0,1346719318);b=v[23588];v[23588]=0;if((b|0)==1){break p}b=v[d+204>>2];v[d+8>>2]=v[d+200>>2];v[d+12>>2]=b;v[d+16>>2]=v[d+208>>2];v[23588]=0;b=v[d+196>>2];v[d>>2]=v[d+192>>2];v[d+4>>2]=b;X(278,d|0,1,a|0,w[d+460|0]>2|0);b=v[23588];v[23588]=0;if((b|0)==1){break p}e=x[a+480192>>1]+1&65535;b=1;while(1){if((b|0)==(e|0)){break ka}f=v[((b<<2)+a|0)+900380>>2];if(!(!f|t[f+60|0]&1)){v[f>>2]=32767}b=b+1|0;continue}}Ab(d+296|0);v[23588]=0;U(262,d+240|0,d+416|0,1346458708);b=v[23588];v[23588]=0;if((b|0)==1){break q}v[23588]=0;b=S(178,v[d+240>>2])|0;f=v[23588];v[23588]=0;if((f|0)==1){break s}if(!(!(c&1)|b^1)){v[23588]=0;U(262,d+296|0,d+416|0,1347305805);b=v[23588];v[23588]=0;if((b|0)==1){break t}v[23588]=0;Q(188,d+296|0,1)|0;b=v[23588];v[23588]=0;if((b|0)==1){break v}b=x[d+406>>1];v[23588]=0;m=a+484344|0;R(225,m|0,Hb(b)|0);b=v[23588];v[23588]=0;if((b|0)==1){break v}b=d+128|0;A=b|3;C=b|1;i=Sb(d+176|0);D=a+480188|0;h=0;while(1){if(Hb(x[d+406>>1])>>>0<=l>>>0){nd(i);e=h;Ab(d+296|0);if(!(c&4)){break $}f=0;if(!E){break aa}g=x[a+480188>>1];b=0;f=1;while(1){if((b|0)==(g|0)){break aa}h=(b<<5)+a|0;t[h+480288|0]=1;h=h+480280|0;v[h>>2]=v[h>>2]|67108864;b=b+1|0;continue}}v[23588]=0;b=S(271,d+240|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break x}v[23588]=0;f=S(279,d+240|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break y}v[23588]=0;U(190,d+128|0,d+240|0,f|0);f=v[23588];v[23588]=0;if((f|0)==1){break z}f=d+128|0;j=jc(d+152|0,f);Ab(f);v[23588]=0;f=W(226,m|0,l&65535,b|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break B}oa:{if(f){o=Lb(d+112|0);v[23588]=0;R(280,d+296|0,o|0);f=v[23588];v[23588]=0;if((f|0)==1){break oa}f=v[m>>2];v[23588]=0;R(281,Yb(f,l)|0,o|0);f=v[23588];v[23588]=0;if((f|0)==1){break oa}n=0;f=Yb(v[m>>2],l);y=Cf(v[f>>2],v[v[f+48>>2]+12>>2],0);Kc(i);F=(b>>>0>1?b:1)-1|0;pa:while(1){b=v[j>>2];v[23588]=0;b=W(156,b|0,v[d+160>>2],1)|0;f=v[23588];v[23588]=0;if((f|0)==1){break C}qa:{if(!b){break qa}v[23588]=0;f=S(206,j|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break C}if(!f){H=d,I=Eb(v[i>>2]),v[H+104>>2]=I;f=Eb(v[i+4>>2]);while(1){b=v[d+104>>2];if(Ob(b,f)){ze(Yb(v[m>>2],l),Te(Ne(d+128|0,w[b|0],w[b+1|0]),n));Re(d+104|0);continue}else{Kc(i);if((n|0)==(F|0)){break qa}b=Yb(v[m>>2],l);n=n+1|0;y=Cf(v[b>>2],v[v[b+48>>2]+12>>2],n);continue pa}}}Ej(d+128|0);e=x[D>>1];v[23588]=0;b=S(206,j|0)|0;g=v[23588];v[23588]=0;ra:{sa:{if((g|0)!=1){r=B(f-1|0,6)+y|0;s=e>>>0<f>>>0;k=s?d+128|0:r;ta:{if(!(b&1)){break ta}v[23588]=0;f=S(206,j|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break C}if((f|0)!=31){if((f-1&255)>>>0>252){break ta}e=(B(f>>>4|0,12)+(f&15)|0)+13|0}else{e=255}t[k|0]=e}if(!(b&2)){break ra}v[23588]=0;f=S(206,j|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){break sa}}break C}t[(s?C:r+1|0)|0]=f}if(!(b&60)){continue}f=0;e=0;if(b&4){v[23588]=0;e=S(206,j|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break C}}if(b&8){v[23588]=0;f=S(206,j|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break C}}g=0;z=0;if(b&16){v[23588]=0;z=S(206,j|0)|0;G=v[23588];v[23588]=0;if((G|0)==1){break C}}if(b&32){v[23588]=0;g=S(206,j|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break C}}b=d+104|0;AV(b,z,g);g=Nc(b);b=d+96|0;AV(b,e,f);f=Nc(b);b=w[d+96|0];ua:{if((b|0)!=13){if(b){break ua}b=0;if(w[d+104|0]==13){break ua}}Ii(d+104|0,d+96|0);Ii(g,f);b=w[d+96|0]}Ao(d+88|0,k,w[d+104|0],w[g|0],b&255,w[f|0]);if(zV(w[d+88|0],w[d+89|0])){b=v[ec(d+80|0,Eb(v[i>>2]))>>2];v[23588]=0;U(282,i|0,b|0,d+88|0);b=v[23588];v[23588]=0;if((b|0)==1){break C}}b=w[(s?A:r+3|0)|0];if((b|0)==43){E=1;continue}if((b|0)!=31){continue}h=1;continue}break}yb(o)}Ab(j);l=l+1|0;continue}break}break C}e=0;f=0;if(c&4){break aa}break H}b=P()|0;O()|0;break b}b=P()|0;O()|0;break o}b=P()|0;O()|0;break o}v[d+176>>2]=-1778364416;v[d+180>>2]=-16756736;v[23588]=0;U(262,d+296|0,d+416|0,1146310725);b=v[23588];v[23588]=0;if((b|0)==1){break E}v[23588]=0;b=S(275,v[d+296>>2])|0;g=v[23588];v[23588]=0;if((g|0)==1){break D}if(b){v[23588]=0;k=S(271,d+296|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break D}j=a+480188|0;b=0;g=f;while(1){va:{if((b|0)==(k|0)){v[23588]=0;R(283,d+296|0,d+176|0);b=v[23588];v[23588]=0;if((b|0)!=1){break va}break D}v[23588]=0;h=S(206,d+296|0)|0;i=v[23588];v[23588]=0;wa:{xa:{if((i|0)!=1){if(x[j>>1]<=b>>>0){break wa}if(!f){break xa}i=((b<<5)+a|0)+480280|0;v[i>>2]=v[i>>2]&-67108865|((h|0)!=0)<<26;break wa}break D}if(h){break wa}g=1;t[((b<<5)+a|0)+480288|0]=1}b=b+1|0;continue}break}f=g&1}Ab(d+296|0);if(!f){break $}v[23588]=0;b=Ld(a+906300|0,0);Y(284,b|0);f=v[23588];v[23588]=0;if((f|0)==1){break _}v[b+16>>2]=810369604;v[b+20>>2]=1869112133;v[b+24>>2]=655376;v[b+28>>2]=0;v[d+296>>2]=0;g=b+48|0;wV(b+32|0,g,d+296|0);v[23588]=0;f=Q(55,d+152|0,9516)|0;h=v[23588];v[23588]=0;if((h|0)==1){break Z}KB(g,f);yb(f);v[23588]=0;f=Q(55,d+128|0,9480)|0;g=v[23588];v[23588]=0;if((g|0)==1){break Y}Ku(b+80|0,f);yb(f);v[23588]=0;R(285,b+4|0,8);f=v[23588];v[23588]=0;if((f|0)==1){break _}vV(d+296|0,w[d+177|0],w[d+179|0],w[d+181|0],w[d+183|0]);f=v[d+300>>2];b=v[b+4>>2];g=v[d+296>>2];t[b|0]=g;t[b+1|0]=g>>>8;t[b+2|0]=g>>>16;t[b+3|0]=g>>>24;t[b+4|0]=f;t[b+5|0]=f>>>8;t[b+6|0]=f>>>16;t[b+7|0]=f>>>24}if(!e){break H}f=a+902204|0;b=0;while(1){if((b|0)==32){break H}v[d+104>>2]=B(b,127)>>>5;v[23588]=0;R(286,d+176|0,4096);e=v[23588];v[23588]=0;if((e|0)==1){break X}v[23588]=0;R(287,d+112|0,d+104|0);e=v[23588];v[23588]=0;if((e|0)==1){break W}v[23588]=0;U(288,d+296|0,d+176|0,d+112|0);e=v[23588];v[23588]=0;if((e|0)==1){break V}e=d+296|0;Fe(d+72|0,e);gf(ye(f,b),v[d+72>>2],v[d+76>>2]);yb(e);yb(d+112|0);e=d+176|0;_b(e);v[23588]=0;R(286,e|0,4078);e=v[23588];v[23588]=0;if((e|0)==1){break T}v[23588]=0;R(287,d+112|0,d+104|0);e=v[23588];v[23588]=0;if((e|0)==1){break S}v[23588]=0;U(288,d+296|0,d+176|0,d+112|0);e=v[23588];v[23588]=0;if((e|0)==1){break R}e=d+296|0;Fe(d- -64|0,e);gf(ye(f,b+32|0),v[d+64>>2],v[d+68>>2]);yb(e);yb(d+112|0);e=d+176|0;_b(e);v[23588]=0;R(286,e|0,4069);e=v[23588];v[23588]=0;if((e|0)==1){break P}v[23588]=0;R(287,d+112|0,d+104|0);e=v[23588];v[23588]=0;if((e|0)==1){break O}v[23588]=0;U(288,d+296|0,d+176|0,d+112|0);e=v[23588];v[23588]=0;if((e|0)==1){break N}e=d+296|0;Fe(d+56|0,e);gf(ye(f,b- -64|0),v[d+56>>2],v[d+60>>2]);yb(e);yb(d+112|0);e=d+176|0;_b(e);v[23588]=0;R(286,e|0,4042);e=v[23588];v[23588]=0;if((e|0)==1){break L}v[23588]=0;R(287,d+112|0,d+104|0);e=v[23588];v[23588]=0;if((e|0)==1){break K}v[23588]=0;U(288,d+296|0,d+176|0,d+112|0);e=v[23588];v[23588]=0;if((e|0)==1){break J}e=d+296|0;Fe(d+48|0,e);gf(ye(f,b+96|0),v[d+48>>2],v[d+52>>2]);b=b+1|0;yb(e);yb(d+112|0);_b(d+176|0);continue}}b=P()|0;O()|0;break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;break U}b=P()|0;O()|0;yb(d+112|0)}_b(d+176|0);break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;break Q}b=P()|0;O()|0;yb(d+112|0)}_b(d+176|0);break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;break M}b=P()|0;O()|0;yb(d+112|0)}_b(d+176|0);break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;break I}b=P()|0;O()|0;yb(d+112|0)}_b(d+176|0);break r}v[23588]=0;U(262,d+296|0,d+416|0,1397575756);b=v[23588];v[23588]=0;ya:{if((b|0)!=1){v[23588]=0;b=S(178,v[d+296>>2])|0;f=v[23588];v[23588]=0;if((f|0)!=1){za:{f=1;if(!(c&2)|b^1){break ya}c=a+480190|0;while(1){e=f&65535;if(e>>>0>x[c>>1]){break ya}v[23588]=0;b=S(279,d+296|0)|0;g=v[23588];v[23588]=0;Aa:{if((g|0)!=1){v[23588]=0;g=S(279,d+296|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break za}if(!(b&7)){break Aa}e=(B(e,104)+a|0)+484380|0;v[e>>2]=g;b=Zc(d+176|0,b&4?32:b&2?16:8,1,1,0);v[23588]=0;W(219,b|0,e|0,d+296|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break Aa}break za}break za}f=f+1|0;continue}}}b=P()|0;O()|0;Ab(d+296|0);break r}b=P()|0;O()|0;break r}Ab(d+296|0);Ab(d+240|0);Ab(d+320|0);Ab(d+344|0)}Yd(d+416|0);Ab(q)}jb=d+464|0;return p|0}b=P()|0;O()|0;break r}b=P()|0;O()|0;Ab(d+296|0);break r}b=P()|0;O()|0;yb(o);break A}b=P()|0;O()|0}Ab(j);break w}b=P()|0;O()|0;break w}b=P()|0;O()|0;break w}b=P()|0;O()|0}nd(i);break u}b=P()|0;O()|0}Ab(d+296|0);break r}b=P()|0;O()|0;break r}b=P()|0;O()|0}Ab(d+240|0);break o}b=P()|0;O()|0;break o}b=P()|0;O()|0;Ab(d+296|0)}Ab(d+320|0);break l}b=P()|0;O()|0;break l}b=P()|0;O()|0}Ab(d+344|0);break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;zb(d+296|0);break h}b=P()|0;O()|0}zb(d+320|0);break f}b=P()|0;O()|0}ac(d+344|0);break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0}Yd(d+416|0)}Ab(q);T(b|0);L()}function jfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,V=0,X=0;f=jb-496|0;jb=f;yc(b);i=jb-16|0;jb=i;g=f+288|0;LQ(i+8|0,g);e=v[i+12>>2];n=b;mc(i,v[b>>2],v[b+8>>2],v[i+8>>2],v[i+12>>2]);b=v[i+4>>2];if((b|0)==(e|0)){Zb(n,v[i+12>>2])}jb=i+16|0;b=(b|0)==(e|0);if(!b){KQ(g)}a:{if(!b){break a}if(!MQ(f+288|0)){break a}if(!c){d=1;break a}Ad(a,134217728);b=f+8|0;Rf(b,3956);v[23588]=0;U(674,f+120|0,b|0,x[f+292>>1]);b=v[23588];v[23588]=0;b:{c:{d:{e:{f:{g:{if((b|0)!=1){b=f+120|0;Ib(a+1298344|0,b);zb(b);ac(f+8|0);b=xc(b,8934);Ib(a+1298356|0,b);zb(b);v[a+480188>>2]=4;v[a+1298404>>2]=14;V=a,X=Hb(x[f+424>>1]),v[V+480196>>2]=X;b=x[f+428>>1];v[a+480260>>2]=56;v[a+480264>>2]=13696;V=a,X=JQ(Hb(b)),v[V+480204>>2]=X;Hq(Vb(v[a+484360>>2],w[a+484376|0]),f+296|0,w[f+294|0]);q=a+480190|0;m=a+480188|0;o=Sb(f+272|0);z=Sb(f+256|0);h:{i:{j:{k:{l:{while(1){if(Hb(x[f+488>>1])>>>0<=(l&65535)>>>0){break k}v[23588]=0;b=S(271,n|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break g}u[f+232>>1]=b;if((b-4e3&65535)>>>0<=61536){break c}d=Hb(x[f+490>>1]);if((Hb(x[f+292>>1])|0)==2){v[23588]=0;b=S(279,n|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break h}d=b-2|0}v[23588]=0;U(190,f+8|0,n|0,d|0);b=v[23588];v[23588]=0;if((b|0)==1){break i}b=f+8|0;h=jc(f+120|0,b);Ab(b);C=x[ke(q,f+232|0)>>1];u[q>>1]=C;v[23588]=0;j=B(x[f+232>>1],104)+a|0;e=j+484380|0;R(277,e|0,1);b=v[23588];v[23588]=0;m:{n:{o:{if((b|0)==1){break o}if(Hb(x[f+292>>1])>>>0>1){break n}v[23588]=0;R(675,h|0,j+484423|0);b=v[23588];v[23588]=0;if((b|0)==1){break o}v[23588]=0;Q(188,h|0,1)|0;b=v[23588];v[23588]=0;if((b|0)==1){break o}v[23588]=0;U(325,h|0,((x[f+232>>1]<<5)+a|0)+946304|0,30);b=v[23588];v[23588]=0;if((b|0)!=1){break m}}e=P()|0;O()|0;break f}b=Lb(f+8|0);v[23588]=0;U(350,h|0,b|0,257);i=v[23588];v[23588]=0;p:{q:{if((i|0)==1){break q}Be(j+484423|0,b);v[23588]=0;Q(188,h|0,1)|0;i=v[23588];v[23588]=0;if((i|0)==1){break q}v[23588]=0;U(350,h|0,b|0,31);i=v[23588];v[23588]=0;if((i|0)==1){break q}Cc(((x[f+232>>1]<<5)+a|0)+946304|0,b);if(!(t[f+128|0]&1)){break p}v[23588]=0;Q(188,h|0,1)|0;i=v[23588];v[23588]=0;if((i|0)!=1){break p}}e=P()|0;O()|0;yb(b);break f}yb(b)}v[23588]=0;R(676,h|0,f+8|0);b=v[23588];v[23588]=0;if((b|0)==1){break l}d=jb-16|0;jb=d;i=bc(w[f+8|0]|w[f+9|0]<<8|(w[f+10|0]<<16|w[f+11|0]<<24));v[e>>2]=i;t[d+15|0]=w[f+12|0];t[d+14|0]=64;V=e,X=w[Wb(d+15|0,d+14|0)|0]<<2,u[V+30>>1]=X;g=bc(w[f+14|0]|w[f+15|0]<<8|(w[f+16|0]<<16|w[f+17|0]<<24));v[e+4>>2]=g;b=bc(w[f+14|0]|w[f+15|0]<<8|(w[f+16|0]<<16|w[f+17|0]<<24))+bc(w[f+18|0]|w[f+19|0]<<8|(w[f+20|0]<<16|w[f+21|0]<<24))|0;v[e+8>>2]=b;if(g>>>0>=i>>>0){g=i-1|0;v[e+4>>2]=g}if(b>>>0>i>>>0){v[e+8>>2]=i;b=i}r:{if(b>>>0<g>>>0){v[e+4>>2]=0;v[e+8>>2]=0;break r}if(b>>>0<=g>>>0){break r}u[e+34>>1]=x[e+34>>1]|2;V=Db(e+68|0,0),X=g,v[V>>2]=X}jb=d+16|0;s:{t:{u:{switch(Hb(x[f+292>>1])|0){case 2:t[j+484417|0]=w[f+26|0]<<3;break;case 0:break t;default:break u}}v[23588]=0;R(214,z|0,C|0);b=v[23588];v[23588]=0;if((b|0)==1){break l}v[23588]=0;R(677,o|0,C|0);b=v[23588];v[23588]=0;if((b|0)==1){break l}i=Md(v[o>>2],x[f+232>>1]-1|0);Kc(i);v[23588]=0;b=S(271,n|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break j}e=v[n+8>>2];d=v[n>>2];v[23588]=0;e=W(156,d|0,e|0,b<<3)|0;d=v[23588];v[23588]=0;if((d|0)==1){break j}if(!e){break s}v[23588]=0;R(678,i|0,b|0);e=v[23588];v[23588]=0;if((e|0)==1){break j}d=0;v[f+248>>2]=0;if(!(!(w[j+484414|0]&2)|b)){b=v[j+484384>>2];v[f+240>>2]=b;e=v[j+484388>>2];v[23588]=0;v[f+244>>2]=e-b;R(679,i|0,f+240|0);b=v[23588];v[23588]=0;if((b|0)!=1){break t}e=P()|0;O()|0;break f}while(1){if(b>>>0<=(d&65535)>>>0){break t}v[23588]=0;e=S(279,n|0)|0;g=v[23588];v[23588]=0;v:{if((g|0)==1){break v}v[23588]=0;v[f+240>>2]=e;e=S(279,n|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break v}v[23588]=0;v[f+244>>2]=e;R(679,i|0,f+240|0);e=v[23588];v[23588]=0;if((e|0)==1){break v}d=d+1|0;continue}break}e=P()|0;O()|0;break f}Ab(h);l=l+1|0;continue}break}Ab(h);break c}e=P()|0;O()|0;break f}w:{x:{y:{z:{if(Hb(x[f+292>>1])){A=w[f+295|0];u[f+238>>1]=4;D=128;break z}v[23588]=0;D=S(271,n|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){e=P()|0;O()|0;break e}b=x[f+292>>1];A=w[f+295|0];u[f+238>>1]=4;if(!Hb(b)){break y}}i=v[n+8>>2];e=0;while(1){A:{if((e&65535)>>>0>=D>>>0){break A}v[23588]=0;b=S(271,n|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break x}if((b|0)==65535){break A}v[23588]=0;A=S(271,n|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break x}v[23588]=0;b=S(271,n|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break x}u[f+238>>1]=b;if(b>>>0>127){break c}V=m,X=x[ke(m,f+238|0)>>1],u[V>>1]=X;v[23588]=0;Q(188,n|0,B(b,A)<<2)|0;b=v[23588];v[23588]=0;if((b|0)==1){break x}e=e+1|0;continue}break}v[23588]=0;Q(155,n|0,i|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break w}}b=x[m>>1];v[23588]=0;E=Q(680,f+240|0,b|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){J=a+484344|0;N=c&1;F=Hb(x[f+426>>1]);b=0;i=0;while(1){B:{C:{D:{E:{if((b&65535)>>>0>=D>>>0){break E}F:{if(!Hb(x[f+292>>1])){d=x[f+238>>1];e=b;break F}v[23588]=0;e=S(271,n|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break B}if((e|0)==65535){break E}v[23588]=0;A=S(271,n|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break B}v[23588]=0;d=S(271,n|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break B}u[f+238>>1]=d}g=v[n+8>>2];h=v[n>>2];v[23588]=0;r=g;G=A&65535;g=G<<2;d=W(156,h|0,r|0,B(g,d&65535)|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break B}if(!d){break E}if(!N){break D}v[23588]=0;K=e&65535;e=W(226,J|0,K|0,G|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break B}if(!e){break D}s=0;G:while(1){if((s|0)==(G|0)){break C}e=0;d=Yb(v[J>>2],K);j=Cf(v[d>>2],v[v[d+48>>2]+12>>2],s);H=0;r=0;H:{I:{J:{switch((F&3)-1|0){case 0:r=!(s&3);break I;case 1:r=!(s&1);break I;case 2:break J;default:break H}}r=(s&3)!=3}}while(1){if(x[f+238>>1]<=e>>>0){s=s+1|0;continue G}d=v[E>>2];v[23588]=0;R(349,f+232|0,n|0);g=v[23588];v[23588]=0;if((g|0)==1){break B}h=B(e,9)+d|0;d=f+232|0;g=Nc(d);p=Se(d);m=j+B(e,6)|0;t[m+1|0]=w[f+232|0];k=w[g|0];t[m|0]=k;g=w[Li(d)|0];t[m+5|0]=g;l=m+5|0;if(k){t[m|0]=k+25;t[h+8|0]=0;t[h|0]=0;t[h+1|0]=0;t[h+2|0]=0;t[h+3|0]=0;t[h+4|0]=0;t[h+5|0]=0;t[h+6|0]=0;t[h+7|0]=0;g=w[l|0]}k=g&255;p=w[p|0];K:{if(p>>>0>=240){d=k|(p&15)<<8;if(d){V=l,X=sk(+(JQ(d)>>>0)/1e4),t[V|0]=X;t[m+3|0]=17;break K}t[m+3|0]=0;break K}I=k>>>4|0;M=k<<4;d=I|M;L:{switch(p|0){case 0:d=j+B(e,6)|0;if(g&255){t[d+3|0]=1;break K}t[d+3|0]=0;break K;case 1:t[(j+B(e,6)|0)+3|0]=2;break K;case 2:t[(j+B(e,6)|0)+3|0]=3;break K;case 3:t[f+228|0]=15;V=h,X=w[Wb(l,f+228|0)|0]|16,t[V|0]=X;t[h+7|0]=0;t[h+1|0]=0;t[h+2|0]=0;t[(j+B(e,6)|0)+3|0]=0;break K;case 4:t[f+228|0]=15;V=h,X=w[Wb(l,f+228|0)|0]|32,t[V|0]=X;t[h+7|0]=0;t[h+1|0]=0;t[h+2|0]=0;t[(j+B(e,6)|0)+3|0]=0;break K;case 5:t[h+7|0]=0;t[h+2|0]=0;t[h+1|0]=g;t[h|0]=0;t[(j+B(e,6)|0)+3|0]=0;break K;case 6:t[h+7|0]=0;t[h+2|0]=g;t[h|0]=0;t[h+1|0]=0;t[(j+B(e,6)|0)+3|0]=0;break K;case 7:t[(j+B(e,6)|0)+3|0]=23;i=0;break K;case 8:t[(j+B(e,6)|0)+3|0]=0;i=d;break K;case 9:t[(j+B(e,6)|0)+3|0]=19;t[f+228|0]=15;V=l,X=w[Wb(l,f+228|0)|0]|16,t[V|0]=X;break K;case 10:t[(j+B(e,6)|0)+3|0]=19;t[f+228|0]=15;V=l,X=w[Wb(l,f+228|0)|0]|32,t[V|0]=X;break K;case 11:t[h+3|0]=d;t[(j+B(e,6)|0)+3|0]=0;break K;case 12:d=j+B(e,6)|0;t[d+4|0]=g;t[d+2|0]=1;t[h+3|0]=0;t[d+3|0]=0;break K;case 13:p=j+B(e,6)|0;M:{N:{if(k&240){t[(j+B(e,6)|0)+2|0]=4;d=(g&240)>>>4|0;break N}if(!(k&15)){break M}t[(j+B(e,6)|0)+2|0]=3;d=g&15}t[p+4|0]=d}t[h+3|0]=0;t[(j+B(e,6)|0)+3|0]=0;break K;case 14:t[(j+B(e,6)|0)+3|0]=19;t[l|0]=!(g&255);break K;case 15:t[(j+B(e,6)|0)+3|0]=16;t[l|0]=(g&240)>>>4;F=g&15;break K;case 16:t[h+5|0]=0;t[h+4|0]=g;t[(j+B(e,6)|0)+3|0]=0;break K;case 17:t[h+6|0]=k&15?g:0;t[(j+B(e,6)|0)+3|0]=0;break K;case 18:t[(j+B(e,6)|0)+3|0]=14;break K;case 19:t[h+8|0]=0;t[h+7|0]=g;t[h+2|0]=0;t[h|0]=0;t[h+1|0]=0;t[(j+B(e,6)|0)+3|0]=0;break K;case 20:t[(j+B(e,6)|0)+3|0]=12;break K;case 22:d=w[m+1|0];O:{if(!d){break O}k=v[o>>2];if(xd(k,v[o+4>>2])>>>0<d>>>0){break O}g=g-1|0;t[l|0]=g;v[23588]=0;S(681,f+120|0)|0;p=v[23588];v[23588]=0;if((p|0)==1){break B}v[f+228>>2]=9;d=Md(k,d-1|0);V=f,X=xd(v[d>>2],v[d+4>>2]),v[V+116>>2]=X;if(y[Jb(f+228|0,f+116|0)>>2]<=(g&255)>>>0){break O}d=j+B(e,6)|0;t[d+2|0]=15;t[d+4|0]=w[l|0]}t[(j+B(e,6)|0)+3|0]=0;break K;case 23:d=w[m+1|0];P:{if(!d){break P}k=v[o>>2];if(xd(k,v[o+4>>2])>>>0<d>>>0){break P}g=g-1|0;t[l|0]=g;d=Md(k,d-1|0);k=v[d>>2];p=xd(k,v[d+4>>2]);d=g&255;if(p>>>0<=d>>>0){break P}d=Md(k,d);g=x[d+8>>1];Q:{if(g){break Q}g=0;k=x[q>>1];if(!Xh(k)){break Q}g=k+1|0;u[q>>1]=g;u[d+8>>1]=g}t[m+1|0]=g}t[(j+B(e,6)|0)+3|0]=0;break K;case 24:d=w[m+1|0];R:{if(!d){break R}k=v[o>>2];if(xd(k,v[o+4>>2])>>>0<d>>>0){break R}g=g-1|0;t[l|0]=g;v[23588]=0;S(681,f+8|0)|0;p=v[23588];v[23588]=0;if((p|0)==1){break B}v[f+228>>2]=9;d=Md(k,d-1|0);V=f,X=xd(v[d>>2],v[d+4>>2]),v[V+116>>2]=X;if(y[Jb(f+228|0,f+116|0)>>2]>(g&255)>>>0){d=j+B(e,6)|0;t[d+2|0]=15;t[d+4|0]=w[l|0]}d=cc(v[z>>2],w[m+1|0]-1|0);g=x[d>>1];S:{if(g){break S}g=0;k=x[q>>1];if(!Xh(k)){break S}g=k+1|0;u[q>>1]=g;u[d>>1]=g}t[m+1|0]=g}t[(j+B(e,6)|0)+3|0]=0;break K;case 25:d=w[m+1|0];T:{if(!d){break T}k=v[o>>2];if(xd(k,v[o+4>>2])>>>0<d>>>0){break T}g=g-1|0;t[l|0]=g;d=Md(k,d-1|0);k=v[d>>2];p=xd(k,v[d+4>>2]);d=g&255;if(p>>>0<=d>>>0){break T}d=Md(k,d);g=x[d+10>>1];U:{if(g){break U}g=0;k=x[q>>1];if(!Xh(k)){break U}g=k+1|0;u[q>>1]=g;u[d+10>>1]=g}t[m+1|0]=g}t[(j+B(e,6)|0)+3|0]=0;break K;case 29:t[(j+B(e,6)|0)+3|0]=11;t[l|0]=d;if(k&15){t[l|0]=M|15;break K}if((g&255)>>>0<16){break K}t[l|0]=I|240;break K;case 32:if(k&240){t[h+3|0]=I;t[(j+B(e,6)|0)+3|0]=0;break K}t[(j+B(e,6)|0)+3|0]=19;t[l|0]=g&15|192;break K;case 33:t[(j+B(e,6)|0)+3|0]=19;t[f+228|0]=15;V=l,X=w[Wb(l,f+228|0)|0]|208,t[V|0]=X;break K;case 34:t[(j+B(e,6)|0)+3|0]=19;t[f+228|0]=15;V=l,X=w[Wb(l,f+228|0)|0]|144,t[V|0]=X;break K;case 73:t[(j+B(e,6)|0)+3|0]=10;break K;case 78:if((g&112|128)==224){t[(j+B(e,6)|0)+3|0]=19;break K}t[(j+B(e,6)|0)+3|0]=0;break K;case 79:d=j+B(e,6)|0;if((g&255)>>>0<=31){t[d+3|0]=16;F=0;break K}t[d+3|0]=17;break K;default:break L}}t[(j+B(e,6)|0)+3|0]=0}k=0;g=w[h+3|0];if(!(w[m+2|0]|!g)){V:{if(g>>>0>=16){t[m+2|0]=5;g=g>>>4|0;break V}t[m+2|0]=6}t[m+4|0]=g;k=1}W:{if(w[m+3|0]){break W}d=w[h+1|0];X:{if(d){t[m+3|0]=2;break X}d=w[h+2|0];if(d){t[m+3|0]=3;break X}d=w[h|0];if(d){t[m+3|0]=19;break X}d=w[h+7|0];if(d){t[m+3|0]=4;t[h+8|0]=d;break X}d=w[h+4|0];if(d){t[m+3|0]=5;t[h+5|0]=d;break X}d=w[h+3|0];if(!(!d|k)){t[m+3|0]=11;t[l|0]=d;if(d&15){d=d|-16;break X}if(!(d&240)){break W}d=d|15;break X}d=w[h+6|0];if(d){t[m+3|0]=8;break X}if(r){t[m+3|0]=20;r=0;d=97;break X}r=0;if(H){break W}d=i&255;if(!d){break W}t[m+3|0]=24;t[l|0]=i;if(i&15){d=i|-16}else{if(!(d&240)){H=1;break W}d=i|15}H=1}t[l|0]=d}e=e+1|0;continue}}}v[a+480228>>2]=256/x[a+480188>>1];k=1;nh(a,1);if(Hb(x[f+292>>1])){Y:{while(1){b=v[n+8>>2];i=v[n>>2];v[23588]=0;b=W(156,i|0,b|0,2)|0;i=v[23588];v[23588]=0;if((i|0)==1){break B}if(!b){break Y}v[23588]=0;b=S(271,n|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break B}if((b|0)==65535){break Y}v[23588]=0;Q(188,n|0,2)|0;b=v[23588];v[23588]=0;if((b|0)==1){break B}v[23588]=0;b=S(279,n|0)|0;i=v[23588];v[23588]=0;if((i|0)!=1){v[23588]=0;Q(188,n|0,b|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){continue}}break}break B}v[23588]=0;Q(188,n|0,34)|0;b=v[23588];v[23588]=0;if((b|0)==1){break B}}Z:{if(!(c&2)){break Z}while(1){b=k&65535;if(b>>>0>C>>>0){break Z}_:{e=(B(b,104)+a|0)+484380|0;if(!v[e>>2]){break _}c=Zc(f+232|0,8,1,0,0);v[23588]=0;W(219,c|0,e|0,n|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break B}c=v[o>>2];if(xd(c,v[o+4>>2])>>>0<b>>>0){break _}j=b-1|0;g=Md(c,j);c=0;b=0;m=jb-112|0;jb=m;$:{h=v[e>>2];if(!Zd(h,v[e+20>>2])){break $}q=v[g>>2];i=xd(q,v[g+4>>2]);if(i>>>0<2){break $}d=jo(m+8|0,e);v[d+20>>2]=0;v[d>>2]=0;aa:{while(1){if((c|0)==(i|0)){break aa}ba:{l=Md(q,c);s=v[l>>2];if(s>>>0>=h>>>0){break ba}l=v[l+4>>2];if(l>>>0>h-s>>>0|268435456-l>>>0<b>>>0){break ba}b=b+l|0;v[d>>2]=b;c=c+1|0;continue}break}i=c}if(!Ng(d)){break $}l=d+68|0;b=0;c=0;while(1){if((c|0)==(i|0)){Dm(e);b=jo(e,d);v[b+4>>2]=0;v[b+8>>2]=v[b>>2];u[b+34>>1]=x[b+34>>1]|2;break $}r=v[d+20>>2]+b|0;q=v[e+20>>2];h=Md(v[g>>2],c);tc(r,q+v[h>>2]|0,v[h+4>>2]);v[h>>2]=b;if(c-10>>>0>=4294967287){V=Db(l,c-1|0),X=b,v[V>>2]=X}c=c+1|0;b=v[h+4>>2]+b|0;continue}}jb=m+112|0;b=x[cc(v[z>>2],j)>>1];if(b){Uz(e,(B(b,104)+a|0)+484380|0,0,v[e>>2],0)}b=Md(v[o>>2],j);V=f,X=Eb(v[b>>2]),v[V+232>>2]=X;c=Eb(v[b+4>>2]);while(1){b=v[f+232>>2];if(!Ob(b,c)){break _}i=x[b+8>>1];if(i){Uz(e,(B(i,104)+a|0)+484380|0,v[b>>2],v[b+4>>2],1)}i=x[b+10>>1];if(i){Uz(e,(B(i,104)+a|0)+484380|0,v[b>>2],v[b+4>>2],0)}lq(f+232|0);continue}}k=k+1|0;continue}}Qt(E);d=1;break b}v[23588]=0;Q(188,n|0,B(g,x[f+238>>1])|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){break C}break B}b=b+1|0;continue}break}e=P()|0;O()|0;Qt(E);break e}e=P()|0;O()|0;break e}e=P()|0;O()|0;break e}e=P()|0;O()|0;break e}e=P()|0;O()|0;break f}e=P()|0;O()|0;break e}e=P()|0;O()|0;break e}e=P()|0;O()|0;ac(f+8|0);break d}e=P()|0;O()|0;break e}Ab(h)}nd(z);IQ(o)}T(e|0);L()}d=0}nd(z);IQ(o)}jb=f+496|0;return d|0}function uea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;d=jb-592|0;jb=d;yc(b);a:{if(!SA(b,d+512|0)){break a}if(!SP(d+512|0)){break a}if(!Pb(v[b>>2],v[b+8>>2],Dc(RP(d+512|0),mb))){break a}b:{if(!c){break b}Ad(a,4);$f(a);t[a+1074368|0]=4;k=Lb(d+496|0);c:{d:{e:{f:{l=d+550|0;g:{if(!(Rb(l,17762,20)|v[d+572>>2]!=276)){if(x[d+570>>1]<260){break g}e=VA(d+529|0,0,20)?1154:34;break e}if(!Rb(l,17741,20)){e=1;break e}g=d- -64|0;Cj(g,3,l);v[23588]=0;R(222,d+104|0,g|0);g=v[23588];v[23588]=0;h:{i:{if((g|0)!=1){v[23588]=0;U(11,d+208|0,5,d+104|0);g=v[23588];v[23588]=0;if((g|0)==1){break i}g=d+208|0;Ib(k,g);zb(g);yb(d+104|0);if(Rb(l,17579,8)){break h}e=1048;break e}f=P()|0;O()|0;break c}f=P()|0;O()|0;yb(d+104|0);break c}if(!Rb(l,17479,12)){e=16;if(!Rb(d+562|0,17783,8)){break e}t[a+1074368|0]=5;break e}if(Rb(l,11577,20)){break f}}e=48;break e}if(!Rb(l,27088,15)){v[23588]=0;g=Q(265,a+1074312|0,54)|0;e=v[23588];v[23588]=0;C=1;if((e|0)==1){break d}v[23588]=0;Q(265,g|0,51)|0;g=v[23588];v[23588]=0;e=16;if((g|0)==1){break d}break e}j:{if(Rb(l,27104,14)){if(Rb(l,27119,14)){break j}}v[23588]=0;g=Q(265,a+1074312|0,57)|0;e=v[23588];v[23588]=0;if((e|0)==1){break d}v[23588]=0;Q(265,g|0,51)|0;g=v[23588];v[23588]=0;e=16;if((g|0)!=1){break e}break d}e=Rb(l,17567,11)?16:256}g=d+104|0;s=d+529|0;Cj(g,3,s);v[23588]=0;R(222,d+208|0,g|0);g=v[23588];v[23588]=0;k:{l:{m:{n:{o:{p:{q:{if((g|0)!=1){g=d+208|0;Ac(a+1298308|0,g);yb(g);v[a+480260>>2]=1;v[a+480264>>2]=31999;Ue(Vb(v[a+484360>>2],w[a+484376|0]),x[d+578>>1]);u[a+480188>>1]=x[d+580>>1];u[d+208>>1]=x[d+584>>1];u[d+104>>1]=255;F=a+480192|0,G=x[Vc(g,d+104|0)>>1],u[F>>1]=G;g=x[d+588>>1];if(g){v[a+480196>>2]=g}g=x[d+590>>1];if(g){g=B(g,1e4);g=g>>>0<1e7?g:1e7;v[a+480204>>2]=g>>>0>32e4?g:32e4}g=x[d+586>>1];v[a+480208>>2]=g<<4&16|g<<3&32768;f=w[a+484376|0];n=v[a+484360>>2];v[23588]=0;ea(340,Vb(n,f)|0,b|0,x[d+576>>1],65535,65535);f=v[23588];v[23588]=0;if((f|0)==1){break d}f=g>>>12&1?(e|0)==34?146:e:e;if(!(x[d+576>>1]|f&1024)){g=w[a+484376|0];e=v[a+484360>>2];v[23588]=0;Y(731,Vb(e,g)|0);g=v[23588];v[23588]=0;if((g|0)==1){break d}}v[23588]=0;Q(155,b|0,v[d+572>>2]+60|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break d}if(x[d+570>>1]>=260){v[23588]=0;U(732,b|0,d+512|0,a|0);g=v[23588];v[23588]=0;if((g|0)==1){break d}}t[d+495|0]=0;z=c&2;D=d+122|0;o=d+241|0;n=Sb(d+480|0);E=a+480192|0;g=-1;p=1;while(1){e=p&65535;if(e>>>0>x[E>>1]){if(!(!(f&2)|q&255)){f=VA(s,0,20)?f|16:f}if(x[d+570>>1]>259){break o}if(c&3){v[23588]=0;U(732,b|0,d+512|0,a|0);c=v[23588];v[23588]=0;if((c|0)==1){break n}}if(!z){break o}o=a+480190|0;e=1;while(1){c=e&65535;if(c>>>0>x[o>>1]){break o}i=v[n>>2];v[23588]=0;W(219,Db(i,c-1|0)|0,(B(c,104)+a|0)+484380|0,b|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){e=e+1|0;continue}break}f=P()|0;O()|0;break k}v[23588]=0;i=S(157,b|0)|0;h=v[23588];v[23588]=0;r:{s:{if((h|0)!=1){yg(b,4);v[23588]=0;U(733,b|0,d+208|0,(i?i:263)|0);i=v[23588];v[23588]=0;if((i|0)==1){break p}t:{if((f|0)==1){i=v[d+208>>2];if((i|0)!=263){f=16;if((i|0)!=245){break t}v[a+1074308>>2]=16777381;v[23588]=0;f=Q(1,d+192|0,13270)|0;i=v[23588];v[23588]=0;if((i|0)!=1){Ib(k,f);zb(f);f=17;break t}f=P()|0;O()|0;break k}v[a+1074308>>2]=16777395;v[23588]=0;f=Q(1,d+176|0,13185)|0;i=v[23588];v[23588]=0;if((i|0)!=1){Ib(k,f);zb(f);f=17;break t}f=P()|0;O()|0;break k}if(w[d+235|0]|w[d+236|0]<<8){break t}i=v[d+208>>2];if(!(!(f&2)|(w[d+237|0]|w[d+238|0]<<8|(w[d+239|0]<<16|w[d+240|0]<<24))|(i|0)!=263)){f=f|16;break t}if(!(!(f&256)|(i|0)==29)){f=f&-257;break t}if(!(f&160)){break t}f=(i|0)==33?f:0}v[23588]=0;i=W(251,a|0,e|0,0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break p}if(!i){break r}i=((e<<2)+a|0)+900380|0;e=v[i>>2];v[23588]=0;R(734,d+208|0,e|0);e=v[23588];v[23588]=0;if((e|0)==1){break p}e=w[d+234|0];u:{if((g|0)==-1){g=e;break u}if(!(f&32)|(e|0)==(g|0)){break u}f=f&-161|128}e=w[d+235|0]|w[d+236|0]<<8;if(!e){break r}v[23588]=0;h=w[d+455|0];j=w[d+451|0]|w[d+452|0]<<8;m=w[d+450|0];r=w[d+449|0];U(735,d+160|0,a|0,e|0);e=v[23588];v[23588]=0;if((e|0)==1){break q}f=h|(j|(m|r))?f&-4:f;i=v[i>>2]+236|0;e=12;h=v[d+160>>2];j=Qc(h,v[d+164>>2]);v:{while(1){w:{if((e|0)==108){if(x[d+570>>1]>259){Kc(n)}e=0;v[23588]=0;i=Q(736,d+144|0,w[d+235|0]|w[d+236|0]<<8)|0;h=v[23588];v[23588]=0;if((h|0)!=1){break w}f=P()|0;O()|0;break v}m=cc(i,e);if(j>>>0>x[m>>1]){F=m,G=x[cc(h,x[cc(i,e)>>1])>>1],u[F>>1]=G}e=e+1|0;continue}break}x:{y:{z:{A:{while(1){h=w[d+235|0]|w[d+236|0]<<8;if(e>>>0>=h>>>0){e=0;if(x[d+570>>1]<=259){break s}B:{while(1){if(e>>>0>=h>>>0){break s}j=w[Db(v[n>>2],e)+3|0];h=v[Db(v[i>>2],e)>>2];v[23588]=0;U(190,d- -64|0,b|0,((j|0)==10?(h+1>>>1|0)+16|0:h)|0);h=v[23588];v[23588]=0;if((h|0)!=1){j=d- -64|0;h=jc(d+104|0,j);Ab(j);j=v[d+160>>2];if(!(!z|Qc(j,v[d+164>>2])>>>0<=e>>>0)){m=x[cc(j,e)>>1];j=Db(v[n>>2],e);j=w[j|0]|w[j+1|0]<<8|(w[j+2|0]<<16|w[j+3|0]<<24);v[23588]=0;v[d+56>>2]=j;v[d>>2]=j;j=fa(737,(B(m,104)+a|0)+484380|0,d|0,h|0,d+495|0)|0;m=v[23588];v[23588]=0;if((m|0)==1){break B}A=j^1|A}Ab(h);e=e+1|0;h=w[d+235|0]|w[d+236|0]<<8;continue}break}f=P()|0;O()|0;break x}f=P()|0;O()|0;Ab(h);break x}v[23588]=0;R(738,b|0,d+104|0);h=v[23588];v[23588]=0;if((h|0)==1){break y}h=d- -64|0;j=w[d+118|0];C:{if(!(j&48|w[d+121|0]!=173)){Zc(h,8,1,0,10);break C}Zc(h,j&16?16:8,j&32?3:1,0,2)}v[23588]=0;R(739,n|0,h|0);h=v[23588];v[23588]=0;if((h|0)!=1){F=Db(v[i>>2],e),G=v[d+104>>2],v[F>>2]=G;m=w[d+121|0];h=v[d+160>>2];if(Qc(h,v[d+164>>2])>>>0>e>>>0){j=x[cc(h,e)>>1];v[23588]=0;h=(B(j,104)+a|0)+484380|0;R(740,d+104|0,h|0);r=v[23588];v[23588]=0;if((r|0)==1){break A}t[h+38|0]=w[o+202|0];t[h+39|0]=w[o+203|0];t[h+40|0]=w[o+204|0];t[h+41|0]=w[o+205|0];h=d+88|0;Hl(h,3,D);v[23588]=0;R(222,d- -64|0,h|0);h=v[23588];v[23588]=0;if((h|0)==1){break z}h=d- -64|0;Cc(((j<<5)+a|0)+946304|0,h);yb(h);f=(w[d+118|0]&3)==3?(f&2)>>>1|0?f|4:f:f}q=m|q;e=e+1|0;continue}break}f=P()|0;O()|0;break x}f=P()|0;O()|0;break x}f=P()|0;O()|0;break x}f=P()|0;O()|0}vc(i)}nd(d+160|0);break k}f=P()|0;O()|0;break k}vc(i);nd(d+160|0)}p=p+1|0;continue}}f=P()|0;O()|0;break c}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}D:{if(!(A&1)){break D}v[23588]=0;c=Q(1,d+104|0,16594)|0;e=v[23588];v[23588]=0;E:{if((e|0)!=1){e=v[a+1298464>>2];v[23588]=0;U(376,e|0,2,c|0);e=v[23588];v[23588]=0;if((e|0)==1){break E}zb(c);break D}f=P()|0;O()|0;break k}f=P()|0;O()|0;zb(c);break k}v[23588]=0;c=Q(402,b|0,5561)|0;e=v[23588];v[23588]=0;if((e|0)==1){break n}if(c){v[23588]=0;c=S(157,b|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break n}v[23588]=0;X(331,a+1298332|0,b|0,c|0,0);c=v[23588];v[23588]=0;if((c|0)==1){break n}f=f|16}v[23588]=0;o=Q(402,b|0,14043)|0;c=v[23588];v[23588]=0;if((c|0)==1){break l}if(o){v[23588]=0;c=S(157,b|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break l}v[23588]=0;e=a+901404|0;U(741,b|0,e|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break l}UA(e);f=f|16}v[23588]=0;c=Q(402,b|0,13805)|0;e=v[23588];v[23588]=0;if((e|0)==1){break l}if(!c){break m}v[23588]=0;c=S(157,b|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){u[d+208>>1]=c>>>5;F=d,G=Af(v[a+484344>>2],v[a+484348>>2]),u[F+64>>1]=G;c=x[Vc(d+208|0,d- -64|0)>>1];e=0;while(1){if((c|0)==(e|0)){f=f|16;break m}v[23588]=0;R(565,b|0,d+208|0);i=v[23588];v[23588]=0;F:{if((i|0)==1){break F}i=v[a+484344>>2];v[23588]=0;R(566,Yb(i,e)|0,d+208|0);i=v[23588];v[23588]=0;if((i|0)==1){break F}e=e+1|0;continue}break}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}v[23588]=0;c=Q(402,b|0,13810)|0;e=v[23588];v[23588]=0;if((e|0)==1){break l}G:{if(!c){break G}v[23588]=0;c=S(157,b|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){u[d+208>>1]=(c>>>0)/20;u[d+64>>1]=x[a+480188>>1];c=x[Vc(d+208|0,d- -64|0)>>1];e=0;while(1){if((c|0)==(e|0)){f=f|16;break G}v[23588]=0;U(413,b|0,((e<<5)+a|0)+480289|0,20);i=v[23588];v[23588]=0;if((i|0)!=1){e=e+1|0;continue}break}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}c=v[b+8>>2];e=v[b>>2];v[23588]=0;c=W(156,e|0,c|0,8)|0;e=v[23588];v[23588]=0;if((e|0)==1){break l}H:{I:{J:{K:{if(c){c=v[b+8>>2];v[23588]=0;Q(414,a|0,b|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break K}f=(c|0)==v[b+8>>2]?f:f|16}L:{if(!(f&16)){break L}if(f&4){v[a+1074308>>2]=17367040;v[23588]=0;c=Q(1,d+208|0,14650)|0;e=v[23588];v[23588]=0;if((e|0)!=1){Ib(k,c);zb(c);break L}f=P()|0;O()|0;break k}if(!(f&2)){break L}v[a+1074308>>2]=18219008;v[23588]=0;c=Q(1,d+208|0,14814)|0;e=v[23588];v[23588]=0;if((e|0)==1){break J}Ib(k,c);zb(c)}M:{N:{O:{P:{Q:{R:{S:{if(!Rb(l,17579,8)){v[23588]=0;c=W(383,d- -64|0,d+558|0,12)|0;e=v[23588];v[23588]=0;if((e|0)==1){break S}v[23588]=0;U(11,d+160|0,1,c|0);e=v[23588];v[23588]=0;if((e|0)==1){break R}v[23588]=0;e=S(742,d+160|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break Q}v[a+1074308>>2]=e;zb(d+160|0);t[a+1074368|0]=y[a+1074308>>2]<19007257?4:5;yb(c);f=24}if(!(!v[a+1074308>>2]|f&8)){t[a+1074368|0]=0;mu(a+1074312|0)}c=f&32;T:{if(!c){break T}t[a+1074368|0]=5;if(!o){pq(a+901404|0)}if(x[d+570>>1]<260){break T}v[23588]=0;W(264,a+1074312|0,4,1)|0;e=v[23588];v[23588]=0;if((e|0)==1){break l}}if(!rh(v[k+4>>2],w[k+11|0])){break M}if(!(f&256)|q&255|g+1>>>0>1){break N}v[23588]=0;c=Q(1,d+160|0,8252)|0;g=v[23588];v[23588]=0;if((g|0)==1){break O}Ib(k,c);zb(c);break M}f=P()|0;O()|0;break k}f=P()|0;O()|0;break P}f=P()|0;O()|0;zb(d+160|0)}yb(c);break k}f=P()|0;O()|0;break k}if(c){v[23588]=0;c=Q(1,d+160|0,11989)|0;g=v[23588];v[23588]=0;if((g|0)!=1){Ib(k,c);zb(c);break M}f=P()|0;O()|0;break k}v[23588]=0;c=Q(1,d+160|0,9700)|0;g=v[23588];v[23588]=0;if((g|0)==1){break I}Ib(k,c);zb(c)}t[d+55|0]=0;U:{if(x[a+480192>>1]){v[23588]=0;c=Q(422,a|0,b|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break U}t[d+55|0]=c}v[23588]=0;X(423,a|0,b|0,1,d+55|0);b=v[23588];v[23588]=0;if((b|0)==1){break U}e=v[a+1074308>>2];V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{if(w[d+55|0]){if(e>>>0>18284543){break ha}v[a+1074308>>2]=18284544;break ha}if(e>>>0<18284544){break ga}}v[23588]=0;b=Q(1,d+40|0,17579)|0;c=v[23588];v[23588]=0;if((c|0)==1){break fa}c=v[a+1074308>>2];v[23588]=0;R(743,d+24|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break ea}v[23588]=0;U(2,d+88|0,b|0,d+24|0);c=v[23588];v[23588]=0;if((c|0)==1){break da}c=d+88|0;Ib(k,c);zb(c);zb(d+24|0);zb(b);e=v[a+1074308>>2]}ia:{if(e-1>>>0>19005952){break ia}b=v[a+484344>>2];f=v[a+484348>>2];if(!xe(b,f,254)){b=w[a+484376|0];c=v[a+484360>>2];v[23588]=0;Y(744,Vb(c,b)|0);b=v[23588];v[23588]=0;if((b|0)==1){break U}f=v[a+484348>>2];b=v[a+484344>>2]}if(xe(b,f,255)){break ia}hA(Vb(v[a+484360>>2],w[a+484376|0]),255,65535)}v[23588]=0;R(745,d+24|0,4105);b=v[23588];v[23588]=0;if((b|0)==1){break ba}b=x[d+570>>1];v[d+20>>2]=b>>>8;v[23588]=0;v[d+4>>2]=b&255;R(433,d+8|0,d+4|0);b=v[23588];v[23588]=0;if((b|0)==1){break aa}v[23588]=0;X(419,d+88|0,d+24|0,d+20|0,d+8|0);b=v[23588];v[23588]=0;if((b|0)==1){break $}c=d+88|0;b=Ib(a+1298344|0,c);zb(c);zb(d+8|0);ac(d+24|0);Ib(a+1298368|0,k);v[a+1298404>>2]=C?8:v[a+1074308>>2]?8:5;if(!w[d+495|0]){break W}Ib(a+1298380|0,b);v[23588]=0;c=Q(1,d+88|0,15244)|0;g=v[23588];v[23588]=0;if((g|0)==1){break Z}Ib(b,c);zb(c);v[23588]=0;b=Q(1,d+24|0,10051)|0;c=v[23588];v[23588]=0;if((c|0)==1){break Y}Ib(a+1298356|0,b);zb(b);v[23588]=0;b=Q(1,d+8|0,10052)|0;c=v[23588];v[23588]=0;if((c|0)==1){break X}Ib(a+1298392|0,b);break V}f=P()|0;O()|0;break k}f=P()|0;O()|0;break ca}f=P()|0;O()|0;zb(d+24|0)}zb(b);break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break _}f=P()|0;O()|0;zb(d+8|0)}ac(d+24|0);break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}v[23588]=0;b=Q(1,d+88|0,10052)|0;c=v[23588];v[23588]=0;if((c|0)==1){break H}Ib(a+1298356|0,b)}zb(b);vc(n);zb(k);break b}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0}vc(n);break c}f=P()|0;O()|0}zb(k);T(f|0);L()}e=1}jb=d+592|0;return e|0}function ufa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;e=jb-336|0;jb=e;yc(b);a:{b:{c:{if(!Vt(b,e+240|0)){break c}if(!eR(e+240|0)){break c}if(!Pb(v[b>>2],v[b+8>>2],Dc(dR(e+240|0),mb))){break c}if(!c){s=1;break c}Ad(a,2);v[a+480260>>2]=64;v[a+480264>>2]=32767;i=Lb(e+224|0);d=x[e+280>>1];j=(d|0)==20479?x[e+294>>1]:d-16464|0;d:{e:{f:{g:{h:{i:{switch(d>>>12|0){case 0:if((d|0)!=520){break d}v[23588]=0;d=Q(1,e+208|0,12229)|0;h=v[23588];v[23588]=0;if((h|0)!=1){Ib(i,d);break e}b=P()|0;O()|0;break a;case 1:j:{if(x[e+302>>1]|(d|0)!=4896){break j}if(!(x[e+278>>1]&65455|(w[e+292|0]|w[e+272|0]&15))){k:{if(t[e+291|0]<0){v[a+1074308>>2]=18219008;v[23588]=0;d=Q(1,e+208|0,14727)|0;f=v[23588];v[23588]=0;if((f|0)!=1){break k}b=P()|0;O()|0;break a}v[a+1074308>>2]=16777216;v[23588]=0;d=Q(1,e+208|0,13270)|0;f=v[23588];v[23588]=0;if((f|0)==1){break h}}Ib(i,d);zb(d);v[23588]=0;f=1;W(264,a+1074312|0,81,1)|0;d=v[23588];v[23588]=0;g=1;if((d|0)!=1){break d}break b}if(w[e+293|0]|(w[e+292|0]|x[e+278>>1])){break j}v[23588]=0;d=Q(1,e+208|0,9436)|0;h=v[23588];v[23588]=0;if((h|0)!=1){Ib(i,d);break e}b=P()|0;O()|0;break a}v[23588]=0;d=Q(1,e+208|0,8454)|0;f=v[23588];v[23588]=0;k=1;if((f|0)!=1){Ib(i,d);zb(d);break f}b=P()|0;O()|0;break a;case 2:v[23588]=0;d=Q(1,e+208|0,6776)|0;f=v[23588];v[23588]=0;g=1;if((f|0)!=1){Ib(i,d);zb(d);break f}b=P()|0;O()|0;break a;case 3:l:{m:{n:{o:{if(d>>>0<=12820){v[23588]=0;f=Q(1,e+208|0,8517)|0;h=v[23588];v[23588]=0;if((h|0)!=1){Ib(i,f);zb(f);break o}b=P()|0;O()|0;break a}v[23588]=0;R(431,e+208|0,4018);f=v[23588];v[23588]=0;if((f|0)==1){break n}v[23588]=0;v[e+192>>2]=x[e+280>>1]-12820;U(432,e+48|0,e+208|0,e+192|0);f=v[23588];v[23588]=0;if((f|0)==1){break m}f=e+48|0;Ib(i,f);zb(f);ac(e+208|0)}f=x[e+280>>1];if(f>>>0<12807){break g}h=v[e+296>>2];if(h){break l}break g}b=P()|0;O()|0;break a}b=P()|0;O()|0;ac(e+208|0);break a}f=WC(f,h);h=xo(e+48|0);v[h+32>>2]=f;v[23588]=0;R(434,a+1298408|0,h|0);f=v[23588];v[23588]=0;if((f|0)!=1){break g}b=P()|0;O()|0;break a;case 4:p:{q:{if((d|0)==16640){v[23588]=0;f=Q(1,e+208|0,8300)|0;h=v[23588];v[23588]=0;if((h|0)!=1){Ib(i,f);zb(f);f=81;break q}b=P()|0;O()|0;break a}v[23588]=0;U(435,e+48|0,d|0,x[e+294>>1]);f=v[23588];v[23588]=0;r:{if((f|0)!=1){f=e+48|0;Ib(i,f);zb(f);v[a+480260>>2]=1;if((j|0)<4201){break r}v[23588]=0;W(264,a+1074312|0,7,1)|0;h=v[23588];v[23588]=0;f=38;if((h|0)==1){break b}break q}b=P()|0;O()|0;break a}f=38;if((j|0)<2386){break p}}v[23588]=0;W(264,a+1074312|0,f|0,1)|0;f=v[23588];v[23588]=0;if((f|0)==1){break b}}h=(d|0)!=16640;g=1;f=0;break d;case 5:d=d&4095;v[a+1074308>>2]=d<<16|(d>>>0>296?x[e+294>>1]:0)&65535;v[23588]=0;d=Q(1,e+208|0,17579)|0;f=v[23588];v[23588]=0;s:{t:{u:{if((f|0)!=1){f=v[a+1074308>>2];v[23588]=0;R(140,e+192|0,f|0);f=v[23588];v[23588]=0;if((f|0)==1){break u}f=0;v[23588]=0;U(2,e+48|0,d|0,e+192|0);h=v[23588];v[23588]=0;if((h|0)==1){break t}h=e+48|0;Ib(i,h);zb(h);zb(e+192|0);break e}b=P()|0;O()|0;break a}b=P()|0;O()|0;break s}b=P()|0;O()|0;zb(e+192|0)}zb(d);break a;case 6:v[23588]=0;d=Q(1,e+208|0,8300)|0;h=v[23588];v[23588]=0;if((h|0)!=1){Ib(i,d);zb(d);v[23588]=0;W(264,a+1074312|0,81,1)|0;d=v[23588];v[23588]=0;h=0;if((d|0)==1){break b}break d}b=P()|0;O()|0;break a;case 7:v[23588]=0;d=Q(1,e+208|0,8312)|0;h=v[23588];v[23588]=0;if((h|0)!=1){Ib(i,d);break e}b=P()|0;O()|0;break a;default:break i}}if((d|0)!=51712){break d}v[23588]=0;d=Q(1,e+208|0,9235)|0;h=v[23588];v[23588]=0;if((h|0)!=1){Ib(i,d);break e}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}v[23588]=0;f=W(264,a+1074312|0,7,1)|0;h=v[23588];v[23588]=0;if((h|0)==1){break b}v[23588]=0;f=W(264,f|0,23,1)|0;h=v[23588];v[23588]=0;if((h|0)==1){break b}v[23588]=0;f=W(264,f|0,38,1)|0;h=v[23588];v[23588]=0;if((h|0)==1){break b}v[23588]=0;W(264,f|0,107,1)|0;f=v[23588];v[23588]=0;if((f|0)==1){break b}g=1;v[a+480260>>2]=1;f=0;h=0;if(d>>>0>12820){break d}}v[23588]=0;Y(666,e+192|0);d=v[23588];v[23588]=0;v:{w:{x:{if((d|0)!=1){d=x[e+280>>1];v[e+160>>2]=d>>>8&15;v[23588]=0;v[e+136>>2]=d&255;R(433,e+176|0,e+136|0);d=v[23588];v[23588]=0;if((d|0)==1){break x}f=0;v[23588]=0;ea(667,e+48|0,e+192|0,i|0,e+160|0,e+176|0);d=v[23588];v[23588]=0;if((d|0)==1){break w}d=e+48|0;Ib(i,d);zb(d);zb(e+176|0);ac(e+192|0);break d}b=P()|0;O()|0;break a}b=P()|0;O()|0;break v}b=P()|0;O()|0;zb(e+176|0)}ac(e+192|0);break a}zb(d);h=0}v[23588]=0;d=Q(1,e+192|0,15001)|0;l=v[23588];v[23588]=0;y:{z:{A:{B:{C:{D:{E:{F:{if((l|0)!=1){Ib(a+1298344|0,d);zb(d);v[23588]=0;d=Q(1,e+176|0,10424)|0;l=v[23588];v[23588]=0;if((l|0)==1){break F}Ib(a+1298356|0,d);zb(d);l=Ib(a+1298368|0,i);v[a+1298404>>2]=v[a+1074308>>2]?8:5;if(g){v[23588]=0;d=Q(265,a+1074312|0,77)|0;g=v[23588];v[23588]=0;if((g|0)==1){break b}v[23588]=0;d=Q(265,d|0,78)|0;g=v[23588];v[23588]=0;if((g|0)==1){break b}v[23588]=0;d=Q(265,d|0,79)|0;g=v[23588];v[23588]=0;if((g|0)==1){break b}v[23588]=0;d=Q(265,d|0,80)|0;g=v[23588];v[23588]=0;if((g|0)==1){break b}v[23588]=0;d=Q(265,d|0,82)|0;g=v[23588];v[23588]=0;if((g|0)==1){break b}v[23588]=0;d=Q(265,d|0,96)|0;g=v[23588];v[23588]=0;if((g|0)==1){break b}v[23588]=0;Q(265,d|0,113)|0;d=v[23588];v[23588]=0;if((d|0)==1){break b}}d=x[e+280>>1];g=d&61440;if(g>>>0>=4097){f=(g|0)!=12288|d>>>0>12819|f}v[23588]=0;d=a+901404|0;Y(668,d|0);g=v[23588];v[23588]=0;if((g|0)==1){break b}if(!f){pq(d)}d=e+160|0;Hi(d,1,e+240|0);v[23588]=0;R(222,e+48|0,d|0);d=v[23588];v[23588]=0;if((d|0)==1){break C}d=e+48|0;Ac(a+1298308|0,d);yb(d);d=x[e+278>>1];if(d&16){v[a+480208>>2]=v[a+480208>>2]|65536}if(d&1){v[a+480208>>2]=v[a+480208>>2]|131072}f=x[e+280>>1];if(!(d&64?0:(f|0)!=4864)){v[a+480208>>2]=v[a+480208>>2]|2}d=w[e+289|0];v[a+480196>>2]=d;if(!(!k|(d|0)!=255?d:0)){v[a+480196>>2]=6}d=w[e+290|0];v[a+480204>>2]=d>>>0<33?k?125e4:32e4:B(d,1e4);t[e+48|0]=w[e+288|0];t[e+160|0]=64;d=w[Wb(e+48|0,e+160|0)|0];v[a+480200>>2]=d<<2;if(!(d|f>>>0>4895)){v[a+480200>>2]=256}g=w[e+291|0];if(x[e+282>>1]!=1|g>>>0>7){break E}v[e+48>>2]=(g<<4)+16;v[e+160>>2]=127;f=v[sd(e+48|0,e+160|0)>>2];break D}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}f=32;if((g|16)==18){break D}d=g&127;f=48;if(!d){break D}v[e+48>>2]=d;v[e+160>>2]=16;f=v[Oe(e+48|0,e+160|0)>>2]}v[a+480228>>2]=f;d=0;q=v[a+1074308>>2]!=0|g<<24>>24<0;if(!q){H=a,I=Dc(Oka(f<<3|5,f>>>29|0,11,0),mb),v[H+480228>>2]=I}r=a+480188|0;u[r>>1]=4;v[a+480232>>2]=h?(j|0)<3299?64:36:36;f=Gc(e+152|0);while(1){if((d|0)==32){d=a+480188|0;if(!x[d>>1]){u[d>>1]=1}d=w[a+484376|0];h=v[a+484360>>2];v[23588]=0;ea(340,Vb(h,d)|0,b|0,x[e+272>>1],255,254);d=v[23588];v[23588]=0;if((d|0)!=1){q=Sb(e+160|0);v[23588]=0;W(217,b|0,q|0,x[e+274>>1])|0;d=v[23588];v[23588]=0;if((d|0)!=1){r=Sb(e+136|0);v[23588]=0;W(217,b|0,r|0,x[e+276>>1])|0;d=v[23588];v[23588]=0;G:{if((d|0)!=1){if(w[e+293|0]!=252){break B}d=0;v[23588]=0;R(669,b|0,e+48|0);h=v[23588];v[23588]=0;if((h|0)==1){break G}while(1){if((d|0)==32){break B}h=w[(e+48|0)+d|0];H:{if(!(h&32)){break H}if(k){Rc(e+32|0,f,d);if(Bb(v[v[e+32>>2]>>2],v[e+36>>2])){break H}}u[((d<<5)+a|0)+480284>>1]=(((h&15)<<8|8)>>>0)/15}d=d+1|0;continue}}break A}break A}b=P()|0;O()|0;break z}b=P()|0;O()|0;break a}h=(d<<5)+a|0;j=h+480280|0;df(j);g=w[(d+e|0)+304|0];o=g&127;I:{if((g|0)!=255){g=g<<24>>24;u[r>>1]=d+1;if(q){u[h+480284>>1]=g&8?204:51}if((g|0)>=0){break I}}v[j>>2]=1024}if((o-16&255)>>>0<=13){u[h+480284>>1]=128;h=e+48|0;Rc(h,f,d);oo(h)}d=d+1|0;continue}}b=P()|0;O()|0;break a}u[e+48>>1]=x[e+274>>1];u[e+32>>1]=3999;f=x[Vc(e+48|0,e+32|0)>>1];u[a+480190>>1]=f;j=c&2;o=e+96|0;d=0;g=0;h=0;J:{K:{L:{while(1){if((f&65535)>>>0<=d>>>0){if(!k){break K}if(!(!(g&1)|h&65535)&x[e+280>>1]!=4864){break L}v[23588]=0;d=h&65535;f=W(264,a+1074312|0,79,d>>>0>1|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break A}v[23588]=0;d=d>>>0<2;f=W(264,f|0,107,d|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break A}v[23588]=0;W(264,f|0,38,d|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break A}v[23588]=0;d=h&65535;Q(133,l|0,(d>>>0>1?17140:17147)|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break A}if(d>>>0<2){break K}v[a+480228>>2]=48;break K}f=cc(v[q>>2],d);f=w[f|0]|w[f+1|0]<<8;v[23588]=0;f=Q(155,b|0,f<<4)|0;n=v[23588];v[23588]=0;if((n|0)==1){break J}M:{N:{if(!f){break N}v[23588]=0;f=Q(670,b|0,e+48|0)|0;n=v[23588];v[23588]=0;if((n|0)==1){break J}if(!f){break N}v[23588]=0;f=d+1|0;n=(B(f,104)+a|0)+484380|0;U(671,e+48|0,n|0,k|0);m=v[23588];v[23588]=0;if((m|0)==1){break J}m=e+16|0;Hi(m,1,o);v[23588]=0;R(222,e+32|0,m|0);m=v[23588];v[23588]=0;if((m|0)==1){break M}m=((f<<5)+a|0)+946304|0;f=e+32|0;Cc(m,f);yb(f);if(w[e+48|0]>1){break N}O:{if(!j|!v[e+64>>2]){break O}f=bR(e+48|0);v[23588]=0;f=Q(155,b|0,f|0)|0;m=v[23588];v[23588]=0;if((m|0)==1){break A}if(!f){break O}f=e+32|0;aR(f,w[e+78|0],w[e+79|0],x[e+282>>1]==1);v[23588]=0;W(219,f|0,n|0,b|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break A}g=1}h=x[e+88>>1]|h}d=d+1|0;f=x[a+480190>>1];continue}break}break A}v[23588]=0;d=Q(1,e+48|0,9700)|0;f=v[23588];v[23588]=0;if((f|0)==1){break A}Ib(l,d);zb(d)}s=1;if(!(c&1)){break y}c=x[e+280>>1];u[e+32>>1]=x[e+276>>1];u[e+16>>1]=255;y=x[Vc(e+32|0,e+16|0)>>1];v[23588]=0;k=a+484344|0;R(225,k|0,y|0);d=v[23588];v[23588]=0;if((d|0)==1){break J}z=c>>>0<4896;c=e+32|0;m=c|5;D=c|3;A=c|4;E=c|2;F=c|1;G=a+480188|0;h=0;o=0;n=0;while(1){if((h|0)==(y|0)){if(!z){break y}a=x[a+480188>>1];if((a|0)>(n+o|0)|(a|0)<=(o-n|0)){break y}d=Af(v[k>>2],v[k+4>>2])-1&65535;b=0;P:{if(Af(v[k>>2],v[k+4>>2])>>>0<=d>>>0){break P}while(1){c=b&65535;if(c>>>0>d>>>0){break P}a=ag(v[k>>2],c);f=v[a>>2];if(Ob(f,v[a+4>>2])){a=Eb(f);f=Eb(v[ag(v[k>>2],c)+4>>2]);c=jb-16|0;jb=c;v[c+8>>2]=a;while(1){if(Ob(a,f)){if(w[a+3|0]==31){t[a+3|0]=20;t[a+5|0]=w[a+5|0]|128}a=v[Bk(c+8|0)>>2];continue}break}jb=c+16|0}b=b+1|0;continue}}break y}v[23588]=0;c=W(226,k|0,h&65535,64)|0;d=v[23588];v[23588]=0;if((d|0)==1){break J}Q:{if(!c){break Q}c=cc(v[r>>2],h);c=w[c|0]|w[c+1|0]<<8;if(!c){break Q}v[23588]=0;c=Q(155,b|0,c<<4)|0;d=v[23588];v[23588]=0;if((d|0)==1){break J}if(!c){break Q}v[23588]=0;Q(188,b|0,2)|0;c=v[23588];v[23588]=0;if((c|0)==1){break J}d=0;c=Yb(v[k>>2],h);c=Cf(v[c>>2],v[v[c+48>>2]+12>>2],0);while(1){if(d>>>0>63){break Q}f=d;v[23588]=0;l=S(206,b|0)|0;d=v[23588];v[23588]=0;R:{if((d|0)!=1){if(l){break R}d=64;if(f>>>0>62){continue}c=Yb(v[k>>2],h);d=f+1|0;c=Cf(v[c>>2],v[v[c+48>>2]+12>>2],d);continue}break A}g=l&31;d=B(g,6)+c|0;p=tg(e+32|0);j=g>>>0<x[G>>1];C=j?d:p;if(l&32){v[23588]=0;R(260,e+16|0,b|0);g=v[23588];v[23588]=0;S:{T:{U:{if((g|0)!=1){p=Nc(e+16|0);g=w[e+16|0];if(g>>>0>239){break U}g=$Q((B(g>>>4|0,12)+(g&15)|0)+13|0);break T}break A}V:{switch(g-254|0){case 0:break T;case 1:break V;default:break S}}g=0}t[C|0]=g}t[(j?d+1|0:F)|0]=w[p|0]}W:{if(!(l&64)){break W}v[23588]=0;p=S(206,b|0)|0;g=v[23588];v[23588]=0;X:{if((g|0)!=1){g=j?d+2|0:E;p=p<<24>>24;t[e+16|0]=p;if((p|0)>-64){break X}t[g|0]=2;t[(j?d+4|0:A)|0]=w[e+16|0]^128;break W}break A}t[g|0]=1;t[e+15|0]=64;H=j?d+4|0:A,I=w[Wb(e+16|0,e+15|0)|0],t[H|0]=I}Y:{if(!(l&128)){break Y}v[23588]=0;R(260,e+16|0,b|0);g=v[23588];v[23588]=0;Z:{_:{if((g|0)!=1){RA(C,w[e+16|0],w[Nc(e+16|0)|0],0);l=j?d+3|0:D;g=w[l|0];if((g|0)==10){break Z}if((g|0)==31){break _}if((g|0)!=20){break Y}d=j?d+5|0:m;g=w[d|0];if((g&240)!=160|x[e+280>>1]>4895){break Y}t[d|0]=g&15^136;break Y}break A}d=w[(j?d+5|0:m)|0];if(d>>>0>15){z=0;break Y}if(d>>>0<=7){n=n+1|0;break Y}o=((d|0)!=8)+o|0;break Y}if(w[(j?d+5|0:m)|0]|x[e+280>>1]>4865){break Y}t[l|0]=37}d=f;continue}}h=h+1|0;continue}}}b=P()|0;O()|0;nd(r)}nd(q);break a}nd(r);nd(q);zb(i)}jb=e+336|0;return s|0}b=P()|0;O()|0}zb(i);T(b|0);L()}function Od(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=jb-16|0;jb=l;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(a>>>0<=244){f=v[116096];h=a>>>0<11?16:a+11&-8;c=h>>>3|0;b=f>>>c|0;if(b&3){c=c+((b^-1)&1)|0;a=c<<3;b=a+464424|0;d=v[a+464432>>2];a=v[d+8>>2];l:{if((b|0)==(a|0)){m=464384,n=Pka(-2,c)&f,v[m>>2]=n;break l}v[a+12>>2]=b;v[b+8>>2]=a}a=d+8|0;b=c<<3;v[d+4>>2]=b|3;b=b+d|0;v[b+4>>2]=v[b+4>>2]|1;break a}k=v[116098];if(k>>>0>=h>>>0){break k}if(b){a=2<<c;a=(0-a|a)&b<<c;b=(0-a&a)-1|0;a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;d=(c|a)+(b>>>a|0)|0;a=d<<3;b=a+464424|0;g=v[a+464432>>2];a=v[g+8>>2];m:{if((b|0)==(a|0)){f=Pka(-2,d)&f;v[116096]=f;break m}v[a+12>>2]=b;v[b+8>>2]=a}v[g+4>>2]=h|3;c=g+h|0;a=d<<3;d=a-h|0;v[c+4>>2]=d|1;v[a+g>>2]=d;if(k){b=(k&-8)+464424|0;e=v[116101];a=1<<(k>>>3);n:{if(!(a&f)){v[116096]=a|f;a=b;break n}a=v[b+8>>2]}v[b+8>>2]=e;v[a+12>>2]=e;v[e+12>>2]=b;v[e+8>>2]=a}a=g+8|0;v[116101]=c;v[116098]=d;break a}j=v[116097];if(!j){break k}b=(0-j&j)-1|0;a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;b=v[((c|a)+(b>>>a|0)<<2)+464688>>2];e=(v[b+4>>2]&-8)-h|0;c=b;while(1){o:{a=v[c+16>>2];if(!a){a=v[c+20>>2];if(!a){break o}}c=(v[a+4>>2]&-8)-h|0;d=c>>>0<e>>>0;e=d?c:e;b=d?a:b;c=a;continue}break}i=v[b+24>>2];d=v[b+12>>2];if((d|0)!=(b|0)){a=v[b+8>>2];v[a+12>>2]=d;v[d+8>>2]=a;break b}c=b+20|0;a=v[c>>2];if(!a){a=v[b+16>>2];if(!a){break j}c=b+16|0}while(1){g=c;d=a;c=a+20|0;a=v[c>>2];if(a){continue}c=d+16|0;a=v[d+16>>2];if(a){continue}break}v[g>>2]=0;break b}h=-1;if(a>>>0>4294967231){break k}a=a+11|0;h=a&-8;j=v[116097];if(!j){break k}e=0-h|0;f=0;p:{if(h>>>0<256){break p}f=31;if(h>>>0>16777215){break p}a=a>>>8|0;g=a+1048320>>>16&8;a=a<<g;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|g))|0;f=(a<<1|h>>>a+21&1)+28|0}c=v[(f<<2)+464688>>2];q:{r:{s:{if(!c){a=0;break s}a=0;b=h<<((f|0)==31?0:25-(f>>>1|0)|0);while(1){t:{g=(v[c+4>>2]&-8)-h|0;if(g>>>0>=e>>>0){break t}d=c;e=g;if(e){break t}e=0;a=c;break r}g=v[c+20>>2];c=v[((b>>>29&4)+c|0)+16>>2];a=g?(g|0)==(c|0)?a:g:a;b=b<<1;if(c){continue}break}}if(!(a|d)){d=0;a=2<<f;a=(0-a|a)&j;if(!a){break k}b=(a&0-a)-1|0;a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;a=v[((c|a)+(b>>>a|0)<<2)+464688>>2]}if(!a){break q}}while(1){b=(v[a+4>>2]&-8)-h|0;c=b>>>0<e>>>0;e=c?b:e;d=c?a:d;b=v[a+16>>2];if(b){a=b}else{a=v[a+20>>2]}if(a){continue}break}}if(!d|v[116098]-h>>>0<=e>>>0){break k}f=v[d+24>>2];b=v[d+12>>2];if((d|0)!=(b|0)){a=v[d+8>>2];v[a+12>>2]=b;v[b+8>>2]=a;break c}c=d+20|0;a=v[c>>2];if(!a){a=v[d+16>>2];if(!a){break i}c=d+16|0}while(1){g=c;b=a;c=a+20|0;a=v[c>>2];if(a){continue}c=b+16|0;a=v[b+16>>2];if(a){continue}break}v[g>>2]=0;break c}c=v[116098];if(c>>>0>=h>>>0){d=v[116101];b=c-h|0;u:{if(b>>>0>=16){v[116098]=b;a=d+h|0;v[116101]=a;v[a+4>>2]=b|1;v[c+d>>2]=b;v[d+4>>2]=h|3;break u}v[116101]=0;v[116098]=0;v[d+4>>2]=c|3;a=c+d|0;v[a+4>>2]=v[a+4>>2]|1}a=d+8|0;break a}i=v[116099];if(i>>>0>h>>>0){b=i-h|0;v[116099]=b;c=v[116102];a=c+h|0;v[116102]=a;v[a+4>>2]=b|1;v[c+4>>2]=h|3;a=c+8|0;break a}a=0;j=h+47|0;b=j;if(v[116214]){c=v[116216]}else{v[116217]=-1;v[116218]=-1;v[116215]=4096;v[116216]=4096;v[116214]=l+12&-16^1431655768;v[116219]=0;v[116207]=0;c=4096}g=b+c|0;e=0-c|0;c=g&e;if(c>>>0<=h>>>0){break a}d=v[116206];if(d){b=v[116204];f=b+c|0;if(d>>>0<f>>>0|b>>>0>=f>>>0){break a}}if(w[464828]&4){break f}v:{w:{d=v[116102];if(d){a=464832;while(1){b=v[a>>2];if(b>>>0<=d>>>0&d>>>0<b+v[a+4>>2]>>>0){break w}a=v[a+8>>2];if(a){continue}break}}b=qp(0);if((b|0)==-1){break g}f=c;d=v[116215];a=d-1|0;if(a&b){f=(c-b|0)+(a+b&0-d)|0}if(f>>>0<=h>>>0|f>>>0>2147483646){break g}d=v[116206];if(d){a=v[116204];e=a+f|0;if(d>>>0<e>>>0|a>>>0>=e>>>0){break g}}a=qp(f);if((b|0)!=(a|0)){break v}break e}f=e&g-i;if(f>>>0>2147483646){break g}b=qp(f);if((b|0)==(v[a>>2]+v[a+4>>2]|0)){break h}a=b}if(!((a|0)==-1|h+48>>>0<=f>>>0)){b=v[116216];b=b+(j-f|0)&0-b;if(b>>>0>2147483646){b=a;break e}if((qp(b)|0)!=-1){f=b+f|0;b=a;break e}qp(0-f|0);break g}b=a;if((a|0)!=-1){break e}break g}d=0;break b}b=0;break c}if((b|0)!=-1){break e}}v[116207]=v[116207]|4}if(c>>>0>2147483646){break d}b=v[23509];c=c+3&-4;a=b+c|0;x:{y:{if(!c|a>>>0>b>>>0){if(_w()>>>0>=a>>>0){break y}if(ya(a|0)|0){break y}a=v[23509]}else{a=b}v[116064]=48;b=-1;break x}v[23509]=a}if(_w()>>>0<a>>>0){if(!(ya(a|0)|0)){break d}}v[23509]=a;if((b|0)==-1|(a|0)==-1|a>>>0<=b>>>0){break d}f=a-b|0;if(f>>>0<=h+40>>>0){break d}}a=v[116204]+f|0;v[116204]=a;if(a>>>0>y[116205]){v[116205]=a}z:{A:{B:{g=v[116102];if(g){a=464832;while(1){d=v[a>>2];c=v[a+4>>2];if((d+c|0)==(b|0)){break B}a=v[a+8>>2];if(a){continue}break}break A}a=v[116100];if(!(a>>>0<=b>>>0?a:0)){v[116100]=b}a=0;v[116209]=f;v[116208]=b;v[116104]=-1;v[116105]=v[116214];v[116211]=0;while(1){d=a<<3;c=d+464424|0;v[d+464432>>2]=c;v[d+464436>>2]=c;a=a+1|0;if((a|0)!=32){continue}break}d=f-40|0;a=b+8&7?-8-b&7:0;c=d-a|0;v[116099]=c;a=a+b|0;v[116102]=a;v[a+4>>2]=c|1;v[(b+d|0)+4>>2]=40;v[116103]=v[116218];break z}if(w[a+12|0]&8|d>>>0>g>>>0|b>>>0<=g>>>0){break A}v[a+4>>2]=c+f;a=g+8&7?-8-g&7:0;c=a+g|0;v[116102]=c;b=v[116099]+f|0;a=b-a|0;v[116099]=a;v[c+4>>2]=a|1;v[(b+g|0)+4>>2]=40;v[116103]=v[116218];break z}if(y[116100]>b>>>0){v[116100]=b}d=b+f|0;c=464832;C:{while(1){if((d|0)!=v[c>>2]){a=464832;c=v[c+8>>2];if(c){continue}break C}break}a=464832;if(w[c+12|0]&8){break C}v[c>>2]=b;v[c+4>>2]=v[c+4>>2]+f;j=(b+8&7?-8-b&7:0)+b|0;v[j+4>>2]=h|3;d=d+(d+8&7?-8-d&7:0)|0;i=h+j|0;a=d-i|0;D:{if((d|0)==(g|0)){v[116102]=i;a=v[116099]+a|0;v[116099]=a;v[i+4>>2]=a|1;break D}if(v[116101]==(d|0)){v[116101]=i;a=v[116098]+a|0;v[116098]=a;v[i+4>>2]=a|1;v[a+i>>2]=a;break D}e=v[d+4>>2];if((e&3)==1){f=e&-8;E:{if(e>>>0<=255){b=e>>>3|0;e=v[d+8>>2];c=v[d+12>>2];if((c|0)==(e|0)){m=464384,n=v[116096]&Pka(-2,b),v[m>>2]=n;break E}v[e+12>>2]=c;v[c+8>>2]=e;break E}h=v[d+24>>2];b=v[d+12>>2];F:{if((d|0)!=(b|0)){c=v[d+8>>2];v[c+12>>2]=b;v[b+8>>2]=c;break F}G:{e=d+20|0;c=v[e>>2];if(c){break G}e=d+16|0;c=v[e>>2];if(c){break G}b=0;break F}while(1){g=e;b=c;e=b+20|0;c=v[e>>2];if(c){continue}e=b+16|0;c=v[b+16>>2];if(c){continue}break}v[g>>2]=0}if(!h){break E}e=v[d+28>>2];c=(e<<2)+464688|0;H:{if(v[c>>2]==(d|0)){v[c>>2]=b;if(b){break H}m=464388,n=v[116097]&Pka(-2,e),v[m>>2]=n;break E}v[h+(v[h+16>>2]==(d|0)?16:20)>>2]=b;if(!b){break E}}v[b+24>>2]=h;c=v[d+16>>2];if(c){v[b+16>>2]=c;v[c+24>>2]=b}c=v[d+20>>2];if(!c){break E}v[b+20>>2]=c;v[c+24>>2]=b}d=d+f|0;e=v[d+4>>2];a=a+f|0}v[d+4>>2]=e&-2;v[i+4>>2]=a|1;v[a+i>>2]=a;if(a>>>0<=255){b=(a&-8)+464424|0;c=v[116096];a=1<<(a>>>3);I:{if(!(c&a)){v[116096]=a|c;a=b;break I}a=v[b+8>>2]}v[b+8>>2]=i;v[a+12>>2]=i;v[i+12>>2]=b;v[i+8>>2]=a;break D}e=31;if(a>>>0<=16777215){b=a>>>8|0;e=b+1048320>>>16&8;b=b<<e;d=b+520192>>>16&4;b=b<<d;c=b+245760>>>16&2;b=(b<<c>>>15|0)-(c|(d|e))|0;e=(b<<1|a>>>b+21&1)+28|0}v[i+28>>2]=e;v[i+16>>2]=0;v[i+20>>2]=0;d=(e<<2)+464688|0;J:{c=v[116097];b=1<<e;K:{if(!(c&b)){v[116097]=b|c;v[d>>2]=i;v[i+24>>2]=d;break K}e=a<<((e|0)==31?0:25-(e>>>1|0)|0);b=v[d>>2];while(1){c=b;if((v[b+4>>2]&-8)==(a|0)){break J}b=e>>>29|0;e=e<<1;d=c+(b&4)|0;b=v[d+16>>2];if(b){continue}break}v[d+16>>2]=i;v[i+24>>2]=c}v[i+12>>2]=i;v[i+8>>2]=i;break D}a=v[c+8>>2];v[a+12>>2]=i;v[c+8>>2]=i;v[i+24>>2]=0;v[i+12>>2]=c;v[i+8>>2]=a}a=j+8|0;break a}while(1){L:{c=v[a>>2];if(c>>>0<=g>>>0){e=c+v[a+4>>2]|0;if(e>>>0>g>>>0){break L}}a=v[a+8>>2];continue}break}d=f-40|0;a=b+8&7?-8-b&7:0;c=d-a|0;v[116099]=c;a=a+b|0;v[116102]=a;v[a+4>>2]=c|1;v[(b+d|0)+4>>2]=40;v[116103]=v[116218];a=(e+(e-39&7?39-e&7:0)|0)-47|0;c=a>>>0<g+16>>>0?g:a;v[c+4>>2]=27;a=v[116211];v[c+16>>2]=v[116210];v[c+20>>2]=a;a=v[116209];v[c+8>>2]=v[116208];v[c+12>>2]=a;v[116210]=c+8;v[116209]=f;v[116208]=b;v[116211]=0;a=c+24|0;while(1){v[a+4>>2]=7;b=a+8|0;a=a+4|0;if(b>>>0<e>>>0){continue}break}if((c|0)==(g|0)){break z}v[c+4>>2]=v[c+4>>2]&-2;e=c-g|0;v[g+4>>2]=e|1;v[c>>2]=e;if(e>>>0<=255){b=(e&-8)+464424|0;c=v[116096];a=1<<(e>>>3);M:{if(!(c&a)){v[116096]=a|c;a=b;break M}a=v[b+8>>2]}v[b+8>>2]=g;v[a+12>>2]=g;v[g+12>>2]=b;v[g+8>>2]=a;break z}a=31;if(e>>>0<=16777215){a=e>>>8|0;d=a+1048320>>>16&8;a=a<<d;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|d))|0;a=(a<<1|e>>>a+21&1)+28|0}v[g+28>>2]=a;v[g+16>>2]=0;v[g+20>>2]=0;b=(a<<2)+464688|0;N:{d=v[116097];c=1<<a;O:{if(!(d&c)){v[116097]=c|d;v[b>>2]=g;break O}a=e<<((a|0)==31?0:25-(a>>>1|0)|0);d=v[b>>2];while(1){b=d;if((e|0)==(v[b+4>>2]&-8)){break N}c=a>>>29|0;a=a<<1;c=(c&4)+b|0;d=v[c+16>>2];if(d){continue}break}v[c+16>>2]=g}v[g+24>>2]=b;v[g+12>>2]=g;v[g+8>>2]=g;break z}a=v[b+8>>2];v[a+12>>2]=g;v[b+8>>2]=g;v[g+24>>2]=0;v[g+12>>2]=b;v[g+8>>2]=a}a=v[116099];if(a>>>0<=h>>>0){break d}b=a-h|0;v[116099]=b;c=v[116102];a=c+h|0;v[116102]=a;v[a+4>>2]=b|1;v[c+4>>2]=h|3;a=c+8|0;break a}a=0;v[116064]=48;break a}P:{if(!f){break P}c=v[d+28>>2];a=(c<<2)+464688|0;Q:{if(v[a>>2]==(d|0)){v[a>>2]=b;if(b){break Q}j=Pka(-2,c)&j;v[116097]=j;break P}v[f+(v[f+16>>2]==(d|0)?16:20)>>2]=b;if(!b){break P}}v[b+24>>2]=f;a=v[d+16>>2];if(a){v[b+16>>2]=a;v[a+24>>2]=b}a=v[d+20>>2];if(!a){break P}v[b+20>>2]=a;v[a+24>>2]=b}R:{if(e>>>0<=15){a=e+h|0;v[d+4>>2]=a|3;a=a+d|0;v[a+4>>2]=v[a+4>>2]|1;break R}v[d+4>>2]=h|3;f=d+h|0;v[f+4>>2]=e|1;v[e+f>>2]=e;if(e>>>0<=255){b=(e&-8)+464424|0;c=v[116096];a=1<<(e>>>3);S:{if(!(c&a)){v[116096]=a|c;a=b;break S}a=v[b+8>>2]}v[b+8>>2]=f;v[a+12>>2]=f;v[f+12>>2]=b;v[f+8>>2]=a;break R}a=31;if(e>>>0<=16777215){a=e>>>8|0;g=a+1048320>>>16&8;a=a<<g;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|g))|0;a=(a<<1|e>>>a+21&1)+28|0}v[f+28>>2]=a;v[f+16>>2]=0;v[f+20>>2]=0;b=(a<<2)+464688|0;T:{c=1<<a;U:{if(!(c&j)){v[116097]=c|j;v[b>>2]=f;break U}a=e<<((a|0)==31?0:25-(a>>>1|0)|0);h=v[b>>2];while(1){b=h;if((v[b+4>>2]&-8)==(e|0)){break T}c=a>>>29|0;a=a<<1;c=(c&4)+b|0;h=v[c+16>>2];if(h){continue}break}v[c+16>>2]=f}v[f+24>>2]=b;v[f+12>>2]=f;v[f+8>>2]=f;break R}a=v[b+8>>2];v[a+12>>2]=f;v[b+8>>2]=f;v[f+24>>2]=0;v[f+12>>2]=b;v[f+8>>2]=a}a=d+8|0;break a}V:{if(!i){break V}c=v[b+28>>2];a=(c<<2)+464688|0;W:{if(v[a>>2]==(b|0)){v[a>>2]=d;if(d){break W}m=464388,n=Pka(-2,c)&j,v[m>>2]=n;break V}v[i+(v[i+16>>2]==(b|0)?16:20)>>2]=d;if(!d){break V}}v[d+24>>2]=i;a=v[b+16>>2];if(a){v[d+16>>2]=a;v[a+24>>2]=d}a=v[b+20>>2];if(!a){break V}v[d+20>>2]=a;v[a+24>>2]=d}X:{if(e>>>0<=15){a=e+h|0;v[b+4>>2]=a|3;a=a+b|0;v[a+4>>2]=v[a+4>>2]|1;break X}v[b+4>>2]=h|3;d=b+h|0;v[d+4>>2]=e|1;v[d+e>>2]=e;if(k){c=(k&-8)+464424|0;g=v[116101];a=1<<(k>>>3);Y:{if(!(a&f)){v[116096]=a|f;a=c;break Y}a=v[c+8>>2]}v[c+8>>2]=g;v[a+12>>2]=g;v[g+12>>2]=c;v[g+8>>2]=a}v[116101]=d;v[116098]=e}a=b+8|0}jb=l+16|0;return a|0}function Q6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;g=jb-32|0;jb=g;a:{b:{c:{d:{e:{if(ue(b,21619)){Lb(a);break e}if(ue(b,9843)){b=jb-128|0;jb=b;f=Lb(a);v[23588]=0;Y(134,b+96|0);a=v[23588];v[23588]=0;f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((a|0)!=1){v[23588]=0;v[b+64>>2]=0;R(1054,b+80|0,b- -64|0);a=v[23588];v[23588]=0;if((a|0)==1){break p}v[23588]=0;a=Q(800,f|0,b+80|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break o}yb(b+80|0);v[23588]=0;a=Q(941,a|0,16736)|0;c=v[23588];v[23588]=0;q:{if((c|0)==1){break q}v[23588]=0;v[b+64>>2]=7;R(1054,b+80|0,b- -64|0);c=v[23588];v[23588]=0;if((c|0)==1){break n}v[23588]=0;a=Q(800,a|0,b+80|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break m}yb(b+80|0);v[23588]=0;a=Q(941,a|0,16736)|0;c=v[23588];v[23588]=0;if((c|0)==1){break q}v[23588]=0;v[b+64>>2]=0;R(1054,b+80|0,b- -64|0);c=v[23588];v[23588]=0;if((c|0)==1){break l}v[23588]=0;a=Q(800,a|0,b+80|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break k}c=b+80|0;yb(c);v[23588]=0;c=Q(55,c|0,14699)|0;d=v[23588];v[23588]=0;if((d|0)==1){break j}d=Gb(c);yb(c);if(!d){break i}v[23588]=0;Q(941,a|0,14699)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break i}}a=P()|0;O()|0;break h}a=P()|0;O()|0;break g}a=P()|0;O()|0;break h}a=P()|0;O()|0;yb(b+80|0);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;yb(b+80|0);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;yb(b+80|0);break h}a=P()|0;O()|0;break h}c=Sb(b- -64|0);r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{d=v[b+108>>2];if(d){v[23588]=0;v[b+16>>2]=d;R(1054,b+32|0,b+16|0);d=v[23588];v[23588]=0;if((d|0)==1){break D}v[23588]=0;U(967,b+48|0,8924,b+32|0);d=v[23588];v[23588]=0;if((d|0)==1){break C}v[23588]=0;R(183,c|0,b+48|0);d=v[23588];v[23588]=0;if((d|0)==1){break B}yb(b+48|0);yb(b+32|0)}if(!Pd(w[b+112|0])){break x}v[23588]=0;d=Q(55,b+48|0,12690)|0;e=v[23588];v[23588]=0;if((e|0)==1){break z}v[23588]=0;R(183,c|0,d|0);e=v[23588];v[23588]=0;if((e|0)==1){break y}yb(d);break w}a=P()|0;O()|0;break r}a=P()|0;O()|0;break A}a=P()|0;O()|0;yb(b+48|0)}yb(b+32|0);break r}a=P()|0;O()|0;break r}a=P()|0;O()|0;yb(d);break r}if(!Pd(w[b+113|0])){break w}v[23588]=0;d=Q(55,b+48|0,12461)|0;e=v[23588];v[23588]=0;if((e|0)==1){break v}v[23588]=0;R(183,c|0,d|0);e=v[23588];v[23588]=0;if((e|0)==1){break u}yb(d)}if(Pd(w[b+114|0])){break t}break s}a=P()|0;O()|0;break r}a=P()|0;O()|0;yb(d);break r}v[23588]=0;d=Q(55,b+32|0,11054)|0;e=v[23588];v[23588]=0;E:{if((e|0)!=1){v[23588]=0;R(183,c|0,d|0);e=v[23588];v[23588]=0;if((e|0)==1){break E}yb(d);break s}a=P()|0;O()|0;break r}a=P()|0;O()|0;yb(d);break r}if(oc(v[c>>2],v[c+4>>2])){break f}v[23588]=0;a=Q(941,a|0,16766)|0;d=v[23588];v[23588]=0;if((d|0)!=1){v[23588]=0;d=Q(55,b|0,16736)|0;e=v[23588];v[23588]=0;F:{G:{H:{if((e|0)!=1){v[23588]=0;U(1055,b+16|0,c|0,d|0);e=v[23588];v[23588]=0;if((e|0)==1){break H}v[23588]=0;Q(800,a|0,b+16|0)|0;a=v[23588];v[23588]=0;if((a|0)==1){break G}yb(b+16|0);yb(d);break f}a=P()|0;O()|0;break r}a=P()|0;O()|0;break F}a=P()|0;O()|0;yb(b+16|0)}yb(d);break r}a=P()|0;O()|0}We(c)}Df(b+96|0)}yb(f);break a}We(c);Df(b+96|0);jb=b+128|0;break e}if(ue(b,8092)){v[g>>2]=0;Ap(a,g);break e}if(ue(b,8070)){v[g>>2]=7;Ap(a,g);break e}if(ue(b,10774)){v[g>>2]=0;Ap(a,g);break e}if(ue(b,10546)){Mc(a,14699);break e}if(ue(b,11323)){b=Mc(g,14699);c=Gb(b);v[23588]=0;Q(55,a|0,(c?15771:15441)|0)|0;a=v[23588];v[23588]=0;if((a|0)==1){break d}yb(b);break e}if(ue(b,7372)){b=jb-48|0;jb=b;_D(b+16|0);v[23588]=0;Y(151,b|0);c=v[23588];v[23588]=0;I:{J:{K:{L:{if((c|0)!=1){v[23588]=0;U(152,b+32|0,b+16|0,b|0);c=v[23588];v[23588]=0;if((c|0)==1){break L}v[23588]=0;R(1015,a|0,b+32|0);a=v[23588];v[23588]=0;if((a|0)==1){break K}zb(b+32|0);zb(b);zb(b+16|0);jb=b+48|0;break e}a=P()|0;O()|0;break I}a=P()|0;O()|0;break J}a=P()|0;O()|0;zb(b+32|0)}zb(b)}zb(b+16|0);break a}if(ue(b,9859)){b=jb-16|0;jb=b;e=jb-16|0;jb=e;v[e+8>>2]=101;c=jb-112|0;jb=c;f=Sb(c+96|0);M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{d=v[e+8>>2];if(d&1){v[23588]=0;R(140,c- -64|0,19988498);d=v[23588];v[23588]=0;if((d|0)==1){break $}v[23588]=0;R(124,f|0,c- -64|0);d=v[23588];v[23588]=0;if((d|0)==1){break _}zb(c- -64|0);d=v[e+8>>2]}if(!(d&4)){break Y}v[23588]=0;d=ga(141)|0;h=v[23588];v[23588]=0;if((h|0)==1){break X}if(!d){break Z}break Y}d=P()|0;O()|0;break N}d=P()|0;O()|0;zb(c- -64|0);break N}v[23588]=0;Y(142,c- -64|0);d=v[23588];v[23588]=0;aa:{if((d|0)!=1){v[23588]=0;R(124,f|0,c- -64|0);d=v[23588];v[23588]=0;if((d|0)==1){break aa}zb(c- -64|0);break Y}d=P()|0;O()|0;break N}d=P()|0;O()|0;zb(c- -64|0);break N}ba:{d=v[e+8>>2];if(!(d&32)){break ba}v[23588]=0;Y(134,c- -64|0);d=v[23588];v[23588]=0;ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{if((d|0)!=1){v[23588]=0;R(143,c+48|0,c- -64|0);d=v[23588];v[23588]=0;if((d|0)==1){break da}d=rh(v[c+52>>2],w[c+59|0]);zb(c+48|0);if(!d){v[23588]=0;Y(144,c+32|0);d=v[23588];v[23588]=0;if((d|0)==1){break ua}v[23588]=0;R(143,c+16|0,c- -64|0);d=v[23588];v[23588]=0;if((d|0)==1){break ta}v[23588]=0;U(145,c+48|0,c+32|0,c+16|0);d=v[23588];v[23588]=0;if((d|0)==1){break sa}v[23588]=0;R(124,f|0,c+48|0);d=v[23588];v[23588]=0;if((d|0)==1){break ra}zb(c+48|0);zb(c+16|0);ac(c+32|0)}d=Xo(c- -64|0);if(!rh(v[d+4>>2],w[d+11|0])){v[23588]=0;Y(146,c+32|0);h=v[23588];v[23588]=0;if((h|0)==1){break oa}v[23588]=0;U(147,c+48|0,c+32|0,d|0);d=v[23588];v[23588]=0;if((d|0)==1){break na}v[23588]=0;R(124,f|0,c+48|0);d=v[23588];v[23588]=0;if((d|0)==1){break ma}zb(c+48|0);ac(c+32|0)}v[23588]=0;R(148,c+48|0,c- -64|0);d=v[23588];v[23588]=0;if((d|0)==1){break ka}d=rh(v[c+52>>2],w[c+59|0]);zb(c+48|0);if(!d){v[23588]=0;Y(144,c+32|0);d=v[23588];v[23588]=0;if((d|0)==1){break ja}v[23588]=0;R(148,c+16|0,c- -64|0);d=v[23588];v[23588]=0;if((d|0)==1){break ia}v[23588]=0;U(145,c+48|0,c+32|0,c+16|0);d=v[23588];v[23588]=0;if((d|0)==1){break ha}v[23588]=0;R(124,f|0,c+48|0);d=v[23588];v[23588]=0;if((d|0)==1){break ga}zb(c+48|0);zb(c+16|0);ac(c+32|0)}Df(c- -64|0);d=v[e+8>>2];break ba}d=P()|0;O()|0;break N}d=P()|0;O()|0;break ca}d=P()|0;O()|0;break pa}d=P()|0;O()|0;break qa}d=P()|0;O()|0;zb(c+48|0)}zb(c+16|0)}ac(c+32|0);break ca}d=P()|0;O()|0;break ca}d=P()|0;O()|0;break la}d=P()|0;O()|0;zb(c+48|0)}ac(c+32|0);break ca}d=P()|0;O()|0;break ca}d=P()|0;O()|0;break ca}d=P()|0;O()|0;break ea}d=P()|0;O()|0;break fa}d=P()|0;O()|0;zb(c+48|0)}zb(c+16|0)}ac(c+32|0);break ca}d=P()|0;O()|0}Df(c- -64|0);break N}va:{if(!(d&64)){break va}v[23588]=0;d=ga(141)|0;h=v[23588];v[23588]=0;if((h|0)==1){break X}if(d){break va}d=c- -64|0;Lb(d);v[23588]=0;R(124,f|0,d|0);d=v[23588];v[23588]=0;if((d|0)==1){break O}zb(c- -64|0)}if(w[e+8|0]&128){v[23588]=0;Y(149,c- -64|0);d=v[23588];v[23588]=0;if((d|0)==1){break W}v[23588]=0;R(124,f|0,c- -64|0);d=v[23588];v[23588]=0;if((d|0)==1){break V}zb(c- -64|0)}v[23588]=0;h=Q(1,c- -64|0,21619)|0;d=v[23588];v[23588]=0;if((d|0)==1){break U}v[23588]=0;U(150,c|0,f|0,h|0);d=v[23588];v[23588]=0;if((d|0)==1){break T}v[23588]=0;Y(151,c+48|0);d=v[23588];v[23588]=0;if((d|0)==1){break S}v[23588]=0;U(152,b|0,c|0,c+48|0);d=v[23588];v[23588]=0;if((d|0)==1){break R}zb(c+48|0);zb(c);zb(h);Rl(f);jb=c+112|0;break M}d=P()|0;O()|0;break N}d=P()|0;O()|0;break N}d=P()|0;O()|0;zb(c- -64|0);break N}d=P()|0;O()|0;break N}d=P()|0;O()|0;break P}d=P()|0;O()|0;break Q}d=P()|0;O()|0;zb(c+48|0)}zb(c)}zb(h);break N}d=P()|0;O()|0;zb(c- -64|0)}Rl(f);T(d|0);L()}jb=e+16|0;v[23588]=0;R(1015,a|0,b|0);a=v[23588];v[23588]=0;if((a|0)!=1){zb(b);jb=b+16|0;break e}break b}if(ue(b,10475)){b=jb-48|0;jb=b;xr(b);v[23588]=0;R(143,b+32|0,b|0);c=v[23588];v[23588]=0;wa:{xa:{if((c|0)!=1){v[23588]=0;R(1015,a|0,b+32|0);a=v[23588];v[23588]=0;if((a|0)==1){break xa}zb(b+32|0);Df(b);jb=b+48|0;break e}a=P()|0;O()|0;break wa}a=P()|0;O()|0;zb(b+32|0)}Df(b);break a}if(ue(b,11286)){b=jb-32|0;jb=b;xr(b);v[23588]=0;R(1015,a|0,Xo(b)|0);a=v[23588];v[23588]=0;if((a|0)!=1){Df(b);jb=b+32|0;break e}a=P()|0;O()|0;Df(b);break a}if(ue(b,9872)){b=jb-48|0;jb=b;xr(b+16|0);c=v[b+28>>2];ya:{if(c){v[23588]=0;v[b+12>>2]=c;R(1054,a|0,b+12|0);a=v[23588];v[23588]=0;if((a|0)!=1){break ya}a=P()|0;O()|0;Df(b+16|0);break a}Lb(a)}Df(b+16|0);jb=b+48|0;break e}if(ue(b,12680)){xr(g);b=w[g+16|0];v[23588]=0;Q(55,a|0,(Pd(b)?15441:15771)|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){Df(g);break e}a=P()|0;O()|0;Df(g);break a}if(ue(b,9888)){xr(g);b=w[g+17|0];v[23588]=0;Q(55,a|0,(Pd(b)?15441:15771)|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){Df(g);break e}a=P()|0;O()|0;Df(g);break a}if(ue(b,12133)){xr(g);b=w[g+18|0];v[23588]=0;Q(55,a|0,(Pd(b)?15441:15771)|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){Df(g);break e}a=P()|0;O()|0;Df(g);break a}if(ue(b,12435)){b=jb-16|0;jb=b;c=jb-32|0;jb=c;d=Lb(b);v[23588]=0;Y(134,c|0);f=v[23588];v[23588]=0;za:{Aa:{Ba:{if((f|0)!=1){v[23588]=0;R(135,d|0,Xo(c)|0);f=v[23588];v[23588]=0;if((f|0)==1){break Ba}Df(c);jb=c+32|0;break za}a=P()|0;O()|0;break Aa}a=P()|0;O()|0;Df(c)}zb(d);break a}v[23588]=0;R(1015,a|0,b|0);a=v[23588];v[23588]=0;if((a|0)!=1){zb(b);jb=b+16|0;break e}break b}if(ue(b,8213)){b=jb-16|0;jb=b;c=jb-48|0;jb=c;d=Lb(b);v[23588]=0;R(137,c+16|0,4138);f=v[23588];v[23588]=0;Ca:{Da:{Ea:{Fa:{Ga:{if((f|0)!=1){v[c+12>>2]=15;v[c+8>>2]=0;v[23588]=0;v[c+4>>2]=0;ea(138,c+32|0,c+16|0,c+12|0,c+8|0,c+4|0);f=v[23588];v[23588]=0;if((f|0)==1){break Ga}v[23588]=0;Q(98,d|0,c+32|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break Fa}zb(c+32|0);ac(c+16|0);jb=c+48|0;break Ca}a=P()|0;O()|0;break Da}a=P()|0;O()|0;break Ea}a=P()|0;O()|0;zb(c+32|0)}ac(c+16|0)}zb(d);T(a|0);L()}v[23588]=0;R(1015,a|0,b|0);a=v[23588];v[23588]=0;if((a|0)!=1){zb(b);jb=b+16|0;break e}break b}if(ue(b,6825)){b=jb-16|0;jb=b;hn(b,0,19565);v[23588]=0;R(1015,a|0,b|0);a=v[23588];v[23588]=0;if((a|0)!=1){zb(b);jb=b+16|0;break e}break b}if(ue(b,6458)){b=jb-48|0;jb=b;c=xc(b+16|0,17626);v[23588]=0;R(1056,b|0,2);d=v[23588];v[23588]=0;Ha:{Ia:{Ja:{Ka:{if((d|0)!=1){v[23588]=0;U(2,b+32|0,c|0,b|0);d=v[23588];v[23588]=0;if((d|0)==1){break Ka}v[23588]=0;R(1015,a|0,b+32|0);a=v[23588];v[23588]=0;if((a|0)==1){break Ja}zb(b+32|0);zb(b);zb(c);jb=b+48|0;break e}a=P()|0;O()|0;break Ha}a=P()|0;O()|0;break Ia}a=P()|0;O()|0;zb(b+32|0)}zb(b)}zb(c);break a}if(ue(b,11309)){b=jb-16|0;jb=b;hn(b,0,17965);v[23588]=0;R(1015,a|0,b|0);a=v[23588];v[23588]=0;if((a|0)!=1){zb(b);jb=b+16|0;break e}break b}if(ue(b,10482)){b=jb-16|0;jb=b;ur(b,0);v[23588]=0;R(1015,a|0,b|0);a=v[23588];v[23588]=0;if((a|0)!=1){zb(b);jb=b+16|0;break e}break b}if(ue(b,10457)){b=jb-16|0;jb=b;ur(b,2);v[23588]=0;R(1015,a|0,b|0);a=v[23588];v[23588]=0;if((a|0)!=1){zb(b);jb=b+16|0;break e}break b}if(ue(b,10442)){b=jb-16|0;jb=b;ur(b,3);v[23588]=0;R(1015,a|0,b|0);a=v[23588];v[23588]=0;if((a|0)!=1){zb(b);jb=b+16|0;break e}break b}Lb(a)}jb=g+32|0;break c}a=P()|0;O()|0;yb(b);break a}return}a=P()|0;O()|0;zb(b)}T(a|0);L()}function Zaa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;g=jb-48|0;jb=g;b=v[a+1074308>>2];if(!(b>>>0>18285125|(b|0)==18284544)){Zf(a+1074312|0,0)}i=a+1074308|0;b=g+32|0;h=a+1074312|0;Cb(b,h,0);d=Bb(v[v[g+32>>2]>>2],v[g+36>>2]);e=a+480180|0;c=v[e>>2];Cb(b,h,0);o=d&(c&16777248)!=0;C=Bb(v[v[g+32>>2]>>2],v[g+36>>2]);D=v[e>>2];a:{d=v[a+1074308>>2];if(d>>>0>18874367){break a}d=!o;f=a+480192|0;c=1;while(1){b:{b=c&65535;if(b>>>0<=x[f>>1]){b=v[((b<<2)+a|0)+900380>>2];if(!b){break b}v[g+32>>2]=B(w[b+20|0],100)>>>6;v[g+16>>2]=100;F=b,G=v[Jb(g+32|0,g+16|0)>>2],t[F+20|0]=G;if(!(d|y[i>>2]<18350080)){break b}j=t[b+26|0];t[b+26|0]=((j>>31|1)+j|0)/2;if(!(d|y[i>>2]<18285314)){break b}WA(Gh(b,2),v[e>>2]);j=v[a+1074308>>2];c:{if(j>>>0<18284544){break c}if(j>>>0>18285135){break b}if(!w[b+34|0]){break c}if(!uj(w[b+31|0])){break c}Nb(h,2,1);if(y[i>>2]>18285135){break b}}if(!(w[b+24|0]|(w[b+23|0]|(w[b+19|0]|w[b+20|0])))){break b}Nb(h,1,1)}d:{if(!(v[a+480180>>2]&16777248)|y[i>>2]>18285313&o){break d}c=x[a+480190>>1]+1&65535;b=1;while(1){if((b|0)==(c|0)){break d}d=B(b,104)+a|0;e=d+484419|0;if(!(w[e|0]|!(w[d+484421|0]|w[d+484420|0]))){t[e|0]=255}b=b+1|0;continue}}d=a+901404|0;f=Hz(d);while(1){if((d|0)!=(f|0)){b=d;j=fo(b);while(1){if((b|0)!=(j|0)){c=w[b|0];e:{f:{if((c-97&255)>>>0<=5){k=c-32|0;break f}if(!(c-88>>>0<2|c-120>>>0<2)){k=99;if((c|0)==75|(c|0)==107){break f}break e}k=122}t[b|0]=k}b=b+1|0;continue}break}d=d+32|0;continue}break}d=v[a+1074308>>2];break a}c=c+1|0;continue}}g:{h:{i:{if((d|0)==18874368|d>>>0>18874895){break i}if(!(v[a+480180>>2]&16777252)){break h}f=x[a+480192>>1]+1&65535;c=0;b=1;while(1){if((b|0)==(f|0)){if(!c){break i}Nb(h,3,1);d=v[i>>2]}else{e=v[((b<<2)+a|0)+900380>>2];if(!(!e|!w[e+31|0])){t[e+33|0]=13;c=1}b=b+1|0;continue}break}}if((d|0)==19005440|d>>>0>19006225){break g}}if(!(v[a+480180>>2]&16777248)){break g}Cb(g+32|0,h,0);if(!Bb(v[v[g+32>>2]>>2],v[g+36>>2])){Cb(g+16|0,h,1);if(!Bb(v[v[g+16>>2]>>2],v[g+20>>2])){break g}}c=x[a+480192>>1]+1&65535;b=1;while(1){if((b|0)==(c|0)){break g}d=v[((b<<2)+a|0)+900380>>2];if(!(!d|!w[d+19|0]|!(t[d+80|0]&1))){t[d+19|0]=0}b=b+1|0;continue}}j:{k:{l:{m:{n:{if(y[i>>2]>19007232){break n}b=a+906300|0;d=ek(b);while(1){if((b|0)==(d|0)){break n}c=g+16|0;e=b+80|0;FM(c,e);v[23588]=0;X(235,g+32|0,0,8,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break m}yb(g+16|0);c=g+32|0;Ku(e,c);b=b+160|0;yb(c);continue}}o:{p:{q:{if(v[a+480180>>2]!=4){break q}c=v[i>>2];if(c>>>0<19007257){break o}if(c>>>0>19071235){break p}if(w[a+1074368|0]!=4){break q}wy(a,5)}c=v[i>>2]}if(c>>>0>19202054){break l}d=19202048;if((c|0)==19202048){break k}}f=x[a+480192>>1]+1&65535;d=1;while(1){if((d|0)==(f|0)){break l}e=v[((d<<2)+a|0)+900380>>2];r:{if(!e|!w[e+20|0]|!w[e+31|0]){break r}b=e+236|0;j=yq(b);while(1){if((b|0)!=(j|0)){l=x[b>>1];b=b+2|0;if(!l){continue}break r}break}t[e+20|0]=0}d=d+1|0;continue}}a=P()|0;O()|0;yb(g+16|0);T(a|0);L()}d=c;if(c>>>0>19267583){break j}}e=!o;f=x[a+480192>>1]+1&65535;b=1;while(1){if((b|0)==(f|0)){break j}c=v[((b<<2)+a|0)+900380>>2];s:{if(!c){break s}d=t[c+26|0];t[c+26|0]=((d>>31|1)+d|0)/2;d=v[i>>2];if(!(e|d>>>0<18350080)){break s}t[c+19|0]=w[c+19|0]+3>>>2}b=b+1|0;continue}}t:{if(d>>>0>19398673){break t}c=x[a+480192>>1];b=1;while(1){e=b&65535;if(e>>>0>c>>>0){break t}e=v[((e<<2)+a|0)+900380>>2];if(!e|w[e+65|0]==255){b=b+1|0;continue}else{Nb(h,94,1);d=v[i>>2]}break}}u:{if(d>>>0>19399427){break u}c=x[a+480192>>1];b=1;while(1){e=b&65535;if(e>>>0>c>>>0){break u}e=v[((e<<2)+a|0)+900380>>2];if(!e|w[e+36|0]>1){b=b+1|0;continue}else{Nb(h,101,1);d=v[i>>2]}break}}v:{if(d>>>0>19923027){break v}c=x[a+480190>>1];b=1;while(1){d=b&65535;if(d>>>0>c>>>0){break v}d=B(d,104)+a|0;if(!Zd(v[d+484380>>2],v[d+484400>>2])|!(w[d+484414|0]&20)){b=b+1|0;continue}else{Nb(h,116,1)}break}}b=jb-16|0;jb=b;u[g+12>>1]=0;v[g+8>>2]=a;Cb(b+8|0,a+1074312|0,0);F=g,G=Bb(v[v[b+8>>2]>>2],v[b+12>>2]),t[F+14|0]=G;jb=b+16|0;q=v[g+8>>2];r=v[g+12>>2];b=a+484344|0;k=b;z=Af(v[b>>2],v[b+4>>2])-1&65535;d=jb-32|0;jb=d;w:{if(Af(v[b>>2],v[b+4>>2])>>>0<=z>>>0){break w}while(1){b=A&65535;if(b>>>0>z>>>0){break w}c=ag(v[k>>2],b);e=v[c>>2];if(Ob(e,v[c+4>>2])){c=Eb(e);E=Eb(v[ag(v[k>>2],b)+4>>2]);v[d+24>>2]=q;v[d+28>>2]=r;v[d+8>>2]=q;v[d+12>>2]=r;j=d+8|0;p=jb-16|0;jb=p;v[p+8>>2]=c;while(1){if(Ob(c,E)){l=jb-16|0;jb=l;s=x[j+4>>1];b=s+1|0;u[j+4>>1]=b;f=v[j>>2];u[j+4>>1]=x[f+480188>>1]>(b&65535)>>>0?b:0;x:{if(fh(w[c|0])){break x}e=v[f+1074308>>2];y:{n=v[f+480180>>2];z:{A:{if((n|0)==2){if(e>>>0>18415615){break A}if(w[c+3|0]!=23){break z}vf(c+5|0,64);break z}if(n&16777248){B:{C:{if(e>>>0>=18285314){if(w[j+6|0]){break C}f=0;b=0;if(e>>>0>18874367){break B}}D:{switch(w[c+3|0]-20|0){case 3:vf(c+5|0,128);break C;case 0:break D;default:break C}}b=w[c+5|0];if((b|0)!=208){if((b|0)!=192){break C}t[c|0]=254;t[c+3|0]=0;break C}t[c+3|0]=0}E:{F:{G:{if(e>>>0>=18350080){if(w[j+6|0]){break G}f=0;b=0;if(e>>>0>18874367){break B}}b=w[c+3|0];if(b>>>0>29){break F}f=1;if(!(1<<b&536873152)){break F}break E}f=0;b=0;if(e>>>0>18874367){break B}b=w[c+3|0]}f=0}b=(b|0)==24|(b|0)==22}H:{if(!(b?1:f)){break H}f=w[c+5|0];b=f&15;if(!b|(b|0)==15){break H}f=f&240;if(!f|(f|0)==240){break H}t[c+5|0]=w[c+3|0]==24?f:b}I:{if((e|0)==19005440|e>>>0>19005699){break I}b=x[v[j>>2]+480192>>1];if(w[j+6|0]|(!b|b>>>0>=w[c+1|0])){break I}t[c+4|0]=0;t[c+2|0]=1}if(w[c+3|0]!=18|w[c+5|0]!=17){break A}if(e>>>0>19468801){break y}Cb(l+8|0,v[j>>2]+1074312|0,22);if(!Bb(v[v[l+8>>2]>>2],v[l+12>>2])|v[v[j>>2]+480208>>2]&4){break A}t[c+5|0]=0;break A}if((n|0)!=4){break A}b=!w[j+6|0];J:{if((b|e>>>0<18285314)&e>>>0<18874368){break J}if(e>>>0>19137025){break y}if(w[c+3|0]!=23|w[c+5|0]<65){break J}t[c+3|0]=0}K:{L:{M:{if(!(b&e>>>0<18874368?0:e>>>0>=18415616)){f=w[c+3|0];b=w[c+2|0];if((f|0)!=10|(b|0)!=11){break M}f=0;t[c+3|0]=0;break K}if(e>>>0>18874639){break L}f=w[c+3|0];b=w[c+2|0]}if((b|0)!=11|(f|0)!=4){break K}b=w[c+4|0];if(!(b|w[j+6|0])){f=4;break K}f=4;m=w[c+5|0];if(!m){break K}t[c+2|0]=0;F=c,G=Au(m+(b<<4)|0),t[F+5|0]=G;break K}if(e>>>0>19007240){break y}f=w[c+3|0]}if(w[c+5|0]|(f|0)!=16){break A}t[c+3|0]=0}if(e>>>0>18874367){break y}}f=w[c+3|0];m=w[c+5|0]&240;N:{O:{if((f|0)!=28|(m|0)!=96){b=0}else{if(!w[j+6|0]|(n|0)!=4){break O}b=e>>>0<18350080}if(!(b|(f|0)==20&(m|0)==96)){break N}}b=B(s,-6)+c|0;while(1){if(b>>>0<c>>>0){if(!((w[b+3|0]|8)!=28|(w[b+5|0]&240)!=96)){t[b+3|0]=0}b=b+6|0;continue}break}f=w[c+3|0]}if((f|0)!=20|(m|0)!=224){break y}b=B(s,-6)+c|0;while(1){if(b>>>0>=c>>>0){break y}if(!(w[b+3|0]!=20|(w[b+5|0]&240)!=224)){t[b+3|0]=0}b=b+6|0;continue}}b=w[c+2|0];if(!((b|0)!=8|e>>>0>19333174|(e|0)==19333120)){e=w[c+4|0];b=w[c+3|0];if(!(!e|(b|0)!=7)){t[c+3|0]=11;break x}P:{Q:{switch(b-5|0){default:if((b|0)!=26){break x}break;case 1:break x;case 2:break P;case 0:break Q}}f=w[c+5|0];if(!(f&15)){t[c+2|0]=0;t[c+3|0]=5;t[c+5|0]=f|e&15;break x}R:{switch(b-5|0){case 1:break x;case 0:case 2:break P;default:break R}}if((b|0)!=26){break x}}t[c+2|0]=0;break x}if(!(w[c+3|0]|((n|0)==16777216|(b|0)!=15))){t[c+2|0]=0;t[c+3|0]=10;t[c+5|0]=w[c+4|0]<<3;break x}if(w[c+3|0]!=10|e>>>0>19922963|(b|0)!=15){break x}if(w[c+4|0]?w[c+5|0]:1){t[c+2|0]=0;break x}t[c+3|0]=0}jb=l+16|0;c=v[Bk(p+8|0)>>2];continue}break}b=v[j+4>>2];v[d+16>>2]=v[j>>2];v[d+20>>2]=b;jb=p+16|0}A=A+1|0;continue}}v[g+32>>2]=q;v[g+36>>2]=r;jb=d+32|0;S:{b=y[a+1074308>>2]<19267584;if(b&o){b=41872;while(1){if((b|0)==42216){break S}d=v[i>>2];c=v[b+4>>2];Nb(h,v[b>>2],d>>>0>=c>>>0|(d|0)==(c&-65536));b=b+8|0;continue}}if(!(b&((D|0)==4&C))){break S}b=42224;while(1){if((b|0)==42464){break S}Nb(h,v[b>>2],y[i>>2]>=y[b+4>>2]);b=b+8|0;continue}}T:{U:{d=v[a+480180>>2];if(d&16777248){b=42464;while(1){if((b|0)==42520){break U}d=v[i>>2];c=v[b+4>>2];e=c&-65536;if(!(d>>>0>=e>>>0&(c>>>0<=d>>>0|d>>>0<=e>>>0))){Zf(h,v[b>>2])}b=b+8|0;continue}}b=42592;c=42528;V:{switch(d-2|0){case 2:while(1){if((c|0)==42592){break U}if(y[i>>2]<y[c+4>>2]){Zf(h,v[c>>2])}c=c+8|0;continue};case 0:break V;default:break T}}while(1){if((b|0)==42680){break U}if(y[i>>2]<y[b+4>>2]){Zf(h,v[b>>2])}b=b+8|0;continue}}d=v[a+480180>>2]}W:{if((d|0)==4){b=v[i>>2];if(b>>>0>18415615){break W}Nb(h,98,1)}b=v[i>>2]}c=8;if(b-19333159>>>0<=33){b=0;while(1){if((b|0)!=5){d=b+77|0;Cb(g+32|0,h,d);Zf(Nb(h,b+86|0,Bb(v[v[g+32>>2]>>2],v[g+36>>2])),d);b=b+1|0;continue}break}b=v[i>>2]}X:{if(b>>>0>=18284544){if(b>>>0>18874627){break X}c=6;if((b|0)==18874368){break X}}Nb(h,c,1)}b=v[a+1074308>>2];Y:{if(w[a+480208|0]&16){if(b>>>0<=19136511){Zf(h,7);break Y}if(!(v[a+480180>>2]&16777248)|b>>>0>19267583){break Y}Nb(h,7,1);break Y}if((b|0)==19922944|b>>>0>19922997){break Y}Zf(h,7)}Cb(g+32|0,h,31);Z:{if(!Bb(v[v[g+32>>2]>>2],v[g+36>>2])){break Z}b=v[i>>2];if(b>>>0<19071234|b>>>0>19398722){break Z}c=x[a+480192>>1];b=1;while(1){d=b&65535;if(d>>>0>c>>>0){break Z}_:{d=v[((d<<2)+a|0)+900380>>2];if(!d){break _}e=w[d+65|0];if(!(w[d+60|0]&4)|(e|0)==255|e>>>0<=w[d- -64|0]){break _}Nb(h,97,1);break Z}b=b+1|0;continue}}d=v[a+480180>>2];$:{if(!(d&16777218)){break $}c=x[a+480190>>1];b=1;while(1){e=b&65535;if(e>>>0>c>>>0){break $}b=b+1|0;if(!(w[(B(e,104)+a|0)+484415|0]&2)){continue}break}aa:{ba:{ca:{if(!(!x[a+480192>>1]|(d|0)!=16777216)){b=v[i>>2];if(b>>>0<19398688){break ba}if(b>>>0>19464277){break ca}Nb(h,109,1)}b=v[i>>2]}if((b|0)==19922944|b>>>0>19922996){break aa}}Zf(h,111);b=v[i>>2]}d=v[a+480180>>2];if(!((d|0)!=2|b>>>0>19464191)){Nb(h,108,1);break $}if((d|0)==2){break $}Zf(h,108)}b=v[i>>2];da:{ea:{if(b>>>0<19333186){break ea}if(b>>>0<=19923013){if(!(v[a+480180>>2]&16777252)){break ea}b=a+906300|0;d=ek(b);while(1){if((b|0)!=(d|0)){fa:{if((w[b+16|0]|w[b+17|0]<<8|(w[b+18|0]<<16|w[b+19|0]<<24))!=1146637647|(w[b+20|0]|w[b+21|0]<<8|(w[b+22|0]<<16|w[b+23|0]<<24))!=-271958638){break fa}if((ed(v[b+4>>2],v[b+8>>2])|0)!=32){break fa}c=Mc(g+32|0,16817);Ku(b+80|0,c);yb(c)}b=b+160|0;continue}break}b=v[i>>2]}if(b>>>0>19988488){break da}}if(!(v[a+480180>>2]&16777252)){break da}b=a+906300|0;d=ek(b);while(1){if((b|0)==(d|0)){break da}a=b;b=b+160|0;if(!xi(v[a+16>>2],v[a+20>>2])){continue}break}Nb(h,117,1)}jb=g+48|0}function h5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=jb-32|0;jb=h;d=Mc(h+16|0,11520);e=dh(c,d);yb(d);a:{b:{c:{d:{e:{if(e){el(a,v[b+24>>2]+1298356|0);break e}d=Mc(h+16|0,10926);e=dh(c,d);yb(d);if(e){el(a,v[b+24>>2]+1298344|0);break e}d=Mc(h+16|0,11350);e=dh(c,d);yb(d);if(e){el(a,v[b+24>>2]+1298392|0);break e}d=Mc(h+16|0,10918);e=dh(c,d);yb(d);if(e){el(a,v[b+24>>2]+1298380|0);break e}d=Mc(h+16|0,8203);e=dh(c,d);yb(d);if(e){c=h+16|0;d=v[v[b+24>>2]+480184>>2];b=32624;f:{g:{while(1){if((b|0)==32672){break g}if((d|0)!=v[b>>2]){b=b+12|0;continue}break}hn(c,0,v[b+8>>2]);break f}Lb(c)}v[23588]=0;R(1015,a|0,c|0);a=v[23588];v[23588]=0;if((a|0)==1){break d}zb(h+16|0);break e}d=Mc(h+16|0,10903);e=dh(c,d);yb(d);if(e){j=v[v[b+24>>2]+480184>>2];c=jb+-64|0;jb=c;b=32624;f=Xf(c+48|0);i=h+16|0;d=Lb(i);while(1){if((b|0)!=32672){if((j|0)==v[b>>2]){e=v[b+4>>2];v[23588]=0;e=Q(1,c+32|0,e|0)|0;g=v[23588];v[23588]=0;h:{i:{j:{k:{l:{m:{if((g|0)!=1){v[23588]=0;U(845,c+24|0,f|0,e|0);g=v[23588];v[23588]=0;if((g|0)==1){break k}if(!w[c+28|0]){break h}if(!rh(v[d+4>>2],w[d+11|0])){v[23588]=0;g=Q(1,c+8|0,17737)|0;m=v[23588];v[23588]=0;if((m|0)==1){break m}v[23588]=0;Q(98,d|0,g|0)|0;m=v[23588];v[23588]=0;if((m|0)==1){break l}zb(g)}v[23588]=0;Q(98,d|0,e|0)|0;g=v[23588];v[23588]=0;if((g|0)!=1){break h}b=P()|0;O()|0;break j}b=P()|0;O()|0;break i}b=P()|0;O()|0;break j}b=P()|0;O()|0;zb(g);break j}b=P()|0;O()|0}zb(e)}zb(d);kM(f);T(b|0);L()}zb(e)}b=b+12|0;continue}break}kM(f);jb=c- -64|0;v[23588]=0;R(1015,a|0,i|0);a=v[23588];v[23588]=0;if((a|0)!=1){zb(h+16|0);break e}c=P()|0;O()|0;zb(h+16|0);break a}d=Mc(h+16|0,8269);e=dh(c,d);yb(d);if(e){el(a,v[b+24>>2]+1298368|0);break e}d=Mc(h+16|0,5623);e=dh(c,d);yb(d);if(e){el(a,v[b+24>>2]+1298320|0);break e}d=Mc(h+16|0,11924);e=dh(c,d);yb(d);if(e){c=h+16|0;xh(c,v[b+24>>2]+1298308|0);b=v[b+24>>2];v[23588]=0;U(1009,a|0,b|0,c|0);a=v[23588];v[23588]=0;if((a|0)!=1){yb(h+16|0);break e}c=P()|0;O()|0;yb(h+16|0);break a}d=Mc(h+16|0,11293);e=dh(c,d);yb(d);if(e){c=v[b+24>>2]+1298408|0;b=v[c+4>>2];n:{if(!oc(v[c>>2],b)){d=jb-32|0;jb=d;v[d+8>>2]=0;v[d+12>>2]=0;v[d+16>>2]=0;v[d>>2]=0;v[d+4>>2]=0;v[d+24>>2]=0;v[d+28>>2]=0;c=1;b=b-40|0;o:{if(v[b>>2]!=v[d>>2]|v[b+4>>2]!=v[d+4>>2]|(v[b+8>>2]!=v[d+8>>2]|v[b+12>>2]!=v[d+12>>2])){break o}if(v[b+16>>2]!=v[d+16>>2]){break o}c=v[b+24>>2]!=v[d+24>>2]|v[b+28>>2]!=v[d+28>>2]}jb=d+32|0;if(c){break n}}Lb(a);break e}m=h+16|0;g=jb-256|0;jb=g;c=v[b+12>>2];v[g+136>>2]=v[b+8>>2];v[g+140>>2]=c;c=v[b+20>>2];v[g+144>>2]=v[b+16>>2];v[g+148>>2]=c;c=v[b+28>>2];v[g+152>>2]=v[b+24>>2];v[g+156>>2]=c;c=v[b+4>>2];v[g+128>>2]=v[b>>2];v[g+132>>2]=c;bN(g+208|0,g+128|0);e=v[b+32>>2];if(e){c=v[b+12>>2];v[g+104>>2]=v[b+8>>2];v[g+108>>2]=c;c=v[b+20>>2];v[g+112>>2]=v[b+16>>2];v[g+116>>2]=c;c=v[b+28>>2];v[g+120>>2]=v[b+24>>2];v[g+124>>2]=c;c=v[b+4>>2];v[g+96>>2]=v[b>>2];v[g+100>>2]=c;b=g+160|0;bN(b,g+96|0);tc(g+52|0,b,44);b=Mw(v[g+72>>2]+1900|0,v[g+68>>2]+1|0,v[g+64>>2])-Mw(1970,1,1)|0;b=Lka(b,b>>31,86400,0);c=B(v[g+60>>2],3600);b=b+c|0;d=mb+(c>>31)|0;d=b>>>0<c>>>0?d+1|0:d;c=B(v[g+56>>2],60);f=c;b=c+b|0;c=(c>>31)+d|0;c=b>>>0<f>>>0?c+1|0:c;d=v[g+52>>2];f=d;b=d+b|0;d=(d>>31)+c|0;d=YG(hH(b,b>>>0<f>>>0?d+1|0:d),mb);f=mb;c=2147483647;l=we(+(e>>>0)/18.2);b=-1;p:{if(l>=0x8000000000000000){break p}c=-2147483648;b=0;if(l<=-0x8000000000000000){break p}if(D(l)<0x8000000000000000){c=D(l)>=1?~~(l>0?F(H(l*2.3283064365386963e-10),4294967295):I((l-+(~~l>>>0>>>0))*2.3283064365386963e-10))>>>0:0;b=~~l>>>0;break p}b=0}e=b+d|0;d=c+f|0;b=hH(e,b>>>0>e>>>0?d+1|0:d);j=jb-16|0;jb=j;i=YG(b,mb);b=mb;n=b;v[j+12>>2]=0;v[j+8>>2]=0;v[j+4>>2]=0;b=Mw(1970,1,1)+Mka(i,b,86400,0)|0;f=b>>31;d=Lka(b,f,1e4,0)+14780|0;c=mb;e=d;c=d>>>0<14780?c+1|0:c;k=Mka(d,c,-14609700,-1)+b|0;d=f+mb|0;d=b>>>0>k>>>0?d+1|0:d;o=Mka(e,c,365242500,0);k=o+k|0;d=mb+d|0;d=k>>>0<o>>>0?d+1|0:d;o=Mka(e,c,-146097e4,-1);k=o+k|0;d=mb+d|0;d=k>>>0<o>>>0?d+1|0:d;c=Mka(e,c,3652425,0);e=mb;o=e;p=k;k=Lka(c,e,-365,-1);e=p+k|0;d=mb+d|0;d=e>>>0<k>>>0?d+1|0:d;if(!((d|0)>0|(d|0)>=0)){d=o-!c|0;c=c-1|0;e=Lka(c,d,-365,-1)+b|0;d=f+mb|0;d=b>>>0>e>>>0?d+1|0:d;b=e;e=(c|0)/-4|0;b=b+e|0;d=(e>>31)+d|0;d=b>>>0<e>>>0?d+1|0:d;e=b;b=(c|0)/100|0;f=b;e=e+b|0;b=(b>>31)+d|0;b=e>>>0<f>>>0?b+1|0:b;d=(c|0)/-400|0;f=d;e=d+e|0;d=(d>>31)+b|0;d=e>>>0<f>>>0?d+1|0:d}f=c;b=Lka(e,d,100,0)+52|0;c=mb;b=Mka(b,b>>>0<52?c+1|0:c,3060,0);c=b+2|0;d=(c|0)/12|0;v[j+12>>2]=f+d;v[j+8>>2]=(c+B(d,-12)|0)+1;b=Lka(b,mb,306,0)+5|0;d=mb;b=Mka(b,b>>>0<5?d+1|0:d,-10,-1)+e|0;v[j+4>>2]=b+1;v[g+248>>2]=0;v[g+240>>2]=0;v[g+244>>2]=0;v[g+232>>2]=0;v[g+236>>2]=0;v[g+228>>2]=v[j+12>>2]-1900;v[g+224>>2]=v[j+8>>2]-1;b=v[j+4>>2];q=g,r=Nka(Mka(i,n,3600,0),mb,24),v[q+216>>2]=r;v[g+220>>2]=b;b=Mka(i,n,60,0);c=mb;q=g,r=Nka(b,c,60),v[q+212>>2]=r;b=Lka(b,c,-60,0)+i|0;v[g+208>>2]=b;jb=j+16|0}c=g+8|0;tc(c,g+208|0,44);b=jb-176|0;jb=b;e=Lb(b+160|0);v[23588]=0;d=Q(1,b+144|0,13386)|0;f=v[23588];v[23588]=0;q:{r:{s:{t:{u:{if((f|0)!=1){f=v[c+20>>2];if(!f){break r}v[23588]=0;v[b+112>>2]=f+1900;R(97,b+128|0,b+112|0);f=v[23588];v[23588]=0;if((f|0)!=1){v[23588]=0;j=Q(98,e|0,b+128|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break u}zb(b+128|0);i=v[c+16>>2];if(i>>>0>11){break r}v[23588]=0;f=Q(1,b+112|0,16764)|0;n=v[23588];v[23588]=0;v:{w:{x:{y:{z:{A:{if((n|0)!=1){v[23588]=0;v[b+80>>2]=i+1;R(99,b+96|0,b+80|0);i=v[23588];v[23588]=0;if((i|0)==1){break A}v[23588]=0;U(2,b+128|0,f|0,b+96|0);i=v[23588];v[23588]=0;if((i|0)==1){break z}v[23588]=0;j=Q(98,j|0,b+128|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break y}zb(b+128|0);zb(b+96|0);zb(f);if(v[c+12>>2]-32>>>0>=4294967265){break v}break r}a=P()|0;O()|0;break t}a=P()|0;O()|0;break w}a=P()|0;O()|0;break x}a=P()|0;O()|0;zb(b+128|0)}zb(b+96|0)}zb(f);break t}v[23588]=0;f=Q(1,b+96|0,16764)|0;i=v[23588];v[23588]=0;B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{if((i|0)!=1){v[23588]=0;R(99,b+80|0,c+12|0);i=v[23588];v[23588]=0;if((i|0)==1){break _}v[23588]=0;U(2,b+128|0,f|0,b+80|0);i=v[23588];v[23588]=0;if((i|0)==1){break Z}v[23588]=0;j=Q(98,j|0,b+128|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break Y}zb(b+128|0);zb(b+80|0);zb(f);n=v[c>>2];f=v[c+8>>2];i=v[c+4>>2];if(!(n|(f|i))|f>>>0>23|i>>>0>59){break r}v[23588]=0;f=Q(1,b+128|0,13591)|0;i=v[23588];v[23588]=0;if((i|0)==1){break V}v[23588]=0;j=Q(98,j|0,f|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break U}zb(f);if(v[c+32>>2]>0){v[23588]=0;f=Q(1,b+80|0,15554)|0;i=v[23588];v[23588]=0;if((i|0)==1){break T}Ib(d,f);zb(f)}v[23588]=0;R(99,b+32|0,c+8|0);f=v[23588];v[23588]=0;if((f|0)==1){break S}v[23588]=0;f=Q(1,b+16|0,14600)|0;i=v[23588];v[23588]=0;if((i|0)==1){break R}v[23588]=0;U(2,b+48|0,b+32|0,f|0);i=v[23588];v[23588]=0;if((i|0)==1){break Q}v[23588]=0;R(99,b|0,c+4|0);i=v[23588];v[23588]=0;if((i|0)==1){break P}v[23588]=0;U(2,b- -64|0,b+48|0,b|0);i=v[23588];v[23588]=0;if((i|0)==1){break O}v[23588]=0;j=Q(98,j|0,b- -64|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break N}zb(b- -64|0);zb(b);zb(b+48|0);zb(f);zb(b+32|0);if(n>>>0<62){break I}v[23588]=0;U(100,m|0,j|0,d|0);c=v[23588];v[23588]=0;if((c|0)==1){break H}break q}a=P()|0;O()|0;break t}a=P()|0;O()|0;break W}a=P()|0;O()|0;break X}a=P()|0;O()|0;zb(b+128|0)}zb(b+80|0)}zb(f);break t}a=P()|0;O()|0;break t}a=P()|0;O()|0;zb(f);break t}a=P()|0;O()|0;break t}a=P()|0;O()|0;break t}a=P()|0;O()|0;break J}a=P()|0;O()|0;break K}a=P()|0;O()|0;break L}a=P()|0;O()|0;break M}a=P()|0;O()|0;zb(b- -64|0)}zb(b)}zb(b+48|0)}zb(f)}zb(b+32|0);break t}v[23588]=0;f=Q(1,b+48|0,14600)|0;i=v[23588];v[23588]=0;if((i|0)==1){break G}v[23588]=0;R(99,b+32|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break F}v[23588]=0;U(2,b- -64|0,f|0,b+32|0);c=v[23588];v[23588]=0;if((c|0)==1){break E}v[23588]=0;c=Q(98,j|0,b- -64|0)|0;j=v[23588];v[23588]=0;if((j|0)==1){break D}zb(b- -64|0);zb(b+32|0);zb(f);v[23588]=0;Q(98,c|0,d|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break r}}a=P()|0;O()|0;break t}a=P()|0;O()|0;break t}a=P()|0;O()|0;break B}a=P()|0;O()|0;break C}a=P()|0;O()|0;zb(b- -64|0)}zb(b+32|0)}zb(f);break t}a=P()|0;O()|0;break t}a=P()|0;O()|0;break s}a=P()|0;O()|0;zb(b+128|0)}zb(d)}zb(e);T(a|0);L()}$c(m,e)}zb(d);zb(e);jb=b+176|0;jb=g+256|0;v[23588]=0;R(1015,a|0,m|0);a=v[23588];v[23588]=0;if((a|0)!=1){zb(h+16|0);break e}c=P()|0;O()|0;zb(h+16|0);break a}d=Mc(h+16|0,12125);e=dh(c,d);yb(d);if(e){c=h+16|0;IP(c,v[b+24>>2]+1298332|0);$:{if(!Qe(c)){break $}d=v[v[b+24>>2]+480180>>2];aa:{ba:{if((d|0)==33554432){break ba}c=1;if((d|0)==32){break aa}if((d|0)==16384){break ba}if((d|0)==16777216){break aa}}c=2}ca:{switch(c-1|0){case 0:v[23588]=0;R(1016,h|0,b|0);c=v[23588];v[23588]=0;if((c|0)!=1){Ac(h+16|0,h);yb(h);break $}break b;case 1:break ca;default:break $}}if(Qe(h+16|0)){v[23588]=0;R(1017,h|0,b|0);c=v[23588];v[23588]=0;if((c|0)==1){break b}Ac(h+16|0,h);yb(h)}if(!Qe(h+16|0)){break $}v[23588]=0;R(1016,h|0,b|0);c=v[23588];v[23588]=0;if((c|0)==1){break b}Ac(h+16|0,h);yb(h)}b=v[b+24>>2];v[23588]=0;U(1009,a|0,b|0,h+16|0);a=v[23588];v[23588]=0;if((a|0)!=1){yb(h+16|0);break e}break b}d=Mc(h+16|0,5475);e=dh(c,d);yb(d);if(e){c=h+16|0;IP(c,v[b+24>>2]+1298332|0);b=v[b+24>>2];v[23588]=0;U(1009,a|0,b|0,c|0);a=v[23588];v[23588]=0;if((a|0)!=1){yb(h+16|0);break e}c=P()|0;O()|0;yb(h+16|0);break a}f=c;c=Mc(h+16|0,7295);d=dh(f,c);yb(c);if(d){a=Lb(a);q=h,r=Eb(v[b+68>>2]),v[q+16>>2]=r;b=Eb(v[b+72>>2]);c=1;while(1){d=v[h+16>>2];if(!Ob(d,b)){break e}if(!(c&1)){v[23588]=0;Q(941,a|0,21589)|0;c=v[23588];v[23588]=0;if((c|0)==1){break c}}v[23588]=0;Q(800,a|0,d|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break c}lq(h+16|0);c=0;continue}}Mc(a,21619)}jb=h+32|0;return}c=P()|0;O()|0;zb(h+16|0);break a}c=P()|0;O()|0;yb(a);break a}c=P()|0;O()|0;yb(h+16|0)}T(c|0);L()}function zW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a:{n=Fh(b,13779);if(!n){break a}o=a+480192|0;b:while(1){if(!Pb(v[b>>2],v[b+8>>2],6)){break a}c:{f=Bg(b);d:{if((f|0)==(Tm(13598)|0)){break d}c=w[21595]|w[21596]<<8|(w[21597]<<16|w[21598]<<24);if(!(f&1616928864)|f&-2139062144){break d}if((c|0)!=(f|0)){break c}}yg(b,4);break a}l=1;c=Rg(b);while(1){d=l&65535;if(d>>>0>x[o>>1]){continue b}d=v[((d<<2)+a|0)+900380>>2];if(d){e:{g=0;if((Tm(16720)|0)==(f|0)){Zb(b,c);break e}e=jb-48|0;jb=e;f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{switch(f-1349079874|0){default:if((f|0)==1095062094){break v}if((f|0)==1095126087){break s}if((f|0)==1129524782){break B}if((f|0)==1145263150){break Y}if((f|0)==1145979182){break X}if((f|0)==1179463214){break z}if((f|0)==1851469358){break F}if((f|0)==1179931728){break n}$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{if((f|0)!=1196830254){if((f|0)==1229341486){break U}if((f|0)==1229345326){break T}if((f|0)==1264266798){break G}if((f|0)==1296182830){break S}if((f|0)==1296248366){break Q}if((f|0)==1297100334){break R}if((f|0)==1297110852){break q}if((f|0)==1298747438){break D}if((f|0)==1313692462){break H}if((f|0)==1313751342){break Z}if((f|0)==1345203758){break ja}if((f|0)==1346711086){break l}if((f|0)==1346720334){break w}if((f|0)==1346722606){break J}if((f|0)==1346784327){break t}if((f|0)==1347175726){break da}if((f|0)==1347179310){break ea}if((f|0)==1347437358){break O}if((f|0)==1347441454){break P}if((f|0)==1347443502){break M}if((f|0)==1347628590){break W}if((f|0)==1347633710){break ca}if((f|0)==1347634478){break ba}if((f|0)==1347703884){break o}if((f|0)==1347831112){break y}if((f|0)==1347833672){break x}if((f|0)==1349076270){break k}if((f|0)==1349076315){break I}if((f|0)==1349078085){break $}if((f|0)==1349078099){break aa}if((f|0)==1349079131){break L}if((f|0)==1378758190){break p}if((f|0)==1381183022){break A}if((f|0)==1447374382){break m}if((f|0)==1447383630){break u}if((f|0)==1447385902){break K}if((f|0)==1447447623){break r}if((f|0)==1447839022){break ha}if((f|0)==1447842606){break ia}if((f|0)==1448106798){break N}if((f|0)==1448226350){break C}if((f|0)==1448291886){break V}if((f|0)==1448297006){break ga}if((f|0)==1448297774){break fa}if((f|0)!=1682320942){if((f|0)==1718508334){break E}if((f|0)!=1179594286|c>>>0>4){break f}if(!Pb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=lv(b,c),v[p>>2]=q;break g}if(c>>>0>1){break f}if(!Pb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Bd(b,c),t[p+15|0]=q;break g}if(c>>>0>4){break f}if(!Pb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=lv(b,c),v[p+4>>2]=q;break g}if(c>>>0>4){break f}if(!Pb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=lv(b,c),v[p+8>>2]=q;break g}if(c>>>0>1){break f}if(!Pb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Bd(b,c),t[p+61|0]=q;break g}if(c>>>0>1){break f}if(!Pb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Bd(b,c),t[p+62|0]=q;break g}if(c>>>0>1){break f}if(!Pb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Bd(b,c),t[p+63|0]=q;break g}if(c>>>0>1){break f}if(!Pb(v[b>>2],v[b+8>>2],c)){break f}p=d- -64|0,q=Bd(b,c),t[p|0]=q;break g}if(c>>>0>1){break f}if(!Pb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Bd(b,c),t[p+81|0]=q;break g}if(c>>>0>1){break f}if(!Pb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Bd(b,c),t[p+82|0]=q;break g}if(c>>>0>1){break f}if(!Pb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Bd(b,c),t[p+83|0]=q;break g}if(c>>>0>1){break f}if(!Pb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Bd(b,c),t[p+84|0]=q;break g}if(c>>>0>1){break f}if(!Pb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Bd(b,c),t[p+101|0]=q;break g}if(c>>>0>1){break f}if(!Pb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Bd(b,c),t[p+102|0]=q;break g;case 0:if(c>>>0>1){break f}if(!Pb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Bd(b,c),t[p+103|0]=q;break g;case 3:break _;case 1:case 2:break f}}if(c>>>0>1){break f}if(!Pb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Bd(b,c),t[p+104|0]=q;break g}if(c>>>0>1){break f}if(!Pb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Bd(b,c),t[p+16|0]=q;break g}if(c>>>0>1){break f}if(!Pb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Bd(b,c),t[p+17|0]=q;break g}if(c>>>0>1){break f}if(!Pb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Bd(b,c),t[p+18|0]=q;break g}if(c>>>0>1){break f}if(!Pb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Bd(b,c),t[p+19|0]=q;break g}if(c>>>0>1){break f}if(!Pb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Bd(b,c),t[p+20|0]=q;break g}if(c>>>0>1){break f}if(!Pb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Bd(b,c),t[p+21|0]=q;break g}if(c>>>0>1){break f}if(!Pb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Bd(b,c),t[p+22|0]=q;break g}if(c>>>0>2){break f}if(!Pb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=UC(b,c),u[p+28>>1]=q;break g}if(c>>>0>1){break f}if(!Pb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Bd(b,c),t[p+30|0]=q;break g}if(c>>>0>1){break f}if(!Pb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Bd(b,c),t[p+31|0]=q;break g}if(c>>>0>1){break f}if(!Pb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=TC(b,c),t[p+26|0]=q;break g}if(c>>>0>1){break f}if(!Pb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Bd(b,c),t[p+27|0]=q;break g}$d(e,b,c);i=jc(e+24|0,e);Ab(e);j=Gh(d,0);h=v[j>>2];while(1){if(_d(h,v[j+4>>2])>>>0<=g>>>0){Ab(i);break g}v[23588]=0;k=S(197,i|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break j}h=v[j>>2];p=Db(h,g),q=k,u[p>>1]=q;g=g+1|0;continue}}$d(e,b,c);i=jc(e+24|0,e);Ab(e);j=Gh(d,1);h=v[j>>2];while(1){if(_d(h,v[j+4>>2])>>>0<=g>>>0){Ab(i);break g}v[23588]=0;k=S(197,i|0)|0;h=v[23588];v[23588]=0;if((h|0)!=1){h=v[j>>2];p=Db(h,g),q=k,u[p>>1]=q;g=g+1|0;continue}break}g=P()|0;O()|0;break i}$d(e,b,c);i=jc(e+24|0,e);Ab(e);j=Gh(d,2);h=v[j>>2];while(1){if(_d(h,v[j+4>>2])>>>0<=g>>>0){Ab(i);break g}v[23588]=0;k=S(197,i|0)|0;h=v[23588];v[23588]=0;if((h|0)!=1){h=v[j>>2];p=Db(h,g),q=k,u[p>>1]=q;g=g+1|0;continue}break}g=P()|0;O()|0;break i}$d(e,b,c);i=jc(e+24|0,e);Ab(e);j=Gh(d,0);h=v[j>>2];while(1){if(_d(h,v[j+4>>2])>>>0<=g>>>0){Ab(i);break g}v[23588]=0;k=S(198,i|0)|0;h=v[23588];v[23588]=0;if((h|0)!=1){h=v[j>>2];p=Db(h,g),q=k,t[p+2|0]=q;g=g+1|0;continue}break}g=P()|0;O()|0;break i}$d(e,b,c);i=jc(e+24|0,e);Ab(e);j=Gh(d,1);h=v[j>>2];while(1){if(_d(h,v[j+4>>2])>>>0<=g>>>0){Ab(i);break g}v[23588]=0;k=S(198,i|0)|0;h=v[23588];v[23588]=0;if((h|0)!=1){h=v[j>>2];p=Db(h,g),q=k,t[p+2|0]=q;g=g+1|0;continue}break}g=P()|0;O()|0;break i}$d(e,b,c);i=jc(e+24|0,e);Ab(e);j=Gh(d,2);h=v[j>>2];while(1){if(_d(h,v[j+4>>2])>>>0<=g>>>0){Ab(i);break g}v[23588]=0;k=S(198,i|0)|0;h=v[23588];v[23588]=0;if((h|0)!=1){h=v[j>>2];p=Db(h,g),q=k,t[p+2|0]=q;g=g+1|0;continue}break}g=P()|0;O()|0;break i}if(c>>>0>128){break f}h=d+108|0;$d(e,b,c);i=jc(e+24|0,e);Ab(e);while(1){if((g|0)==128){Ab(i);break g}v[23588]=0;j=S(198,i|0)|0;k=v[23588];v[23588]=0;if((k|0)!=1){p=Kb(h,g),q=j,t[p|0]=q;g=g+1|0;continue}break}g=P()|0;O()|0;break i}if(c>>>0>256){break f}h=d+236|0;$d(e,b,c);i=jc(e+24|0,e);Ab(e);while(1){if((g|0)==128){Ab(i);break g}v[23588]=0;j=S(197,i|0)|0;k=v[23588];v[23588]=0;if((k|0)!=1){p=cc(h,g),q=j,u[p>>1]=q;g=g+1|0;continue}break}g=P()|0;O()|0;break i}if(c>>>0>32){break f}j=d+492|0;$d(e,b,c);i=jc(e+24|0,e);Ab(e);h=Lb(e);while(1){if((c|0)==(g|0)){break h}v[23588]=0;k=S(199,i|0)|0;m=v[23588];v[23588]=0;ka:{if((m|0)==1){break ka}v[23588]=0;Q(200,h|0,k|0)|0;k=v[23588];v[23588]=0;if((k|0)==1){break ka}g=g+1|0;continue}break}g=P()|0;O()|0;yb(h);break i}if(c>>>0>32){break f}j=d+524|0;$d(e,b,c);i=jc(e+24|0,e);Ab(e);h=Lb(e);la:{while(1){if((c|0)!=(g|0)){v[23588]=0;k=S(199,i|0)|0;m=v[23588];v[23588]=0;if((m|0)==1){break la}v[23588]=0;Q(200,h|0,k|0)|0;k=v[23588];v[23588]=0;if((k|0)==1){break la}g=g+1|0;continue}break}Cc(j,h);yb(h);Ab(i);break g}g=P()|0;O()|0;yb(h);break i}if(c>>>0>1){break f}if(!Pb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Bd(b,c),t[p+34|0]=q;break g}if(c>>>0>2){break f}if(!Pb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=UC(b,c),u[p+12>>1]=q;break g}if(c>>>0>1){break f}if(!Pb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Bd(b,c),t[p+23|0]=q;break g}if(c>>>0>1){break f}if(!Pb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Bd(b,c),t[p+24|0]=q;break g}if(c>>>0>1){break f}if(!Pb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Bd(b,c),t[p+25|0]=q;break g}if(c>>>0>1){break f}if(!Pb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Bd(b,c),t[p+35|0]=q;break g}if(c>>>0>1){break f}if(!Pb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Bd(b,c),t[p+36|0]=q;break g}if(c>>>0>1){break f}if(!Pb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Bd(b,c),t[p+105|0]=q;break g}if(c>>>0>1){break f}if(!Pb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Bd(b,c),t[p+85|0]=q;break g}if(c>>>0>1){break f}if(!Pb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Bd(b,c),t[p+65|0]=q;break g}if(c>>>0>1){break f}if(!Pb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Bd(b,c),t[p+100|0]=q;break g}if(c>>>0>1){break f}if(!Pb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Bd(b,c),t[p+80|0]=q;break g}if(c>>>0>1){break f}if(!Pb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Bd(b,c),t[p+60|0]=q;break g}if(c>>>0>1){break f}if(!Pb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=TC(b,c),t[p+33|0]=q;break g}g=1;i=Io(b,c);if(!Ho(i)){break f}t[d+14|0]=i;break f}p=d,q=B(jv(b,c),1e4)+(y[d+40>>2]%1e4|0)|0,v[p+40>>2]=q;break g}h=(jv(b,c)>>>0)%1e4|0;g=v[d+40>>2];v[d+40>>2]=h+g-(g>>>0)%1e4;break g}v[e+24>>2]=240;p=e,q=Io(b,c),v[p>>2]=q;Qg(d+48|0,v[Jb(e+24|0,e)>>2]);break g}v[e+24>>2]=240;p=e,q=Io(b,c),v[p>>2]=q;Qg(d+68|0,v[Jb(e+24|0,e)>>2]);break g}v[e+24>>2]=240;p=e,q=Io(b,c),v[p>>2]=q;Qg(d+88|0,v[Jb(e+24|0,e)>>2]);break g}g=P()|0;O()|0}Ab(i);T(g|0);L()}Cc(j,h);yb(h);Ab(i)}g=1}jb=e+48|0;if(!g){Zb(b,c);break e}if((Tm(16725)|0)==(f|0)){e=w[d+15|0];t[d+15|0]=0;t[d+100|0]=w[d+100|0]&224|(e>>>5&4|e>>>6&1);t[d+60|0]=e>>>1&2|(e<<1&4|(w[d+60|0]&240|e&1));t[d+80|0]=w[d+80|0]&240|(e>>>4&2|(e>>>2&4|e>>>3&1))}}}l=l+1|0;continue}}}return n|0}function VV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=jb-304|0;jb=e;yc(b);if(Sq(b,17792)){o=Lb(e+288|0);v[23588]=0;f=Q(230,b|0,o|0)|0;g=v[23588];v[23588]=0;a:{b:{c:{d:{e:{f:{if((g|0)!=1){if(!f){break a}v[23588]=0;f=Q(245,b|0,e+280|0)|0;g=v[23588];v[23588]=0;g:{if((g|0)==1){break g}if(!f){break a}if(!aC(w[e+280|0],w[e+281|0])){break a}f=Dc($B(e+280|0),mb);g=v[b+8>>2];m=v[b>>2];v[23588]=0;f=W(156,m|0,g|0,f|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break g}if(!f){break a}if(!c){break b}v[23588]=0;R(246,a|0,4096);d=v[23588];v[23588]=0;if((d|0)==1){break g}v[23588]=0;R(247,a+1298308|0,o|0);d=v[23588];v[23588]=0;if((d|0)==1){break g}d=w[e+282|0];u[a+480188>>1]=32;u[a+480192>>1]=d;nh(a,1);v[23588]=0;d=Q(1,e+264|0,9436)|0;f=v[23588];v[23588]=0;h:{i:{j:{k:{l:{m:{n:{o:{p:{if((f|0)!=1){Ib(a+1298344|0,d);zb(d);v[23588]=0;d=Q(1,e+248|0,7053)|0;f=v[23588];v[23588]=0;if((f|0)==1){break p}Ib(a+1298356|0,d);zb(d);v[23588]=0;Y(248,e+48|0);d=v[23588];v[23588]=0;if((d|0)==1){break o}t[e+216|0]=w[e+281|0];v[23588]=0;t[e+8|0]=w[e+280|0];R(249,e+232|0,e+8|0);d=v[23588];v[23588]=0;if((d|0)==1){break n}v[23588]=0;X(250,e+96|0,e+48|0,e+216|0,e+232|0);d=v[23588];v[23588]=0;if((d|0)==1){break m}d=e+96|0;Ib(a+1298368|0,d);zb(d);zb(e+232|0);ac(e+48|0);v[a+1298404>>2]=5;if(w[e+280|0]<2){break i}u[e+96>>1]=8192;v[23588]=0;d=S(194,b|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break k}u[e+48>>1]=d;r=a,s=B(x[ke(e+96|0,e+48|0)>>1],1e4)>>>8|0,v[r+480204>>2]=s;v[23588]=0;t[e+96|0]=1;d=S(206,b|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break j}t[e+48|0]=d;r=a,s=w[jf(e+96|0,e+48|0)|0],v[r+480196>>2]=s;v[23588]=0;Q(188,b|0,3)|0;d=v[23588];v[23588]=0;if((d|0)!=1){v[23588]=0;d=S(194,b|0)|0;f=v[23588];v[23588]=0;if((f|0)!=1){break h}}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break l}b=P()|0;O()|0;zb(e+232|0)}ac(e+48|0);break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}t[e+96|0]=32;v[23588]=0;d=S(206,b|0)|0;f=v[23588];v[23588]=0;q:{if((f|0)!=1){t[e+48|0]=d;r=a,s=B(w[jf(e+96|0,e+48|0)|0],1e4),v[r+480204>>2]=s;v[23588]=0;t[e+96|0]=1;d=S(206,b|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break q}t[e+48|0]=d;r=a,s=w[jf(e+96|0,e+48|0)|0],v[r+480196>>2]=s;v[23588]=0;d=S(206,b|0)|0;f=v[23588];v[23588]=0;if((f|0)!=1){break h}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}v[a+480208>>2]=d>>>2&16|12;m=Sb(e+232|0);p=e+96|12;n=Sb(e+216|0);h=a+480190|0;i=1;while(1){r:{s:{d=i&65535;if(d>>>0>x[a+480192>>1]){break s}v[23588]=0;f=W(251,a|0,d|0,0)|0;d=v[23588];v[23588]=0;t:{if((d|0)==1){break t}if(!f){break s}v[23588]=0;d=Q(240,b|0,f+492|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break t}if(!d){break s}v[23588]=0;k=S(206,b|0)|0;d=v[23588];v[23588]=0;u:{v:{w:{if((d|0)!=1){Tb(e+96|0,0,120);if(!k){break r}x:{if(w[e+280|0]){v[23588]=0;d=Q(252,b|0,e+96|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break w}if(!d){break r}if(w[e+280|0]){break x}}d=gc(e+88|0,p,96);g=v[d+4>>2];d=v[d>>2];v[23588]=0;Nk(165,e+48|0,b,d,g);d=v[23588];v[23588]=0;if((d|0)==1){break v}if(!v[e+52>>2]){break r}}g=f+236|0;d=0;break u}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}while(1){if((d|0)!=120){r=cc(g,d),s=(w[(e+96|0)+d|0]+x[h>>1]|0)+1|0,u[r>>1]=s;d=d+1|0;continue}break}v[23588]=0;d=f+48|0;U(253,e+8|0,d|0,b|0);g=v[23588];v[23588]=0;if((g|0)==1){break e}v[23588]=0;g=f+68|0;U(253,e+32|0,g|0,b|0);j=v[23588];v[23588]=0;if((j|0)==1){break e}v[23588]=0;j=f+88|0;U(253,e+80|0,j|0,b|0);l=v[23588];v[23588]=0;if((l|0)==1){break e}v[23588]=0;R(254,b|0,e+72|0);l=v[23588];v[23588]=0;if((l|0)==1){break f}v[f>>2]=(w[e+73|0]|w[e+74|0]<<8)&4095;l=w[e+73|0]|w[e+74|0]<<8;Ou(w[e+75|0]|w[e+76|0]<<8,d,0);Ou(w[e+75|0]|w[e+76|0]<<8,g,1);Ou(w[e+75|0]|w[e+76|0]<<8,j,2);r=e,s=Eb(v[d>>2]),v[r+48>>2]=s;l=l>>>12&3;q=Eb(v[f+52>>2]);while(1){d=v[e+48>>2];if(Ob(d,q)){t[e+44|0]=64;t[e+70|0]=((w[d+2|0]<<6)- -64>>>0)/127;r=d,s=w[Wb(e+44|0,e+70|0)|0],t[r+2|0]=s;Ke(e+48|0);continue}else{r=e,s=Eb(v[g>>2]),v[r+48>>2]=s;d=Eb(v[f+72>>2])}break}while(1){g=v[e+48>>2];if(Ob(g,d)){t[e+44|0]=64;t[e+70|0]=((w[g+2|0]<<6)+128>>>0)/255;r=g,s=w[Wb(e+44|0,e+70|0)|0],t[r+2|0]=s;Ke(e+48|0);continue}break}r=e,s=Eb(v[j>>2]),v[r+48>>2]=s;j=1<<l;l=Eb(v[f+92>>2]);while(1){d=v[e+48>>2];if(Ob(d,l)){g=d;d=t[d+2|0];d=Lka(d^-128,d>>31^-1,j,0);f=mb;y:{if((f|0)>=-1&d>>>0>=4294967292|(f|0)>=0){d=d+4|0;f=d>>>0<4?f+1|0:f;d=((f&7)<<29|d>>>3)&536870911;f=0;break y}f=0-((d>>>0>3)+f|0)|0;d=3-d|0;f=((f&7)<<29|d>>>3)&536870911;d=0-f|0;f=0-((f|0)!=0)|0}r=g,s=Hc(d,f)^128,t[r+2|0]=s;Ke(e+48|0);continue}else{f=x[h>>1]+1|0;u[e+70>>1]=f;d=0;f=f&65535;g=4e3-f|0;g=g>>>0>4e3?0:g;z:{A:{B:{while(1){if((d|0)==(k|0)){break A}if((d|0)==(g|0)){v[23588]=0;Q(188,b|0,20)|0;d=v[23588];v[23588]=0;if((d|0)!=1){break A}b=P()|0;O()|0;break d}v[23588]=0;j=d+f|0;Q(240,b|0,((j<<5)+a|0)+946304|0)|0;l=v[23588];v[23588]=0;if((l|0)==1){break z}v[23588]=0;R(255,b|0,e+48|0);l=v[23588];v[23588]=0;C:{if((l|0)==1){break C}v[23588]=0;R(256,e+48|0,(B(j,104)+a|0)+484380|0);j=v[23588];v[23588]=0;if((j|0)==1){break C}v[23588]=0;u[e+44>>1]=w[e+72|0]|d<<8&32512|((w[e+67|0]&3)!=0)<<15;R(257,n|0,e+44|0);j=v[23588];v[23588]=0;if((j|0)==1){break B}d=d+1|0;continue}break}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}v[23588]=0;R(257,m|0,e+70|0);d=v[23588];v[23588]=0;if((d|0)!=1){v[e+48>>2]=3999;v[e+44>>2]=k+x[h>>1];r=h,s=v[sd(e+48|0,e+44|0)>>2],u[r>>1]=s;break r}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}}}b=P()|0;O()|0;break d}d=Lb(e+96|0);v[23588]=0;f=Q(230,b|0,d|0)|0;g=v[23588];v[23588]=0;D:{E:{F:{G:{H:{if((g|0)!=1){I:{if(f){v[23588]=0;U(11,e+48|0,7,d|0);f=v[23588];v[23588]=0;if((f|0)==1){break I}f=e+48|0;Ib(a+1298320|0,f);zb(f)}yb(d);d=0;J:{while(1){if((d|0)==32){v[23588]=0;d=Q(258,b|0,e+32|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break G}if(!d){break F}d=v[e+32>>2];if(d>>>0<12){break H}f=v[b+8>>2];g=v[b>>2];v[23588]=0;d=W(156,g|0,f|0,d-11|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break G}if(d){break J}break H}f=(d<<5)+a|0;df(f+480280|0);v[23588]=0;R(231,b|0,f+480289|0);f=v[23588];v[23588]=0;if((f|0)!=1){d=d+1|0;continue}break}b=P()|0;O()|0;break d}d=v[e+32>>2]-11|0;v[e+80>>2]=d;h=Sb(e+96|0);v[23588]=0;U(234,b|0,h|0,d|0);d=v[23588];v[23588]=0;K:{if((d|0)!=1){v[e+48>>2]=50529027;d=e+48|0;r=e,s=B(v[Jb(e+80|0,d)>>2],85),v[r+72>>2]=s;g=Lb(d);v[e+8>>2]=v[e+36>>2];d=v[Jb(e+72|0,e+8|0)>>2];v[23588]=0;R(46,g|0,d|0);d=v[23588];v[23588]=0;L:{if((d|0)==1){break L}d=0;M:{while(1){f=v[e+80>>2];if(f>>>0<=d>>>0){break M}i=v[h>>2];k=w[Kb(i,d)|0];j=f;f=d+1|0;if(!((k|0)!=255|j-f>>>0<2)){f=t[Kb(i,f)|0];i=w[Kb(i,d+2|0)|0];r=e,s=yh(g),v[r+8>>2]=s;k=v[lj(e+24|0,e+8|0)>>2];v[23588]=0;X(237,g|0,k|0,i|0,f|0);f=v[23588];v[23588]=0;if((f|0)!=1){d=d+3|0;continue}break L}v[23588]=0;R(47,g|0,k<<24>>24);i=v[23588];v[23588]=0;d=f;if((i|0)!=1){continue}break}break L}v[23588]=0;X(235,e+8|0,5,7,g|0);d=v[23588];v[23588]=0;if((d|0)!=1){N:{f=e+8|0;d=Ac(g,f);yb(f);f=Lc(d);i=Gb(d);v[23588]=0;ea(236,a+1298332|0,f|0,i|0,74,0);f=v[23588];v[23588]=0;if((f|0)==1){break N}yb(d);hc(h);break H}}}b=P()|0;O()|0;yb(g);break K}b=P()|0;O()|0}hc(h);break d}}b=P()|0;O()|0;yb(d);break d}d=w[a+484376|0];f=v[a+484360>>2];v[23588]=0;U(238,Vb(f,d)|0,b|0,w[e+285|0]|w[e+286|0]<<8);d=v[23588];v[23588]=0;if((d|0)==1){break G}i=c&1;if(i){v[23588]=0;R(225,a+484344|0,w[e+283|0]|w[e+284|0]<<8);d=v[23588];v[23588]=0;if((d|0)==1){break G}}h=a+484344|0;f=b;d=0;while(1){O:{if((w[e+283|0]|w[e+284|0]<<8)>>>0>d>>>0){b=v[f+8>>2];g=v[f>>2];v[23588]=0;b=W(156,g|0,b|0,4)|0;g=v[23588];v[23588]=0;if((g|0)==1){break D}if(b){break O}}if(!(c&2)){break F}d=0;c=a+480190|0;while(1){b=x[c>>1];if(d>>>0>=b>>>0){d=0;f=a+480190|0;while(1){if(b>>>0<=d>>>0){break F}c=x[cc(v[n>>2],d)>>1];g=c&255;P:{if(!g){break P}h=v[m>>2];g=g-1&65535;if(Qc(h,v[m+4>>2])>>>0<=g>>>0){break P}j=b;b=x[cc(h,g)>>1]+(c>>>8&127)&65535;if(j>>>0<b>>>0){break P}b=B(b,104);g=b+a|0;c=g+484380|0;h=v[c>>2];if(!Zd(h,v[g+484400>>2])){break P}g=b;b=a+484380|0;g=g+b|0;i=x[g+34>>1];b=b+B(d+1|0,104)|0;v[b>>2]=h;u[b+34>>1]=x[b+34>>1]&65534|i&1;if(!Ng(b)){break P}tc(v[b+20>>2],v[g+20>>2],Hj(v[c>>2],x[c+34>>1]))}d=d+1|0;b=x[f>>1];continue}}b=x[cc(v[n>>2],d)>>1];if(b&255){d=d+1|0;continue}d=d+1|0;g=B(d,104)+a|0;b=Zc(e+96|0,u[g+484414>>1]&1?16:8,1,0,b<<16>>16>=0?0:6);v[23588]=0;W(219,b|0,g+484380|0,f|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){continue}break}b=P()|0;O()|0;break d}v[23588]=0;b=S(157,f|0)|0;g=v[23588];v[23588]=0;Q:{R:{S:{T:{if((g|0)!=1){v[23588]=0;U(190,e+48|0,f|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break T}b=e+48|0;g=jc(e+96|0,b);Ab(b);if(!i){break R}v[23588]=0;b=S(206,g|0)|0;k=v[23588];v[23588]=0;if((k|0)==1){break Q}v[23588]=0;Q(188,g|0,1)|0;k=v[23588];v[23588]=0;if((k|0)==1){break Q}v[23588]=0;b=W(226,h|0,d&65535,b+1|0)|0;k=v[23588];v[23588]=0;if((k|0)==1){break Q}if(!b){break R}v[23588]=0;b=Q(232,g|0,e+48|0)|0;k=v[23588];v[23588]=0;if((k|0)==1){break E}if(!b){break S}b=v[h>>2];v[23588]=0;R(233,Yb(b,d)|0,e+48|0);b=v[23588];v[23588]=0;if((b|0)!=1){break S}break E}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=v[h>>2];v[23588]=0;U(239,Yb(b,d)|0,1,g|0);b=v[23588];v[23588]=0;if((b|0)==1){break E}}Ab(g);d=d+1|0;continue}break}break E}b=P()|0;O()|0;break d}nd(n);nd(m);break b}b=P()|0;O()|0;Ab(g);break d}b=P()|0;O()|0;break d}i=i+1|0;continue}}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0}nd(n);nd(m)}yb(o);T(b|0);L()}d=1}yb(o)}jb=e+304|0;return d|0}function Yja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0;e=jb-400|0;jb=e;yc(b);g=e+376|0;f=dC(b,g);if(!f){Su(g)}a:{b:{c:{d:{e:{if(!f){break e}if(!GU(e+376|0)){break e}if(!Pb(v[b>>2],v[b+8>>2],Dc(72,0))){break e}if(!c){d=1;break e}Ad(a,1);v[a+480208>>2]=v[a+480208>>2]&-25231361|16842752;g=w[e+385|0];u[a+480190>>1]=63;u[a+480188>>1]=g;f:{g:{while(1){if((g&65535)>>>0<=d>>>0){h:{Tb(e+304|0,0,64);d=1;i:{while(1){j:{g=d&65535;if(g>>>0>x[a+480190>>1]){iC(b,a+1298308|0);g=e+296|0;d=jb-16|0;jb=d;k:{if(!Pb(v[b>>2],v[b+8>>2],8)){t[d|0]=0;bi(g,8,d);break k}an(d+8|0,g);td(d,b,v[d+8>>2],v[d+12>>2])}jb=d+16|0;n=Sb(e+280|0);g=x[e+386>>1];if(!g){break i}d=0;v[23588]=0;g=W(321,b|0,n|0,B(g,w[e+385|0])<<1)|0;f=v[23588];v[23588]=0;if((f|0)!=1){break j}g=P()|0;O()|0;break a}f=(B(g,104)+a|0)+484380|0;md(f,1);i=g+(e+304|0)|0;g=Le(b);t[i|0]=g;if(g<<24>>24>=0){A=f,C=EU(b)<<1,v[A>>2]=C}d=d+1|0;continue}break}if(!g){break f}}d=v[n>>2];fc(e+272|0,d,ed(d,v[n+4>>2])>>>1|0);l=Sb(e+256|0);v[23588]=0;R(322,l|0,x[e+388>>1]<<8);d=v[23588];v[23588]=0;if((d|0)==1){break h}d=0;l:{m:{n:{while(1){g=d&65535;d=x[e+388>>1];if(g>>>0>=d>>>0){break m}v[e+208>>2]=d-g;v[e+152>>2]=2e3;d=e+208|0;f=v[sd(d,e+152|0)>>2];d=Sb(d);v[23588]=0;f=W(321,b|0,d|0,f<<8)|0;h=v[23588];v[23588]=0;if((h|0)==1){break l}if(!f){break n}f=ec(e+248|0,Eb(v[l+4>>2]));h=Eb(v[d>>2]);j=Eb(v[e+212>>2]);f=v[f>>2];v[23588]=0;X(323,l|0,f|0,h|0,j|0);f=v[23588];v[23588]=0;if((f|0)!=1){hc(d);d=g+2e3|0;continue}break}break c}hc(d);d=0;break g}re(e+232|0,v[l>>2],v[l+4>>2]);_g(e+240|0,v[e+232>>2],v[e+236>>2]);p=a+484376|0;d=w[p|0];g=v[a+484360>>2];v[23588]=0;R(324,Vb(g,d)|0,x[e+386>>1]);d=v[23588];v[23588]=0;if((d|0)==1){break d}q=a+484344|0;s=c&1;j=0;while(1){if(x[e+386>>1]<=j>>>0){h=c&2;g=1;o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{while(1){c=g&65535;if(c>>>0>x[a+480190>>1]){break v}v[23588]=0;d=w[c+(e+304|0)|0];U(325,b|0,((c<<5)+a|0)+946304|0,d&63);f=v[23588];v[23588]=0;if((f|0)==1){break t}A:{B:{if(d<<24>>24<0){break B}v[23588]=0;d=S(326,b|0)|0;f=v[23588];v[23588]=0;C:{D:{E:{F:{G:{H:{I:{J:{if((f|0)==1){break J}c=B(c,104)+a|0;f=c+484392|0;v[f>>2]=d<<1;v[23588]=0;d=S(326,b|0)|0;j=v[23588];v[23588]=0;if((j|0)==1){break I}if(d>>>0>=2){v[c+484396>>2]=v[f>>2]+(d<<1);d=c+484414|0;u[d>>1]=x[d>>1]|8}v[23588]=0;d=S(206,b|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break s}t[e+72|0]=d;t[e+176|0]=64;A=c+484410|0,C=w[Wb(e+72|0,e+176|0)|0]<<2,u[A>>1]=C;v[23588]=0;d=S(206,b|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break J}t[c+484417|0]=d<<4;c=c+484380|0;to(c);if(!v[c>>2]){break B}v[23588]=0;f=S(206,b|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break D}d=0;switch(f|0){case 4:case 5:break C;case 2:case 3:break F;case 1:break G;case 0:break H;default:break g}}g=P()|0;O()|0;break b}g=P()|0;O()|0;break b}if(h){f=Sb(e+72|0);j=v[b+8>>2];i=v[b>>2];k=v[c>>2];v[23588]=0;j=W(156,i|0,j|0,k|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break r}if(!j){break w}d=v[c>>2];v[23588]=0;U(327,b|0,f|0,d|0);d=v[23588];v[23588]=0;if((d|0)==1){break r}A=e,C=Eb(v[f>>2]),v[A+176>>2]=C;j=Eb(v[e+76>>2]);while(1){d=v[e+176>>2];if(Ob(d,j)){i=d;d=w[d|0];t[i|0]=d<<7|(d^-1)>>>1&127;Ge(e+176|0);continue}break}re(e+200|0,v[f>>2],v[e+76>>2]);d=ee(e+192|0);v[23588]=0;j=v[d+4>>2];v[e+16>>2]=v[d>>2];v[e+20>>2]=j;d=Eg(328,e+208|0,v[e+200>>2],v[e+204>>2],e+16|0);j=v[23588];v[23588]=0;K:{if((j|0)!=1){j=Zc(e+176|0,16,1,0,16);v[23588]=0;W(219,j|0,c|0,d|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break K}Ab(d);hc(f);break B}g=P()|0;O()|0;break o}g=P()|0;O()|0;Ab(d);break o}c=v[c>>2];break E}f=Sb(e+72|0);d=v[c>>2];v[23588]=0;U(329,e+176|0,b|0,d|0);d=v[23588];v[23588]=0;L:{M:{N:{if((d|0)!=1){d=e+176|0;j=Km(f,d);hc(d);if(h){re(e+144|0,v[j>>2],v[e+76>>2]);d=ee(e+136|0);v[23588]=0;i=v[d+4>>2];v[e+24>>2]=v[d>>2];v[e+28>>2]=i;d=Eg(328,e+152|0,v[e+144>>2],v[e+148>>2],e+24|0);i=v[23588];v[23588]=0;if((i|0)==1){break N}i=Zc(e+176|0,8,1,0,2);v[23588]=0;W(219,i|0,c|0,d|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break M}Ab(d)}hc(j);break B}g=V(30480)|0;if((O()|0)!=(da(30480)|0)){break L}_(g|0)|0;d=0;v[23588]=0;Z(18);a=v[23588];v[23588]=0;if((a|0)!=1){break u}g=P()|0;O()|0;break L}g=P()|0;O()|0;break L}g=P()|0;O()|0;Ab(d)}hc(f);break b}if(h){d=Zc(e+72|0,(f|0)==2?8:16,1,0,0);v[23588]=0;W(219,d|0,c|0,b|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break B}g=P()|0;O()|0;break b}c=B(v[c>>2],f-1|0)}v[23588]=0;Q(188,b|0,c|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break B}}g=P()|0;O()|0;break b}j=Sb(e+72|0);d=v[c>>2];v[23588]=0;U(330,e+176|0,b|0,d|0);d=v[23588];v[23588]=0;O:{P:{if((d|0)!=1){i=e+176|0;d=Km(j,i);hc(i);if(!h){break O}if((f|0)!=5){break P}A=e,C=Eb(v[d>>2]),v[A+176>>2]=C;k=Eb(v[e+76>>2]);while(1){i=v[e+176>>2];if(!Ob(i,k)){break P}m=i;i=w[i|0];t[m|0]=w[(i>>>7|0)+26353|0]^i;Ge(e+176|0);continue}}g=V(30480)|0;if((O()|0)!=(da(30480)|0)){break x}_(g|0)|0;d=0;v[23588]=0;Z(18);a=v[23588];v[23588]=0;if((a|0)!=1){break A}g=P()|0;O()|0;break x}re(e+104|0,v[d>>2],v[e+76>>2]);i=ee(e+96|0);v[23588]=0;k=v[i+4>>2];v[e+32>>2]=v[i>>2];v[e+36>>2]=k;i=Eg(328,e+112|0,v[e+104>>2],v[e+108>>2],e+32|0);k=v[23588];v[23588]=0;if((k|0)==1){break z}f=(f|0)==5;f=Zc(e+176|0,f?16:8,1,0,f?16:1);v[23588]=0;W(219,f|0,c|0,i|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break y}Ab(i)}hc(d)}g=g+1|0;continue}break}hc(j);break g}g=P()|0;O()|0;break x}g=P()|0;O()|0;Ab(i)}hc(j);break b}hc(f);break g}Q:{R:{S:{T:{U:{V:{W:{d=x[e+390>>1]|w[e+392|0]<<16;if(d){c=Sb(e+176|0);v[23588]=0;b=W(321,b|0,c|0,d|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break q}if(!b){break U}re(e- -64|0,v[c>>2],v[c+4>>2]);b=ee(e+56|0);v[23588]=0;g=v[b+4>>2];v[e+8>>2]=v[b>>2];v[e+12>>2]=g;b=Eg(328,e+72|0,v[e+64>>2],v[e+68>>2],e+8|0);g=v[23588];v[23588]=0;if((g|0)==1){break W}v[23588]=0;X(331,a+1298332|0,b|0,d|0,1);d=v[23588];v[23588]=0;if((d|0)==1){break V}Ab(b);hc(c)}v[23588]=0;Y(332,e+40|0);b=v[23588];v[23588]=0;if((b|0)==1){break T}v[23588]=0;U(213,e+176|0,e+40|0,w[e+384|0]);b=v[23588];v[23588]=0;if((b|0)==1){break S}b=e+176|0;Ib(a+1298344|0,b);zb(b);ac(e+40|0);v[23588]=0;b=Q(1,b|0,10046)|0;c=v[23588];v[23588]=0;if((c|0)==1){break R}Ib(a+1298356|0,b);zb(b);v[23588]=0;b=Q(1,e+40|0,5104)|0;c=v[23588];v[23588]=0;if((c|0)==1){break Q}Ib(a+1298368|0,b);zb(b);v[a+1298404>>2]=10;d=1;break g}g=P()|0;O()|0;break p}g=P()|0;O()|0;Ab(b);break p}hc(c);d=0;break g}g=P()|0;O()|0;break b}g=P()|0;O()|0;ac(e+40|0);break b}g=P()|0;O()|0;break b}g=P()|0;O()|0;break b}hc(f);break g}g=P()|0;O()|0;break b}g=P()|0;O()|0;break b}g=P()|0;O()|0;break o}g=P()|0;O()|0}hc(c);break b}hc(f);break b}A=cc(v[Vb(v[a+484360>>2],w[p|0])>>2],j),C=j,u[A>>1]=C;X:{Y:{if(!s){break Y}v[23588]=0;r=j&65535;d=W(226,q|0,r|0,64)|0;g=v[23588];v[23588]=0;if((g|0)==1){break X}if(!d){break Y}f=x[a+480188>>1];i=0;while(1){d=f&65535;if(d>>>0<=i>>>0){break Y}d=cc(v[e+272>>2],B(d,j)+i|0);d=w[d|0]|w[d+1|0]<<8;Z:{if(d>>>0>=x[e+388>>1]){break Z}g=0;y=0-i|0;z=d<<8;d=Yb(v[q>>2],j);d=id(v[d>>2],v[v[d+48>>2]+12>>2],0,i&65535);while(1){if((g|0)==64){break Z}Bq(e+208|0,v[e+240>>2],v[e+244>>2],(g<<2)+z|0,4);f=v[e+208>>2];h=Kb(f,0);m=w[h|0]&63;t[d|0]=m?m+48|0:0;k=Kb(f,1);t[d+1|0]=w[k|0]<<2&60|w[h|0]>>>6;o=w[k|0];h=Kb(f,2);k=w[Kb(f,3)|0];f=w[h|0];h=k<<4|f>>>4;u[e+72>>1]=h;f=f<<2&60|o>>>6;_:{if(!(w[Kb(e+296|0,f>>>3|0)|0]>>>(f&7)&1)|!(h?1:f)){break _}t[d+5|0]=h;o=k>>>4|0;t[d+4|0]=o;$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{switch(f|0){case 0:case 1:case 2:case 32:case 33:case 34:Of(d,f&15,h&255);if(!w[d+4|0]){break _}t[d+2|0]=f>>>0<32?3:4;break _;case 9:t[d+3|0]=10;t[d+5|0]=h>>>1;if(h>>>0<512){break _}t[d+2|0]=15;t[d+4|0]=k>>>5;break _;case 10:case 42:if(h>>>0>254){break ja}f=f&15;break;case 50:break aa;case 48:break ba;case 43:break ca;case 47:break da;case 17:case 18:case 26:case 27:break ea;case 22:case 25:case 28:case 29:case 30:break fa;case 16:case 19:case 20:case 21:case 23:case 31:break ga;case 13:break ha;case 11:case 15:break ia;case 3:case 4:case 5:case 6:case 7:case 12:break ka;default:break $}}Of(d,f,h&255);break _}t[d+3|0]=19;t[d+5|0]=o|(f>>>0<32?16:32);if(k&15){t[d+2|0]=3;t[d+4|0]=(h&240)>>>4;break _}t[d+2|0]=4;t[d+4|0]=h&15;break _}t[d+3|0]=(f|0)==11?12:16;A=d,C=Au(h),t[A+5|0]=C;break _}t[d+3|0]=14;if((h&255)>>>0<64){break _}t[d+5|0]=0;break _}t[d+3|0]=19;t[d+5|0]=h&15|f<<4;break _}t[d+3|0]=19;u[e+152>>1]=15;A=d,C=w[Vc(e+72|0,e+152|0)|0]|f<<4,t[A+5|0]=C;break _}t[d+3|0]=19;if(h&255){t[d+5|0]=h&15|((f|0)==17?16:(f|0)==26?16:32);if(!(k&240)){break _}t[d+2|0]=f>>>0>25?6:5;break _}t[d+5|0]=o|(f>>>0>25?-80:-96);break _}if(!h){break $}t[d+3|0]=17;v[e+152>>2]=8;v[e+112>>2]=h+4;A=d,C=sg(v[Oe(e+152|0,e+112|0)>>2]/8|0),t[A+5|0]=C;break _}t[d+3|0]=14;k=B(y,6)+d|0;m=x[a+480188>>1];f=0;while(1){if((f|0)==(m|0)){break _}h=k+B(f,6)|0;if(!w[h+3|0]){t[h+3|0]=12;A=h,C=Au(r),t[A+5|0]=C}f=f+1|0;continue}}t[d+3|0]=9;f=h&7;if(f){t[d+5|0]=w[f+26345|0];break _}f=h>>>4|0;if((f|0)==128){break $}t[d+5|0]=f;if(!(h&2048)){t[d+5|0]=f^128;break _}t[d+5|0]=f^-1;break _}t[d+5|0]=0;t[d+3|0]=0;if(!m){t[d|0]=255;break _}t[d+3|0]=25;break _}t[d+3|0]=0}g=g+1|0;f=x[a+480188>>1];d=B(f,6)+d|0;continue}}i=i+1|0;continue}}j=j+1|0;continue}break}g=P()|0;O()|0;break b}break c}}else{tB(a,d&65535);u[((d<<5)+a|0)+480284>>1]=(d&3)-1>>>0<2?64:192;d=d+1|0;g=x[a+480188>>1];continue}break}g=P()|0;O()|0;break b}hc(l)}hc(n)}jb=e+400|0;return d|0}g=P()|0;O()|0;break b}g=P()|0;O()|0;hc(d)}hc(l)}hc(n);T(g|0);L()}function QG(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,y=0,D=0,E=0,F=0,G=0,H=C(0),I=0;e=jb-144|0;jb=e;d=Tb(e,0,144);v[d+76>>2]=-1;v[d+44>>2]=a;v[d+32>>2]=1117;v[d+84>>2]=a;x=c;a=0;h=jb-304|0;jb=h;a:{b:{c:{d:{if(v[d+4>>2]){break d}Xw(d);if(v[d+4>>2]){break d}break c}g=w[b|0];if(!g){break a}e:{f:{g:{h:{while(1){i:{c=g&255;j:{if(Vk(c)){while(1){g=b;b=b+1|0;if(Vk(w[g+1|0])){continue}break}ki(d,0,0);while(1){b=v[d+4>>2];k:{if((b|0)!=v[d+104>>2]){v[d+4>>2]=b+1;b=w[b|0];break k}b=rd(d)}if(Vk(b)){continue}break}b=v[d+4>>2];c=v[d+116>>2];if((c|0)>0|(c|0)>=0){b=b-1|0;v[d+4>>2]=b}b=b-v[d+44>>2]|0;c=b>>31;i=b;e=n+v[d+124>>2]|0;b=m+v[d+120>>2]|0;e=b>>>0<m>>>0?e+1|0:e;f=b;b=i+b|0;i=c+e|0;m=b;n=b>>>0<f>>>0?i+1|0:i;break j}l:{m:{n:{if((c|0)==37){c=w[b+1|0];if((c|0)==42){break n}if((c|0)!=37){break m}}ki(d,0,0);o:{if(w[b|0]==37){while(1){c=v[d+4>>2];p:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;g=w[c|0];break p}g=rd(d)}if(Vk(g)){continue}break}b=b+1|0;break o}c=v[d+4>>2];if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;g=w[c|0];break o}g=rd(d)}if(w[b|0]!=(g|0)){b=v[d+116>>2];if((b|0)>0|(b|0)>=0){v[d+4>>2]=v[d+4>>2]-1}if((g|0)>=0){break a}f=0;if(y){break a}break c}c=v[d+4>>2]-v[d+44>>2]|0;g=c>>31;f=c;c=n+v[d+124>>2]|0;e=m+v[d+120>>2]|0;c=e>>>0<m>>>0?c+1|0:c;i=e;e=f+e|0;f=c+g|0;m=e;n=e>>>0<i>>>0?f+1|0:f;g=b;break j}l=0;b=b+2|0;break l}if(!(!$j(c)|w[b+2|0]!=36)){e=jb-16|0;v[e+12>>2]=x;c=c-48|0;c=(c>>>0>1?(c<<2)-4|0:0)+x|0;v[e+8>>2]=c+4;l=v[c>>2];b=b+3|0;break l}l=v[x>>2];x=x+4|0;b=b+1|0}c=0;while(1){e=w[b|0];if($j(e)){b=b+1|0;c=(B(c,10)+e|0)-48|0;continue}break}r=0;if((e|0)==109){o=0;r=(l|0)!=0;e=w[b+1|0];b=b+1|0;a=0}g=b+1|0;k=3;f=r;q:{r:{switch((e&255)-65|0){case 39:e=b+2|0;b=w[b+1|0]==104;g=b?e:g;k=b?-2:-1;break q;case 43:e=b+2|0;b=w[b+1|0]==108;g=b?e:g;k=b?3:1;break q;case 51:case 57:k=1;break q;case 11:k=2;break q;case 41:break q;case 0:case 2:case 4:case 5:case 6:case 18:case 23:case 26:case 32:case 34:case 35:case 36:case 37:case 38:case 40:case 45:case 46:case 47:case 50:case 52:case 55:break r;default:break e}}k=0;g=b}b=w[g|0];e=(b&47)==3;D=e?1:k;p=e?b|32:b;s:{if((p|0)==91){break s}t:{if((p|0)!=110){if((p|0)!=99){break t}c=(c|0)>1?c:1;break s}RG(l,D,m,n);break j}ki(d,0,0);while(1){b=v[d+4>>2];u:{if((b|0)!=v[d+104>>2]){v[d+4>>2]=b+1;b=w[b|0];break u}b=rd(d)}if(Vk(b)){continue}break}b=v[d+4>>2];e=v[d+116>>2];if((e|0)>0|(e|0)>=0){b=b-1|0;v[d+4>>2]=b}b=b-v[d+44>>2]|0;f=b>>31;j=b;e=n+v[d+124>>2]|0;b=m+v[d+120>>2]|0;e=b>>>0<m>>>0?e+1|0:e;i=b;b=j+b|0;n=e+f|0;n=b>>>0<i>>>0?n+1|0:n;m=b}j=c;s=c>>31;ki(d,c,s);b=v[d+4>>2];v:{if((b|0)!=v[d+104>>2]){v[d+4>>2]=b+1;break v}if((rd(d)|0)<0){break f}}b=v[d+116>>2];if((b|0)>0|(b|0)>=0){v[d+4>>2]=v[d+4>>2]-1}b=16;w:{x:{y:{z:{A:{switch(p-88|0){default:b=p-65|0;if(b>>>0>6|!(1<<b&113)){break w}case 9:case 13:case 14:case 15:TG(h+8|0,d,D,0);b=v[d+4>>2]-v[d+44>>2]|0;if(v[d+120>>2]!=(0-b|0)|v[d+124>>2]!=(0-((b>>31)+((b|0)!=0)|0)|0)){break y}break g;case 3:case 11:case 27:if((p|16)==115){Tb(h+32|0,-1,257);t[h+32|0]=0;if((p|0)!=115){break x}t[h+65|0]=0;t[h+46|0]=0;u[h+42>>1]=0;u[h+44>>1]=0;break x}e=w[g+1|0];f=(e|0)==94;Tb(h+32|0,f,257);t[h+32|0]=0;b=f?g+2|0:g+1|0;B:{C:{D:{g=w[(f?2:1)+g|0];if((g|0)!=45){if((g|0)==93){break D}k=(e|0)!=94;break B}k=(e|0)!=94;t[h+78|0]=k;break C}k=(e|0)!=94;t[h+126|0]=k}b=b+1|0}g=b;while(1){e=w[g|0];E:{if((e|0)!=45){if(!e){break f}if((e|0)==93){break x}break E}e=45;f=w[g+1|0];if(!f|(f|0)==93){break E}i=g+1|0;b=w[g-1|0];F:{if(f>>>0<=b>>>0){e=f;break F}while(1){b=b+1|0;t[b+(h+32|0)|0]=k;e=w[i|0];if(e>>>0>b>>>0){continue}break}}g=i}t[(e+h|0)+33|0]=k;g=g+1|0;continue};case 23:b=8;break z;case 12:case 29:b=10;break z;case 1:case 2:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 22:case 25:case 26:case 28:case 30:case 31:break w;case 0:case 24:case 32:break z;case 17:break A}}b=0}j=0;i=0;e=0;f=0;s=0;E=jb-16|0;jb=E;G:{if((b|0)==1){v[116064]=28;break G}while(1){c=v[d+4>>2];H:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;c=w[c|0];break H}c=rd(d)}if(Vk(c)){continue}break}I:{J:{switch(c-43|0){case 0:case 2:break J;default:break I}}s=(c|0)==45?-1:0;c=v[d+4>>2];if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;c=w[c|0];break I}c=rd(d)}K:{L:{M:{N:{if(!((b|0)!=0&(b|0)!=16|(c|0)!=48)){c=v[d+4>>2];O:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;c=w[c|0];break O}c=rd(d)}if((c&-33)==88){b=16;c=v[d+4>>2];P:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;c=w[c|0];break P}c=rd(d)}if(w[c+79201|0]<16){break M}b=v[d+116>>2];if((b|0)>0|(b|0)>=0){v[d+4>>2]=v[d+4>>2]-1}ki(d,0,0);break G}if(b){break N}b=8;break M}b=b?b:10;if(b>>>0>w[c+79201|0]){break N}b=v[d+116>>2];if((b|0)>0|(b|0)>=0){v[d+4>>2]=v[d+4>>2]-1}ki(d,0,0);v[116064]=28;break G}if((b|0)!=10){break M}e=c-48|0;if(e>>>0<=9){b=0;while(1){b=B(b,10)+e|0;f=b>>>0<429496729;c=v[d+4>>2];Q:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;c=w[c|0];break Q}c=rd(d)}e=c-48|0;if(f&e>>>0<=9){continue}break}j=b}R:{if(e>>>0>9){break R}k=Lka(j,0,10,0);f=mb;b=e;while(1){c=v[d+4>>2];S:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;c=w[c|0];break S}c=rd(d)}e=c-48|0;q=e>>>0>9;j=b+k|0;i=j>>>0<b>>>0?f+1|0:f;if((i|0)==429496729&j>>>0>=2576980378|i>>>0>429496729|q){break R}k=Lka(j,i,10,0);f=mb;b=e;if((f|0)==-1&k>>>0<=(b^-1)>>>0|(f|0)!=-1){continue}break}b=10;break L}b=10;if(e>>>0<=9){break L}break K}if(b-1&b){f=w[c+79201|0];if(f>>>0<b>>>0){while(1){e=B(b,e)+f|0;j=e>>>0<119304647;c=v[d+4>>2];T:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;c=w[c|0];break T}c=rd(d)}f=w[c+79201|0];if(j&f>>>0<b>>>0){continue}break}j=e}if(b>>>0<=f>>>0){break L}while(1){k=Lka(j,i,b,0);e=mb;f=f&255;if((e|0)==-1&(f^-1)>>>0<k>>>0){break L}c=f+k|0;e=c>>>0<f>>>0?e+1|0:e;j=c;i=e;c=v[d+4>>2];U:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;c=w[c|0];break U}c=rd(d)}f=w[c+79201|0];if(b>>>0<=f>>>0){break L}uf(E,b,0,0,0,j,i,0,0);if(!(v[E+8>>2]|v[E+12>>2])){continue}break}break L}k=t[(B(b,23)>>>5&7)+79457|0];e=w[c+79201|0];if(e>>>0<b>>>0){while(1){f=f<<k|e;j=f>>>0<134217728;c=v[d+4>>2];V:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;c=w[c|0];break V}c=rd(d)}e=w[c+79201|0];if(j&e>>>0<b>>>0){continue}break}j=f}if(b>>>0<=e>>>0){break L}f=k;q=f&31;if((f&63)>>>0>=32){f=0;q=-1>>>q|0}else{f=-1>>>q|0;q=f|(1<<q)-1<<32-q}if(!f&j>>>0>q>>>0){break L}while(1){c=k&31;F=e&255;if((k&63)>>>0>=32){e=j<<c;c=0}else{e=(1<<c)-1&j>>>32-c|i<<c;c=j<<c}j=F|c;i=e;c=v[d+4>>2];W:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;c=w[c|0];break W}c=rd(d)}e=w[c+79201|0];if(b>>>0<=e>>>0){break L}if((f|0)==(i|0)&j>>>0<=q>>>0|f>>>0>i>>>0){continue}break}}if(w[c+79201|0]>=b>>>0){break K}while(1){c=v[d+4>>2];X:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;c=w[c|0];break X}c=rd(d)}if(w[c+79201|0]<b>>>0){continue}break}v[116064]=68;j=-1;i=-1;s=0}b=v[d+116>>2];if((b|0)>0|(b|0)>=0){v[d+4>>2]=v[d+4>>2]-1}b=s;c=b^j;j=c-b|0;e=b>>31;i=(e^i)-((b>>>0>c>>>0)+e|0)|0}jb=E+16|0;b=v[d+4>>2]-v[d+44>>2]|0;if(v[d+120>>2]==(0-b|0)&v[d+124>>2]==(0-((b>>31)+((b|0)!=0)|0)|0)){break g}if(!(!l|(p|0)!=112)){v[l>>2]=j;break w}RG(l,D,j,i);break w}if(!l){break w}b=v[h+16>>2];c=v[h+20>>2];e=v[h+8>>2];f=v[h+12>>2];Y:{switch(D|0){case 0:G=l,H=oF(e,f,b,c),z[G>>2]=H;break w;case 1:G=l,I=Hw(e,f,b,c),A[G>>3]=I;break w;case 2:break Y;default:break w}}v[l>>2]=e;v[l+4>>2]=f;v[l+8>>2]=b;v[l+12>>2]=c;break w}i=(p|0)==99;c=i?c+1|0:31;Z:{if((D|0)==1){e=l;if(r){e=Od(c<<2);if(!e){break h}}v[h+296>>2]=0;v[h+300>>2]=0;b=0;while(1){a=e;_:{while(1){e=v[d+4>>2];$:{if((e|0)!=v[d+104>>2]){v[d+4>>2]=e+1;e=w[e|0];break $}e=rd(d)}if(!w[(e+h|0)+33|0]){break _}t[h+27|0]=e;e=Wr(h+28|0,h+27|0,1,h+296|0);if((e|0)==-2){continue}o=0;if((e|0)==-1){break f}if(a){v[(b<<2)+a>>2]=v[h+28>>2];b=b+1|0}if(!((b|0)==(c|0)&r)){continue}break}f=1;b=c;c=b<<1|1;e=ks(a,c<<2);if(e){continue}break e}break}o=0;c=a;if(h+296|0?v[h+296>>2]:0){break f}break Z}if(r){b=0;e=Od(c);if(!e){break h}while(1){a=e;while(1){e=v[d+4>>2];aa:{if((e|0)!=v[d+104>>2]){v[d+4>>2]=e+1;e=w[e|0];break aa}e=rd(d)}if(!w[(e+h|0)+33|0]){c=0;o=a;break Z}t[a+b|0]=e;b=b+1|0;if((c|0)!=(b|0)){continue}break}f=1;b=c;c=b<<1|1;e=ks(a,c);if(e){continue}break}o=a;a=0;break e}b=0;if(l){while(1){a=v[d+4>>2];ba:{if((a|0)!=v[d+104>>2]){v[d+4>>2]=a+1;a=w[a|0];break ba}a=rd(d)}if(w[(a+h|0)+33|0]){t[b+l|0]=a;b=b+1|0;continue}else{c=0;a=l;o=a;break Z}}}while(1){a=v[d+4>>2];ca:{if((a|0)!=v[d+104>>2]){v[d+4>>2]=a+1;a=w[a|0];break ca}a=rd(d)}if(w[(a+h|0)+33|0]){continue}break}a=0;o=0;c=0}e=v[d+4>>2];f=v[d+116>>2];if((f|0)>0|(f|0)>=0){e=e-1|0;v[d+4>>2]=e}f=e-v[d+44>>2]|0;k=f;e=f+v[d+120>>2]|0;f=v[d+124>>2]+(f>>31)|0;f=e>>>0<k>>>0?f+1|0:f;if(!(f|e)|((e|0)!=(j|0)|(f|0)!=(s|0))&(p|0)==99){break i}if(r){v[l>>2]=a}da:{if(i){break da}if(c){v[(b<<2)+c>>2]=0}if(!o){o=0;break da}t[b+o|0]=0}a=c}b=v[d+4>>2]-v[d+44>>2]|0;e=b>>31;i=b;c=n+v[d+124>>2]|0;b=m+v[d+120>>2]|0;c=b>>>0<m>>>0?c+1|0:c;f=b;b=i+b|0;e=c+e|0;m=b;n=b>>>0<f>>>0?e+1|0:e;y=((l|0)!=0)+y|0}b=g+1|0;g=w[g+1|0];if(g){continue}break a}break}a=c;break g}f=1;o=0;a=0;break e}f=r;break b}f=r}if(y){break b}}y=-1}if(!f){break a}Mb(o);Mb(a)}jb=h+304|0;jb=d+144|0;return y}function Uea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;k=jb-208|0;jb=k;if(!Kt(a)){e=k+48|0;rQ(e,a);f=k+176|0;pf(f,e,128,2);e=k+192|0;Ec(e,f);Cc(b+492|0,e);yb(e)}u[c+34>>1]=x[c+34>>1]&65489;h=k+192|0;f=jb-32|0;jb=f;a:{b:{switch(w[a+128|0]-4|0){default:v[f+28>>2]=0;ho(h,0,f+28|0);break a;case 0:case 4:break b}}t[f+28|0]=w[a+129|0];t[f+24|0]=100;e=f+24|0;g=w[Wb(f+28|0,e)|0];t[f+24|0]=w[a+130|0];t[f+20|0]=100;e=w[Wb(e,f+20|0)|0];v[f+28>>2]=e;c:{if(w[a+140|0]&16){j=Hb(w[a+150|0]|w[a+151|0]<<8);o=Hb(w[a+152|0]|w[a+153|0]<<8);l=v[c>>2];r=+(l>>>0)/6553600;g=zq(r*+((j|g<<16)>>>0));v[f+24>>2]=l-g;s=f,y=zq(r*+((o|e<<16)>>>0)),v[s+20>>2]=y;s=f,y=v[Jb(f+24|0,f+20|0)>>2],v[s+28>>2]=y;break c}j=v[c>>2];o=v[c+20>>2];if(!Zd(j,o)){break c}l=j>>>7|0;g=B(l,(g<<7>>>0)/100|0);v[f+24>>2]=j-g;v[f+20>>2]=B(l,(e<<7>>>0)/100|0);e=v[Jb(f+24|0,f+20|0)>>2];l=x[c+34>>1];j=B(Kd(l),j);d:{if(l&1){fc(f+8|0,o,j);o=v[f+8>>2];l=Kd(x[c+34>>1]);j=o+(B(l,e+g|0)<<1)|0;n=u[o+(B(g,l)<<1)>>1];l=0-l<<1;while(1){e:{f:{if(e){p=u[j>>1]-n|0;o=p>>31;if((o^p)-o>>>0>=1536){break f}}else{e=0}break e}e=e-1|0;j=j+l|0;continue}break}break d}fc(f,o,j);o=v[f>>2];l=Kd(x[c+34>>1]);n=0-l|0;j=o+B(l,e+g|0)|0;l=t[o+B(g,l)|0];while(1){g:{h:{if(e){p=t[j|0]-l|0;o=p>>31;if((o^p)-o>>>0>=6){break h}}else{e=0}break g}e=e-1|0;j=j+n|0;continue}break}}v[f+28>>2]=e}ho(h,g,f+28|0)}jb=f+32|0;o=ic(h);if(!(!v[o>>2]|w[a+128|0]!=4)){u[c+34>>1]=x[c+34>>1]|2;e=v[k+192>>2];v[c+4>>2]=e;v[c+8>>2]=e+v[o>>2]}e=w[a+134|0];if((e-1&255)>>>0<=198){t[k+48|0]=e;t[k+176|0]=100;e=(w[Wb(k+48|0,k+176|0)|0]<<7>>>0)/100|0}else{e=128}t[k+47|0]=e;t[k+48|0]=64;e=k+47|0;f=k+48|0;s=c,y=w[jf(e,f)|0]>>>1|0,u[s+32>>1]=y;t[k+48|0]=64;s=b,y=w[Wb(e,f)|0],v[s+4>>2]=y;v[c+24>>2]=40460;Al(c,+t[a+139|0]/12+ +(0-w[a+143|0]|0)+ +t[a+138|0]/1536);t[b+34|0]=w[a+142|0]&2?2:1;if(w[a+142|0]&2){Lj(b,127,1);Kj(b,0,1)}i:{if(!Zd(v[c>>2],v[c+20>>2])){break i}b=w[a+140|0];if(b&1){b=v[c>>2];e=v[c+20>>2];j:{if(!Zd(b,e)|b>>>0<2){break j}k:{l:{switch(Ek(x[c+34>>1])-1|0){case 3:f=0;h=b>>>1|0;while(1){if((f|0)!=(h|0)){pc(e+(f<<2)|0,e+(b+(f^-1)<<2)|0);f=f+1|0;continue}break};break k;case 1:f=0;h=b>>>1|0;while(1){if((f|0)!=(h|0)){ly(e+(f<<1)|0,e+(b+(f^-1)<<1)|0);f=f+1|0;continue}break};break k;case 0:break l;default:break j}}f=0;h=b>>>1|0;while(1){if((f|0)!=(h|0)){Ii(e+f|0,e+(b+(f^-1)|0)|0);f=f+1|0;continue}break}}tj(c,d)}b=w[a+140|0]}if(b&4){m:{e=v[c>>2];b=v[c+20>>2];if(!Zd(e,b)){break m}f=x[c+34>>1];e=B(Kd(f),e);n:{o:{switch(Zm(f)-1|0){case 1:f=0;while(1){if((e|0)!=(f|0)){h=b+(f<<1)|0;u[h>>1]=x[h>>1]^-1;f=f+1|0;continue}break};break n;case 0:break o;default:break m}}f=0;while(1){if((e|0)!=(f|0)){h=b+f|0;t[h|0]=w[h|0]^-1;f=f+1|0;continue}break}}tj(c,d)}}i=w[a+170|0]!=2|w[a+171|0]>100?i:w[a+172|0]<101;b=x[c+34>>1];if(!(!(w[a+141|0]?1:i|w[a+160|0]!=0)|b&1)){e=Jt(v[c>>2],Kd(b)<<1&254);if(!e){break i}b=e;h=v[c>>2];g=x[c+34>>1];j=B(Kd(g),h);f=v[c+20>>2];g=Hj(h,g);h=jb-16|0;jb=h;v[h+12>>2]=j;wc(h+12|0,g);j=v[h+12>>2];while(1){if(j){u[b>>1]=t[f|0]<<8;f=f+1|0;b=b+2|0;j=j-1|0;continue}break}jb=h+16|0;u[c+34>>1]=x[c+34>>1]|1;pQ(c,e,v[c>>2],d)}p:{if(t[a+141|0]>=0){break p}fc(k+48|0,v[c+20>>2],B(v[c>>2],Kd(x[c+34>>1])));f=v[k+52>>2];e=v[k+48>>2];q:while(1){if((0-t[a+141|0]|0)<=(m|0)){break p}g=u[e>>1];h=cc(e,f);b=e;while(1)if((b|0)==(h|0)){m=m+1|0;continue q}else{g=kd(u[b>>1]-kd(g,1)|0,1);u[b>>1]=g;b=b+2|0;continue}}}r:{if(!i){break r}fc(k+48|0,v[c+20>>2],B(v[c>>2],Kd(x[c+34>>1])));i=v[k+52>>2];b=(i|0)/2|0;h=b>>31;n=b;b=w[a+172|0];g=w[a+171|0];e=g;f=0-(b>>>0<e>>>0)|0;b=b-e|0;e=f<<24|b>>>8;j=b<<24;f=n+j|0;b=e+h|0;b=Hc(Mka(f,f>>>0<j>>>0?b+1|0:b,i,i>>31),mb);f=b;j=b>>31;b=g<<24;g=b;e=b>>31;b=v[k+48>>2];m=cc(b,i);while(1){if((b|0)==(m|0)){break r}i=u[b>>1];i=Lka(g,e,i,i>>31)+838860800|0;h=mb;s=b,y=Hc(Mka(i,i>>>0<838860800?h+1|0:h,1677721600,0),mb),u[s>>1]=y;b=b+2|0;e=e+j|0;i=f+g|0;e=i>>>0<f>>>0?e+1|0:e;g=i;continue}}s:{if(!w[a+160|0]){break s}fc(k+176|0,v[c+20>>2],B(v[c>>2],Kd(x[c+34>>1])));b=w[a+163|0];i=w[a+162|0];t:{if(w[a+161|0]<=1){f=0;e=v[k+180>>2];h=0;break t}f=v[k+180>>2];e=(f|0)/2|0;j=e>>31;g=e;e=w[a+164|0];h=0-(i>>>0>e>>>0)|0;e=e-i|0;m=e<<23;g=g+m|0;e=(h<<23|e>>>9)+j|0;f=Hc(Mka(g,g>>>0<m>>>0?e+1|0:e,f,f>>31),mb);e=v[k+180>>2];h=(e|0)/2|0;j=h>>31;n=h;h=w[a+165|0];m=0-(b>>>0>h>>>0)|0;g=h-b|0;h=m<<23|g>>>9;m=g<<23;g=n+m|0;h=h+j|0;h=Hc(Mka(g,g>>>0<m>>>0?h+1|0:h,e,e>>31),mb)}g=b<<23;i=i<<23;j=(k+48|0)+((w[a+160|0]&2)<<2)|0;m=0;b=v[k+176>>2];l=cc(b,e);e=0;while(1){if((b|0)==(l|0)){break s}n=(u[b>>1]>>1)-e|0;v[k+56>>2]=n;p=n;n=(i|0)/8388608|0;m=kd(B(p,n),8)+m|0;v[k+52>>2]=m;e=kd(B(m,n),6)+e|0;e=kd(kd(B(e,(g|0)/8388608|0),6)+e|0,2);v[k+48>>2]=e;s=b,y=dd(v[j>>2]),u[s>>1]=y;b=b+2|0;g=h+g|0;i=f+i|0;continue}}u:{if(t[a+141|0]<=0){break u}fc(k+48|0,v[c+20>>2],B(v[c>>2],Kd(x[c+34>>1])));m=0;f=v[k+52>>2];e=v[k+48>>2];v:while(1){if(t[a+141|0]<=(m|0)){break u}g=u[e>>1];i=cc(e,f);b=e;while(1)if((b|0)==(i|0)){m=m+1|0;continue v}else{g=((u[b>>1]<<1)+g|0)/3|0;u[b>>1]=g;b=b+2|0;continue}}}b=v[c+20>>2];f=x[c+34>>1];e=B(v[c>>2],Kd(f));w:{if(f&1){fc(k+32|0,b,e);j=jb-16|0;jb=j;b=v[k+32>>2];m=cc(b,v[k+36>>2]);l=jb-16|0;jb=l;v[l+12>>2]=b;q=j+8|0;f=ho(q,b,l+12|0);x:{if((b|0)==(m|0)){break x}e=b+2|0;if((m|0)==(e|0)){break x}s=(mk(x[e>>1],x[v[f>>2]>>1])?0:4)+f|0,y=e,v[s>>2]=y;h=f+4|0;while(1){g=e;i=e+2|0;if((m|0)!=(i|0)){e=g+4|0;if((m|0)==(e|0)){v[l+12>>2]=m;e=x[g+2>>1];if(!mk(e,x[v[f>>2]>>1])){f=h;if(mk(e,x[v[f>>2]>>1])){break x}}v[f>>2]=i;break x}n=x[v[f>>2]>>1];p=x[e>>1];g=x[g+2>>1];y:{if(mk(p,g)){if(mk(p,n)){v[f>>2]=e}if(mk(g,x[v[h>>2]>>1])){continue}break y}if(mk(g,n)){v[f>>2]=i}i=e;if(mk(p,x[v[h>>2]>>1])){continue}}v[h>>2]=i;continue}break}v[l+12>>2]=g}jb=l+16|0;v[j+4>>2]=0-u[v[j+8>>2]>>1];s=j,y=u[v[ic(q)>>2]>>1],v[s>>2]=y;z:{e=v[Oe(j+4|0,j)>>2];if((e|0)>32766|!e){break z}while(1){if((b|0)==(m|0)){break z}u[b>>1]=(B(u[b>>1],32767)|0)/(e|0);b=b+2|0;continue}}break w}fc(k+24|0,b,e);j=jb-16|0;jb=j;b=v[k+24>>2];m=Kb(b,v[k+28>>2]);l=jb-16|0;jb=l;v[l+12>>2]=b;q=j+8|0;f=ho(q,b,l+12|0);A:{if((b|0)==(m|0)){break A}e=b+1|0;if((m|0)==(e|0)){break A}s=(sl(w[e|0],w[v[f>>2]])?0:4)+f|0,y=e,v[s>>2]=y;h=f+4|0;while(1){g=e;i=e+1|0;if((m|0)!=(i|0)){e=g+2|0;if((m|0)==(e|0)){v[l+12>>2]=m;e=w[g+1|0];if(!sl(e,w[v[f>>2]])){f=h;if(sl(e,w[v[f>>2]])){break A}}v[f>>2]=i;break A}n=w[v[f>>2]];p=w[e|0];g=w[g+1|0];B:{if(sl(p,g)){if(sl(p,n)){v[f>>2]=e}if(sl(g,w[v[h>>2]])){continue}break B}if(sl(g,n)){v[f>>2]=i}i=e;if(sl(p,w[v[h>>2]])){continue}}v[h>>2]=i;continue}break}v[l+12>>2]=g}jb=l+16|0;v[j+4>>2]=0-t[v[j+8>>2]];s=j,y=t[v[ic(q)>>2]],v[s>>2]=y;C:{e=v[Oe(j+4|0,j)>>2];if((e|0)>126|!e){break C}while(1){if((b|0)==(m|0)){break C}t[b|0]=(B(t[b|0],127)|0)/(e|0);b=b+1|0;continue}}}jb=j+16|0;D:{if((w[a+134|0]-101&255)>>>0>98){break D}f=x[c+34>>1];e=B(v[c>>2],Kd(f));b=v[c+20>>2];if(f&1){i=k+16|0;v[i>>2]=b;v[i+4>>2]=(b+(e<<1)|0)-b>>1;b=(3276800-(w[a+134|0]<<14)|0)/100|0;h=0-b|0;f=32768-b|0;e=v[i>>2];g=cc(e,v[i+4>>2]);while(1){if((e|0)!=(g|0)){i=u[e>>1];E:{if((i|0)>(b|0)){n=f+((B(b,i-b|0)|0)/(f|0)|0)|0;break E}n=((B(b,b+i|0)|0)/(f|0)|0)-f|0;if((h|0)>(i|0)){break E}n=(B(f,i)|0)/(b|0)|0}s=e,y=dd(n),u[s>>1]=y;e=e+2|0;continue}break}break D}i=sn(k+8|0,b,b+e|0);e=v[i>>2];b=(3276800-(w[a+134|0]<<14)|0)/100|0;h=0-b|0;f=32768-b|0;g=Kb(e,v[i+4>>2]);while(1){if((e|0)!=(g|0)){i=t[e|0]<<8;F:{if((i|0)>(b|0)){n=f+((B(b,i-b|0)|0)/(f|0)|0)|0;break F}n=((B(b,b+i|0)|0)/(f|0)|0)-f|0;if((h|0)>(i|0)){break F}n=(B(f,i)|0)/(b|0)|0}s=e,y=nS((n|0)/256|0),t[s|0]=y;e=e+1|0;continue}break}}oQ(c);if(w[a+128|0]!=8){break i}b=w[a+131|0];if(!b){break i}e=v[o>>2];if(!e){break i}s=Db(c+68|0,0),y=v[k+192>>2]+B(e,b+1|0)|0,v[s>>2]=y;b=v[k+192>>2];v[c+12>>2]=b;v[c+16>>2]=b+v[o>>2];h=v[o>>2];i=w[a+131|0];if(h>>>0>268435456/(i>>>0)>>>0){break i}f=v[c>>2];e=B(h,i);if(f>>>0>268435456-e>>>0){break i}f=e+f|0;e=Ek(x[c+34>>1]);j=Jt(f,e);if(!j){break i}g=b+B(h,i+1|0)|0;v[c>>2]=f;b=j;j=v[c+20>>2];i=v[k+192>>2];h=tc(b,j,B(e,i+v[o>>2]|0));m=j+B(e,i)|0;a=w[a+131|0];b=0;while(1){if((a|0)==(b|0)){tc(h+B(e,g)|0,j+B(e,i+v[o>>2]|0)|0,B(e,f-g|0));pQ(c,h,f,d)}else{b=b+1|0;l=v[o>>2];tc(h+B(e,i+B(b,l)|0)|0,m,B(e,l));continue}break}}jb=k+208|0}function zaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=jb-784|0;jb=d;yc(b);a:{b:{c:{d:{e:{f:{if(!ci(b,d+776|0)){break f}if(!cM(v[d+776>>2],v[d+780>>2])){break f}if(!wA(b,d+768|0)){break f}g=v[d+768>>2];if(!bM(g)){break f}f=1313423693;if((g|0)!=1179012417){f=1414090313;if((g|0)!=538987841){break f}}m=je(d+744|0,b);j=Sb(d+728|0);g:{h:{i:{j:{k:{l:{m:{if(!c){v[23588]=0;X(851,d+136|0,m|0,((g|0)==1179012417?1:2)|0,f|0);b=v[23588];v[23588]=0;if((b|0)!=1){break m}a=P()|0;O()|0;break a}v[23588]=0;U(852,d+136|0,m|0,((g|0)==1179012417?1:2)|0);b=v[23588];v[23588]=0;if((b|0)==1){break l}}b=d+136|0;Tt(j,b);Yd(b);v[23588]=0;U(853,d+704|0,j|0,f|0);b=v[23588];v[23588]=0;if((b|0)!=1){v[23588]=0;b=S(178,v[d+704>>2])|0;e=v[23588];v[23588]=0;if((e|0)==1){break k}e=0;if(!b){break g}v[23588]=0;b=Q(854,d+704|0,d+624|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break k}if(!b){break g}b=w[d+689|0];if(!b){break g}v[23588]=0;e=W(156,v[d+704>>2],v[d+712>>2],b|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break k}if(!c|e^1){break g}v[23588]=0;R(246,a|0,8388608);b=v[23588];v[23588]=0;if((b|0)==1){break k}v[a+480208>>2]=w[d+688|0]<<4&16^28;u[d+136>>1]=w[d+689|0];u[d+496>>1]=127;p=a,q=x[Vc(d+136|0,d+496|0)>>1],u[p+480188>>1]=q;v[a+480196>>2]=w[d+690|0];v[a+480204>>2]=B(w[d+691|0],1e4);v[a+480200>>2]=w[d+696|0]<<1;v[23588]=0;R(136,a+1298344|0,((g|0)==1179012417?16935:16901)|0);b=v[23588];v[23588]=0;if((b|0)==1){break k}v[23588]=0;b=Q(1,d+608|0,13170)|0;e=v[23588];v[23588]=0;if((e|0)==1){break i}Ib(a+1298356|0,b);zb(b);v[a+1298404>>2]=5;b=d+496|0;aA(b,2,d+624|0);v[23588]=0;R(222,d+136|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break j}k=(g|0)!=1179012417;b=d+136|0;Ac(a+1298308|0,b);yb(b);l=(g|0)==1179012417;b=0;while(1){n:{o:{p:{if(x[a+480188>>1]<=b>>>0){b=Eb(v[j>>2]);f=Eb(v[j+4>>2]);e=jb-16|0;jb=e;v[e+8>>2]=b;while(1){q:{if(!Ob(b,f)){break q}if(VU(1380209231,v[b>>2],v[b+4>>2])){break q}b=v[Mm(e+8|0)>>2];continue}break}jb=e+16|0;if(Ob(b,Eb(v[j+4>>2]))){break p}break h}f=(b<<5)+a|0;h=f+480280|0;df(h);v[23588]=0;e=S(206,d+704|0)|0;n=v[23588];v[23588]=0;r:{s:{if((n|0)!=1){if(l){break r}if(e>>>0<129){break s}break o}a=P()|0;O()|0;break b}u[f+480284>>1]=e<<1;break n}if(e<<24>>24<0){break o}v[d+136>>2]=e<<2;v[d+496>>2]=256;p=f+480284|0,q=v[sd(d+136|0,d+496|0)>>2],u[p>>1]=q;break n}v[23588]=0;U(853,d+136|0,j|0,1380209231);b=v[23588];v[23588]=0;t:{if((b|0)!=1){v[23588]=0;b=S(206,d+136|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break t}e=w[a+484376|0];f=v[a+484360>>2];v[23588]=0;ea(340,Vb(f,e)|0,d+136|0,b+1&255,255,254);b=v[23588];v[23588]=0;if((b|0)==1){break t}Ab(d+136|0);break h}a=P()|0;O()|0;break b}a=P()|0;O()|0;Ab(d+136|0);break b}v[h>>2]=1024}b=b+1|0;continue}}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}u:{if(!(c&1)){break u}u[d+56>>1]=0;v[23588]=0;U(855,d+560|0,j|0,1414807888);b=v[23588];v[23588]=0;if((b|0)==1){break c}b=v[d+564>>2];e=v[d+560>>2];v[23588]=0;f=a+484344|0;R(225,f|0,Bf(e,b)&65535);b=v[23588];v[23588]=0;v:{if((b|0)!=1){p=d,q=Eb(v[d+560>>2]),v[p+88>>2]=q;l=Eb(v[d+564>>2]);w:{x:{y:{z:{A:{while(1){b=v[d+88>>2];if(!Ob(b,l)){k=a+484348|0;b=0;break w}b=je(d+136|0,b);v[23588]=0;e=S(206,b|0)|0;h=v[23588];v[23588]=0;if((h|0)!=1){v[23588]=0;u[d+480>>1]=e;e=S(157,b|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break A}v[23588]=0;U(190,d+496|0,b|0,e|0);e=v[23588];v[23588]=0;if((e|0)==1){break z}e=jc(d+584|0,d+496|0);v[23588]=0;h=v[e+12>>2];v[d+8>>2]=v[e+8>>2];v[d+12>>2]=h;v[d+16>>2]=v[e+16>>2];h=v[e+4>>2];v[d>>2]=v[e>>2];v[d+4>>2]=h;X(856,d|0,x[d+480>>1],k|0,a|0);e=v[23588];v[23588]=0;if((e|0)==1){break y}Ab(d+496|0);p=d,q=x[ke(d+56|0,d+480|0)>>1],u[p+56>>1]=q;Ab(b);Mf(d+88|0);continue}break}a=P()|0;O()|0;break x}a=P()|0;O()|0;break x}a=P()|0;O()|0;break x}a=P()|0;O()|0;Ab(d+496|0)}Ab(b);break v}while(1){e=b&65535;if(e>>>0>=x[d+56>>1]){Uc(d+560|0);break u}B:{if(!xe(v[a+484344>>2],v[k>>2],e)){v[23588]=0;W(226,f|0,e|0,64)|0;e=v[23588];v[23588]=0;if((e|0)==1){break B}}b=b+1|0;continue}break}a=P()|0;O()|0;break v}a=P()|0;O()|0}Uc(d+560|0);break b}C:{if((g|0)==1179012417){v[23588]=0;U(855,d+88|0,j|0,1414745673);b=v[23588];v[23588]=0;if((b|0)==1){break d}p=d,q=Eb(v[d+88>>2]),v[p+120>>2]=q;f=c&2;k=d+504|0;l=Eb(v[d+92>>2]);g=a+480190|0;while(1){b=v[d+120>>2];if(!Ob(b,l)){Uc(d+88|0);break C}c=je(d+560|0,b);v[23588]=0;b=Q(857,c|0,d+136|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){D:{if(!b){break D}b=w[d+137|0];if((b|0)==255){break D}v[23588]=0;e=W(251,a|0,b+1|0,0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break e}if(!e){break D}h=x[g>>1];b=0;v[23588]=0;U(858,d+136|0,e|0,h|0);e=v[23588];v[23588]=0;if((e|0)==1){break e}while(1){if(w[d+166|0]<=b>>>0){break D}E:{if(!Xh(x[g>>1])){break E}v[23588]=0;e=Q(859,c|0,d+496|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break e}if(!e){break E}e=x[g>>1]+1|0;u[g>>1]=e;if(v[d+496>>2]!=1347240275){break E}h=d+480|0;Hi(h,2,k);v[23588]=0;R(222,d+56|0,h|0);h=v[23588];v[23588]=0;F:{if((h|0)!=1){e=e&65535;h=d+56|0;Cc(((e<<5)+a|0)+946304|0,h);yb(h);v[23588]=0;e=(B(e,104)+a|0)+484380|0;U(860,d+496|0,d+136|0,e|0);h=v[23588];v[23588]=0;if((h|0)==1){break e}if(!f){break F}h=d+56|0;aM(h,x[d+534>>1]);v[23588]=0;W(219,h|0,e|0,c|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){break E}break e}break e}h=x[e+34>>1];e=v[e>>2];v[23588]=0;Q(188,c|0,Hj(e,h)|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break e}}b=b+1|0;continue}}Ab(c);Mf(d+120|0);continue}break}break e}v[23588]=0;U(855,d+480|0,j|0,1179011410);b=v[23588];v[23588]=0;if((b|0)!=1){p=d,q=Eb(v[d+480>>2]),v[p+472>>2]=q;k=c&2;l=d+496|4;h=Eb(v[d+484>>2]);e=a+480190|0;G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{while(1){b=v[d+472>>2];if(!Ob(b,h)){Uc(d+480|0);break C}c=je(d+560|0,b);v[23588]=0;b=S(157,c|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break P}Q:{R:{if((b|0)!=538986817){break R}v[23588]=0;b=Q(861,c|0,d+464|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break O}if(!(b&v[d+464>>2]==1414745673)){break R}v[23588]=0;b=Q(862,c|0,d+136|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break N}if(!b){break R}b=w[d+141|0];if((b|0)==255){break R}v[23588]=0;b=W(251,a|0,b+1|0,0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break M}if(!b){break R}g=x[e>>1];v[23588]=0;U(863,d+136|0,b|0,g|0);b=v[23588];v[23588]=0;if((b|0)==1){break M}v[23588]=0;U(852,d+496|0,c|0,2);b=v[23588];v[23588]=0;if((b|0)==1){break Q}v[23588]=0;U(855,d+120|0,d+496|0,1179011410);b=v[23588];v[23588]=0;if((b|0)==1){break L}Yd(d+496|0);p=d,q=Eb(v[d+120>>2]),v[p+112>>2]=q;n=Eb(v[d+124>>2]);S:{T:{while(1){b=v[d+112>>2];if(!Ob(b,n)){break S}b=je(d+88|0,b);v[23588]=0;g=S(157,b|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break K}U:{V:{if((g|0)!=538989377){break V}g=x[e>>1];if(!Xh(g)){break V}f=x[d+460>>1];u[d+460>>1]=f-1;if(!f){Ab(b);break S}i=g+1|0;u[e>>1]=i;v[23588]=0;g=Q(861,b|0,d+80|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break J}if(!(g&v[d+80>>2]==1347240275)){break T}v[23588]=0;U(190,d+496|0,b|0,v[d+84>>2]);g=v[23588];v[23588]=0;W:{if((g|0)!=1){f=d+496|0;g=jc(d+56|0,f);Ab(f);v[23588]=0;f=Q(864,g|0,f|0)|0;o=v[23588];v[23588]=0;if((o|0)==1){break U}if(f){break W}Ab(g);Ab(b);break S}a=P()|0;O()|0;break H}f=d+24|0;Me(f,2,l);v[23588]=0;R(222,d+40|0,f|0);f=v[23588];v[23588]=0;if((f|0)==1){break I}f=i&65535;i=d+40|0;Cc(((f<<5)+a|0)+946304|0,i);yb(i);v[23588]=0;f=(B(f,104)+a|0)+484380|0;U(865,d+496|0,d+136|0,f|0);i=v[23588];v[23588]=0;if((i|0)==1){break U}X:{if(!k){break X}v[23588]=0;Q(155,g|0,v[d+496>>2]+4|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break U}i=d+40|0;aM(i,x[d+536>>1]);v[23588]=0;W(219,i|0,f|0,g|0)|0;f=v[23588];v[23588]=0;if((f|0)!=1){break X}break I}Ab(g)}Ab(b);Mf(d+112|0);continue}break}break I}Ab(b)}Uc(d+120|0)}Ab(c);Mf(d+472|0);continue}break}a=P()|0;O()|0;break G}a=P()|0;O()|0;break G}a=P()|0;O()|0;break G}a=P()|0;O()|0;break G}a=P()|0;O()|0;break G}a=P()|0;O()|0;Yd(d+496|0);break G}a=P()|0;O()|0;break H}a=P()|0;O()|0;break H}a=P()|0;O()|0;Ab(g)}Ab(b);Uc(d+120|0)}Ab(c);Uc(d+480|0);break b}a=P()|0;O()|0;break b}e=1}Ab(d+704|0);Yd(j);Ab(m)}jb=d+784|0;return e|0}a=P()|0;O()|0;Ab(c);Uc(d+88|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0}Ab(d+704|0)}Yd(j);Ab(m);T(a|0);L()}function nt(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=jb-32|0;jb=h;v[h+28>>2]=c;a:{if((c|0)<=0){break a}k=v[b+656>>2];if(!(!k|v[a+480180>>2]!=16777216)){m=v[k+44>>2]!=0}i=v[b+104>>2];b:{c:{d:{if(!k){j=c;break d}if((c|0)>128){break c}j=c-1|0;l=x[cc(k+236|0,j)>>1];e:{if((l-1&65535)>>>0<=3998){i=(B(l,104)+a|0)+484380|0;break e}Cb(h+16|0,a+1074312|0,43);if(!Bb(v[v[h+16>>2]>>2],v[h+20>>2])){break e}if(!pj(v[b+656>>2])){break a}}j=w[Kb(k+108|0,j)|0];v[h+28>>2]=j}if(j>>>0<121){break b}c=j}f:{if(!(v[a+480180>>2]&16777248?(c|0)!=255:0)){Un(a,b);if(d){break f}Cb(h+16|0,a+1074312|0,100);if(!Bb(v[v[h+16>>2]>>2],v[h+20>>2])|!(w[a+480208|0]&4)|!w[b+789|0]){break f}v[b+88>>2]=v[b+88>>2]&-6145;break f}if(!x[a+480192>>1]){break f}v[b+88>>2]=v[b+88>>2]|4096}g:{if((c|0)!=254){break g}d=v[b+88>>2];c=a+480180|0;if(!(!(d&512)|v[c>>2]!=2)){v[b+88>>2]=d|2048;break g}v[b+88>>2]=d|2101248;h:{if(v[c>>2]&16777248){if(!x[a+480192>>1]){break h}Cb(h+16|0,a+1074312|0,50);if(Bb(v[v[h+16>>2]>>2],v[h+20>>2])){break h}}v[b+688>>2]=0}Cb(h+16|0,a+1074312|0,50);if(Bb(v[v[h+16>>2]>>2],v[h+20>>2])){v[b+8>>2]=0;v[b+12>>2]=0}v[b+696>>2]=0}Cb(h+16|0,a+1074312|0,20);if(!Bb(v[v[h+16>>2]>>2],v[h+20>>2])){break a}t[b+797|0]=0;t[b+802|0]=0;break a}i:{j:{k:{if(m){if(d){l=w[b+797|0];if(l){break k}}v[b+708>>2]=0}if(d){break j}if(!(!(v[a+480180>>2]&1048588)|!i)){u[b+770>>1]=t[i+36|0];u[b+772>>1]=t[i+37|0]}if(i){Cb(h+16|0,a+1074312|0,24);l=0;o=1;if(!Bb(v[v[h+16>>2]>>2],v[h+20>>2])){break i}v[b+704>>2]=v[i+24>>2];break i}l=0;break i}l=B((v[v[k+44>>2]+36>>2]<<16>>16)+1|0,(j<<16>>16)-(l<<16>>16)|0)-v[b+852>>2]|0;v[b+708>>2]=l;v[b+852>>2]=0-l}o=(i|0)!=0;l=1;if(xi(v[b+8>>2],v[b+12>>2])){break i}l=a+1074312|0;Cb(h+16|0,l,54);l:{if(!Bb(v[v[h+16>>2]>>2],v[h+20>>2])){break l}if(pj(v[b+656>>2])){Cb(h+8|0,l,117);if(!Bb(v[v[h+8>>2]>>2],v[h+12>>2])){break l}}v[b+700>>2]=0;break a}Cb(h+16|0,l,39);l=(Bb(v[v[h+16>>2]>>2],v[h+20>>2])^-1)&d}m:{if(Jm(v[a+480180>>2])){v[h+28>>2]=u[b+770>>1]+j;oe(h+28|0,12,131);break m}LR(h+28|0)}j=a+1074312|0;Cb(h+16|0,j,34);n:{if(Bb(v[v[h+16>>2]>>2],v[h+20>>2])){d=Bl(c);break n}d=v[h+28>>2]}t[b+797|0]=d;t[b+851|0]=w[b+851|0]&183|64;if(!(v[a+480180>>2]&16777250?0:l)){t[b+803|0]=0}d=eh(a,v[h+28>>2],u[b+772>>1],v[b+704>>2]);t[b+831|0]=0;Cb(h+16|0,j,48);if(Bb(v[v[h+16>>2]>>2],v[h+20>>2])){GN(a,b,k,i)}Cb(h+16|0,j,115);if(!(!Bb(v[v[h+16>>2]>>2],v[h+20>>2])|!k|!w[k+26|0])){if(!x[b+784>>1]){u[b+784>>1]=x[b+692>>1]+1}FN(b+692|0,c,w[k+26|0],w[k+27|0])}o:{if(e^1|l){break o}v[b+776>>2]=0;v[b+780>>2]=0;if(!k){break o}Cb(h+16|0,j,29);if(Bb(v[v[h+16>>2]>>2],v[h+20>>2])){t[b+798|0]=w[k+16|0]}if(!(w[k+60|0]&8)){oj(b+724|0)}if(!(w[k+80|0]&8)){oj(b+732|0)}if(!(w[k+100|0]&8)){oj(b+740|0)}if(w[k+20|0]){c=lt(Tn(a));n=w[k+20|0];Cb(h+16|0,j,28);n=((B(c,n)<<16>>16)/64<<16)+65536>>16;p:{if(Bb(v[v[h+16>>2]>>2],v[h+20>>2])){c=v[b+752>>2];break p}c=(v[b+688>>2]+1|0)/2|0}u[b+776>>1]=(B(c,n)|0)/199}q:{if(!w[k+19|0]){break q}q=b,r=(B(lt(Tn(a)),w[k+19|0])<<16>>16)/32|0,u[q+778>>1]=r;Cb(h+16|0,j,28);if(Bb(v[v[h+16>>2]>>2],v[h+20>>2])|x[b+784>>1]){break q}u[b+784>>1]=x[b+692>>1]+1}c=w[k+23|0];if(c){n=lt(Tn(a));p=w[b+837|0];t[b+796|0]=p+1;u[b+780>>1]=(B(p,(B(c,n+1|0)<<16>>16)/128<<16>>16)+1|0)/128}c=w[k+24|0];if(!c){break o}n=lt(Tn(a));p=w[b+838|0];t[b+795|0]=p+1;u[b+782>>1]=(B(p,(B(c,n+1|0)<<16>>16)/128<<16>>16)+1|0)/128}if(!o){break a}c=0;r:{s:{if(!d){break s}if(!(v[b+700>>2]?l:0)){v[b+700>>2]=d}t:{u:{if(!m){if(!l){Cb(h+16|0,j,69);if(Bb(v[v[h+16>>2]>>2],v[h+20>>2])){break u}Cb(h+8|0,j,46);if(Bb(v[v[h+8>>2]>>2],v[h+12>>2])|v[a+480180>>2]==1){break u}}v[b+708>>2]=d;t[b+851|0]=w[b+851|0]&239}if(!l){break u}if(v[b+76>>2]|w[a+480180|0]&2){break t}}v[b+104>>2]=i;d=v[i>>2];v[b+84>>2]=d;v[b+76>>2]=d;v[b+80>>2]=0;v[b>>2]=0;v[b+4>>2]=0;v:{w:{if(!(v[a+480208>>2]&2097152)){Cb(h+16|0,j,96);if(!Bb(v[v[h+16>>2]>>2],v[h+20>>2])){break w}}if(w[b+789|0]){break w}v[h+16>>2]=v[b+76>>2]-1;q=b,r=v[Jb(b+660|0,h+16|0)>>2],v[q+4>>2]=r;break v}v[b+660>>2]=0}m=x[i+34>>1];d=m&1023;o=d|v[b+88>>2]&-525056;v[b+88>>2]=o;x:{y:{if(m&8){v[b+80>>2]=v[i+12>>2];m=v[i+16>>2];v[b+88>>2]=(d&16?o|4:o&-524295)|2;v[b+84>>2]=m;if(y[b+76>>2]>m>>>0){break y}break x}if(!(d&2)){break x}v[b+80>>2]=v[i+4>>2];m=v[i+8>>2];v[b+84>>2]=m;if(y[b+76>>2]<=m>>>0){break x}}v[b+76>>2]=m}Cb(h+16|0,j,83);if(!(!Bb(v[v[h+16>>2]>>2],v[h+20>>2])|v[b+80>>2])){d=v[i>>2];v[b+84>>2]=d;v[b+76>>2]=d}d=v[b+88>>2];z:{if(!(d&128)){break z}i=v[b+76>>2];if(!i){break z}v[b+4>>2]=i-1;v[b+88>>2]=d|128}A:{if(w[b+822|0]>3){break A}Cb(h+16|0,j,21);B:{C:{D:{if(!Bb(v[v[h+16>>2]>>2],v[h+20>>2])){i=v[a+480180>>2];if(!(i&16777248)){break D}m=16;if(v[a+480208>>2]&4){break C}break B}i=v[a+480180>>2]}m=32;if((i|0)==16){break B}}if(i&67633152){break A}m=0}t[b+819|0]=m}Cb(h+16|0,j,21);if(Bb(v[v[h+16>>2]>>2],v[h+20>>2])|w[b+825|0]>3){break t}t[b+820|0]=0}i=v[b>>2];if(y[b+76>>2]<=y[b+4>>2]){d=v[b+80>>2];v[b>>2]=i;v[b+4>>2]=d}if(!l){break s}c=1;if(!(v[a+480180>>2]&17301536)|(v[b+696>>2]?0:w[b+89|0]&16)){break s}d=1;if(!(w[a+480208|0]&8)){break r}d=1;if(!w[b+789|0]){break r}}if(!(v[b+696>>2]|(!(v[a+480180>>2]&17301536)|!(w[b+89|0]&16)))){tm(b);Cb(h+16|0,j,21);if(!Bb(v[v[h+16>>2]>>2],v[h+20>>2])){t[b+818|0]=0;v[b+756>>2]=0}v[b+696>>2]=65536;v[b+88>>2]=v[b+88>>2]&-4097}E:{if(!c){i=w[b+789|0];break E}i=w[b+789|0];if(!(w[a+480208|0]&8)){break E}d=1;if(!(i&255)){break r}}if(!(i&255?0:v[a+480180>>2]&1048580)){v[b+696>>2]=65536;v[b+88>>2]=v[b+88>>2]&-4097}d=c}Cb(h+16|0,j,40);F:{G:{if(Bb(v[v[h+16>>2]>>2],v[h+20>>2])){if(d){if(!(!(w[a+480208|0]&8)|!w[b+789|0])){v[b+88>>2]=v[b+88>>2]&-4196353;i=1;break F}v[b+88>>2]=v[b+88>>2]&-4194305;i=1;break F}c=v[b+88>>2]&-4196353;break G}c=v[b+88>>2]&-4196353;v[b+88>>2]=c;i=1;if(d){break F}}u[b+842>>1]=65535;v[b+88>>2]=c&-6326273|2097152;Cb(h+16|0,j,23);H:{if(Bb(v[v[h+16>>2]>>2],v[h+20>>2])){break H}Cb(h+8|0,j,22);if(Bb(v[v[h+8>>2]>>2],v[h+12>>2])){break H}Cb(h+16|0,j,52);if(Bb(v[v[h+16>>2]>>2],v[h+20>>2])){break H}Cb(h+8|0,j,71);if(Bb(v[v[h+8>>2]>>2],v[h+12>>2])){break H}t[b+839|0]=0;t[b+808|0]=0}if(e){t[b+818|0]=0;v[b+756>>2]=0}v[b+20>>2]=0;v[b+24>>2]=0;c=v[a+480208>>2]&8192;I:{J:{if(k){i=1;d=w[k+22|0];K:{if(!ff(d)){i=!(c>>>13|0);break K}q=b,r=_q(d),t[q+838|0]=r}c=w[k+21|0];if(ff(c)){q=b,r=_q(c),t[q+837|0]=r;break J}if(i){break J}c=(i|0)!=0;break I}v[b+776>>2]=0;v[b+780>>2]=0;c=!c;break I}c=1;d=w[k+25|0];if((d|0)==255){break I}t[b+845|0]=d}L:{if(w[b+837|0]>=127){Cb(h+16|0,j,36);if(!Bb(v[v[h+16>>2]>>2],v[h+20>>2])){break L}}if(!c){break L}if((Vp(a,b,1,256)|0)<0|!(w[b+89|0]&2)){break L}c=v[a+1298300>>2];if(!Ed(c)|(g|0)==65535){break L}_p(c,g,w[b+837|0]>>>1|0,1)}i=0;if(!(w[b+89|0]&2)){break F}if(!Ed(v[a+1298300>>2])|(g|0)==65535){break F}Cb(h+16|0,j,111);if(Bb(v[v[h+16>>2]>>2],v[h+20>>2])){hk(v[a+1298300>>2],g);break F}Cb(h+16|0,j,110);if(!Bb(v[v[h+16>>2]>>2],v[h+20>>2])){break F}rz(v[a+1298300>>2],g,0,1,0)}c=v[b+88>>2];if(f){c=c&-1025;v[b+88>>2]=c}M:{N:{if(w[a+24618|0]&16?c&1024:0){break N}a=v[b+104>>2];if(!(f?1:!a|!(w[a+35|0]&4))){break N}a=v[b+656>>2];if(!a|!(w[a+15|0]&2)){break M}}if(f){break M}v[b+700>>2]=0}if(i){break a}u[b+136>>1]=0;v[b+132>>2]=4194304;v[b+112>>2]=0;v[b+116>>2]=0}jb=h+32|0}function xX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,z=0,A=0;e=jb-1472|0;jb=e;yc(b);Wo(a);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(!tr(b,e+1448|0)){break n}if(!XD(e+1448|0)){break n}if(!c){j=1;break n}if(!sr(v[b>>2],x[e+1466>>1]|x[e+1468>>1]<<16)){break n}if(!sr(v[b>>2],(x[e+1466>>1]|x[e+1468>>1]<<16)+(x[e+1460>>1]<<2)|0)){break n}Mv(a);z=e,A=Lv(),v[z+72>>2]=A;c=e+72|0;Kv(Tj(v[a+4>>2])+32|0,c);rr(c);l=v[Tj(v[a+4>>2])+32>>2];v[e+1444>>2]=x[e+1462>>1]|x[e+1464>>1]<<16;z=e,A=Vg(v[b>>2]),v[z+1184>>2]=A;v[e+1144>>2]=214748364;d=e+1184|0;z=e,A=B(v[Jb(d,e+1144|0)>>2],20),v[z+72>>2]=A;qn(l,v[Jb(e+1444|0,c)>>2]);Tb(d,0,256);r=Sb(e+1168|0);o:{while(1){j=x[e+1460>>1]<=s>>>0;if(!j){v[23588]=0;c=Q(155,b|0,(x[e+1466>>1]|x[e+1468>>1]<<16)+(s<<2)|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break m}if(!c){break o}c=v[b+8>>2];d=v[b>>2];v[23588]=0;c=W(156,d|0,c|0,4)|0;d=v[23588];v[23588]=0;if((d|0)==1){break m}if(!c){break o}v[23588]=0;c=S(157,b|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break l}v[23588]=0;d=Q(155,b|0,c|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break l}if(!d){break o}v[23588]=0;d=Q(158,b|0,e+1144|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break k}if(!d){break o}v[23588]=0;d=W(159,b|0,r|0,x[e+1156>>1])|0;f=v[23588];v[23588]=0;if((f|0)==1){break k}if(!d){break o}f=v[r>>2];g=v[b>>2];v[23588]=0;d=x[e+1156>>1];g=S(160,g|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break j}h=c+20|0;if(g>>>0<=h+(d<<3)>>>0){break o}c=d?f:0;f=x[e+1156>>1];g=h+(f<<3)|0;d=0;h=x[e+1158>>1];p:{if(!(h&1)){while(1){if(d>>>0>=f>>>0){break p}if(!c){break o}f=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);h=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[23588]=0;f=fa(161,h|0,f|0,l|0,v[e+1444>>2])|0;h=v[23588];v[23588]=0;if((h|0)==1){break i}if(!f){break o}v[23588]=0;f=Q(155,b|0,g|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break i}if(!f){break o}f=gc(e+1136|0,Kb(v[l>>2],w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)),w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24));h=v[f+4>>2];f=v[f>>2];v[23588]=0;Nk(162,e+72|0,b,f,h);f=v[23588];v[23588]=0;if((f|0)==1){break h}if(v[e+76>>2]!=(w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24))){break o}d=d+1|0;c=c+8|0;f=x[e+1156>>1];continue}}q:{r:{s:{t:{u:{if(h&4){if(!c){break o}d=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);f=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[23588]=0;d=fa(161,f|0,d|0,l|0,v[e+1444>>2])|0;f=v[23588];v[23588]=0;if((f|0)==1){break g}if(!d){break o}m=Kb(v[l>>2],w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));k=(w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24))&-2;if(!k){break o}v[23588]=0;f=x[e+1162>>1];d=Q(155,b|0,g+x[e+1160>>1]|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break f}if(!d){break o}d=v[b+8>>2];g=v[b>>2];v[23588]=0;d=W(156,g|0,d|0,v[e+1148>>2]-x[e+1160>>1]|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break f}if(!d){break o}v[23588]=0;U(163,e+48|0,b|0,v[e+1148>>2]-x[e+1160>>1]|0);d=v[23588];v[23588]=0;if((d|0)==1){break b}d=e+48|0;g=qr(e+72|0,d);Ab(d);q=0;n=0;v:{w:{x:{while(1){h=0;y:{while(1){if(x[e+1156>>1]<=(n&65535)>>>0){break x}v[23588]=0;d=Q(164,g|0,f+1|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break y}i=f&15;o=x[(i<<1)+25968>>1];z:{A:{if(o>>>0<=d>>>0){v[23588]=0;i=w[i+26016|0];p=Q(164,g|0,i|0)|0;u=v[23588];v[23588]=0;if((u|0)==1){break y}d=p+(d-o<<i)|0;if((d|0)!=(f|0)){f=d&15;break z}v[23588]=0;d=Q(164,g|0,4)|0;i=v[23588];v[23588]=0;if((i|0)==1){break y}if((d|0)==15){v[23588]=0;i=Q(164,g|0,1)|0;d=v[23588];v[23588]=0;if((d|0)==1){break y}d=65535;if(!i){break A}Ab(g);break p}d=d+65520|0}if(d>>>0>65535){break z}}d=d&1?0-(d+1>>>1|0)|0:d>>>1|0;p=h+m|0;i=x[e+1158>>1];B:{if(i&2){q=d+q|0;d=q;break B}d=i&512?d:d^32768}o=d>>>8|0;i=i&1024;t[p+1|0]=i?d:o;t[p|0]=i?o:d;h=h+2|0}if(h>>>0<k>>>0){continue}break}n=n+1|0;if(n>>>0>=x[e+1156>>1]){break r}d=(n<<3)+c|0;h=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);k=w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24);v[23588]=0;h=fa(161,h|0,k|0,l|0,v[e+1444>>2])|0;k=v[23588];v[23588]=0;if((k|0)==1){break y}if(!h){break t}k=(w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24))&-2;if(!k){break u}m=Kb(v[l>>2],w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));continue}break}j=V(30480)|0;if((O()|0)!=(da(30480)|0)){break v}_(j|0)|0;v[23588]=0;Z(18);c=v[23588];v[23588]=0;if((c|0)==1){break w}}Ab(g);break p}j=P()|0;O()|0}Ab(g);break a}if(!c){break o}d=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);f=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[23588]=0;d=fa(161,f|0,d|0,l|0,v[e+1444>>2])|0;f=v[23588];v[23588]=0;if((f|0)==1){break e}if(!d){break o}q=Kb(v[l>>2],w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));if(x[e+1160>>1]>256){break o}m=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);f=x[e+1162>>1];v[23588]=0;d=Q(155,b|0,g|0)|0;g=v[23588];v[23588]=0;C:{D:{if((g|0)!=1){if(!d){break o}d=gc(e+40|0,e+1184|0,x[e+1160>>1]);g=v[d+4>>2];d=v[d>>2];v[23588]=0;Nk(165,e+72|0,b,d,g);d=v[23588];v[23588]=0;if((d|0)==1){break D}d=x[e+1160>>1];if(d>>>0>y[e+76>>2]){break o}g=v[b+8>>2];h=v[b>>2];v[23588]=0;d=W(156,h|0,g|0,v[e+1148>>2]-d|0)|0;g=v[23588];v[23588]=0;if((g|0)!=1){break C}}j=P()|0;O()|0;break a}j=P()|0;O()|0;break a}if(!d){break o}v[23588]=0;U(163,e+48|0,b|0,v[e+1148>>2]-x[e+1160>>1]|0);d=v[23588];v[23588]=0;if((d|0)==1){break c}d=e+48|0;g=qr(e+72|0,d);Ab(d);k=0;n=0;E:{F:{G:{while(1){h=0;H:{while(1){if(x[e+1156>>1]<=(k&65535)>>>0){break G}v[23588]=0;d=Q(164,g|0,f+1|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break H}i=f&7;o=w[i+26e3|0];I:{J:{if(o>>>0<=d>>>0){v[23588]=0;i=w[i+26008|0];p=Q(164,g|0,i|0)|0;u=v[23588];v[23588]=0;if((u|0)==1){break H}d=p+(d-o<<i)|0;if((d|0)!=(f|0)){f=d&7;break I}v[23588]=0;d=Q(164,g|0,3)|0;i=v[23588];v[23588]=0;if((i|0)==1){break H}if((d|0)==7){v[23588]=0;i=Q(164,g|0,1)|0;d=v[23588];v[23588]=0;if((d|0)==1){break H}d=255;if(!i){break J}Ab(g);break p}d=d+248|0}if(d>>>0>255){break I}}d=w[(e+1184|0)+d|0];i=d+n|0;p=d;d=x[e+1158>>1]&2;t[h+q|0]=d?i:p;n=d?i:n;h=h+1|0}if(h>>>0<m>>>0){continue}break}k=k+1|0;if(k>>>0>=x[e+1156>>1]){break q}d=(k<<3)+c|0;h=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);m=w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24);v[23588]=0;h=fa(161,h|0,m|0,l|0,v[e+1444>>2])|0;m=v[23588];v[23588]=0;if((m|0)==1){break H}if(!h){break s}m=w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24);q=Kb(v[l>>2],w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));continue}break}j=V(30480)|0;if((O()|0)!=(da(30480)|0)){break E}_(j|0)|0;v[23588]=0;Z(18);c=v[23588];v[23588]=0;if((c|0)==1){break F}}Ab(g);break p}j=P()|0;O()|0}Ab(g);break a}Ab(g);break o}Ab(g);break o}Ab(g);break o}Ab(g);break p}Ab(g)}s=s+1|0;continue}break}re(e+24|0,v[l>>2],v[l+4>>2]);_g(e+32|0,v[e+24>>2],v[e+28>>2]);b=ee(e+16|0);v[23588]=0;c=v[b+4>>2];v[e+8>>2]=v[b>>2];v[e+12>>2]=c;b=Eg(166,e+72|0,v[e+32>>2],v[e+36>>2],e+8|0);c=v[23588];v[23588]=0;if((c|0)==1){break d}gd(Tj(v[a+4>>2])+12|0,b);Ab(b)}qe(r)}jb=e+1472|0;return j|0}j=P()|0;O()|0;break a}j=P()|0;O()|0;break a}j=P()|0;O()|0;break a}j=P()|0;O()|0;break a}j=P()|0;O()|0;break a}j=P()|0;O()|0;break a}j=P()|0;O()|0;break a}j=P()|0;O()|0;break a}j=P()|0;O()|0;break a}j=P()|0;O()|0;break a}j=P()|0;O()|0;break a}j=P()|0;O()|0}qe(r);T(j|0);L()}function GP(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;l=jb-336|0;jb=l;m=i&65535;p=d;q=e&65535;s=(e^i)&-2147483648;k=h;z=i>>>16&32767;A=e>>>16&32767;a:{b:{if(z-32767>>>0>4294934529&A-32767>>>0>=4294934530){break b}j=e&2147483647;if(!(!d&(j|0)==2147418112?!(b|c):j>>>0<2147418112)){o=d;s=e|32768;break a}e=i&2147483647;if(!(!h&(e|0)==2147418112?!(f|g):e>>>0<2147418112)){o=h;s=i|32768;b=f;c=g;break a}if(!(b|d|(j^2147418112|c))){if(!(f|h|(e^2147418112|g))){b=0;c=0;s=2147450880;break a}s=s|2147418112;b=0;c=0;break a}if(!(f|h|(e^2147418112|g))){b=0;c=0;break a}if(!(b|d|(c|j))){b=!(f|h|(e|g));o=b?0:o;s=b?2147450880:s;b=0;c=0;break a}if(!(f|h|(e|g))){s=s|2147418112;b=0;c=0;break a}if((j|0)==65535|j>>>0<65535){i=b;d=!(p|q);h=d<<6;j=E(d?b:p)+32|0;b=E(d?c:q);b=h+((b|0)==32?j:b)|0;Kf(l+320|0,i,c,p,q,b-15|0);n=16-b|0;p=v[l+328>>2];q=v[l+332>>2];c=v[l+324>>2];b=v[l+320>>2]}if(e>>>0>65535){break b}d=!(k|m);e=d<<6;h=E(d?f:k)+32|0;d=E(d?g:m);d=e+((d|0)==32?h:d)|0;Kf(l+304|0,f,g,k,m,d-15|0);n=(d+n|0)-16|0;k=v[l+312>>2];m=v[l+316>>2];f=v[l+304>>2];g=v[l+308>>2]}e=m|65536;B=e;C=k;d=k;k=e<<15|d>>>17;d=d<<15|g>>>17;h=0-d|0;e=k;i=1963258675-(e+((d|0)!=0)|0)|0;uf(l+288|0,d,e,0,0,h,i,0,0);j=v[l+296>>2];uf(l+272|0,0-j|0,0-(v[l+300>>2]+((j|0)!=0)|0)|0,0,0,h,i,0,0);h=v[l+280>>2];i=h<<1|v[l+276>>2]>>>31;h=v[l+284>>2]<<1|h>>>31;uf(l+256|0,i,h,0,0,d,e,0,0);j=h;h=v[l+264>>2];uf(l+240|0,i,j,0,0,0-h|0,0-(v[l+268>>2]+((h|0)!=0)|0)|0,0,0);h=v[l+248>>2];i=h<<1|v[l+244>>2]>>>31;h=v[l+252>>2]<<1|h>>>31;uf(l+224|0,i,h,0,0,d,e,0,0);j=h;h=v[l+232>>2];uf(l+208|0,i,j,0,0,0-h|0,0-(v[l+236>>2]+((h|0)!=0)|0)|0,0,0);h=v[l+216>>2];i=h<<1|v[l+212>>2]>>>31;h=v[l+220>>2]<<1|h>>>31;uf(l+192|0,i,h,0,0,d,e,0,0);e=h;h=v[l+200>>2];uf(l+176|0,i,e,0,0,0-h|0,0-(v[l+204>>2]+((h|0)!=0)|0)|0,0,0);i=d;h=v[l+184>>2];d=h<<1|v[l+180>>2]>>>31;e=d-1|0;h=(v[l+188>>2]<<1|h>>>31)-!d|0;uf(l+160|0,i,k,0,0,e,h,0,0);d=f;j=g<<15|d>>>17;uf(l+144|0,d<<15,j,0,0,e,h,0,0);k=v[l+172>>2];m=v[l+160>>2];D=v[l+152>>2];d=m+D|0;i=v[l+164>>2];j=i+v[l+156>>2]|0;j=d>>>0<D>>>0?j+1|0:j;m=(i|0)==(j|0)&d>>>0<m>>>0|i>>>0>j>>>0;i=m+v[l+168>>2]|0;k=i>>>0<m>>>0?k+1|0:k;m=!j&d>>>0>1|(j|0)!=0;i=m+i|0;k=i>>>0<m>>>0?k+1|0:k;uf(l+112|0,e,h,0,0,0-i|0,0-(((i|0)!=0)+k|0)|0,0,0);uf(l+128|0,1-d|0,0-((d>>>0>1)+j|0)|0,0,0,e,h,0,0);J=(A-z|0)+n|0;e=v[l+116>>2];x=e;d=v[l+112>>2];j=e<<1|d>>>31;m=d<<1;n=j;d=j;h=v[l+140>>2];u=h;e=v[l+136>>2];j=h<<1|e>>>31;i=e<<1|v[l+132>>2]>>>31;h=i+m|0;j=d+j|0;j=h>>>0<i>>>0?j+1|0:j;i=h;e=j;j=j-(h>>>0<13927)|0;r=j;k=q|65536;M=k;D=p;j=p;k=k<<1|j>>>31;p=j<<1|c>>>31;d=0;j=d|k;q=j;w=Lka(r,d,j,0);d=mb;t=d;j=b;d=c<<1|j>>>31;z=j<<1;A=d;h=h-13927|0;j=(e|0)==(r|0)&h>>>0<i>>>0|e>>>0>r>>>0;e=(e|0)==(n|0)&i>>>0<m>>>0|e>>>0<n>>>0;d=v[l+120>>2];k=v[l+124>>2]<<1|d>>>31;i=d<<1;m=j;n=e;e=u>>>31|0;d=e+(x>>>31|i)|0;j=k;j=d>>>0<e>>>0?j+1|0:j;e=d;d=n+d|0;j=d>>>0<e>>>0?j+1|0:j;e=d;d=m+d|0;k=d>>>0<e>>>0?j+1|0:j;e=d;d=d-1|0;F=k-!e|0;G=0;i=Lka(A,o,F,G);e=i+w|0;k=mb+t|0;k=e>>>0<i>>>0?k+1|0:k;m=(k|0)==(t|0)&e>>>0<w>>>0|k>>>0<t>>>0;w=d;i=Lka(d,0,p,0);d=i+e|0;j=mb+k|0;j=d>>>0<i>>>0?j+1|0:j;n=d;i=j;e=(j|0)==(k|0)&d>>>0<e>>>0|j>>>0<k>>>0;d=m+e|0;k=0;k=d>>>0<e>>>0?1:k;e=Lka(q,o,F,G);d=e+d|0;j=mb+k|0;u=d;d=d>>>0<e>>>0?j+1|0:j;m=Lka(q,o,w,o);k=mb;x=Lka(F,G,p,o);e=x+m|0;j=mb+k|0;j=e>>>0<x>>>0?j+1|0:j;x=e;e=j;j=(k|0)==(j|0)&m>>>0>x>>>0|j>>>0<k>>>0;m=u+e|0;d=d+j|0;j=m;m=j>>>0<e>>>0?d+1|0:d;u=j;e=0;d=e+n|0;j=i+x|0;j=d>>>0<e>>>0?j+1|0:j;e=j;k=(j|0)==(i|0)&d>>>0<n>>>0|i>>>0>j>>>0;i=u+k|0;j=m;u=i;i=i>>>0<k>>>0?j+1|0:j;n=d;m=e;x=h;h=Lka(h,0,p,o);e=mb;t=Lka(r,o,A,o);d=t+h|0;j=mb+e|0;j=d>>>0<t>>>0?j+1|0:j;e=(e|0)==(j|0)&d>>>0<h>>>0|e>>>0>j>>>0;h=j;H=u;t=e;I=z&-2;k=Lka(w,o,I,0);e=k+d|0;j=mb+j|0;j=e>>>0<k>>>0?j+1|0:j;u=e;k=e;e=j;h=(j|0)==(h|0)&d>>>0>k>>>0|h>>>0>j>>>0;d=t+h|0;k=0;k=d>>>0<h>>>0?1:k;j=d;h=n+d|0;d=k+m|0;d=h>>>0<j>>>0?d+1|0:d;t=h;j=h;h=d;k=(d|0)==(m|0)&j>>>0<n>>>0|d>>>0<m>>>0;d=H+k|0;j=i;N=d;n=d>>>0<k>>>0?j+1|0:j;K=Lka(q,o,x,o);H=mb;i=Lka(F,G,I,o);d=i+K|0;j=mb+H|0;j=d>>>0<i>>>0?j+1|0:j;F=d;k=Lka(r,o,p,o);i=d+k|0;m=j;d=j+mb|0;d=i>>>0<k>>>0?d+1|0:d;L=i;j=Lka(A,o,w,o);i=i+j|0;k=mb+d|0;G=i;k=i>>>0<j>>>0?k+1|0:k;i=k;w=0;O=(d|0)==(k|0)&G>>>0<L>>>0|d>>>0>k>>>0;j=(d|0)==(m|0)&F>>>0>L>>>0|d>>>0<m>>>0;d=j+((m|0)==(H|0)&F>>>0<K>>>0|m>>>0<H>>>0)|0;k=0;d=O+d|0;m=i|0;k=m+t|0;j=(d|w)+h|0;w=k;d=k;j=d>>>0<m>>>0?j+1|0:j;m=j;h=(h|0)==(j|0)&d>>>0<t>>>0|h>>>0>j>>>0;d=h+N|0;j=n;H=d;h=d>>>0<h>>>0?j+1|0:j;t=Lka(r,o,I,o);r=mb;k=Lka(A,o,x,o);d=k+t|0;j=mb+r|0;j=d>>>0<k>>>0?j+1|0:j;n=0;k=(j|0)==(r|0)&d>>>0<t>>>0|j>>>0<r>>>0;r=j;d=j+u|0;j=(k|n)+e|0;n=d;j=d>>>0<r>>>0?j+1|0:j;u=(e|0)==(j|0)&d>>>0<u>>>0|e>>>0>j>>>0;i=0;e=i+d|0;d=j;k=G+d|0;k=e>>>0<i>>>0?k+1|0:k;e=(d|0)==(k|0)&e>>>0<n>>>0|d>>>0>k>>>0;d=u+e|0;j=0;j=d>>>0<e>>>0?1:j;e=d;d=d+w|0;j=j+m|0;j=d>>>0<e>>>0?j+1|0:j;e=j;j=(m|0)==(j|0)&d>>>0<w>>>0|j>>>0<m>>>0;i=j+H|0;k=h;h=i;k=h>>>0<j>>>0?k+1|0:k;i=k;c:{if((k|0)==131071|k>>>0<131071){uf(l+80|0,d,e,h,i,f,g,C,B);j=b<<17;b=0;c=v[l+88>>2];n=b-c|0;k=v[l+80>>2];m=v[l+84>>2];D=(k|m)!=0;r=n-D|0;n=(j-(v[l+92>>2]+(b>>>0<c>>>0)|0)|0)-(n>>>0<D>>>0)|0;b=k;k=0-k|0;m=0-(((b|0)!=0)+m|0)|0;b=J+16382|0;break c}k=h<<31;d=(e&1)<<31|d>>>1;e=e>>>1|k;h=(i&1)<<31|h>>>1;i=i>>>1|0;uf(l+96|0,d,e,h,i,f,g,C,B);q=0;m=v[l+104>>2];n=q-m|0;k=v[l+96>>2];p=v[l+100>>2];z=(k|p)!=0;r=n-z|0;n=((b<<16)-(v[l+108>>2]+(m>>>0>q>>>0)|0)|0)-(n>>>0<z>>>0)|0;j=k;k=0-j|0;m=0-(((j|0)!=0)+p|0)|0;z=b;A=c;p=D;q=M;b=J+16383|0}if((b|0)>=32767){s=s|2147418112;b=0;c=0;break a}d:{if((b|0)>0){c=r;j=n<<1|c>>>31;r=c<<1|m>>>31;n=j;p=h;q=i&65535|b<<16;j=m<<1|k>>>31;b=k<<1;break d}if((b|0)<=-113){b=0;c=0;break a}Em(l- -64|0,d,e,h,i,1-b|0);Kf(l+48|0,z,A,p,q,b+112|0);d=v[l+64>>2];e=v[l+68>>2];p=v[l+72>>2];q=v[l+76>>2];uf(l+32|0,f,g,C,B,d,e,p,q);c=v[l+40>>2];i=c<<1;c=v[l+44>>2]<<1|c>>>31;b=v[l+56>>2];h=v[l+36>>2];n=h>>>31|i;i=b-n|0;n=v[l+60>>2]-((b>>>0<n>>>0)+c|0)|0;c=v[l+32>>2];k=h<<1|c>>>31;c=c<<1;j=v[l+52>>2];b=v[l+48>>2];h=(k|0)==(j|0)&c>>>0>b>>>0|j>>>0<k>>>0;r=i-h|0;n=n-(h>>>0>i>>>0)|0;h=b;b=h-c|0;j=j-((c>>>0>h>>>0)+k|0)|0}uf(l+16|0,f,g,C,B,3,0,0,0);uf(l,f,g,C,B,5,0,0,0);h=d;m=p;p=d&1;c=b+p|0;d=0;k=j+d|0;k=b>>>0>c>>>0?k+1|0:k;i=c;c=k;g=(k|0)==(g|0)&i>>>0>f>>>0|g>>>0<k>>>0;d=(d|0)==(k|0)&i>>>0<p>>>0|d>>>0>k>>>0;b=d+r|0;j=n;j=b>>>0<d>>>0?j+1|0:j;f=b;d=b;b=j;g=(d|0)==(C|0)&(j|0)==(B|0)?g:(B|0)==(j|0)&d>>>0>C>>>0|j>>>0>B>>>0;d=h+g|0;k=e;k=d>>>0<g>>>0?k+1|0:k;g=(e|0)==(k|0)&d>>>0<h>>>0|e>>>0>k>>>0;e=m+g|0;j=q;j=e>>>0<g>>>0?j+1|0:j;g=e;e=d;m=g;d=v[l+20>>2];h=(d|0)==(c|0)&y[l+16>>2]<i>>>0|c>>>0>d>>>0;d=v[l+28>>2];g=v[l+24>>2];h=j>>>0<2147418112&((f|0)==(g|0)&(b|0)==(d|0)?h:(d|0)==(b|0)&g>>>0<f>>>0|b>>>0>d>>>0);g=e+h|0;d=k;d=g>>>0<h>>>0?d+1|0:d;h=(d|0)==(k|0)&e>>>0>g>>>0|d>>>0<k>>>0;e=m+h|0;k=e>>>0<h>>>0?j+1|0:j;h=e;e=v[l+4>>2];i=(e|0)==(c|0)&y[l>>2]<i>>>0|c>>>0>e>>>0;c=v[l+12>>2];e=v[l+8>>2];c=k>>>0<2147418112&((e|0)==(f|0)&(b|0)==(c|0)?i:(c|0)==(b|0)&e>>>0<f>>>0|b>>>0>c>>>0);b=c+g|0;j=b>>>0<c>>>0?d+1|0:d;c=j;f=(d|0)==(j|0)&b>>>0<g>>>0|d>>>0>j>>>0;e=h+f|0;d=k;o=e|o;s=s|(e>>>0<f>>>0?d+1|0:d)}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=o;v[a+12>>2]=s;jb=l+336|0}function fka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;e=jb+-64|0;jb=e;yc(a);a:{b:{if(b>>>0<=2){G=e,H=Le(a),t[G+56|0]=H;Zb(a,2);G=e,H=Rg(a),u[G+58>>1]=H;G=e,H=Bg(a),v[G+60>>2]=H;break b}wo(a,e+56|0);if(b>>>0>5){break a}}t[e+57|0]=0}c:{q=d+484344|0;E=Cd(x[e+58>>1],1,1024);o=AB(q,E);if((o|0)==65535){break c}b=Yb(v[d+484344>>2],o);A=Cf(v[b>>2],v[v[b+48>>2]+12>>2],0);f=x[d+480188>>1];u[e>>1]=f-1;u[e+40>>1]=w[e+56|0];F=x[Vc(e,e+40|0)>>1];p=F+1|0;b=p&65535;f=b>>>0<f>>>0?f:b;while(1)if((b|0)==(f|0)){t[c+13|0]=w[e+57|0]>>>4;b=w[c+12|0];t[e|0]=0;b=(b|0)!=0;y=Om(e+40|0,p,e);A=d+480188|0;d:while(1){if((m|0)==(E|0)){hc(y);break c}e:{f=Kb(v[y>>2],0);d=w[f|0];f:{g:{if(!d){v[23588]=0;f=S(206,a|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break e}p=f<<24>>24;if((p|0)<0){v[23588]=0;f=S(206,a|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break e}G=Kb(v[y>>2],0),H=f,t[G|0]=H}t[e|0]=0;h:{i:{f=p&63;if(!f){break i}v[23588]=0;j=S(206,a|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break h}t[e|0]=j;j:{k:{switch(f-1|0){case 0:t[c+12|0]=0;t[e+36|0]=1;G=c,H=w[jf(e+36|0,e)|0],t[G+14|0]=H;t[c+15|0]=0;break j;case 1:if(!j){break i}t[c+15|0]=j;t[c+12|0]=1;b=w[c+13|0];if(!b){break j}t[c+14|0]=B(B(b,j),15);break j;case 2:t[c+13|0]=j>>>4;if(j>>>0>=16){b=w[c+12|0];j=0;v[e+36>>2]=0;v[e+32>>2]=0;r=0;if(!b){break f}break g}j=0;t[c+12|0]=0;v[e+36>>2]=0;v[e+32>>2]=0;r=0;if(!(b&1)){break f}break g;case 3:r=0;v[e+36>>2]=0;v[e+32>>2]=0;if(b&1){break g}break f;case 5:if(!j){break i}b=(w[c+12|0]?15:14)+c|0;d=w[b|0];t[b|0]=d>>>0<256-j>>>0?d+j|0:-1;break j;case 6:break k;default:break i}}if(!j){break i}b=(w[c+12|0]?15:14)+c|0;d=w[b|0];t[b|0]=d>>>0>j+1>>>0?d-j|0:1}j=0;v[e+36>>2]=0;v[e+32>>2]=0;break g}j=0;v[e+36>>2]=0;v[e+32>>2]=0;r=0;if(!(b&1)){break f}break g}break e}t[f|0]=d-1;j=0;v[e+36>>2]=0;v[e+32>>2]=0;r=0;if(!(b&1)){break f}}d=w[c+13|0];b=w[c+12|0];if(b){r=0;if(!d){break f}}l:{if(b){v[e>>2]=1;v[e+24>>2]=B(d,w[c+15|0])<<1;d=v[Oe(e,e+24|0)>>2];break l}d=B(w[c+14|0],30)+30|0}b=255;k=0;while(1){m:{if(!b){b=0;break m}f=B(b,d);k=(f|0)/48|0;if(f-1536>>>0<10752){break m}b=b-1|0;continue}break}v[e+36>>2]=b;v[e+32>>2]=k;oe(e+32|0,32,255);r=1;v[e>>2]=1;G=c,H=v[Oe(e,e+36|0)>>2],t[G+16|0]=H}C=m-1|0;D=1;b=Yb(v[q>>2],o);b=id(v[b>>2],v[v[b+48>>2]+12>>2],m,1);while(1){h=D&65535;if(h>>>0>F>>>0){if(r){ze(Yb(v[q>>2],o),Eh(vo(Te(Ne(e,17,w[e+32|0]),m),0)));ze(Yb(v[q>>2],o),Eh(Te(Ne(e,16,w[e+36|0]),m)))}if(j&240){ze(Yb(v[q>>2],o),aV(Te(Ne(e,20,j>>>4|224),m)))}b=j&15;if(b){ze(Yb(v[q>>2],o),aV(Te(Ne(e,20,Cd((B(b,w[c+16|0])>>>0)/15&255,1,15)|96),m)))}m=m+1|0;b=0;continue d}n:{o:{p:{q:{r:{f=Kb(v[y>>2],h);d=w[f|0];if(!d){v[23588]=0;l=S(206,a|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break e}if(l&128){v[23588]=0;f=S(206,a|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break e}G=Kb(v[y>>2],h),H=f,t[G|0]=H}p=1;if(l&64){v[23588]=0;f=S(206,a|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break e}t[b+1|0]=f;p=!f}if(!(l&32)){g=w[b|0];break r}v[23588]=0;g=S(206,a|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break e}t[b|0]=g;if((g-1&255)>>>0<=107){d=Bl(g+24|0);t[b|0]=d;G=Hd(v[c>>2],h),H=d,t[G+1|0]=H;g=w[b|0];break o}if((g+127&255)>>>0<=107){d=Bl((g&127)+24|0);G=Hd(v[c>>2],h),H=d,t[G|0]=H;t[b|0]=0;break q}if((g|0)!=255){break r}g=254;break p}t[f|0]=d-1;break n}if(g&255){break o}}if(!w[b+1|0]){g=0;break o}g=w[Hd(v[c>>2],h)+1|0];t[b+1|0]=0}t[b|0]=g}if(_c(g)){G=Hd(v[c>>2],h),H=0,t[G+5|0]=H}t[e+23|0]=0;t[e+22|0]=0;if(l&16){t[b+2|0]=1;v[23588]=0;f=S(206,a|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break e}t[b+4|0]=f+2>>>2}g=0;z=0;s=0;s:{if(!(l&8)){break s}v[23588]=0;f=S(206,a|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break e}v[23588]=0;s=S(206,a|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break e}t:{switch(f-1|0){case 0:t[b|0]=254;break s;case 1:t[b|0]=255;break s;case 2:d=Hd(v[c>>2],h);t[b|0]=w[d+1|0];t[d+5|0]=0;break s;case 3:d=Eu(s,w[c+16|0]);s=d?d|-48:0;z=d?20:0;if(w[b|0]){break s}d=Hd(v[c>>2],h);t[b|0]=w[d+1|0];t[d+5|0]=0;break s;case 4:t[e|0]=1;G=e,H=Eu(s,w[c+16|0]),t[G+24|0]=H;s=w[jf(e,e+24|0)|0];G=Hd(v[c>>2],h),H=0,t[G+5|0]=H;z=15;break s;case 5:case 6:case 7:case 8:u:{if(!m){break u}if((f|0)==w[Hd(v[c>>2],h)+4|0]){break u}if(!ze(Yb(v[q>>2],o),Lm(vo(Te(Ne(e,20,(f+122|160)&255),C),h)))){break u}G=Hd(v[c>>2],h),H=f,t[G+4|0]=H}d=Hd(v[c>>2],h);if(!w[b|0]){t[b|0]=w[d+1|0]}t[d+5|0]=0;z=10;break s;case 9:break t;default:break s}}d=Hd(v[c>>2],h);f=w[d+5|0];t[d+5|0]=f^1;s=f?-98:-97;z=20}v:{w:{x:{if(!(l&4)){break x}v[23588]=0;n=S(206,a|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break e}v[23588]=0;i=S(206,a|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break e}t[e+23|0]=i;f=1;g=1;y:{switch(n-1|0){case 0:yB(e,i<<24>>24<<3,128);d=w[b|0];if(_c(d)){G=b,H=Bl(d+v[e>>2]|0),t[G|0]=H}t[e+23|0]=w[e+4|0]^128;g=35;break x;case 1:d=Eu(i,w[c+16|0]);t[e+23|0]=d;if(!d){break w}t[e+23|0]=d|208;g=20;break v;case 3:case 4:G=e,H=$U(i,w[c+16|0],1),t[G+23|0]=H;g=(n|0)==4?2:3;break v;case 5:if(!w[b|0]){G=b,H=w[Hd(v[c>>2],h)|0],t[G|0]=H}G=e,H=$U(i,w[c+16|0],0),t[G+23|0]=H;g=4;break v;case 6:G=b,H=Bl(i+25|0),t[G|0]=H;t[e+23|0]=255;g=4;break v;case 7:case 8:case 9:z:{if(!m){break z}if((n|0)==w[Hd(v[c>>2],h)+2|0]){break z}if(!ze(Yb(v[q>>2],o),Lm(vo(Te(Ne(e,20,(n-8|48)&255),C),h)))){break z}G=Hd(v[c>>2],h),H=n,t[G+2|0]=H}G=e,H=xB(i,w[c+16|0]),t[G+23|0]=H;g=5;break v;case 10:G=e,H=_U(i,w[c+16|0]),t[G+23|0]=H;g=18;break v;case 11:d=Eu(i,w[c+16|0]);t[e+23|0]=d;if(d){t[e+23|0]=d|192;g=20;break v}t[b|0]=254;break w;case 2:break v;default:break y}}g=0}f=0;break v}g=0}i=0;d=1;A:{if(l&2){v[23588]=0;l=S(206,a|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break e}v[23588]=0;n=S(206,a|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break e}t[e+22|0]=n;i=9;d=0;k=0;B:{switch(l-1|0){case 0:case 1:k=1;G=e,H=ZU(n,w[c+16|0],(l|0)==1),t[G+22|0]=H;i=11;break A;case 2:G=e,H=_U(n,w[c+16|0]),t[G+22|0]=H;k=1;i=18;break A;case 3:case 4:case 5:C:{if(!m){break C}if((l|0)==w[Hd(v[c>>2],h)+3|0]){break C}if(!ze(Yb(v[q>>2],o),Lm(vo(Te(Ne(e,20,(l-4|64)&255),C),h)))){break C}G=Hd(v[c>>2],h),H=l,t[G+3|0]=H}G=e,H=xB(n,w[c+16|0]),t[G+22|0]=H;k=1;i=8;break A;case 7:case 8:G=e,H=ZU(n,w[c+16|0],(l|0)==8),t[G+22|0]=H;k=1;i=29;break A;case 9:G=e,H=xB(n,w[c+16|0]),t[G+22|0]=H;k=1;i=27;break A;case 6:break A;default:break B}}i=0;d=1}k=0}if(f){YU(b,m,x[A>>1],g,e+23|0)}if(k){YU(b,m,x[A>>1],i,e+22|0)}D:{E:{F:{G:{H:{if(!p){break H}if(!_c(w[b|0])){break H}if(!g){break G}if(!d|(g|0)==4){break H}t[e+22|0]=255;i=4}d=b+2|0;if(w[b+2|0]!=1){break D}if(g){break F}t[e+23|0]=w[b+4|0];g=13;break E}t[e+23|0]=255;d=b+2|0;g=4;if(w[b+2|0]!=1){break D}}if(i){break D}t[e+22|0]=w[b+4|0];i=13}t[d|0]=0}p=tg(e);Ao(e+24|0,p,g,w[e+23|0],i,w[e+22|0]);I:{if(w[d|0]){break I}f=w[e+2|0];if(!f){break I}t[b+2|0]=f;t[b+4|0]=w[e+4|0]}k=w[e+3|0];J:{if(z){Ao(e+24|0,p,k&255,w[e+5|0],z,s&255);K:{if(w[d|0]){break K}d=w[e+2|0];if(!d){break K}t[b+2|0]=d;t[b+4|0]=w[e+4|0]}k=w[e+3|0];break J}if(!(k&255)){break n}}t[b+3|0]=k;t[b+5|0]=w[e+5|0]}b=b+6|0;D=D+1|0;continue}}break}a=P()|0;O()|0;hc(y);T(a|0);L()}else{t[A+B(b,6)|0]=254;b=b+1|0;continue}}jb=e- -64|0;return o|0}function jka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=jb-288|0;jb=e;yc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if(!dV(b,e+216|0)){break p}if(!eV(e+216|0)){break p}if(!c){d=1;break p}Ad(a,131072);d=jb-16|0;jb=d;i=e+128|0;f=xc(d,3913);$c(i,f);zb(f);jb=d+16|0;v[23588]=0;U(305,e+176|0,i|0,e+216|4);d=v[23588];v[23588]=0;q:{if((d|0)!=1){d=e+176|0;Ib(a+1298344|0,d);zb(d);i=e+128|0;ac(i);f=xc(d,11066);Ib(a+1298356|0,f);zb(f);v[a+1298404>>2]=5;LB(i,3,e+229|0);Ec(d,i);Ac(a+1298308|0,d);yb(d);f=e+104|0;Cj(f,3,e+259|0);Ec(i,f);v[23588]=0;U(11,d|0,5,i|0);d=v[23588];v[23588]=0;if((d|0)==1){break b}d=e+176|0;Ib(a+1298320|0,d);zb(d);yb(e+128|0);d=xo(d);o=d,p=Cd(w[e+279|0],1,31),v[o+8>>2]=p;o=d,p=Cd(w[e+280|0],1,12),v[o+4>>2]=p;v[d>>2]=w[e+281|0]+1900;i=a+1298408|0;Kc(i);DB(i,d);g=e+136|0;i=Sb(e+160|0);r:{s:{t:{while(1){d=v[b+8>>2];f=v[b>>2];v[23588]=0;d=W(156,f|0,d|0,8)|0;f=v[23588];v[23588]=0;u:{v:{w:{x:{y:{if((f|0)!=1){if(!d){break r}v[23588]=0;R(306,b|0,e- -64|0);d=v[23588];v[23588]=0;if((d|0)==1){break y}d=v[e+68>>2];z:{l=w[e+220|0];switch(l-3|0){case 1:break x;case 0:break z;default:break w}}f=2;if(v[e+64>>2]!=1431389523){break v}break u}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}f=4;if(v[e+64>>2]!=1431389523){break v}break u}f=0;if(l>>>0>7){break u}}d=v[e+64>>2]==1146113363?-1:d;f=0}l=v[e+68>>2];v[e+128>>2]=v[e+64>>2];v[e+132>>2]=l;v[23588]=0;U(190,e+104|0,b|0,d|0);d=v[23588];v[23588]=0;if((d|0)==1){break t}jc(g,e+104|0);v[23588]=0;R(307,i|0,e+128|0);d=v[23588];v[23588]=0;if((d|0)==1){break s}zd(e+128|0);Ab(e+104|0);v[23588]=0;Q(188,b|0,f|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){continue}break}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;zd(e+128|0);Ab(e+104|0);break c}v[23588]=0;l=S(174,e+128|0)|0;b=v[23588];v[23588]=0;A:{B:{C:{if((b|0)!=1){v[23588]=0;U(308,e+104|0,i|0,1431389523);b=v[23588];v[23588]=0;if((b|0)==1){break C}d=e+104|0;b=gd(l,d);Ab(d);u[e+102>>1]=0;u[e+100>>1]=65534;if(w[e+220|0]<3){break A}v[23588]=0;d=S(194,b|0)|0;f=v[23588];v[23588]=0;if((f|0)!=1){break B}break e}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}u[e+102>>1]=d;if(w[e+220|0]<4){break A}v[23588]=0;d=S(194,b|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break e}u[e+100>>1]=w[e+220|0]==4?d?d:-2:d}d=w[a+484376|0];f=v[a+484360>>2];v[23588]=0;g=S(202,b|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break e}v[23588]=0;U(238,Vb(f,d)|0,b|0,g>>>1|0);d=v[23588];v[23588]=0;if((d|0)==1){break e}d=Vb(v[a+484360>>2],w[a+484376|0]);d=CB(v[d>>2],v[d+4>>2]);Ef(e+102|0,d);Ef(e+100|0,d);v[23588]=0;U(308,e+104|0,i|0,1414807888);d=v[23588];v[23588]=0;if((d|0)==1){break h}d=e+104|0;b=gd(b,d);Ab(d);d=v[b>>2];v[23588]=0;d=S(178,d|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break e}if(!(c&1)|d^1){break q}v[23588]=0;R(309,b|0,e|0);d=v[23588];v[23588]=0;if((d|0)==1){break i}o=a+480188|0,p=Cd(w[e+2|0],1,32)+1|0,u[o>>1]=p;v[23588]=0;d=Q(218,e+88|0,x[e>>1])|0;f=v[23588];v[23588]=0;if((f|0)==1){break j}o=e,p=Eb(v[d>>2]),v[o+40>>2]=p;g=Eb(v[d+4>>2]);D:{E:{while(1){h=v[e+40>>2];if(!Ob(h,g)){f=x[a+480188>>1];v[23588]=0;f=Q(310,e+104|0,f|0)|0;g=v[23588];v[23588]=0;if((g|0)!=1){g=a+484376|0;h=Vb(v[a+484360>>2],w[g|0]);h=Dl(v[h>>2],v[h+4>>2]);v[23588]=0;k=a+484344|0;R(225,k|0,h|0);h=v[23588];v[23588]=0;if((h|0)==1){break g}g=Vb(v[a+484360>>2],w[g|0]);o=e,p=Eb(v[g>>2]),v[o+64>>2]=p;h=Eb(v[g+4>>2]);F:{while(1){G:{g=v[e+64>>2];if(!Ob(g,h)){g=w[a+484376|0];h=v[a+484360>>2];v[23588]=0;j=Vb(h,g);h=x[e+100>>1];g=Q(311,j|0,h|0)|0;j=v[23588];v[23588]=0;if((j|0)!=1){break G}break g}j=v[d>>2];n=Bf(j,v[d+4>>2]);m=x[g>>1];if(n>>>0>m>>>0){v[23588]=0;j=fa(312,Og(j,m)|0,w[e+220|0],f|0,a|0)|0;m=v[23588];v[23588]=0;if((m|0)==1){break F}u[g>>1]=j}Re(e- -64|0);continue}break}H:{if(!g){break H}g=Vb(v[a+484360>>2],w[a+484376|0]);j=x[e+102>>1];if(!j){if(CB(v[g>>2],v[g+4>>2])>>>0<=h>>>0){break H}}g=Yb(v[k>>2],x[cc(v[g>>2],h)>>1]);ze(g,Lm(Te(Ne(e- -64|0,12,j&255),v[g+12>>2]-1|0)))}uk(f);Uc(d);break q}break g}b=P()|0;O()|0;break f}v[23588]=0;f=w[e+220|0]<3?9:8;Q(188,b|0,f-4|0)|0;k=v[23588];v[23588]=0;if((k|0)!=1){v[23588]=0;k=S(157,b|0)|0;j=v[23588];v[23588]=0;if((j|0)==1){break E}yg(b,f);v[23588]=0;U(190,e- -64|0,b|0,f+k|0);f=v[23588];v[23588]=0;if((f|0)==1){break D}j=h;f=e- -64|0;h=jc(e+104|0,f);gd(j,h);Ab(h);Ab(f);Mf(e+40|0);continue}break}b=P()|0;O()|0;break f}b=P()|0;O()|0;break f}b=P()|0;O()|0;break f}b=P()|0;O()|0;ac(e+128|0);break a}v[23588]=0;U(308,e- -64|0,i|0,1196641603);d=v[23588];v[23588]=0;if((d|0)==1){break n}d=e- -64|0;b=gd(b,d);Ab(d);d=v[b>>2];v[23588]=0;d=S(178,d|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break e}if(d){v[23588]=0;Q(188,b|0,1)|0;d=v[23588];v[23588]=0;if((d|0)==1){break e}v[23588]=0;d=S(202,b|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break e}v[23588]=0;ea(313,a+1298332|0,b|0,d|0,40,0);d=v[23588];v[23588]=0;if((d|0)==1){break e}}v[23588]=0;U(308,e- -64|0,i|0,1146113363);d=v[23588];v[23588]=0;if((d|0)==1){break k}v[23588]=0;U(308,e+40|0,i|0,1229999443);d=v[23588];v[23588]=0;if((d|0)==1){break o}d=e+40|0;b=gd(b,d);Ab(d);v[23588]=0;d=S(206,b|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break m}h=a+480190|0;u[h>>1]=d;k=!(c&2);f=1;I:{while(1){J:{c=f&65535;if(c>>>0>(d&65535)>>>0){break I}d=30;K:{L:{M:{if(w[e+220|0]>=2){v[23588]=0;d=S(206,b|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break M}}v[23588]=0;U(314,b|0,((c<<5)+a|0)+946304|0,d|0);d=v[23588];v[23588]=0;if((d|0)==1){break M}v[23588]=0;R(315,b|0,e+24|0);d=v[23588];v[23588]=0;if((d|0)==1){break L}v[23588]=0;g=B(c,104)+a|0;j=g+484380|0;R(316,e+24|0,j|0);c=v[23588];v[23588]=0;if((c|0)==1){break L}d=w[e+220|0];if(d>>>0>=8){v[23588]=0;R(317,b|0,g+484423|0);c=v[23588];v[23588]=0;if((c|0)==1){break L}d=w[e+220|0]}v[23588]=0;Q(188,b|0,((d&255)>>>0>1?6:2)|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break L}v[23588]=0;c=S(157,e- -64|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){v[23588]=0;U(190,e|0,e- -64|0,c|0);c=v[23588];v[23588]=0;if((c|0)!=1){break K}}b=P()|0;O()|0;break l}b=P()|0;O()|0;break l}b=P()|0;O()|0;break l}c=jc(e+40|0,e);Ab(e);d=v[c>>2];v[23588]=0;d=S(178,d|0)|0;m=v[23588];v[23588]=0;if((m|0)!=1){N:{if(k|d^1){break N}d=Zc(e,u[g+484414>>1]&1?16:8,1,0,(w[e+39|0]&12)==4?7:0);v[23588]=0;W(219,d|0,j|0,c|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){break N}break J}Ab(c);f=f+1|0;d=x[h>>1];continue}}break}b=P()|0;O()|0;Ab(c);break l}$f(a);v[a+480204>>2]=12e5;v[a+480208>>2]=24;v[a+480196>>2]=6;v[a+480200>>2]=256;v[a+480228>>2]=48;v[a+480232>>2]=48;v[23588]=0;d=1;W(264,a+1074312|0,114,1)|0;a=v[23588];v[23588]=0;if((a|0)==1){break m}Ab(e- -64|0);Ab(b);Yd(i)}jb=e+288|0;return d|0}b=P()|0;O()|0;break l}b=P()|0;O()|0;break d}b=P()|0;O()|0}Ab(e- -64|0);break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;uk(f)}Uc(d);break d}b=P()|0;O()|0}Ab(l)}Yd(i);break a}b=P()|0;O()|0;yb(e+128|0)}T(b|0);L()}function dga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0;d=jb-1344|0;jb=d;yc(b);f=jb-16|0;jb=f;FR(f+8|0,d+232|0);e=v[f+12>>2];mc(f,v[b>>2],v[b+8>>2],v[f+8>>2],v[f+12>>2]);j=v[f+4>>2];if((j|0)==(e|0)){Zb(b,v[f+12>>2])}jb=f+16|0;a:{if((e|0)!=(j|0)){break a}if(!HR(d+232|0)){break a}if(!Pb(v[b>>2],v[b+8>>2],Dc(GR(v[d+1336>>2]),mb))){break a}if(!c){m=1;break a}yc(b);b=je(d+232|0,b);v[23588]=0;R(618,d+216|0,b|0);f=v[23588];v[23588]=0;b:{c:{d:{e:{f:{g:{h:{i:{if((f|0)!=1){Ab(b);v[23588]=0;U(619,d+200|0,d+216|0,1196314451);b=v[23588];v[23588]=0;if((b|0)==1){break i}v[23588]=0;U(619,d+184|0,d+216|0,1280331091);b=v[23588];v[23588]=0;if((b|0)==1){break h}if(oc(v[d+200>>2],v[d+204>>2])){break b}if(!oc(v[d+184>>2],v[d+188>>2])){break g}break b}c=P()|0;O()|0;Ab(b);break d}c=P()|0;O()|0;break e}c=P()|0;O()|0;break f}v[23588]=0;R(246,a|0,1);b=v[23588];v[23588]=0;j:{k:{l:{m:{n:{if((b|0)!=1){$f(a);v[a+480188>>2]=4;v[a+480208>>2]=25231360;D=d,E=Eb(v[d+184>>2]),v[D+48>>2]=E;g=c&2;m=Eb(v[d+188>>2]);f=a+480190|0;o:{p:{while(1){e=v[d+48>>2];if(!Ob(e,m)){break p}b=x[f>>1];if(!Xh(b)){break p}b=b+1|0;u[f>>1]=b;v[23588]=0;b=B(b&65535,104)+a|0;j=b+484380|0;R(277,j|0,1);i=v[23588];v[23588]=0;q:{r:{if((i|0)!=1){v[23588]=0;i=Q(620,e|0,d+232|0)|0;l=v[23588];v[23588]=0;if((l|0)==1){break r}if(!i){break c}if(Wt(d+232|0)){break q}break c}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}v[23588]=0;i=Q(55,d+168|0,d+232|0)|0;l=v[23588];v[23588]=0;if((l|0)==1){break o}Cc(((x[f>>1]<<5)+a|0)+946304|0,i);yb(i);i=v[d+268>>2];v[j>>2]=i;v[b+484388>>2]=i;v[b+484384>>2]=v[d+264>>2];i=b+484414|0;u[i>>1]=x[i>>1]|2;u[b+484410>>1]=255;s:{if(g){b=Zc(d+16|0,8,1,0,0);v[23588]=0;W(219,b|0,j|0,e|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break s}}Mf(d+48|0);continue}break}c=P()|0;O()|0;break j}D=d,E=Eb(v[d+200>>2]),v[D+160>>2]=E;q=a+484344|0;A=c&1;r=a+484360|0;C=Eb(v[d+204>>2]);l=a+484376|0;o=a+480190|0;s=a+484380|0;y=a+946304|0;c=1;m=1;while(1){t:{u:{v:{w:{x:{y:{b=v[d+160>>2];if(!Ob(b,C)){break y}if(!(c&1)){v[23588]=0;c=S(272,r|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break x}if(!c){break y}}Kc(Vb(v[a+484360>>2],w[l|0]));v[23588]=0;c=Q(621,b|0,d+232|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break w}if(!(c&!x[d+1318>>1])|v[d+1320>>2]-5>>>0<4294967292){break c}c=w[l|0];f=v[a+484360>>2];v[23588]=0;U(5,d+48|0,5,d+232|0);e=v[23588];v[23588]=0;if((e|0)==1){break k}v[23588]=0;R(273,Vb(f,c)|0,d+48|0);c=v[23588];v[23588]=0;if((c|0)==1){break l}zb(d+48|0);z:{if(A){v[23588]=0;U(190,d+48|0,b|0,v[d+1328>>2]);b=v[23588];v[23588]=0;if((b|0)==1){break m}b=d+48|0;jc(d+136|0,b);break z}v[23588]=0;b=S(174,d+112|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break n}c=ID(d+48|0,b);jc(d+136|0,c);Ab(c)}Ab(b);Tb(d+48|0,0,64);c=1;A:{B:{C:{while(1){if((c|0)==32){break C}b=(B(c,34)+d|0)+198|0;f=b+32|0;Um(d,f);D:{E:{if(wj(w[v[d>>2]])){break E}e=w[b- -64|0];if(e>>>0>15){break B}b=w[b+65|0];if(b>>>0>64){break B}if(!Wt(f)){break B}j=b<<2;i=e<<4;f=0;b=1;F:{while(1){g=b&65535;e=x[o>>1];if(g>>>0>e>>>0){break F}v[23588]=0;U(524,d+16|0,v[d>>2],v[d+4>>2]);e=v[23588];v[23588]=0;if((e|0)==1){break D}e=jb-32|0;jb=e;k=d+16|0;Fe(e+24|0,k);DR(e+16|0,((g<<5)+a|0)+946304|0);h=v[e+20>>2];v[e+8>>2]=v[e+16>>2];v[e+12>>2]=h;h=v[e+24>>2];p=v[e+12>>2];n=v[e+28>>2];if((p|0)==(n|0)){h=(jT(h,n,v[e+8>>2],p)|0)!=0}else{h=1}jb=e+32|0;yb(k);G:{H:{if(h){break H}D=cc(d+48|0,c),E=b,u[D>>1]=E;e=B(g,104)+a|0;g=e+484410|0;h=x[g>>1];if((h|0)==255){break G}f=b;if(w[e+484417|0]!=(i&255)){break H}if((h|0)==(j|0)){break G}}b=b+1|0;continue}break}t[e+484417|0]=i;u[g>>1]=j;break E}f=f&65535;if(!f){break E}if(!Xh(e)){break E}b=e+1|0;u[o>>1]=b;D=cc(d+48|0,c),E=b,u[D>>1]=E;b=B(x[o>>1],104)+s|0;Dm(b);e=B(f,104)+s|0;g=jo(b,e);u[b+30>>1]=j;t[b+37|0]=i;xS(g,e);f=(f<<5)+y|0;e=v[f+4>>2];b=(x[o>>1]<<5)+y|0;v[b>>2]=v[f>>2];v[b+4>>2]=e;e=v[f+28>>2];v[b+24>>2]=v[f+24>>2];v[b+28>>2]=e;e=v[f+20>>2];v[b+16>>2]=v[f+16>>2];v[b+20>>2]=e;e=v[f+12>>2];v[b+8>>2]=v[f+8>>2];v[b+12>>2]=e}c=c+1|0;continue}break}break v}i=0;v[d+40>>2]=0;v[d+32>>2]=0;v[d+36>>2]=0;v[d+24>>2]=0;v[d+28>>2]=0;v[d+16>>2]=0;v[d+20>>2]=0;e=64;j=65535;p=x[d+1320>>1];f=0;I:while(1){J:{if(f){break J}v[23588]=0;b=W(156,v[d+136>>2],v[d+144>>2],1)|0;c=v[23588];v[23588]=0;if((c|0)==1){break A}if(b){break J}b=j;break u}e=e+1|0;if(e>>>0>=64){v[23588]=0;j=Q(359,q|0,64)|0;b=v[23588];v[23588]=0;if((b|0)==1){break A}b=65535;if((j|0)==65535){break u}b=w[l|0];c=v[a+484360>>2];e=0;v[23588]=0;R(522,Vb(c,b)|0,j|0);b=v[23588];v[23588]=0;if((b|0)==1){break A}}b=0;c=Yb(v[q>>2],j&65535);c=id(v[c>>2],v[v[c+48>>2]+12>>2],e,0);while(1){if((b|0)==(p|0)){continue I}g=(d+16|0)+B(b,7)|0;h=w[g+6|0];K:{if(h){t[g+6|0]=h-1;h=w[g+4|0]|w[g+5|0]<<8;t[c+4|0]=h;t[c+5|0]=h>>>8;g=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);t[c|0]=g;t[c+1|0]=g>>>8;t[c+2|0]=g>>>16;t[c+3|0]=g>>>24;f=f-1|0;break K}v[23588]=0;h=W(156,v[d+136>>2],v[d+144>>2],1)|0;k=v[23588];v[23588]=0;if((k|0)==1){break v}if(!h){break K}if(v[d+144>>2]==v[d+1324>>2]){i=Vb(v[a+484360>>2],w[l|0]);Ue(i,CB(v[i>>2],v[i+4>>2]));i=e}v[23588]=0;h=S(206,d+136|0)|0;k=v[23588];v[23588]=0;L:{if((k|0)!=1){h=h<<24>>24;if((h|0)>=0){break L}h=h&127;t[g+6|0]=h;k=w[g+4|0]|w[g+5|0]<<8;t[c+4|0]=k;t[c+5|0]=k>>>8;g=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);t[c|0]=g;t[c+1|0]=g>>>8;t[c+2|0]=g>>>16;t[c+3|0]=g>>>24;f=f+h|0;break K}break v}if((h-1&255)>>>0<=35){t[c|0]=h+48}v[23588]=0;h=S(206,d+136|0)|0;k=v[23588];v[23588]=0;M:{N:{if((k|0)!=1){D=c,E=w[cc(d+48|0,h&31)|0],t[D+1|0]=E;if(!(h&128)){break N}t[c+3|0]=w[g+3|0];t[c+5|0]=w[g+5|0];break M}break v}v[23588]=0;R(260,d|0,d+136|0);h=v[23588];v[23588]=0;O:{if((h|0)!=1){h=w[d|0];if(h>>>0>19){break M}n=h<<1;z=w[n+26944|0];t[c+3|0]=z;k=w[Nc(d)|0];t[c+5|0]=k;if((z|0)!=16|k>>>0<32){break O}t[c+3|0]=17;break M}break v}if(819137>>>h&1){break M}t[c+5|0]=w[n+26945|0]|k&15}h=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[g|0]=h;t[g+1|0]=h>>>8;t[g+2|0]=h>>>16;t[g+3|0]=h>>>24;h=w[c+4|0]|w[c+5|0]<<8;t[g+4|0]=h;t[g+5|0]=h>>>8}c=c+6|0;b=b+1|0;continue}}}m=0;break t}break v}Fj(r,0);v[23588]=0;b=Q(1,d+232|0,6470)|0;c=v[23588];v[23588]=0;P:{if((c|0)!=1){Ib(a+1298344|0,b);zb(b);v[23588]=0;b=Q(1,d+48|0,6772)|0;c=v[23588];v[23588]=0;if((c|0)==1){break P}Ib(a+1298356|0,b);zb(b);v[a+1298404>>2]=5;m=1;break b}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;Ab(d+136|0);break j}Q:{if(!i&e>>>0>62){break Q}b=b&65535;if((b|0)==65535){break Q}ze(Yb(v[q>>2],b),Eh(Te(Ne(d,14,i&255),e)))}c=32}Ab(d+136|0);if(c>>>0<32){break b}Mf(d+160|0);c=0;continue}}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;zb(d+48|0);break j}c=P()|0;O()|0}Uc(d+184|0)}Uc(d+200|0)}Yd(d+216|0)}T(c|0);L()}m=0}Uc(d+184|0);Uc(d+200|0);Yd(d+216|0)}jb=d+1344|0;return m|0}function Ega(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,Q=0,R=0,S=0,V=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0;d=jb-336|0;jb=d;a:{if(!cd(b,1080)){break a}if(!no(b,d+332|0)){break a}Ad(a,1);m=kS(d+312|0);if(!jS(d+332|0,m)){break a}f=x[m+10>>1];if(!f|f>>>0>127){break a}if(!c){g=1;break a}r=a+480188|0;u[r>>1]=f;p=w[m+14|0];E=w[m+13|0];h=w[m+12|0];F=1;if(!ne(d+332|0,26874)){F=ne(d+332|0,26879)}if(w[m+15|0]){Nb(a+1074312|0,5,1);f=x[a+480188>>1]}g=d+332|0;s=ne(g,16692);e=1;if(!ne(g,17456)){e=ne(d+332|0,13500)}z=(f&65535)==8&(E|0)!=0;cd(b,0);OA(b,a+1298308|0,20);u[a+480190>>1]=31;l=(h|0)!=0;q=a+480188|0;g=1;f=s;while(1)if((g|0)==32){b:{c:{d:{e:{f:{g:{N=v[m+4>>2];if(N>>>0>=G>>>0){h=d+176|0;eS(b,h);cd(b,x[m+8>>1]);g=w[d+177|0];e=128;j=a+484376|0;Hq(Vb(v[a+484360>>2],w[j|0]),h|2,128);h=!g&f;k=h?k:0;f=w[d+176|0];h:{if(f>>>0>128){break h}e=f;if(f){break h}f=v[Vb(v[a+484360>>2],w[a+484376|0])>>2];g=128;while(1){e=g;if(e>>>0<2){e=1;break h}g=e-1|0;if(!x[cc(f,g)>>1]){continue}break}}o=dS(b,Vb(v[a+484360>>2],w[j|0]),e&65535,i,r,k,0);H=1;i:{if(!(h&x[a+480188>>1]==8)){H=(p|0)!=0;break i}v[m>>2]=11183}j:{if(!z){break j}f=Vb(v[a+484360>>2],w[a+484376|0]);aa=d,ba=Eb(v[f>>2]),v[aa+160>>2]=ba;h=Eb(v[f+4>>2]);while(1){f=v[d+160>>2];if(!Ob(f,h)){break j}u[f>>1]=x[f>>1]>>>1;Re(d+160|0);continue}}f=a+484376|0;Ue(Vb(v[a+484360>>2],w[f|0]),w[d+177|0]);Q=e-1|0;e=w[d+177|0];k:{if((Q&65535)>>>0>=e>>>0){g=x[r>>1];if((e|0)!=120|(g|0)!=4){break k}}Ue(Vb(v[a+484360>>2],w[f|0]),0);g=x[a+480188>>1]}v[a+480260>>2]=56;v[a+480264>>2]=13696;v[a+480204>>2]=125e4;v[a+480196>>2]=6;k=0;v[a+480208>>2]=0;aa=a,ba=Xb(256/((g&65535)>>>0)|0,32,128),v[aa+480228>>2]=ba;nh(a,0);t[d+175|0]=0;l:{if(l&1){p=1;e=1;break l}p=1;e=0;l=0;h=s;m:while(1){n:{q=0;if(o>>>0<=(l&65535)>>>0){break n}g=0;while(1)if((g|0)==256){l=l+1|0;continue m}else{f=d+144|0;j=tg(d+160|0);Hu(f,b,j);i=Nc(f);n=gB(w[j|0]);o:{p:{q:{r:{j=w[d+144|0];if((j-7&255)>>>0<3){h=0;break r}f=w[i|0];if(!((j|0)!=14|f>>>0<=1)){h=0;break q}if(!((j|0)==15&(f&255)>>>0>31)){h=n?h:0;if((j|0)!=13){break r}q=q+1|0;if((q&65535)>>>0<2){break o}}h=0;break o}if((j|0)==8){break p}if((j|0)!=14){break o}f=w[i|0]}if((f&240)!=128){break o}t[d+80|0]=f<<4;aa=d,ba=w[jf(d+175|0,d+80|0)|0],t[aa+175|0]=ba;break o}aa=d,ba=w[jf(d+175|0,i)|0],t[aa+175|0]=ba;f=t[i|0];if((f|0)>=0){k=1;break o}e=(f|0)!=-92&f>>>0>4294967183|e}p=n&p;g=g+1|0;continue}}break}f=k^-1;k=0;k=(e|f)&1?k:w[d+175|0]>47;e=h&1}j=e;cd(b,x[m+8>>1]);e=x[a+480188>>1];n=a+484344|0;I=o+z&65535;wg(n,I);R=z?4:e;o=a+1074312|0;_=k^1;$=c&1;l=0;k=0;s:{t:{u:{while(1){if((l|0)==(I|0)){break t}v:{if(z){e=(l&65534)>>>1|0;f=l&1;if(!f){if(!oh(n,e,64)){break t}}g=Yb(v[n>>2],e);e=f<<2;break v}if(!oh(n,l&65535,64)){break t}g=Yb(v[n>>2],l);e=0}h=0;q=id(v[g>>2],v[v[g+48>>2]+12>>2],0,e);if(!$){J=0;K=0;break s}e=x[r>>1];t[d+80|0]=0;f=e;e=d+80|0;C=Om(d+160|0,f,e);f=x[r>>1];v[23588]=0;t[d+80|0]=0;D=W(577,d+144|0,f|0,e|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){M=0;w:{x:while(1){y:{if((M|0)==64){break w}g=0;f=0;S=0;while(1){if((g|0)==(R|0)){M=M+1|0;J=f&S|J;q=B(x[r>>1],6)+q|0;continue x}v[23588]=0;h=B(g,6)+q|0;U(578,d+80|0,b|0,h|0);e=v[23588];v[23588]=0;if((e|0)!=1){e=w[d+80|0];y=Nc(d+80|0);i=w[y|0];if(e|i){z:{if(!(!E|(e&255)!=14)){e=0;t[y|0]=0;t[d+80|0]=0;i=w[y|0];break z}if(!E|(e&255)!=15|(i&255)>>>0<32){break z}i=31;t[y|0]=31;e=w[d+80|0]}Of(h,e&255,i&255)}e=1;A:{B:{C:{D:{E:{i=w[h+3|0];switch(i-14|0){case 2:break A;case 0:break D;case 3:break E;default:break C}}k=w[h+5|0]<100|k;S=1;break B}if(!j){break B}t[h+5|0]=0;break B}if(!((i|0)!=9|_)){e=w[h+5|0];if((e|0)==164){t[h+3|0]=20;t[h+5|0]=145;break B}aa=h,ba=sg(e<<1),t[aa+5|0]=ba;break B}if((i|0)!=19){break B}e=w[h+5|0];if(e>>>0>15){break B}i=e&1;e=!i;y=!i;i=V&1;V=(i|0)==(e|0)?V:y;K=((e|0)!=(i|0))+K|0}e=f}F:{if(!w[h|0]){f=w[h+1|0];if(!f|z){break F}i=w[Kb(v[C>>2],g)|0];if(!i|(f|0)==(i|0)){break F}i=Kb(v[D>>2],g);f=w[i|0]+1|0;t[i|0]=f;if((f&255)>>>0<4){break F}v[23588]=0;W(264,o|0,85,1)|0;f=v[23588];v[23588]=0;if((f|0)!=1){break F}break y}aa=Kb(v[D>>2],g),ba=0,t[aa|0]=ba}f=w[h+1|0];if(f){aa=Kb(v[C>>2],g),ba=f,t[aa|0]=ba}g=g+1|0;f=e;continue}break}}break}f=P()|0;O()|0;hc(D);break u}hc(D);hc(C);l=l+1|0;continue}break}f=P()|0;O()|0}hc(C);break b}h=k}G:{H:{I:{if((p^-1|X)&1){break I}J:{if(ne(d+332|0,16692)){break J}if(ne(d+332|0,17461)){break J}if(!ne(d+332|0,13490)){break I}}v[a+480208>>2]=v[a+480208>>2]|2162688;e=Nb(Nb(Nb(o,85,1),91,1),92,1);K:{if(w[d+175|0]>47){break K}e=Nb(e,84,1);if(w[d+177|0]==127){break K}Nb(e,83,1)}if(!(p&1)){break G}break H}if(p&1){break H}if(s^1|w[d+177|0]!=127|(Q&65535)>>>0>128){break G}v[m>>2]=8454;break G}if((K|0)>6|H){break G}v[a+480208>>2]=v[a+480208>>2]|8388608}if((s|H)==1){Nb(o,89,1)}if(F){Nb(o,84,1)}L:{if(!(c&2)){break L}cd(b,x[m+8>>1]+(B(I,R)<<8)|0);f=(p&s^1|Y)&1;g=1;while(1){if((g|0)==32){break L}k=B(g,104)+a|0;c=k+484380|0;e=v[c>>2];if(e){i=2;if(!F){i=cS(b,13799)?10:0;e=v[c>>2]}j=Zc(d+160|0,8,1,0,i);e=QA(j,e)+v[b+8>>2]|0;if(!f){aa=c,ba=v[Yc(c,k+484388|0)>>2],v[aa>>2]=ba}vg(j,c,b);cd(b,e)}g=g+1|0;continue}}M:{if((h&s^-1|J)&1){break M}b=bS(d+120|0,0);c=v[b+20>>2];v[d+40>>2]=v[b+16>>2];v[d+44>>2]=c;c=v[b+12>>2];v[d+32>>2]=v[b+8>>2];v[d+36>>2]=c;c=v[b+4>>2];v[d+24>>2]=v[b>>2];v[d+28>>2]=c;b=d+160|0;Zt(b,a,0,d+24|0);Z=A[v[d+160>>2]>>3];Di(b);if(!(Z>=480)){break M}c=Nb(o,5,1);b=aS(d+96|0,Z);e=v[b+20>>2];v[d+16>>2]=v[b+16>>2];v[d+20>>2]=e;e=v[b+12>>2];v[d+8>>2]=v[b+8>>2];v[d+12>>2]=e;e=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=e;b=d+160|0;Zt(b,a,0,d);e=w[v[d+160>>2]+26|0];Di(b);if(e){Zf(c,5);break M}v[m>>2]=17044}b=d+332|0;e=b;f=ic(b);c=b;while(1){if((e|0)!=(f|0)){h=w[e|0];t[c|0]=h>>>0>32?h:32;c=c+1|0;e=e+1|0;continue}break}Rf(d+80|0,16797);v[23588]=0;b=W(579,d+48|0,b|0,f|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break g}v[23588]=0;U(11,d- -64|0,1,b|0);c=v[23588];v[23588]=0;if((c|0)==1){break f}v[23588]=0;U(145,d+160|0,d+80|0,d- -64|0);c=v[23588];v[23588]=0;if((c|0)==1){break e}c=d+160|0;Ib(a+1298344|0,c);zb(c);zb(d- -64|0);yb(b);ac(d+80|0);b=xc(c,12238);Ib(a+1298356|0,b);zb(b);b=v[m>>2];if(b){Ql(a+1298368|0,b)}v[a+1298404>>2]=14}g=G>>>0<=N>>>0;break a}f=P()|0;O()|0;break c}f=P()|0;O()|0;break d}f=P()|0;O()|0;zb(d- -64|0)}yb(b)}ac(d+80|0)}T(f|0);L()}else{j=B(g,104)+a|0;h=j+484380|0;o=jA(b,d+176|0,h,((g<<5)+a|0)+946304|0,x[q>>1]==4);h=v[h>>2];N:{if(e){t[j+484417|0]=0-(w[d+200|0]<<3);break N}l=h>>>0<65536&l}j=Hb(x[d+198>>1]);O:{if(j){X=!Hb(x[d+204>>1])|X;break O}Y=w[d+201|0]==64|Y}n=f&1;f=0;P:{if(!n){break P}k=(j<<1)+k|0;n=w[d+200|0];f=!n;if(n|!j){break P}f=w[d+201|0]==64}G=o+G|0;i=h+i|0;g=g+1|0;continue}}jb=d+336|0;return g|0}function r7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=C(0),g=C(0),h=C(0),i=0,j=C(0),k=C(0),l=0,m=0,n=0,o=C(0),p=0,q=0,r=0,s=0,u=0,x=C(0),y=C(0),A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=C(0),Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=C(0),Z=0,_=0,$=C(0);a:{if(!w[a+5046|0]){break a}g=z[a+4268>>2];HK(a);if(g==z[a+4268>>2]){break a}Ex(a)}b:{if(!w[a+5045|0]){break b}if(!$h(a+44|0)){break b}i=v[a+44>>2];p=Jc(i,0);q=Jc(i,1);i=v[a+56>>2];l=Jc(i,0);m=Jc(i,1);c:{if(!(!w[a+5044|0]|(!d|w[a+4264|0]&2))){z[l>>2]=z[a+5036>>2];z[m>>2]=z[a+5040>>2];t[a+5044|0]=0;q=q+4|0;p=p+4|0;m=m+4|0;l=l+4|0;n=d-1|0;break c}n=d}r=n;s=a+4888|0;u=a+4864|0;U=a+4504|0;V=a+4960|0;W=a+4868|0;X=a+4892|0;D=a+4628|0;E=a+4604|0;Q=a+4916|0;F=a+4532|0;G=a+4508|0;H=a+4772|0;I=a+4748|0;R=a+4940|0;J=a+4676|0;K=a+4652|0;L=a+4724|0;M=a+4700|0;S=a+4844|0;N=a+4580|0;O=a+4556|0;T=a+4820|0;d:{while(1){if(!r){break d}g=z[p>>2];g=C(C(C(z[a+5008>>2]-g)*z[a+4276>>2])+g);z[a+5008>>2]=g;_=Oc(v[a+4864>>2],v[W>>2],v[a+4880>>2]),$=g,z[_>>2]=$;g=z[q>>2];g=C(C(C(z[a+5012>>2]-g)*z[a+4276>>2])+g);z[a+5012>>2]=g;_=Oc(v[a+4888>>2],v[X>>2],v[a+4904>>2]),$=g,z[_>>2]=$;g=C(C(C(C(C(Ph(u,v[a+4356>>2])*C(.6800000071525574))+C(Ph(u,v[a+4360>>2])*C(-.5)))-C(Ph(u,v[a+4364>>2])*C(.6200000047683716)))+C(Ph(u,v[a+4368>>2])*C(-.5)))-C(Ph(u,v[a+4372>>2])*C(.6200000047683716)));if(t[a+4264|0]&1){e=g;g=C(z[Oc(v[a+4816>>2],v[T>>2],v[a+4836>>2])>>2]+C(e*C(.6180340051651001)));_=Oc(v[a+4816>>2],v[T>>2],v[a+4832>>2]),$=C(e-C(g*C(.6180340051651001))),z[_>>2]=$}x=z[a+4280>>2];_=a,$=C(Ph(u,v[a+4352>>2])+z[a+5020>>2]),z[_+5020>>2]=$;e=C(Ph(s,v[a+4376>>2])+z[a+5024>>2]);z[a+5024>>2]=e;f=z[a+5020>>2];h=C(C(C(z[a+4980>>2]-z[Oc(v[a+4624>>2],v[D>>2],v[a+4644>>2])>>2])*z[a+4444>>2])+z[Oc(v[a+4624>>2],v[D>>2],v[a+4644>>2])>>2]);z[a+4980>>2]=h;P=C(h*z[a+4440>>2]);k=C(e*C(.7070000171661377));j=C(f*C(-.7070000171661377));f=C(k+j);h=z[a+4272>>2];e=C(P+C(f*h));_=Oc(v[a+4624>>2],v[D>>2],v[a+4640>>2]),$=C(f-C(h*e)),z[_>>2]=$;f=C(C(C(z[a+4976>>2]-z[Oc(v[a+4600>>2],v[E>>2],v[a+4620>>2])>>2])*z[a+4436>>2])+z[Oc(v[a+4600>>2],v[E>>2],v[a+4620>>2])>>2]);z[a+4976>>2]=f;h=z[a+4272>>2];f=C(C(f*z[a+4432>>2])+C(e*h));_=Oc(v[a+4600>>2],v[E>>2],v[a+4616>>2]),$=C(e-C(h*f)),z[_>>2]=$;y=C(C(e*C(-.15000000596046448))+C(f*C(-.20000000298023224)));if(t[a+4264|0]&1){e=C(C(C(z[a+4972>>2]-z[Oc(v[a+4576>>2],v[N>>2],v[a+4596>>2])>>2])*z[a+4428>>2])+z[Oc(v[a+4576>>2],v[N>>2],v[a+4596>>2])>>2]);z[a+4972>>2]=e;h=z[a+4272>>2];e=C(C(e*z[a+4424>>2])+C(f*h));_=Oc(v[a+4576>>2],v[N>>2],v[a+4592>>2]),$=C(f-C(h*e)),z[_>>2]=$;f=C(C(C(z[a+4968>>2]-z[Oc(v[a+4552>>2],v[O>>2],v[a+4572>>2])>>2])*z[a+4420>>2])+z[Oc(v[a+4552>>2],v[O>>2],v[a+4572>>2])>>2]);z[a+4968>>2]=f;h=z[a+4272>>2];f=C(C(f*z[a+4416>>2])+C(e*h));_=Oc(v[a+4552>>2],v[O>>2],v[a+4568>>2]),$=C(e-C(h*f)),z[_>>2]=$;y=C(C(C(e*C(.3499999940395355))+y)+C(f*C(-.3799999952316284)))}_=Oc(v[a+4912>>2],v[Q>>2],v[a+4928>>2]),$=f,z[_>>2]=$;e=C(z[Oc(v[a+4912>>2],v[Q>>2],v[a+4932>>2])>>2]*z[a+4496>>2]);z[a+5028>>2]=C(C(z[a+5028>>2]-e)*z[a+4500>>2])+e;e=C(C(C(z[a+4964>>2]-z[Oc(v[a+4528>>2],v[F>>2],v[a+4548>>2])>>2])*z[a+4412>>2])+z[Oc(v[a+4528>>2],v[F>>2],v[a+4548>>2])>>2]);z[a+4964>>2]=e;f=z[a+5028>>2];o=z[a+4272>>2];h=C(C(f*o)+C(e*z[a+4408>>2]));_=Oc(v[a+4528>>2],v[F>>2],v[a+4544>>2]),$=C(f-C(o*h)),z[_>>2]=$;e=C(C(C(z[a+4960>>2]-z[Oc(v[a+4504>>2],v[G>>2],v[a+4524>>2])>>2])*z[a+4404>>2])+z[Oc(v[a+4504>>2],v[G>>2],v[a+4524>>2])>>2]);z[a+4960>>2]=e;f=C(e*z[a+4400>>2]);e=z[a+4272>>2];o=C(f+C(h*e));_=Oc(v[a+4504>>2],v[G>>2],v[a+4520>>2]),$=C(h-C(e*o)),z[_>>2]=$;z[a+5020>>2]=o;e=C(C(C(C(C(Ph(s,v[a+4380>>2])*C(.7070000171661377))+C(Ph(s,v[a+4384>>2])*C(-.6000000238418579)))-C(Ph(s,v[a+4388>>2])*C(.5)))+C(Ph(s,v[a+4392>>2])*C(-.6000000238418579)))-C(Ph(s,v[a+4396>>2])*C(.5)));if(t[a+4264|0]&1){f=e;e=C(z[Oc(v[a+4840>>2],v[S>>2],v[a+4860>>2])>>2]+C(e*C(.6180340051651001)));_=Oc(v[a+4840>>2],v[S>>2],v[a+4856>>2]),$=C(f-C(e*C(.6180340051651001))),z[_>>2]=$}Y=z[a+4280>>2];f=C(C(C(z[a+5004>>2]-z[Oc(v[a+4768>>2],v[H>>2],v[a+4788>>2])>>2])*z[a+4492>>2])+z[Oc(v[a+4768>>2],v[H>>2],v[a+4788>>2])>>2]);z[a+5004>>2]=f;P=C(f*z[a+4488>>2]);f=C(j-k);j=z[a+4272>>2];k=C(P+C(f*j));_=Oc(v[a+4768>>2],v[H>>2],v[a+4784>>2]),$=C(f-C(j*k)),z[_>>2]=$;f=C(C(C(z[a+5e3>>2]-z[Oc(v[a+4744>>2],v[I>>2],v[a+4764>>2])>>2])*z[a+4484>>2])+z[Oc(v[a+4744>>2],v[I>>2],v[a+4764>>2])>>2]);z[a+5e3>>2]=f;j=z[a+4272>>2];f=C(C(f*z[a+4480>>2])+C(k*j));_=Oc(v[a+4744>>2],v[I>>2],v[a+4760>>2]),$=C(k-C(j*f)),z[_>>2]=$;k=C(C(C(h*C(.3799999952316284))+C(k*C(-.15000000596046448)))+C(f*C(-.20000000298023224)));if(t[a+4264|0]&1){h=C(C(C(z[a+4996>>2]-z[Oc(v[a+4720>>2],v[L>>2],v[a+4740>>2])>>2])*z[a+4476>>2])+z[Oc(v[a+4720>>2],v[L>>2],v[a+4740>>2])>>2]);z[a+4996>>2]=h;j=z[a+4272>>2];h=C(C(h*z[a+4472>>2])+C(f*j));_=Oc(v[a+4720>>2],v[L>>2],v[a+4736>>2]),$=C(f-C(j*h)),z[_>>2]=$;f=C(C(C(z[a+4992>>2]-z[Oc(v[a+4696>>2],v[M>>2],v[a+4716>>2])>>2])*z[a+4468>>2])+z[Oc(v[a+4696>>2],v[M>>2],v[a+4716>>2])>>2]);z[a+4992>>2]=f;j=z[a+4272>>2];f=C(C(f*z[a+4464>>2])+C(h*j));_=Oc(v[a+4696>>2],v[M>>2],v[a+4712>>2]),$=C(h-C(j*f)),z[_>>2]=$;k=C(C(C(h*C(.3499999940395355))+k)+C(f*C(-.3799999952316284)))}Z=q+4|0;n=p+4|0;h=C(g*x);y=C(y-C(o*C(.3799999952316284)));o=C(e*Y);_=Oc(v[a+4936>>2],v[R>>2],v[a+4952>>2]),$=f,z[_>>2]=$;g=C(z[Oc(v[a+4936>>2],v[R>>2],v[a+4956>>2])>>2]*z[a+4496>>2]);z[a+5032>>2]=C(C(z[a+5032>>2]-g)*z[a+4500>>2])+g;g=C(C(C(z[a+4988>>2]-z[Oc(v[a+4672>>2],v[J>>2],v[a+4692>>2])>>2])*z[a+4460>>2])+z[Oc(v[a+4672>>2],v[J>>2],v[a+4692>>2])>>2]);z[a+4988>>2]=g;e=z[a+5032>>2];f=z[a+4272>>2];g=C(C(e*f)+C(g*z[a+4456>>2]));_=Oc(v[a+4672>>2],v[J>>2],v[a+4688>>2]),$=C(e-C(f*g)),z[_>>2]=$;f=z[a+4284>>2];e=C(C(C(z[a+4984>>2]-z[Oc(v[a+4648>>2],v[K>>2],v[a+4668>>2])>>2])*z[a+4452>>2])+z[Oc(v[a+4648>>2],v[K>>2],v[a+4668>>2])>>2]);z[a+4984>>2]=e;x=z[a+4272>>2];e=C(C(e*z[a+4448>>2])+C(g*x));_=Oc(v[a+4648>>2],v[K>>2],v[a+4664>>2]),$=C(g-C(x*e)),z[_>>2]=$;z[a+5024>>2]=e;e=C(-e);x=z[a+4288>>2];i=U;e:{f:{while(1){if((i|0)==(V|0)){g:{e=C(o+C(C(C(e*C(.3799999952316284))+k)*x));g=C(h+C(C(C(g*C(.3799999952316284))+y)*f));if(!(w[a+4264|0]&2)){break g}p=n;n=Z;break f}}else{A=v[i+16>>2];B=A-1|0;v[i+16>>2]=B;if((A|0)<=0){v[i+16>>2]=B+v[i+12>>2]}A=v[i+20>>2];B=A-1|0;v[i+20>>2]=B;if((A|0)<=0){v[i+20>>2]=B+v[i+12>>2]}i=i+24|0;continue}break}z[l>>2]=C(g+z[a+5036>>2])*C(.5);z[m>>2]=C(e+z[a+5040>>2])*C(.5);z[a+5040>>2]=e;z[a+5036>>2]=g;if((r|0)==1){break e}r=r-1|0;p=p+8|0;m=m+4|0;l=l+4|0;n=q+8|0}q=n;z[l>>2]=g;z[m>>2]=e;r=r-1|0;m=m+4|0;l=l+4|0;continue}break}t[a+5044|0]=1}n=a;a=v[a+56>>2];ri(n,b,c,Jc(a,0),Jc(a,1),d)}}function Nea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=jb-288|0;jb=g;e=jb-128|0;jb=e;f=je(g+104|0,c);v[23588]=0;n=S(174,f+20|0)|0;c=v[23588];v[23588]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{if((c|0)!=1){v[23588]=0;p=S(174,f+40|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break B}v[23588]=0;q=S(174,f+60|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break A}v[23588]=0;i=S(174,f+80|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break z}v[23588]=0;o=S(174,f+100|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break y}v[23588]=0;k=S(174,f+120|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break x}j=Sb(f+140|0);yc(f);v[f+172>>2]=1873739776;u[f+176>>1]=0;v[23588]=0;d=Q(769,f|0,e+112|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break w}if(!d){break n}d=v[e+112>>2];if((d|0)!=1414744396&(d|0)!=1179011410){break n}c=v[e+120>>2];if((c|0)!=1163280727&(c|0)!=1702257015){break n}t[f+176|0]=(d|0)==1414744396;v[23588]=0;U(770,e+96|0,f|0,2);c=v[23588];v[23588]=0;if((c|0)==1){break v}h=v[e+96>>2];C:{if(Jq(h,v[e+100>>2])>>>0<4){break C}c=by(h,1);d=v[c+4>>2];c=v[c>>2];Yh(e+40|0,c,d);if(v[e+40>>2]!=1635017060){break C}Yh(e- -64|0,c,d);if(!(t[e+68|0]&1)){break C}c=by(h,2);Yh(e+24|0,v[c>>2],v[c+4>>2]);if(v[e+28>>2]){break C}c=by(h,3);Yh(e+88|0,v[c>>2],v[c+4>>2]);if(v[e+88>>2]){break C}v[23588]=0;Q(155,f|0,12)|0;c=v[23588];v[23588]=0;if((c|0)==1){break u}v[23588]=0;U(770,e+40|0,f|0,1);c=v[23588];v[23588]=0;if((c|0)==1){break t}c=e+40|0;Tt(e+96|0,c);Yd(c)}v[23588]=0;U(771,e- -64|0,e+96|0,544501094);c=v[23588];v[23588]=0;if((c|0)==1){break s}v[23588]=0;d=Q(772,e- -64|0,f+156|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break k}if(!d){break o}d=x[f+156>>1];if((d|0)!=1){break q}v[23588]=0;d=S(202,e- -64|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break r}break k}d=P()|0;O()|0;break b}d=P()|0;O()|0;break c}d=P()|0;O()|0;break d}d=P()|0;O()|0;break e}d=P()|0;O()|0;break f}d=P()|0;O()|0;break g}d=P()|0;O()|0;break h}d=P()|0;O()|0;break h}d=P()|0;O()|0;break i}d=P()|0;O()|0;break i}d=P()|0;O()|0;break i}if((d|0)==4){v[23588]=0;h=S(197,e- -64|0)|0;c=v[23588];v[23588]=0;D:{if((c|0)!=1){v[23588]=0;d=S(197,e- -64|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break D}if((h|0)!=2|(d|0)!=1){break p}t[f+177|0]=1;break p}d=P()|0;O()|0;break j}d=P()|0;O()|0;break j}d=x[f+156>>1]}if((d&65535)!=65534){break p}v[23588]=0;d=Q(773,e- -64|0,e+40|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break l}if(!d){break o}c=v[e+60>>2];v[e+16>>2]=v[e+56>>2];v[e+20>>2]=c;c=v[e+52>>2];v[e+8>>2]=v[e+48>>2];v[e+12>>2]=c;c=e+24|0;v[c>>2]=w[e+8|0]|w[e+9|0]<<8|(w[e+10|0]<<16|w[e+11|0]<<24);u[c+4>>1]=w[e+12|0]|w[e+13|0]<<8;u[c+6>>1]=w[e+14|0]|w[e+15|0]<<8;r=c,s=pA(w[e+16|0]|w[e+17|0]<<8|(w[e+18|0]<<16|w[e+19|0]<<24),w[e+20|0]|w[e+21|0]<<8|(w[e+22|0]<<16|w[e+23|0]<<24)),v[r+8>>2]=s;v[c+12>>2]=mb;u[f+172>>1]=v[c>>2]}v[23588]=0;U(771,e+40|0,e+96|0,1635017060);c=v[23588];v[23588]=0;E:{F:{G:{H:{I:{J:{if((c|0)!=1){c=e+40|0;m=gd(n,c);Ab(c);c=v[m>>2];v[23588]=0;d=S(178,c|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break k}if(!d){v[23588]=0;U(771,e+40|0,e+96|0,544039792);c=v[23588];v[23588]=0;if((c|0)==1){break J}c=e+40|0;gd(m,c);Ab(c)}v[23588]=0;U(771,e+40|0,e+96|0,1952670054);c=v[23588];v[23588]=0;if((c|0)==1){break I}v[23588]=0;d=S(157,e+40|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break H}v[f+152>>2]=d;Ab(e+40|0);if(v[f+152>>2]?x[f+156>>1]==17:0){break E}h=x[f+158>>1];d=fM(h,x[f+170>>1]);if(!d){break E}c=x[f+168>>1];if((c>>>0)/(h>>>0)>>>0<d<<1>>>0?c:0){break G}c=v[m>>2];v[23588]=0;d=S(160,c|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break k}c=fM(x[f+158>>1],x[f+170>>1]);break F}d=P()|0;O()|0;break j}d=P()|0;O()|0;break j}d=P()|0;O()|0;break j}d=P()|0;O()|0;Ab(e+40|0);break j}c=v[m>>2];v[23588]=0;d=S(160,c|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break k}c=x[f+168>>1]}v[f+152>>2]=(d>>>0)/((c&65535)>>>0)}v[23588]=0;d=Q(774,f|0,e+96|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break k}u[f+174>>1]=d;v[23588]=0;R(775,f|0,e+96|0);c=v[23588];v[23588]=0;if((c|0)==1){break k}v[23588]=0;U(771,e+40|0,e+96|0,1886221175);c=v[23588];v[23588]=0;if((c|0)==1){break m}c=e+40|0;gd(o,c);Ab(c)}Ab(e- -64|0);Yd(e+96|0)}jb=e+128|0;break a}d=P()|0;O()|0;break j}d=P()|0;O()|0;break j}d=P()|0;O()|0}Ab(e- -64|0)}Yd(e+96|0)}Yd(j);Ab(k)}Ab(o)}Ab(i)}Ab(q)}Ab(p)}Ab(n)}Ab(f);T(d|0);L()}c=v[f+20>>2];v[23588]=0;d=S(714,c|0)|0;c=v[23588];v[23588]=0;K:{L:{if((c|0)!=1){M:{if(!d|(x[f+158>>1]-3&65535)>>>0<65534){break M}N:{O:{c=x[f+170>>1];P:{if(!c){if((kk(f)|0)==85){break P}break M}if(c>>>0>31){break O}}if((kk(f)|0)!=3){break N}break M}if(c>>>0>64){break M}}d=kk(f);c=30240;while(1){Q:{R:{if((c|0)!=30264){if((d|0)!=v[c>>2]){break R}}else{c=30264}break Q}c=c+4|0;continue}break}if((c|0)==30264){break M}rt(a,b);v[23588]=0;d=Q(55,g+88|0,21619)|0;c=v[23588];v[23588]=0;S:{T:{U:{V:{W:{if((c|0)!=1){h=Cc(((b<<5)+a|0)+946304|0,d);yb(d);v[23588]=0;d=B(b,104)+a|0;i=d+484380|0;R(277,i|0,0);c=v[23588];v[23588]=0;if((c|0)==1){break W}v[i>>2]=v[f+152>>2];v[d+484404>>2]=v[f+160>>2];c=v[a+1298404>>2];v[23588]=0;X(715,f|0,i|0,c|0,h|0);c=v[23588];v[23588]=0;if((c|0)==1){break W}je(g- -64|0,f+20|0);d=x[f+158>>1];j=Zc(g+56|0,8,d>>>0>1?2:1,0,0);c=kk(f);if((c|0)!=17|d>>>0>2){break U}wc(i,268435456);c=B(b,104)+a|0;b=c+484414|0;u[b>>1]=x[b>>1]&65470|((d|0)==2)<<6|1;if(Ng(i)){break V}break S}l=P()|0;O()|0;break K}l=P()|0;O()|0;break K}j=v[c+484400>>2];h=v[i>>2];k=je(g+32|0,g- -64|0);d=x[f+158>>1];c=x[f+168>>1];v[23588]=0;b=v[k+12>>2];v[g+16>>2]=v[k+8>>2];v[g+20>>2]=b;v[g+24>>2]=v[k+16>>2];b=v[k+4>>2];v[g+8>>2]=v[k>>2];v[g+12>>2]=b;ea(716,j|0,h|0,g+8|0,c|0,d|0);b=v[23588];v[23588]=0;if((b|0)==1){break L}tj(i,a);break T}if((c|0)==85){v[23588]=0;c=W(559,a|0,b|0,g- -64|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break L}if(c){break T}break S}X:{Y:{Z:{if(VP(x[f+156>>1])){break Z}_:{if(!Pd(w[f+177|0])){break _}if((kk(f)|0)!=1|x[f+170>>1]!=32|x[f+168>>1]!=d<<2){break _}wd(j,32);b=12;break Y}if((kk(f)|0)!=1|x[f+170>>1]!=24|x[f+168>>1]!=d<<2){break Z}wd(j,32);b=13;break Y}if((kk(f)&65534)!=6){break X}wd(j,16);b=(kk(f)|0)==6?17:16}cg(j,b);v[23588]=0;W(219,j|0,i|0,g- -64|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break T}break L}d=x[f+170>>1];c=(d-1>>>3|0)-1|0;b=c<<3;h=b&31;wd(j,(c>>>0<7?(b&63)>>>0>=32?4196360>>>h|0:((1<<h)-1&4196360)<<32-h|136321040>>>h:8)&255);if(d>>>0<9){cg(j,1)}if((kk(f)|0)==3){cg(j,3)}v[23588]=0;W(219,j|0,i|0,g- -64|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break L}}Dz(i,v[a+480180>>2]);tj(i,a);l=1}Ab(g- -64|0)}UP(f);jb=g+288|0;return l|0}l=P()|0;O()|0;break K}l=P()|0;O()|0;Ab(g- -64|0)}UP(f);T(l|0);L()}
function YI(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=jb-272|0;jb=h;a:{b:{if(g){of(h+256|0,f,32);v[23588]=0;W(527,h+240|0,f|0,32)|0;k=v[23588];v[23588]=0;if((k|0)!=1){break b}f=P()|0;O()|0;break a}Lb(h+256|0);Lb(h+240|0)}c:{d:{e:{f:{g:{h:{i:{j:{if(ss(c)){k=v[b+24>>2];i=v[k+484344>>2];if(xe(i,v[k+484348>>2],c&65535)){break j}}v[23588]=0;U(1085,a|0,h+256|0,h+240|0);a=v[23588];v[23588]=0;if((a|0)!=1){break i}f=P()|0;O()|0;break c}c=Yb(i,c);if(!(!((e|0)<0|v[c+12>>2]<=(d|0)|(d|0)<0)&x[k+480188>>1]>e>>>0)){v[23588]=0;U(1085,a|0,h+256|0,h+240|0);a=v[23588];v[23588]=0;if((a|0)!=1){break i}f=P()|0;O()|0;break c}c=id(v[c>>2],v[v[c+48>>2]+12>>2],d,e&65535);_f(h+256|0);_f(h+240|0);k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{d=w[c|0];if(!_c(d)){if(!Kp(d)){break A}}e=w[c+1|0];k=v[b+24>>2];v[23588]=0;X(1086,h+208|0,k|0,d|0,e|0);d=v[23588];v[23588]=0;e=1;if((d|0)==1){break y}v[23588]=0;R(1015,h+224|0,h+208|0);d=v[23588];v[23588]=0;if((d|0)!=1){break z}f=P()|0;O()|0;break v}e=0;v[23588]=0;Q(55,h+224|0,16730)|0;d=v[23588];v[23588]=0;if((d|0)==1){break x}}v[23588]=0;k=Q(800,h+256|0,h+224|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break w}yb(h+224|0);if(e){zb(h+208|0)}e=9918;d=w[c|0];if(!_c(d)){e=Kp(d)?10228:16730}v[23588]=0;d=Q(55,h+224|0,e|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break u}v[23588]=0;e=Q(800,h+240|0,d|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break t}yb(d);if(f-6>>>0>4294967290){break l}v[23588]=0;d=Q(55,h+192|0,17790)|0;i=v[23588];v[23588]=0;if((i|0)==1){break s}v[23588]=0;i=Q(800,k|0,d|0)|0;l=v[23588];v[23588]=0;if((l|0)==1){break r}yb(d);v[23588]=0;d=Q(55,h+176|0,17790)|0;l=v[23588];v[23588]=0;if((l|0)==1){break q}v[23588]=0;l=Q(800,e|0,d|0)|0;j=v[23588];v[23588]=0;if((j|0)==1){break p}yb(d);d=c+1|0;B:{if(w[c+1|0]){v[23588]=0;R(544,h+160|0,d|0);j=v[23588];v[23588]=0;if((j|0)!=1){break B}break d}v[23588]=0;Q(55,h+160|0,16735)|0;j=v[23588];v[23588]=0;if((j|0)==1){break d}}v[23588]=0;j=Q(800,i|0,h+160|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break o}i=h+160|0;yb(i);d=w[d|0];v[23588]=0;d=Q(55,i|0,(d?10722:16735)|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break n}v[23588]=0;l=Q(800,l|0,d|0)|0;i=v[23588];v[23588]=0;if((i|0)!=1){break m}f=P()|0;O()|0;yb(d);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;yb(h+224|0);if(!e){break c}}zb(h+208|0);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;yb(d);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;yb(d);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;yb(d);break c}f=P()|0;O()|0;yb(h+160|0);break c}f=P()|0;O()|0;break c}yb(d);if(f-9>>>0>4294967287){break l}C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{i=fh(w[c|0]);O:{if(i){v[23588]=0;m=Q(55,h+128|0,17790)|0;d=v[23588];v[23588]=0;if((d|0)==1){break N}d=w[c+4|0];n=w[c+2|0];v[23588]=0;o=h,p=gk(n,d)&255,v[o+96>>2]=p;R(543,h+112|0,h+96|0);d=v[23588];v[23588]=0;if((d|0)==1){break M}d=0;v[23588]=0;U(971,h+144|0,m|0,h+112|0);m=v[23588];v[23588]=0;if((m|0)!=1){break O}f=P()|0;O()|0;break G}d=w[c+2|0];if(d){d=ZL(v[v[v[b+24>>2]+8>>2]+88>>2],d);v[23588]=0;d=W(527,h+128|0,1,d|0)|0;m=v[23588];v[23588]=0;if((m|0)==1){break E}v[23588]=0;R(544,h+112|0,c+4|0);m=v[23588];v[23588]=0;if((m|0)==1){break L}v[23588]=0;U(971,h+144|0,d|0,h+112|0);m=v[23588];v[23588]=0;d=1;if((m|0)!=1){break O}f=P()|0;O()|0;break J}d=0;v[23588]=0;Q(55,h+144|0,16734)|0;m=v[23588];v[23588]=0;if((m|0)==1){break e}}v[23588]=0;j=Q(800,j|0,h+144|0)|0;m=v[23588];v[23588]=0;if((m|0)==1){break K}yb(h+144|0);if(d){yb(h+112|0);yb(h+128|0)}if(i){yb(h+112|0);yb(h+128|0)}d=5491;if(!fh(w[c|0])){d=w[c+2|0]?5487:16734}v[23588]=0;d=Q(55,h+144|0,d|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break D}v[23588]=0;i=Q(800,l|0,d|0)|0;l=v[23588];v[23588]=0;if((l|0)!=1){break C}f=P()|0;O()|0;yb(d);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break F}f=P()|0;O()|0;break I}f=P()|0;O()|0;yb(h+144|0);if(!d){break H}}yb(h+112|0)}yb(h+128|0)}if(!i){break c}}yb(h+112|0)}yb(h+128|0);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}yb(d);if(f-13>>>0>4294967283){break l}v[23588]=0;d=Q(55,h+96|0,17790)|0;l=v[23588];v[23588]=0;P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{if((l|0)!=1){v[23588]=0;l=Q(800,j|0,d|0)|0;j=v[23588];v[23588]=0;if((j|0)==1){break Z}yb(d);v[23588]=0;d=Q(55,h+80|0,17790)|0;j=v[23588];v[23588]=0;if((j|0)==1){break Y}v[23588]=0;i=Q(800,i|0,d|0)|0;j=v[23588];v[23588]=0;if((j|0)==1){break X}yb(d);_:{if(fh(w[c|0])){d=w[c+5|0];j=w[c+3|0];b=0;v[23588]=0;o=h,p=gk(j,d)&4095,v[o+16>>2]=p;R(1087,h- -64|0,h+16|0);d=v[23588];v[23588]=0;if((d|0)!=1){break _}f=P()|0;O()|0;break c}d=w[c+3|0];if(d){b=YL(v[v[v[b+24>>2]+8>>2]+84>>2],d);v[23588]=0;b=W(527,h+48|0,1,b|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break W}v[23588]=0;R(544,h+32|0,c+5|0);d=v[23588];v[23588]=0;if((d|0)==1){break V}v[23588]=0;U(971,h- -64|0,b|0,h+32|0);d=v[23588];v[23588]=0;b=1;if((d|0)!=1){break _}f=P()|0;O()|0;break S}b=0;v[23588]=0;Q(55,h- -64|0,16730)|0;d=v[23588];v[23588]=0;if((d|0)==1){break U}}v[23588]=0;Q(800,l|0,h- -64|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break T}yb(h- -64|0);if(b){yb(h+32|0);yb(h+48|0)}b=11086;if(!fh(w[c|0])){b=w[c+3|0]?11086:16730}v[23588]=0;b=Q(55,h- -64|0,b|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break Q}v[23588]=0;Q(800,i|0,b|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break P}f=P()|0;O()|0;yb(b);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;yb(d);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;yb(d);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break R}f=P()|0;O()|0;break c}f=P()|0;O()|0;yb(h- -64|0);if(!b){break c}}yb(h+32|0)}yb(h+48|0);break c}f=P()|0;O()|0;break c}yb(b);if(!f){break k}}$:{aa:{ba:{ca:{b=Gb(k);da:{if(b>>>0>f>>>0){v[23588]=0;X(130,h+16|0,k|0,0,f|0);b=v[23588];v[23588]=0;if((b|0)!=1){b=h+16|0;Ac(k,b);yb(b);break da}f=P()|0;O()|0;break c}if(!g){break da}v[23588]=0;b=W(527,h+16|0,f-b|0,32)|0;c=v[23588];v[23588]=0;if((c|0)==1){break ca}v[23588]=0;Q(800,k|0,b|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break ba}yb(b)}b=Gb(e);if(b>>>0<=f>>>0){break $}v[23588]=0;X(130,h|0,e|0,0,f|0);b=v[23588];v[23588]=0;if((b|0)==1){break aa}Ac(e,h);yb(h);break k}f=P()|0;O()|0;break c}f=P()|0;O()|0;yb(b);break c}f=P()|0;O()|0;break c}if(!g){break k}v[23588]=0;b=W(527,h|0,f-b|0,32)|0;c=v[23588];v[23588]=0;if((c|0)==1){break h}v[23588]=0;Q(800,e|0,b|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break g}yb(b)}v[23588]=0;U(1085,a|0,k|0,e|0);a=v[23588];v[23588]=0;if((a|0)==1){break f}}yb(h+240|0);yb(h+256|0);jb=h+272|0;return}f=P()|0;O()|0;break c}f=P()|0;O()|0;yb(b);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0}yb(h+240|0)}yb(h+256|0);T(f|0);L()}function Tfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;d=jb-304|0;jb=d;yc(b);a:{b:{c:{d:{if(!Vt(b,d+208|0)){break d}if(!yR(d+208|0)){break d}if(!Pb(v[b>>2],v[b+8>>2],Dc(xR(d+208|0),mb))){break d}if(!c){g=1;break d}if(!cd(b,w[d+212|0])){break d}Ad(a,268435456);$f(a);v[a+480208>>2]=4;Nb(a+1074312|0,114,1);f=d+88|0;i=xc(f,15278);Ib(a+1298344|0,i);zb(i);i=xc(f,10232);Ib(a+1298356|0,i);zb(i);v[a+1298404>>2]=5;i=d+16|0;pf(i,d+208|6,48,3);Ec(f,i);Ac(a+1298308|0,f);yb(f);f=w[d+262|0];u[a+480188>>1]=f+1;v[a+480228>>2]=w[d+265|0];v[a+480204>>2]=B(w[d+266|0],1e4);v[a+480196>>2]=w[d+267|0];while(1){if((e|0)==(f|0)){e:{u[a+480190>>1]=w[d+300|0];f=x[d+302>>1];i=d+192|0;v[i>>2]=0;v[i+4>>2]=0;Gc(i+8|0);if(f){Ak(i,f);DA(i,f)}v[23588]=0;U(631,b|0,i|0,x[d+302>>1]);f=v[23588];v[23588]=0;if((f|0)==1){break b}z=Sb(d+176|0);r=Sb(d+160|0);v[23588]=0;W(409,b|0,z|0,w[d+301|0])|0;f=v[23588];v[23588]=0;if((f|0)==1){break c}v[23588]=0;W(409,b|0,r|0,w[d+300|0])|0;f=v[23588];v[23588]=0;if((f|0)==1){break c}p=c&2;s=d+126|0;n=d+88|6;f=0;f:{while(1){e=f;if(e>>>0>=w[d+300|0]){g=1;if(!(c&1)){break e}v[d+68>>2]=0;q=a+484376|0;Kc(Vb(v[a+484360>>2],w[q|0]));F=d,G=Eb(v[i>>2]),v[F+64>>2]=G;y=a+484344|0;C=Eb(v[i+4>>2]);D=a+484348|0;break f}v[23588]=0;f=e+1|0;h=B(f,104)+a|0;k=h+484380|0;R(277,k|0,0);g=v[23588];v[23588]=0;g:{if((g|0)!=1){g=Db(v[r>>2],e);g=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);if(!g){continue}v[23588]=0;g=Q(155,b|0,g|0)|0;j=v[23588];v[23588]=0;h:{if((j|0)==1){break h}if(!g){continue}v[23588]=0;g=Q(632,b|0,d+88|0)|0;j=v[23588];v[23588]=0;if((j|0)==1){break h}if(!g){continue}g=d+72|0;Me(g,2,n);v[23588]=0;R(222,d+16|0,g|0);g=v[23588];v[23588]=0;if((g|0)==1){break c}g=d+16|0;Cc(((f<<5)+a|0)+946304|0,g);yb(g);j=d+72|0;tk(j,2,s);v[23588]=0;R(222,g|0,j|0);g=v[23588];v[23588]=0;if((g|0)==1){break c}g=d+16|0;Be(h+484423|0,g);yb(g);g=w[d+138|0];if(g>>>0<=15){u[h+484408>>1]=B(g,17);g=h+484414|0;u[g>>1]=x[g>>1]|32}t[d+16|0]=w[d+139|0];t[d+72|0]=64;F=h+484412|0,G=w[Wb(d+16|0,d+72|0)|0],u[F>>1]=G;v[h+484404>>2]=w[d+141|0]|w[d+142|0]<<8;m=h+484384|0;g=w[d+147|0]|w[d+148|0]<<8|(w[d+149|0]<<16|w[d+150|0]<<24);v[m>>2]=g;q=h+484388|0;j=w[d+151|0]|w[d+152|0]<<8|(w[d+153|0]<<16|w[d+154|0]<<24);v[q>>2]=j;y=w[d+155|0]|w[d+156|0]<<8|(w[d+157|0]<<16|w[d+158|0]<<24);v[k>>2]=y;l=w[d+140|0];if(l&1){g=g>>>1|0;v[m>>2]=g;j=j>>>1|0;v[q>>2]=j;v[k>>2]=y>>>1}i:{if(g>>>0>=j>>>0){break i}h=h+484414|0;g=x[h>>1];u[h>>1]=g|2;if(!(l&2)){break i}u[h>>1]=g|6}Ck(k);if(!p){continue}e=Db(v[r>>2],e);e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);v[23588]=0;Q(155,b|0,e+w[d+92|0]|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){break g}}break c}break c}e=Zc(d+16|0,t[d+140|0]&1?16:8,1,0,1);v[23588]=0;W(219,e|0,k|0,b|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){continue}break}break c}while(1){j:{k:{k=v[d+64>>2];if(!Ob(k,C)){b=v[d+68>>2];c=b&63;if(!c){break k}f=w[a+484376|0];e=v[a+484360>>2];v[23588]=0;b=b>>>6|0;f=Q(311,Vb(e,f)|0,b&65535)|0;e=v[23588];v[23588]=0;if((e|0)!=1){if(!f){break k}b=x[cc(v[Vb(v[a+484360>>2],w[a+484376|0])>>2],b&65535)>>1];f=v[a+484344>>2];v[23588]=0;R(633,Yb(f,b)|0,c|0);b=v[23588];v[23588]=0;if((b|0)!=1){break k}}break c}c=w[k+3|0];if(w[k+2|0]>w[d+262|0]|c>>>0>=w[d+301|0]){break j}c=Db(v[z>>2],c);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[23588]=0;c=Q(155,b|0,c|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break c}if(!c){break j}v[23588]=0;R(634,b|0,d+88|0);c=v[23588];v[23588]=0;if((c|0)==1){break c}e=w[d+92|0];if(!e){break j}f=w[k|0]|w[k+1|0]<<8;t[d+16|0]=w[d+93|0];t[d+72|0]=w[d+262|0]-w[k+2|0];j=w[Wb(d+16|0,d+72|0)|0];v[d+60>>2]=e+f;F=d,G=v[Yc(d+68|0,d+60|0)>>2],v[F+68>>2]=G;v[d+40>>2]=0;v[d+44>>2]=0;v[d+32>>2]=0;v[d+36>>2]=0;v[d+24>>2]=0;v[d+28>>2]=0;v[d+16>>2]=0;v[d+20>>2]=0;c=f&63;p=f>>>6|0;s=0;while(1){if((e&255)>>>0<=s>>>0){break j}e=Vb(v[a+484360>>2],w[q|0]);h=c>>>0>63;p=h+p|0;f=p&65535;if(Qc(v[e>>2],v[e+4>>2])>>>0<=f>>>0){v[23588]=0;R(324,e|0,p+1&65535);e=v[23588];v[23588]=0;if((e|0)==1){break c}v[23588]=0;n=Q(359,y|0,64)|0;e=v[23588];v[23588]=0;if((e|0)==1){break c}e=Vb(v[a+484360>>2],w[q|0]);F=cc(v[e>>2],f),G=n,u[F>>1]=G}m=v[a+484344>>2];o=v[D>>2];n=x[cc(v[e>>2],f)>>1];if(!xe(m,o,n)){break j}f=0;e=Yb(m,n);m=h?0:c;e=id(v[e>>2],v[v[e+48>>2]+12>>2],m,w[k+2|0]);l:{while(1){if((f|0)==(j|0)){c=w[d+93|0];if(c>>>0<=j>>>0){break l}v[23588]=0;Q(188,b|0,B(c-j|0,5)|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break l}break c}v[23588]=0;R(635,d+72|0,b|0);c=v[23588];v[23588]=0;if((c|0)!=1){c=d+72|0;h=Nc(c);E=Se(c);l=Li(c);o=ic(c);c=w[d+72|0];A=c-1&255;m:{if(A>>>0<=142){c=(B((c&240)>>>4|0,12)+(c&15)|0)+13|0;t[e|0]=c;t[(d+16|0)+f|0]=c;break m}t[e|0]=0}c=w[h|0];t[e+2|0]=1;t[e+1|0]=c;c=w[E|0];n:{if((c|0)!=255){t[e+4|0]=c;break n}t[e+2|0]=0}c=w[l|0];o:{if(c>>>0>22){break o}t[e+3|0]=w[c+26992|0];h=w[o|0];t[e+5|0]=h;c=e+5|0;p:{switch(w[l|0]-4|0){case 3:t[c|0]=h&3|64;break o;case 4:t[c|0]=h&3|48;break o;case 7:l=v[i>>2];if(uc(l,v[i+4>>2])>>>0<=h>>>0){break o}o=c;c=Db(l,h);c=w[c|0]|w[c+1|0]<<8;t[o|0]=c>>>6;h=Yb(v[a+484344>>2],n);h=id(v[h>>2],v[v[h+48>>2]+12>>2],m,x[a+480188>>1]-1&65535);t[h+5|0]=c&63;t[h+3|0]=14;break o;case 8:o=c;c=v[d+60>>2];t[o|0]=c>>>6;h=Yb(v[a+484344>>2],n);h=id(v[h>>2],v[v[h+48>>2]+12>>2],m,x[a+480188>>1]-1&65535);t[h+5|0]=c&63;t[h+3|0]=14;break o;case 10:t[c|0]=h&15|128;break o;case 12:t[d+15|0]=15;F=c,G=w[Wb(c,d+15|0)|0]|208,t[F|0]=G;break o;case 13:t[d+15|0]=15;F=c,G=w[Wb(c,d+15|0)|0]|192,t[F|0]=G;break o;case 14:t[d+15|0]=15;F=c,G=w[Wb(c,d+15|0)|0]|224,t[F|0]=G;break o;case 0:case 16:case 17:if(!(h&15)){break o}l=h&240;if(!l|(l|0)==240){break o}t[c|0]=h|15;break o;case 9:case 18:break p;default:break o}}if(A>>>0<143){break o}t[e|0]=w[(d+16|0)+f|0]}e=e+6|0;f=f+1|0;continue}break}break c}c=m+1|0;s=s+1|0;e=w[d+92|0];continue}}a=Vb(v[a+484360>>2],w[a+484376|0]);F=d,G=Eb(v[a>>2]),v[F+88>>2]=G;b=Eb(v[a+4>>2]);c=65535;while(1){a=v[d+88>>2];if(!Ob(a,b)){break e}if(x[a>>1]==65535){q:{if((c&65535)!=65535){break q}v[23588]=0;c=Q(359,y|0,64)|0;f=v[23588];v[23588]=0;if((f|0)!=1){break q}break c}u[a>>1]=c}Re(d+88|0);continue}}Ke(d- -64|0);continue}}}else{u[((e<<5)+a|0)+480284>>1]=B(w[(d+e|0)+268|0],17);e=e+1|0;continue}break}vc(r);vc(z);vc(i)}jb=d+304|0;return g|0}a=P()|0;O()|0;vc(r);vc(z);break a}a=P()|0;O()|0}vc(i);T(a|0);L()}function LN(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=C(0),r=0,s=0,A=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=C(0),S=C(0),T=0,U=0,V=0,W=C(0),X=0;m=jb-48|0;jb=m;t[m+40|0]=0;h=b+223848|0;j=m+40|0;Ri(h,Rh(e,wi(e,fo(e),j))+1|0);re(j,v[h>>2],v[b+223852>>2]);h=jb-16|0;jb=h;t[h+15|0]=0;gc(m+32|0,e,Rh(e,wi(e,fo(e),h+15|0)));jb=h+16|0;G=v[m+32>>2];H=v[m+36>>2];i=jb-16|0;jb=i;I=a+906300|0;s=a+1074312|0;n=B(c,872)+b|0;J=n+1415|0;K=n+1304|0;L=n+1392|0;D=n+1368|0;E=n+1364|0;M=n+1336|0;N=n+1308|0;O=n+1300|0;P=n+1280|0;Q=n+1402|0;p=n+1466|0;R=C(w[p|0]);S=C(f>>>0);F=n+616|0;l=v[n+1272>>2];T=a+480188|0;k=1;r=255;while(1){if((o|0)!=(H|0)&y[j+4>>2]>g>>>0){e=w[Kb(G,o)|0];h=e-48|0;a:{b:{c:{if((h&255)>>>0<=9){break c}if((e-65&255)>>>0<=5){h=e-55|0;break c}d:{e:{f:{switch(e-97|0){case 2:g:{e=Ol(a,b,c,3,0)-1|0;if((e&255)>>>0>249){break g}e=v[Ld(I,e)>>2];if(!e){break g}e=Ky(e,47496,44552);if(!e){break g}h=nb[v[v[e>>2]+192>>2]](e,F,c)|0;e=(h|0)!=255;h=e?h:0;if(e|!l){break c}break d}if(l){break d}h=0;break c;case 21:Cb(i+8|0,s,28);h:{if(!Bb(v[v[i+8>>2]>>2],v[i+12>>2])){Cb(i,s,1);e=0;if(!Bb(v[v[i>>2]>>2],v[i+4>>2])){break h}}e=u[L>>1]}h=B(v[D>>2],v[E>>2]);e=B(v[a+1074456>>2],e+v[K>>2]|0);e=Xb((Hc(Mka(Lka(h,h>>31,e,e>>31),mb,1048576,0),mb)|0)/2|0,1,127);break e;case 20:e=B(v[D>>2],v[E>>2]);h=e;A=e>>31;e=B(v[a+1074456>>2],v[M>>2]);e=Xb((Hc(Mka(Lka(h,A,e,e>>31),mb,67108864,0),mb)|0)/2|0,1,127);break e;case 23:v[i+8>>2]=v[N>>2]/2;v[i>>2]=127;e=v[sd(i+8|0,i)>>2];break e;case 24:v[i+8>>2]=v[O>>2]/2;v[i>>2]=127;e=v[sd(i+8|0,i)>>2];break e;case 0:e=0;if(!l){break e}h=x[l+28>>1];if(!h){break e}e=h-1>>>7&127;break e;case 1:e=0;if(!l){break e}h=x[l+28>>1];if(!h){break e}e=h-1&127;break e;case 14:e=v[P>>2]>>>8|0;break e;case 7:e=(x[T>>1]<=c>>>0?w[Q|0]-1|0:c)&127;break e;case 12:e=w[n+704|0]>>>7|0;break e;case 15:e=0;if(!l){break e}h=w[l+30|0];if(!h){break e}e=h-1&127;break e;case 25:i:{if(!d|t[p|0]<0){break i}j:{if(g>>>0<3){break j}e=v[j>>2];if(w[Kb(e,g-3|0)|0]!=240){break j}if(w[Kb(e,g-2|0)|0]>239){break i}}q=Qp(b,R,S);k:{if(q<C(4294967296)&q>=C(0)){e=~~q>>>0;break k}e=0}t[p|0]=e;r=128;break e}r=(r&255)==255?f:r;e=f;break e;case 18:l:{if(!g){h=0;break l}e=v[j>>2];h=g;while(1){h=h-1|0;A=Kb(e,h);if(!h){break l}if(w[A|0]!=240){continue}break}}if(g-h>>>0<5){break a}A=v[j>>2];if(w[Kb(A,h)|0]!=240){break a}h=h+5|0;e=0;while(1){if((g|0)!=(h|0)){e=w[Kb(A,h)|0]+e|0;h=h+1|0;continue}break};e=0-e&127;break e;case 13:break f;default:break a}}e=w[J|0];e=_c(e)?e-1|0:0}h=((k^-1)&1)+g|0;U=Kb(v[j>>2],h),V=e,t[U|0]=V;g=h+1|0;k=1;break b}e=x[F+786>>1];h=(e?e-1|0:c)&15;e=w[l+31|0];if((e|0)!=17){h=uj(e)?e-1&15:0}}e=Kb(v[j>>2],g);m:{if(k){t[e|0]=h;break m}t[e|0]=w[e|0]<<4|h;g=g+1|0}k=(k^-1)&1}}o=o+1|0;continue}else{if(r<<24>>24>=0){t[p|0]=r}fc(i+8|0,v[j>>2],((k^-1)&1)+g|0);e=v[i+12>>2];v[j>>2]=v[i+8>>2];v[j+4>>2]=e;jb=i+16|0}break}p=v[m+44>>2];h=0;n:while(1){n=0;while(1){e=h;o:{p:{q:{r:{while(1){if(y[m+44>>2]<=e>>>0){break o}f=v[m+40>>2];k=Kb(f,e);g=t[k|0];if((g|0)==-16){g=e;if(p-g>>>0>=4){h=4;if((w[Kb(f,e+1|0)|0]&254)==240){break p}}s:{while(1){g=g+1|0;if(p>>>0<=g>>>0){break s}if(w[Kb(f,g)|0]!=247){continue}break}h=(g-e|0)+1|0;if(h){break p}}U=Kb(f,p),V=247,t[U|0]=V;p=p+1|0;h=p-e|0;break q}if((g|0)<0){break r}if(n&255){e=e-1|0;U=Kb(f,e),V=n,t[U|0]=V;continue}break}h=h+1|0;continue n}U=m,V=LP(g&255),v[U+16>>2]=V;v[m+28>>2]=p-e;h=v[Jb(m+16|0,m+28|0)>>2]}if(!h){break o}f=v[m+40>>2];k=Kb(f,e)}r=w[k|0];Bq(m+16|0,f,v[m+44>>2],e,h);f=gc(m+8|0,v[m+16>>2],v[m+20>>2]);g=v[f+4>>2];v[m>>2]=v[f>>2];v[m+4>>2]=g;k=jb-32|0;jb=k;i=v[m+4>>2];t:{if(!i){break t}j=Pd(w[b+223884|0]);u:{f=v[m>>2];l=Kb(f,0);g=w[l|0]-250|0;if(g>>>0>5|!(1<<g&37)){break u}o=x[a+480188>>1];g=0;while(1){if((g|0)==(o|0)){break u}s=(B(g,872)+b|0)+1453|0;t[s|0]=127;t[s+1|0]=0;g=g+1|0;continue}}v:{if((i|0)!=4|w[l|0]!=240){break v}g=w[Kb(f,1)|0];if((g&254)!=240){break v}i=(B(c,872)+b|0)+616|0;l=Kb(f,2);o=w[Kb(f,3)|0];f=o<<24>>24;w:{x:{y:{z:{A:{B:{l=w[l|0];switch(l|0){case 3:break y;case 2:break z;case 1:break A;case 0:break B;default:break x}}if((g|0)==241|(f|0)<0){break x}g=B(c,872)+b|0;l=g+1453|0;if(d){f=jh(Qp(b,C(w[l|0]),C((f&255)>>>0)))}t[l|0]=f;t[g+1412|0]=0;f=Vp(a,i,!(v[g+704>>2]&32768),256);if((f|0)<0|!(w[g+705|0]&2)){break t}g=v[a+1298300>>2];if(j|Ed(g)^1){break t}_p(g,c,f>>>2&255,1);break t}if((g|0)==241|(f|0)<0){break x}g=B(c,872)+b|0;j=g+1454|0;if(d){f=jh(Qp(b,C(w[j|0]),C((f&255)>>>0)))}t[j|0]=f;t[g+1411|0]=0;Vp(a,i,!(v[g+704>>2]&32768),256);break t}if((g|0)==241){break w}if(f>>>0>31){break t}g=B(c,872)+b|0;t[g+1461|0]=(f&240)>>>4;Vp(a,i,!(v[g+704>>2]&32768),256);break t}if((g|0)==241){break w}g=(f|0)<0;f=Ol(a,b,c,3,0)-1|0;if(g|(f&255)>>>0>249){break t}t[k+24|0]=f;g=Ld(a+906300|0,f&255);f=v[g>>2];if(!f){break t}q=C(C(127-o|0)/C(127));if(j){j=0;i=jb-16|0;jb=i;U=i,V=zj(k+24|0),v[U>>2]=V;f=jb-16|0;jb=f;l=b+223860|0;o=Jy(l,f+12|0,w[k+24|0]);g=v[o>>2];if(!g){g=jb-16|0;jb=g;j=ic(l);s=lh(f,sc(24),mh(g+8|0,j));j=v[s>>2];D=w[v[i>>2]];v[j+20>>2]=0;t[j+16|0]=D;U=ic(s),V=1,t[U+4|0]=V;jb=g+16|0;Jg(l,v[f+12>>2],o,v[f>>2]);g=be(f);qk(f);j=1}Ig(i+8|0,v[ec(f,g)>>2],j);jb=f+16|0;f=vd(v[i+8>>2]);jb=i+16|0;z[f+4>>2]=q;break t}if(!d){et(v[f+20>>2],q);break t}et(v[f+20>>2],Qp(b,z[g+144>>2],q));break t}if(l&128){break w}if((g|0)!=241){break t}}o=Ol(a,b,c,3,0)-1|0;if((f|0)<0|(o&255)>>>0>249){break t}i=v[Ld(a+906300|0,o&255)>>2];if(!i){break t}g=(g|0)==241?l+128|0:l&127;q=C(C((f&255)>>>0)/C(127));if(j){U=$N(b+223872|0,pN(k+24|0,o,g)),W=q,z[U>>2]=W;break t}f=v[i>>2];if(!d){nb[v[f+44>>2]](i,g,q);break t}V=i,X=g,W=Qp(b,C(nb[v[f+48>>2]](i,g)),q),U=v[v[i>>2]+44>>2],nb[U](V|0,X|0,C(W));break t}if(j){break t}j=x[a+480188>>1];C:{if(j>>>0>c>>>0){g=c+1|0;break C}g=x[(B(c,872)+b|0)+1402>>1];if(!g){break t}}if(w[(B(c,872)+b|0)+707|0]&4|j>>>0<(g&65535)>>>0){break t}g=Ol(a,b,c,3,0)-1|0;if((g&255)>>>0>249){break t}g=v[Ld(a+906300|0,g)>>2];if(!g){break t}j=w[l|0];if((j|0)==240){_g(k+16|0,v[m>>2],v[m+4>>2]);f=v[v[g>>2]+72>>2];i=v[k+20>>2];v[k>>2]=v[k+16>>2];v[k+4>>2]=i;nb[f|0](g,k)|0;break t}U=k,X=LP(j),v[U+24>>2]=X;v[k+12>>2]=i;i=k+24|0;j=v[Jb(i,k+12|0)>>2];v[k+24>>2]=0;tc(i,f,j);nb[v[v[g>>2]+68>>2]](g,v[k+24>>2])|0}jb=k+32|0;n=r>>>0<240?r:n;h=e+h|0;continue}break}break}jb=m+48|0}function b$(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0,C=0;l=jb-560|0;jb=l;v[l+548>>2]=k;v[l+552>>2]=b;a:{b:{c:{d:{if(_j(a,l+552|0)){v[f>>2]=v[f>>2]|4;a=0;break d}v[l+96>>2]=1158;b=l+96|0;s=se(l+136|0,l+144|0,b);m=v[s>>2];v[l+132>>2]=m;v[l+128>>2]=m+400;y=Lb(b);o=Lb(l+80|0);q=Lb(l- -64|0);p=Lb(l+48|0);u=Lb(l+32|0);v[23588]=0;na(1167,c|0,d|0,l+120|0,l+116|0,l+112|0,y|0,o|0,q|0,p|0,l+28|0);b=v[23588];v[23588]=0;if((b|0)!=1){v[j>>2]=v[i>>2];z=e&512;A=z>>>9|0;k=v[l+28>>2];e=0;while(1){e:{f:{g:{h:{i:{j:{k:{l:{if((e|0)==4){break l}v[23588]=0;b=Q(1141,a|0,l+552|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break c}if(!b){break l}m:{n:{o:{p:{q:{switch(t[(l+120|0)+e|0]){case 1:if((e|0)==3){break e}b=v[a>>2];v[23588]=0;b=S(1143,b|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break c}v[23588]=0;b=W(1168,h|0,1,b|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break c}if(b){v[23588]=0;R(1169,l+16|0,a|0);b=v[23588];v[23588]=0;if((b|0)!=1){v[23588]=0;R(49,u|0,v[l+16>>2]);b=v[23588];v[23588]=0;if((b|0)!=1){break p}}a=P()|0;O()|0;break a}v[f>>2]=v[f>>2]|4;a=0;break i;case 4:break m;case 2:break n;case 3:break o;case 0:break q;default:break e}}if((e|0)==3){break e}}while(1){v[23588]=0;b=Q(1141,a|0,l+552|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break b}if(!b){break e}b=v[a>>2];v[23588]=0;b=S(1143,b|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break b}v[23588]=0;b=W(1168,h|0,1,b|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break b}if(!b){break e}v[23588]=0;R(1169,l+16|0,a|0);b=v[23588];v[23588]=0;if((b|0)!=1){v[23588]=0;R(49,u|0,v[l+16>>2]);b=v[23588];v[23588]=0;if((b|0)!=1){continue}}break}a=P()|0;O()|0;break a}r:{if(!Gb(q)){break r}b=v[a>>2];v[23588]=0;b=S(1143,b|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break c}if((b|0)!=v[zc(q)>>2]){break r}v[23588]=0;S(1145,a|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break c}t[g|0]=0;r=Gb(q)>>>0>1?q:r;break e}s:{if(!Gb(p)){break s}b=v[a>>2];v[23588]=0;b=S(1143,b|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break c}if((b|0)!=v[zc(p)>>2]){break s}v[23588]=0;S(1145,a|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break c}t[g|0]=1;r=Gb(p)>>>0>1?p:r;break e}c=Gb(q);b=Gb(p);t:{if(c){if(!b){break t}v[l+28>>2]=k;v[f>>2]=v[f>>2]|4;a=0;break i}if(!b){break e}}B=g,C=!Gb(p),t[B|0]=C;break e}if(!(e>>>0<2|r|((e|0)==2&w[l+123|0]!=0|A))){r=0;break e}c=ec(l+16|0,he(o));u:{v:{if(!e|w[(e+l|0)+119|0]>1){break v}while(1){w:{b=Tk(o);d=v[c>>2];if(!Ob(d,b)){break w}b=v[d>>2];v[23588]=0;b=W(1168,h|0,1,b|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break u}if(!b){break w}Ke(c);continue}break}b=he(o);b=bu(v[c>>2],b);if(Gb(u)>>>0>=b>>>0){d=ym(Tk(u),0-b|0);n=Tk(u);x=he(o);b=jb-16|0;jb=b;v[b>>2]=x;v[b+8>>2]=d;while(1){x:{x=Ob(d,n);if(!x){break x}if(!oc(v[d>>2],v[v[b>>2]>>2])){break x}d=Ke(b+8|0);Ke(b);d=v[d>>2];continue}break}jb=b+16|0;if(x^1){break v}}B=c,C=v[ec(l+8|0,he(o))>>2],v[B>>2]=C}v[l+8>>2]=v[c>>2];y:{while(1){b=Tk(o);if(!Ob(v[l+8>>2],b)){break y}v[23588]=0;b=Q(1141,a|0,l+552|0)|0;c=v[23588];v[23588]=0;z:{if((c|0)==1){break z}if(!b){break y}b=v[a>>2];v[23588]=0;b=S(1143,b|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break z}if((b|0)!=v[v[l+8>>2]>>2]){break y}v[23588]=0;S(1145,a|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break f}Ke(l+8|0);continue}break}break f}if(!z){break e}b=Tk(o);if(!Ob(v[l+8>>2],b)){break e}v[l+28>>2]=k;v[f>>2]=v[f>>2]|4;a=0;break i}break f}b=0;n=v[l+112>>2];A:{while(1){B:{v[23588]=0;c=Q(1141,a|0,l+552|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break B}if(!c){break A}c=v[a>>2];v[23588]=0;c=S(1143,c|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break h}v[23588]=0;d=W(1168,h|0,64,c|0)|0;x=v[23588];v[23588]=0;if((x|0)==1){break h}C:{if(d){d=v[j>>2];if((d|0)==v[l+548>>2]){v[23588]=0;U(1170,i|0,j|0,l+548|0);d=v[23588];v[23588]=0;if((d|0)==1){break h}d=v[j>>2]}v[j>>2]=d+4;v[d>>2]=c;b=b+1|0;break C}if(!Gb(y)|!b|(c|0)!=(n|0)){break A}if(v[l+128>>2]==(m|0)){v[23588]=0;U(1164,s|0,l+132|0,l+128|0);c=v[23588];v[23588]=0;if((c|0)==1){break h}m=v[l+132>>2]}c=m+4|0;v[l+132>>2]=c;v[m>>2]=b;m=c;b=0}v[23588]=0;S(1145,a|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){continue}}break}a=P()|0;O()|0;break a}if(!b|v[s>>2]==(m|0)){break k}if(v[l+128>>2]==(m|0)){v[23588]=0;U(1164,s|0,l+132|0,l+128|0);c=v[23588];v[23588]=0;if((c|0)==1){break g}m=v[l+132>>2]}c=m+4|0;v[l+132>>2]=c;v[m>>2]=b;break j}v[l+28>>2]=k;D:{if(!r){break D}k=1;while(1){if(Gb(r)>>>0<=k>>>0){break D}v[23588]=0;b=Q(1142,a|0,l+552|0)|0;c=v[23588];v[23588]=0;E:{if((c|0)==1){break E}F:{if(!b){b=v[a>>2];v[23588]=0;b=S(1143,b|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break E}if((b|0)==v[zi(r,k)>>2]){break F}}v[f>>2]=v[f>>2]|4;a=0;break i}v[23588]=0;S(1145,a|0)|0;b=v[23588];v[23588]=0;k=k+1|0;if((b|0)!=1){continue}}break}a=P()|0;O()|0;break a}a=1;b=v[s>>2];if((b|0)==(m|0)){break i}a=0;v[l+16>>2]=0;Ff(y,b,m,l+16|0);if(v[l+16>>2]){v[f>>2]=v[f>>2]|4;break i}a=1;break i}c=m}G:{if((k|0)<=0){break G}v[23588]=0;b=Q(1142,a|0,l+552|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break g}H:{if(!b){b=v[a>>2];v[23588]=0;b=S(1143,b|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break g}if((b|0)==v[l+116>>2]){break H}}v[l+28>>2]=k;v[f>>2]=v[f>>2]|4;a=0;break i}v[23588]=0;d=S(1145,a|0)|0;m=v[23588];v[23588]=0;b=k;if((m|0)==1){break g}while(1){if((b|0)<=0){k=0;break G}v[23588]=0;m=Q(1142,d|0,l+552|0)|0;n=v[23588];v[23588]=0;I:{if((n|0)==1){break I}J:{if(!m){m=v[d>>2];v[23588]=0;m=S(1143,m|0)|0;n=v[23588];v[23588]=0;if((n|0)==1){break I}v[23588]=0;m=W(1168,h|0,64,m|0)|0;n=v[23588];v[23588]=0;if((n|0)==1){break I}if(m){break J}}v[l+28>>2]=b;v[f>>2]=v[f>>2]|4;a=0;break i}if(v[j>>2]==v[l+548>>2]){v[23588]=0;U(1170,i|0,j|0,l+548|0);m=v[23588];v[23588]=0;if((m|0)==1){break I}}m=v[d>>2];v[23588]=0;m=S(1143,m|0)|0;n=v[23588];v[23588]=0;if((n|0)==1){break I}n=v[j>>2];v[j>>2]=n+4;v[n>>2]=m;v[23588]=0;S(1145,d|0)|0;m=v[23588];v[23588]=0;b=b-1|0;if((m|0)!=1){continue}}break}break f}if(v[j>>2]!=v[i>>2]){m=c;break e}v[l+28>>2]=k;v[f>>2]=v[f>>2]|4;a=0}Fc(u);Fc(p);Fc(q);Fc(o);yb(y);Wc(s);break d}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;v[l+28>>2]=k;break a}e=e+1|0;continue}}a=P()|0;O()|0;break a}jb=l+560|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0}Fc(u);Fc(p);Fc(q);Fc(o);yb(y);Wc(s);T(a|0);L()}function sW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;e=jb-224|0;jb=e;yc(b);a:{b:{c:{d:{if(!BC(b,e+176|0)){break d}if(!EC(e+176|0)){break d}if(!c){n=1;break d}Ad(a,2048);$f(a);d=jb-16|0;jb=d;f=e+8|0;h=xc(d,3947);$c(f,h);zb(h);jb=d+16|0;v[23588]=0;U(213,e+80|0,f|0,w[e+179|0]);d=v[23588];v[23588]=0;e:{f:{g:{h:{i:{j:{k:{if((d|0)!=1){d=e+80|0;Ib(a+1298344|0,d);zb(d);f=e+8|0;ac(f);h=xc(d,11070);Ib(a+1298356|0,h);zb(h);v[a+1298404>>2]=5;h=a+480188|0;u[h>>1]=w[e+216|0];u[a+480190>>1]=w[e+212|0];Me(f,2,e+176|4);Ec(d,f);Ac(a+1298308|0,d);yb(d);d=w[e+179|0];l:{if(d>>>0>=9){if(d>>>0>=11){f=(d|0)==11?16:32;d=0;while(1){if((d|0)==(f|0)){break l}h=kv(b);m:{if((h|0)==100){v[((d<<5)+a|0)+480280>>2]=256;break m}v[e+80>>2]=(h<<1)+128;v[e+8>>2]=0;v[e+160>>2]=256;s=((d<<5)+a|0)+480284|0,y=v[Ij(e+80|0,e+8|0,e+160|0)>>2],u[s>>1]=y}d=d+1|0;continue}}f=e+80|0;d=jb-16|0;jb=d;n:{if(!Pb(v[b>>2],v[b+8>>2],16)){pC(f);break n}av(d+8|0,f);td(d,b,v[d+8>>2],v[d+12>>2])}jb=d+16|0;d=0;while(1){if((d|0)==16){break l}u[((d<<5)+a|0)+480284>>1]=t[(e+80|0)+d|0]&1?64:192;d=d+1|0;continue}}u[h>>1]=4;yg(b,1);nh(a,1)}o:{if(w[e+179|0]>=13){d=e+80|0;dv(d,b);f=Nc(d);d=w[e+80|0];if(d>>>0<=31){t[e+80|0]=125;d=125}v[a+480204>>2]=B(d,1e4);v[a+480196>>2]=w[f|0];break o}v[a+480196>>2]=6;v[a+480204>>2]=125e4}ug(Vb(v[a+484360>>2],w[a+484376|0]),w[e+213|0]);l=Sb(e+160|0);f=w[e+179|0];q=v[b+8>>2]+((f>>>0>13)<<1)|0;d=0;p:{if(f>>>0<14){break p}v[23588]=0;R(214,l|0,w[e+213|0]);f=v[23588];v[23588]=0;if((f|0)!=1){break p}d=P()|0;O()|0;break b}q:{r:{s:{while(1){t:{if(w[e+213|0]<=d>>>0){d=0;if(w[e+179|0]!=10){break s}m=v[b+8>>2];k=a+480190|0;d=1;while(1){j=x[k>>1];if(j>>>0<(d&65535)>>>0){break t}v[23588]=0;f=Q(215,b|0,e+80|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break r}if(f){f=0;u:{if(w[e+212|0]<(w[e+126|0]|w[e+127|0]<<8|(w[e+128|0]<<16|w[e+129|0]<<24))>>>0|w[e+80|0]>1){break u}h=w[e+130|0]|w[e+131|0]<<8|(w[e+132|0]<<16|w[e+133|0]<<24);if(h>>>0>1048576|w[e+136|0]>64|h>>>0<(w[e+137|0]|w[e+138|0]<<8|(w[e+139|0]<<16|w[e+140|0]<<24))>>>0){break u}f=h>>>0>=(w[e+141|0]|w[e+142|0]<<8|(w[e+143|0]<<16|w[e+144|0]<<24))>>>0}if(!f){break t}}d=d+1|0;continue}}s=cc(v[Vb(v[a+484360>>2],w[a+484376|0])>>2],d),y=d,u[s>>1]=y;if(w[e+179|0]>=14){v[23588]=0;f=S(194,b|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break q}s=cc(v[l>>2],d),y=f,u[s>>1]=y}f=x[a+480188>>1];v[23588]=0;Q(188,b|0,f<<1)|0;f=v[23588];v[23588]=0;if((f|0)==1){break q}d=d+1|0;continue}break}v[23588]=0;Q(155,b|0,m|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break c}d=j>>>0>=(d&65535)>>>0}j=a+480190|0;f=x[j>>1];v[23588]=0;v[e+80>>2]=0;m=W(216,e- -64|0,f|0,e+80|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break k}n=d?59:65;k=e+80|1;f=1;v:{while(1){h=f&65535;if(h>>>0>x[j>>1]){h=Sb(e+48|0);v[23588]=0;n=W(217,b|0,h|0,x[e+214>>1])|0;d=v[23588];v[23588]=0;w:{if((d|0)!=1){if(!n){break e}d=0;k=0;f=v[h>>2];if(!oc(f,v[h+4>>2])){f=Eb(f);g=Eb(v[h+4>>2]);k=jb-16|0;jb=k;x:{if(!Ob(f,g)){break x}v[k+8>>2]=f;while(1){j=v[Re(k+8|0)>>2];if(!Ob(j,g)){break x}f=Dk(w[f|0]|w[f+1|0]<<8,w[j|0]|w[j+1|0]<<8)?j:f;continue}}jb=k+16|0;k=w[f|0]|w[f+1|0]<<8}v[23588]=0;j=Q(218,e+32|0,k|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break w}y:{while(1){if((d|0)==(k|0)){if(!(c&2)){break j}i=Zc(e+80|0,8,1,0,1);o=a+480190|0;f=x[o>>1];g=1;z:{A:while(1){p=g&65535;if(p>>>0>(f&65535)>>>0){break j}d=v[b+8>>2];f=v[b>>2];v[23588]=0;d=W(156,f|0,d|0,1)|0;f=v[23588];v[23588]=0;if((f|0)==1){break z}if(!d){break j}r=v[b+8>>2];d=0;while(1){f=x[o>>1];if(f>>>0<=d>>>0){g=g+1|0;continue A}if((p|0)!=v[Db(v[m>>2],d)>>2]){d=d+1|0;continue}v[23588]=0;Q(155,b|0,r|0)|0;f=v[23588];v[23588]=0;if((f|0)!=1){v[23588]=0;d=d+1|0;W(219,i|0,(B(d,104)+a|0)+484380|0,b|0)|0;f=v[23588];v[23588]=0;if((f|0)!=1){continue}}break}break}d=P()|0;O()|0;break i}d=P()|0;O()|0;break i}v[23588]=0;f=S(194,b|0)|0;g=v[23588];v[23588]=0;B:{if((g|0)==1){break B}v[23588]=0;Q(188,b|0,1)|0;g=v[23588];v[23588]=0;if((g|0)==1){break B}if(f){v[23588]=0;U(190,e+8|0,b|0,B(f,3)+(w[e+179|0]==1?3:0)|0);f=v[23588];v[23588]=0;if((f|0)==1){break y}g=e+8|0;f=jc(e+80|0,g);gd(Og(v[j>>2],d),f);Ab(f);Ab(g)}d=d+1|0;continue}break}d=P()|0;O()|0;break i}d=P()|0;O()|0;break i}d=P()|0;O()|0;break h}d=P()|0;O()|0;break h}C:{D:{if(w[e+179|0]<=9){v[23588]=0;R(220,b|0,e+80|0);g=v[23588];v[23588]=0;E:{F:{if((g|0)==1){break F}v[23588]=0;R(221,e+80|0,(B(h,104)+a|0)+484380|0);g=v[23588];v[23588]=0;if((g|0)==1){break F}g=e+48|0;Me(g,2,k);v[23588]=0;R(222,e+8|0,g|0);g=v[23588];v[23588]=0;if((g|0)==1){break E}break D}d=P()|0;O()|0;break g}d=P()|0;O()|0;break g}v[23588]=0;U(223,b|0,e+80|0,n|0);g=v[23588];v[23588]=0;if((g|0)==1){break C}v[23588]=0;U(224,e+80|0,(B(h,104)+a|0)+484380|0,d|0);g=v[23588];v[23588]=0;if((g|0)==1){break C}g=e+48|0;Me(g,2,k);v[23588]=0;R(222,e+8|0,g|0);g=v[23588];v[23588]=0;if((g|0)==1){break v}}g=e+8|0;Cc(((h<<5)+a|0)+946304|0,g);yb(g);s=Db(v[m>>2],h-1|0),y=x[e+126>>1]|x[e+128>>1]<<16,v[s>>2]=y;f=f+1|0;continue}break}d=P()|0;O()|0;break g}d=P()|0;O()|0;break g}d=P()|0;O()|0;break b}d=P()|0;O()|0;break b}d=P()|0;O()|0;ac(e+8|0);break a}d=P()|0;O()|0;break b}if(!(c&1)){break f}v[23588]=0;g=a+484344|0;R(225,g|0,w[e+213|0]);c=v[23588];v[23588]=0;G:{if((c|0)!=1){f=a+480188|0;a=0;while(1){H:{if(w[e+213|0]<=a>>>0){break f}d=64;c=v[l>>2];if(Qc(c,v[l+4>>2])>>>0>a>>>0){d=x[cc(c,a)>>1]}v[23588]=0;c=W(226,g|0,a&65535,d&65535)|0;d=v[23588];v[23588]=0;if((d|0)==1){break G}I:{if(c){c=x[f>>1];v[23588]=0;Q(155,b|0,B(((w[e+179|0]>13)<<1)+(c<<1)|0,a)+q|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break G}c=Sb(e+80|0);d=x[f>>1];v[23588]=0;i=W(217,b|0,c|0,d|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break I}d=0;J:{if(!i){break J}while(1){if(x[f>>1]<=d>>>0){break J}K:{i=cc(v[c>>2],d);i=w[i|0]|w[i+1|0]<<8;if(!i|i>>>0>x[e+214>>1]){break K}i=cc(v[h>>2],i-1|0);i=(w[i|0]|w[i+1|0]<<8)-1&65535;if(i>>>0>=k>>>0){break K}o=v[g>>2];p=v[j>>2];v[23588]=0;U(227,Yb(o,a)|0,d&65535,Og(p,i)|0);i=v[23588];v[23588]=0;if((i|0)!=1){break K}break H}d=d+1|0;continue}}nd(c)}a=a+1|0;continue}}break}d=P()|0;O()|0;nd(c);break i}d=P()|0;O()|0;break i}d=P()|0;O()|0}Uc(j)}nd(h)}vc(m);break b}Uc(j)}nd(h);vc(m);nd(l)}jb=e+224|0;return n|0}d=P()|0;O()|0}nd(l)}T(d|0);L()}function i$(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0,C=0;l=jb-560|0;jb=l;v[l+548>>2]=k;v[l+552>>2]=b;a:{b:{c:{d:{if(cj(a,l+552|0)){v[f>>2]=v[f>>2]|4;a=0;break d}v[l+104>>2]=1158;b=l+104|0;s=se(l+136|0,l+144|0,b);m=v[s>>2];v[l+132>>2]=m;v[l+128>>2]=m+400;x=Lb(b);o=Lb(l+88|0);q=Lb(l+72|0);p=Lb(l+56|0);u=Lb(l+40|0);v[23588]=0;na(1161,c|0,d|0,l+120|0,l+119|0,l+118|0,x|0,o|0,q|0,p|0,l+36|0);b=v[23588];v[23588]=0;if((b|0)!=1){v[j>>2]=v[i>>2];y=e&512;z=y>>>9|0;d=v[l+36>>2];k=h;h=0;while(1){e:{f:{g:{h:{i:{j:{k:{if((h|0)==4){break k}v[23588]=0;b=Q(1125,a|0,l+552|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break c}if(!b){break k}l:{m:{n:{o:{p:{switch(t[(l+120|0)+h|0]){case 1:if((h|0)==3){break e}b=v[a>>2];v[23588]=0;b=S(1127,b|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break c}if(uh(v[k+8>>2],1,b)){v[23588]=0;R(1162,l+24|0,a|0);b=v[23588];v[23588]=0;if((b|0)!=1){v[23588]=0;R(47,u|0,t[l+24|0]);b=v[23588];v[23588]=0;if((b|0)!=1){break o}}a=P()|0;O()|0;break a}v[f>>2]=v[f>>2]|4;a=0;break h;case 4:break l;case 2:break m;case 3:break n;case 0:break p;default:break e}}if((h|0)==3){break e}}while(1){v[23588]=0;b=Q(1125,a|0,l+552|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break b}if(!b){break e}b=v[a>>2];v[23588]=0;b=S(1127,b|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break b}if(!uh(v[k+8>>2],1,b)){break e}v[23588]=0;R(1162,l+24|0,a|0);b=v[23588];v[23588]=0;if((b|0)!=1){v[23588]=0;R(47,u|0,t[l+24|0]);b=v[23588];v[23588]=0;if((b|0)!=1){continue}}break}a=P()|0;O()|0;break a}q:{if(!Gb(q)){break q}b=v[a>>2];v[23588]=0;b=S(1127,b|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break c}if(w[Sc(q,0)|0]!=(b&255)){break q}v[23588]=0;S(1129,a|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break c}t[g|0]=0;r=Gb(q)>>>0>1?q:r;break e}r:{if(!Gb(p)){break r}b=v[a>>2];v[23588]=0;b=S(1127,b|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break c}if(w[Sc(p,0)|0]!=(b&255)){break r}v[23588]=0;S(1129,a|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break c}t[g|0]=1;r=Gb(p)>>>0>1?p:r;break e}c=Gb(q);b=Gb(p);s:{if(c){if(!b){break s}v[l+36>>2]=d;v[f>>2]=v[f>>2]|4;a=0;break h}if(!b){break e}}B=g,C=!Gb(p),t[B|0]=C;break e}if(!(h>>>0<2|r|((h|0)==2&w[l+123|0]!=0|z))){r=0;break e}B=l,C=he(o),v[B+16>>2]=C;c=lj(l+24|0,l+16|0);t:{if(!h|w[(h+l|0)+119|0]>1){break t}while(1){u:{B=l,C=yh(o),v[B+16>>2]=C;if(!yi(c,l+16|0)){break u}if(!uh(v[k+8>>2],1,t[v[c>>2]])){break u}Ge(c);continue}break}B=l,C=he(o),v[B+16>>2]=C;b=Nn(c,l+16|0);if(Gb(u)>>>0>=b>>>0){B=l,C=yh(u),v[B+16>>2]=C;e=Fp(l+16|0,0-b|0);n=yh(u);A=he(o);b=jb-32|0;jb=b;v[b+16>>2]=n;v[b+24>>2]=e;v[b+8>>2]=A;while(1){e=yi(b+24|0,b+16|0);if(!(!e|w[v[b+24>>2]]!=w[v[b+8>>2]])){Ge(b+24|0);Ge(b+8|0);continue}break}jb=b+32|0;if(e^1){break t}}B=l,C=he(o),v[B+8>>2]=C;B=c,C=v[lj(l+16|0,l+8|0)>>2],v[B>>2]=C}v[l+16>>2]=v[c>>2];v:{w:{while(1){B=l,C=yh(o),v[B+8>>2]=C;if(!yi(l+16|0,l+8|0)){break v}v[23588]=0;b=Q(1125,a|0,l+552|0)|0;c=v[23588];v[23588]=0;x:{if((c|0)==1){break x}if(!b){break v}b=v[a>>2];v[23588]=0;b=S(1127,b|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break x}if(w[v[l+16>>2]]!=(b&255)){break v}v[23588]=0;S(1129,a|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break w}Ge(l+16|0);continue}break}a=P()|0;O()|0;v[l+36>>2]=d;break a}a=P()|0;O()|0;v[l+36>>2]=d;break a}if(!y){break e}B=l,C=yh(o),v[B+8>>2]=C;if(!yi(l+16|0,l+8|0)){break e}v[l+36>>2]=d;v[f>>2]=v[f>>2]|4;a=0;break h}b=0;n=w[l+118|0];y:{while(1){z:{v[23588]=0;c=Q(1125,a|0,l+552|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break z}if(!c){break y}c=v[a>>2];v[23588]=0;e=S(1127,c|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break g}A:{if(uh(v[k+8>>2],64,e)){c=v[j>>2];if((c|0)==v[l+548>>2]){v[23588]=0;U(1163,i|0,j|0,l+548|0);c=v[23588];v[23588]=0;if((c|0)==1){break g}c=v[j>>2]}v[j>>2]=c+1;t[c|0]=e;b=b+1|0;break A}if(!Gb(x)|!b|(n|0)!=(e&255)){break y}if(v[l+128>>2]==(m|0)){v[23588]=0;U(1164,s|0,l+132|0,l+128|0);c=v[23588];v[23588]=0;if((c|0)==1){break g}m=v[l+132>>2]}c=m+4|0;v[l+132>>2]=c;v[m>>2]=b;m=c;b=0}v[23588]=0;S(1129,a|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){continue}}break}a=P()|0;O()|0;break a}if(!b|v[s>>2]==(m|0)){break j}if(v[l+128>>2]==(m|0)){v[23588]=0;U(1164,s|0,l+132|0,l+128|0);c=v[23588];v[23588]=0;if((c|0)==1){break f}m=v[l+132>>2]}e=m+4|0;v[l+132>>2]=e;v[m>>2]=b;break i}v[l+36>>2]=d;B:{if(!r){break B}k=1;while(1){if(Gb(r)>>>0<=k>>>0){break B}v[23588]=0;b=Q(1126,a|0,l+552|0)|0;c=v[23588];v[23588]=0;C:{if((c|0)==1){break C}D:{if(!b){b=v[a>>2];v[23588]=0;b=S(1127,b|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break C}if(w[gg(r,k)|0]==(b&255)){break D}}v[f>>2]=v[f>>2]|4;a=0;break h}v[23588]=0;S(1129,a|0)|0;b=v[23588];v[23588]=0;k=k+1|0;if((b|0)!=1){continue}}break}a=P()|0;O()|0;break a}a=1;b=v[s>>2];if((b|0)==(m|0)){break h}a=0;v[l+24>>2]=0;Ff(x,b,m,l+24|0);if(v[l+24>>2]){v[f>>2]=v[f>>2]|4;break h}a=1;break h}e=m}E:{if((d|0)<=0){break E}v[23588]=0;b=Q(1126,a|0,l+552|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break f}F:{if(!b){b=v[a>>2];v[23588]=0;b=S(1127,b|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break f}if(w[l+119|0]==(b&255)){break F}}v[l+36>>2]=d;v[f>>2]=v[f>>2]|4;a=0;break h}v[23588]=0;c=S(1129,a|0)|0;m=v[23588];v[23588]=0;b=d;if((m|0)==1){break f}while(1){if((b|0)<=0){d=0;break E}v[23588]=0;m=Q(1126,c|0,l+552|0)|0;n=v[23588];v[23588]=0;G:{if((n|0)==1){break G}H:{if(!m){m=v[c>>2];v[23588]=0;m=S(1127,m|0)|0;n=v[23588];v[23588]=0;if((n|0)==1){break G}if(uh(v[k+8>>2],64,m)){break H}}v[l+36>>2]=b;v[f>>2]=v[f>>2]|4;a=0;break h}if(v[j>>2]==v[l+548>>2]){v[23588]=0;U(1163,i|0,j|0,l+548|0);m=v[23588];v[23588]=0;if((m|0)==1){break G}}m=v[c>>2];v[23588]=0;m=S(1127,m|0)|0;n=v[23588];v[23588]=0;if((n|0)==1){break G}n=v[j>>2];v[j>>2]=n+1;t[n|0]=m;v[23588]=0;S(1129,c|0)|0;m=v[23588];v[23588]=0;b=b-1|0;if((m|0)!=1){continue}}break}a=P()|0;O()|0;v[l+36>>2]=d;break a}if(v[j>>2]!=v[i>>2]){m=e;break e}v[l+36>>2]=d;v[f>>2]=v[f>>2]|4;a=0}yb(u);yb(p);yb(q);yb(o);yb(x);Wc(s);break d}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}h=h+1|0;continue}}a=P()|0;O()|0;break a}jb=l+560|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0}yb(u);yb(p);yb(q);yb(o);yb(x);Wc(s);T(a|0);L()}function Tp(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0;g=jb-16|0;jb=g;i=x[a+480192>>1]>=c>>>0?v[((c<<2)+a|0)+900380>>2]:i;s=v[b+752>>2];k=w[b+802|0];a:{if(!k){Cb(g+8|0,a+1074312|0,11);if(Bb(v[v[g+8>>2]>>2],v[g+12>>2])){break a}}b:{c:{if(!i){break c}if(!_c(k)){break c}d:{l=k-1|0;k=cc(i+236|0,l);if(x[k>>1]){break d}Cb(g+8|0,a+1074312|0,43);if(!Bb(v[v[g+8>>2]>>2],v[g+12>>2])){break d}if(uj(w[i+31|0])){break d}v[b+656>>2]=i;break a}if(w[Kb(i+108|0,l)|0]>120){break a}k=x[k>>1];l=(k-1&65535)>>>0<3999?(B(k,104)+a|0)+484380|0:0;break b}l=(B(c,104)+a|0)+484380|0;if(!x[a+480192>>1]){break b}if(k>>>0>250){break a}Cb(g+8|0,a+1074312|0,43);if(Bb(v[v[g+8>>2]>>2],v[g+12>>2])){if(i){l=0;if(uj(w[i+31|0])){break b}}t[b+803|0]=0;v[b+656>>2]=0;break a}l=0}k=v[b+104>>2];n=(k|0)!=0&(k|0)!=(l|0);j=v[b+656>>2];p=!i|v[a+480180>>2]!=16777216?p:v[i+44>>2]!=0;q=d^1;h=(j|0)!=(i|0);if((q|h|n)==1){u[b+774>>1]=0}r=!n;if(!(r|(h|!(d&p)))){break a}e:{if(!(d&n)){break e}k=a+1074312|0;Cb(g+8|0,k,32);if(!(!Bb(v[v[g+8>>2]>>2],v[g+12>>2])|!(w[a+480208|0]&8))){l=v[b+8>>2]|v[b+12>>2]?v[b+104>>2]:l}m=v[a+480180>>2];f:{if(!(i?h|!(m&1048580):1)|(m|0)==268435456){break f}if((m|0)==1){if(xi(v[b+8>>2],v[b+12>>2])){break f}}Cb(g+8|0,k,79);if(!Bb(v[v[g+8>>2]>>2],v[g+12>>2])){break e}if(!xi(v[b+8>>2],v[b+12>>2])){break e}}o=1}g:{if(!v[b+16>>2]|(!n|(h|!x[a+480192>>1]))){break g}Cb(g+8|0,a+1074312|0,87);if(!Bb(v[v[g+8>>2]>>2],v[g+12>>2])){break g}o=_c(w[b+788|0])^1|o}h:{i:{j:{k:{l:{if(xi(v[b+8>>2],v[b+12>>2])|!(v[a+480180>>2]&16777248)){break l}if(i){if(uj(w[i+31|0])){break l}}k=1;break k}if(!(h|n)){break j}k=(j|0)!=(i|0)}if(!d){break i}Cb(g+8|0,a+1074312|0,61);if(!Bb(v[v[g+8>>2]>>2],v[g+12>>2])){break i}j=v[b+656>>2];if(!j){j=0;m=0;h=v[b+104>>2];if(!h){break i}break h}h=v[b+104>>2];m=0;break h}k=0}v[b+656>>2]=i;j=i;m=k;h=l}m:{n:{o:{if(!e){break o}p:{if(w[a+480180|0]&3){if(h){if(Zd(v[h>>2],v[h+20>>2])){break p}}if(!pj(j)){break o}}if(!h){break n}}if(u[h+34>>1]<0){break o}v[b+688>>2]=x[h+30>>1]}i=(h|0)!=0;if(!(n&o)|!h){break m}Cb(g+8|0,a+1074312|0,85);if(Bb(v[v[g+8>>2]>>2],v[g+12>>2])){u[b+772>>1]=t[h+37|0]}i=1;if(v[a+480180>>2]!=2){break m}if(!Zd(v[h>>2],v[h+20>>2])){break m}v[b+704>>2]=v[h+24>>2];break m}if(!(!j|!w[j+34|0])){k=v[b+688>>2];if(j){k=v[j+4>>2]<<2}v[b+688>>2]=k;i=0;break m}i=0;v[b+688>>2]=0}if(o){break a}t[b+803|0]=0;q:{if(!j){break q}Cb(g+8|0,a+1074312|0,29);if(!(z=1,A=(Bb(v[v[g+8>>2]>>2],v[g+12>>2])^-1)&i,C=w[j+34|0]|m,C?z:A)){break q}t[b+798|0]=w[j+16|0]}l=64;v[b+752>>2]=64;if(h){l=x[h+32>>1];v[b+752>>2]=l}if(j){v[b+752>>2]=B(v[j+4>>2],l)>>>6}r:{if(!(v[a+480180>>2]&1048580?e:1)){break r}Cb(g+8|0,a+1074312|0,48);if(Bb(v[v[g+8>>2]>>2],v[g+12>>2])){break r}GN(a,b,j,h)}s:{t:{u:{if(!f){break u}f=a+1074312|0;Cb(g+8|0,f,19);v:{w:{x:{y:{z:{A:{B:{C:{if(Bb(v[v[g+8>>2]>>2],v[g+12>>2])){if(!v[b+76>>2]){e=1;break B}if(!(!c|q)){e=(w[a+480208|0]&8)>>>3|0;if(e){break B}break C}e=0;if(c){break C}break B}c=v[a+480180>>2]&17301536;e=1;D:{if(!d|!c){break D}c=1;e=1;if(w[a+480208|0]&8){break D}e=1;if(!v[b+76>>2]){break D}e=0;if(!(w[b+89|0]&16)){break D}e=!v[b+696>>2]}if(!j|(!c|m)){break z}if(!e){break y}c=v[b+88>>2];e=c&6144;break A}if(d){break B}if(!(w[b+89|0]&24)){e=0;break B}e=(w[a+480208|0]&4)>>>2|0}if(!v[b+696>>2]|m){break z}if(!e){break y}c=v[b+88>>2];e=c&2048}v[b+88>>2]=c|2097152;if(!j){break v}if(e){break w}if(!(w[j+60|0]&8)){oj(b+724|0)}if(!(w[j+80|0]&8)){oj(b+732|0)}if(w[j+100|0]&8){break v}oj(b+740|0);break v}if(e){break x}}if(j){if(t[j+60|0]&1){break u}Cb(g+8|0,f,32);if(Bb(v[v[g+8>>2]>>2],v[g+12>>2])){oj(b+724|0);break u}tm(b);break u}c=0;if(!h){break t}break s}v[b+88>>2]=v[b+88>>2]|2097152;if(!j){break v}}tm(b)}Cb(g+8|0,f,21);if(Bb(v[v[g+8>>2]>>2],v[g+12>>2])){break u}t[b+818|0]=0;v[b+756>>2]=0}c=0;if(h){break s}if(!j){break t}c=1;if(uj(w[j+31|0])){break s}}v[b+752>>2]=0;v[b+104>>2]=0;break a}E:{F:{G:{H:{I:{if(!(!d|(i^1|v[b+104>>2]!=(h|0)))){d=v[a+480180>>2];if(v[b+76>>2]?d&16777250:0){break a}if((d|0)!=4){break I}Cb(g+8|0,a+1074312|0,40);if(!Bb(v[v[g+8>>2]>>2],v[g+12>>2])|w[b+789|0]){break I}d=v[b+88>>2];break H}v[b+88>>2]=v[b+88>>2]&-6145;e=a+1074312|0;Cb(g+8|0,e,18);J:{if(z=Bb(v[v[g+8>>2]>>2],v[g+12>>2]),A=1,C=v[a+480180>>2]&16777248,C?z:A){f=-640;if(!(v[b+104>>2]!=(h|0)|m)){break J}}f=-768}v[b+88>>2]=f&v[b+88>>2];K:{if(!j){break K}t[b+730|0]=w[j+60|0];t[b+738|0]=w[j+80|0];t[b+746|0]=w[j+100|0];L:{if((w[j+100|0]&17)!=17){break L}Cb(g+8|0,e,36);if(Bb(v[v[g+8>>2]>>2],v[g+12>>2])|w[b+837|0]){break L}t[b+837|0]=127}e=w[j+21|0];if(ff(e)){z=b,A=_q(e),t[z+837|0]=A}e=w[j+22|0];if(!ff(e)){break K}z=b,A=_q(e),t[z+838|0]=A}if(c){break G}if(!d){break E}break F}d=v[b+88>>2]&-6145}v[b+88>>2]=d&-640;if(!c){break F}}v[b+76>>2]=0;v[b+104>>2]=0;break a}if(v[b+76>>2]){break E}c=a+1074312|0;Cb(g+8|0,c,54);if(!Bb(v[v[g+8>>2]>>2],v[g+12>>2])){Cb(g,c,39);if(!Bb(v[v[g>>2]>>2],v[g+4>>2])){break E}}v[b+8>>2]=0;v[b+12>>2]=0}M:{if(w[b+788|0]!=255){break M}Cb(g+8|0,a+1074312|0,100);if(!Bb(v[v[g+8>>2]>>2],v[g+12>>2])|(!(v[a+480208>>2]&4)|r)){break M}c=v[b+104>>2];if(c){v[b+88>>2]=v[b+88>>2]|x[c+34>>1]&1023}v[b+752>>2]=s;v[b+688>>2]=x[h+30>>1];if(!(w[h+34|0]&32)){break a}aq(b,x[h+28>>1],a);break a}v[b+104>>2]=h;v[b+76>>2]=v[h>>2];v[b+80>>2]=v[h+4>>2];v[b+84>>2]=v[h+8>>2];e=a+1074312|0;Cb(g+8|0,e,83);if(!(!Bb(v[v[g+8>>2]>>2],v[g+12>>2])|v[b+80>>2])){v[b+84>>2]=v[h>>2]}v[b+88>>2]=v[b+88>>2]|x[h+34>>1]&1023;Cb(g+8|0,e,21);if(Bb(v[v[g+8>>2]>>2],v[g+12>>2])){t[b+818|0]=0;v[b+756>>2]=0}N:{O:{if(p){v[b+704>>2]=v[h+24>>2];t[b+851|0]=w[b+851|0]|64;c=0;break O}if(!(n|q)){d=v[a+480180>>2];if(d&5){break N}}v[b+704>>2]=v[h+24>>2];c=t[h+37|0]}u[b+772>>1]=c;d=v[a+480180>>2]}if(Jm(d)){c=t[h+36|0]}else{c=0}u[b+770>>1]=c;Cb(g+8|0,e,69);if(!(Bb(v[v[g+8>>2]>>2],v[g+12>>2])|v[a+480180>>2]==1)){v[b+708>>2]=0}v[b+852>>2]=0;i=v[b+88>>2];if(i&8){v[b+80>>2]=v[h+12>>2];v[b+84>>2]=v[h+16>>2];i=i>>>2&4|i|2;v[b+88>>2]=i}P:{if(!(i&2)){i=v[b+76>>2];break P}i=v[b+76>>2];c=v[b+84>>2];if(i>>>0<=c>>>0){break P}v[b+76>>2]=c;i=c}if(!(v[a+480180>>2]&16777248)|y[b+4>>2]<i>>>0){break a}v[b>>2]=0;v[b+4>>2]=0}jb=g+16|0}function vja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0;e=jb-272|0;jb=e;yc(b);d=jb-16|0;jb=d;i=e+112|0;iU(d+8|0,i);g=v[d+12>>2];mc(d,v[b>>2],v[b+8>>2],v[d+8>>2],v[d+12>>2]);h=v[d+4>>2];if((h|0)==(g|0)){Zb(b,v[d+12>>2])}jb=d+16|0;d=(g|0)==(h|0);if(!d){hU(i)}a:{if(!d){break a}if(!jU(e+112|0)){break a}if(!c){f=1;break a}Ad(a,v[(x[e+228>>1]<<2)+26384>>2]);v[a+480208>>2]=v[a+480208>>2]|16777216;d=e+48|0;f=xc(d,13023);Ib(a+1298344|0,f);zb(f);f=xc(d,10263);Ib(a+1298356|0,f);zb(f);f=jb-16|0;jb=f;g=e+8|0;i=xc(f,4392);$c(g,i);zb(i);jb=f+16|0;v[23588]=0;X(229,d|0,g|0,w[e+191|0],e+188|0);d=v[23588];v[23588]=0;b:{if((d|0)!=1){d=e+48|0;Ib(a+1298368|0,d);zb(d);f=e+8|0;ac(f);Ql(a+1298392|0,(x[e+228>>1]<<2)+26432|0);Ql(a+1298380|0,v[(x[e+228>>1]<<2)+26480>>2]);v[a+1298404>>2]=5;Me(f,2,e+112|4);Ec(d,f);Ac(a+1298308|0,d);yb(d);Me(f,2,e+148|0);Ec(d,f);c:{if(xq(d,9700)){v[23588]=0;U(11,e+8|0,5,e+48|0);d=v[23588];v[23588]=0;if((d|0)==1){break c}d=e+8|0;Ib(a+1298320|0,d);zb(d)}yb(e+48|0);u[a+480188>>1]=32;d=0;d:{while(1){if((d|0)!=32){g=(d<<5)+a|0;i=g+480280|0;df(i);f=w[(d+e|0)+193|0];e:{if(f>>>0<=15){v[e+48>>2]=f<<4|8;v[e+8>>2]=256;y=g+480284|0,z=v[sd(e+48|0,e+8|0)>>2],u[y>>1]=z;break e}if((f|0)!=16){if((f|0)!=255){break e}u[a+480188>>1]=d;break d}u[g+480284>>1]=128;v[i>>2]=256}d=d+1|0;continue}break}d=x[a+480188>>1]}f=0;if(!(d&65535)){break a}v[e+48>>2]=w[e+225|0]<<2;v[e+8>>2]=256;y=a,z=v[Jb(e+48|0,e+8|0)>>2],v[y+480200>>2]=z;v[a+480196>>2]=w[e+226|0];v[a+480204>>2]=B(w[e+227|0],1e4);if(cd(b,x[e+230>>1]|x[e+232>>1]<<16)){so(Vb(v[a+484360>>2],w[a+484376|0]),b,w[e+234|0]+1|0,255,254)}if(!cd(b,v[e+240>>2])){break a}l=a+480190|0;d=w[e+248|0]+1|0;u[l>>1]=d;m=e+80|0;n=a+480180|0;i=1;while(1){f:{g:{j=i&65535;if(j>>>0>(d&65535)>>>0){break g}d=jb-16|0;jb=d;g=e+48|0;fc(d+8|0,g,62);f=v[d+12>>2];mc(d,v[b>>2],v[b+8>>2],v[d+8>>2],v[d+12>>2]);h=v[d+4>>2];if((h|0)==(f|0)){Zb(b,v[d+12>>2])}jb=d+16|0;d=(f|0)==(h|0);if(!d){Tb(g,0,62)}if(!d){break g}d=0;f=B(j,104)+a|0;k=f+484380|0;md(k,0);h=e+32|0;Me(h,2,e+48|0);g=e+8|0;Ec(g,h);Cc(((j<<5)+a|0)+946304|0,g);yb(g);tk(h,2,m);Ec(g,h);Be(f+484423|0,g);yb(g);g=x[e+106>>1];v[f+484404>>2]=g;if(!Jm(v[n>>2])){break f}while(1){if((d|0)==16){break f}if((g|0)==x[(d<<1)+26528>>1]){t[f+484417|0]=d<<4;break f}else{d=d+1|0;continue}}}h:{if(!(c&2)){break h}if(!cd(b,v[e+244>>2])){break h}d=1;f=a+480190|0;while(1){g=d&65535;if(g>>>0>x[f>>1]){break h}g=B(g,104)+a|0;vg(Zc(e+48|0,u[g+484414>>1]&1?16:8,1,0,1),g+484380|0,b);d=d+1|0;continue}}n=a+484344|0;wg(n,w[e+239|0]+1|0);f=wq(a);d=jb-16|0;jb=d;v[d+12>>2]=0;bt(d+12|0,f);k=v[d+12>>2];jb=d+16|0;cd(b,w[e+235|0]|w[e+236|0]<<8|(w[e+237|0]<<16|w[e+238|0]<<24));p=c&1;q=a+480188|0;r=a+480180|0;j=0;m=1;i:{j:{k:{while(1){if(w[e+239|0]<j>>>0){if(v[a+480180>>2]==1){break k}c=v[a+480208>>2]&-8454145;break j}l:{d=Rg(b);if(d>>>0>=3){c=e+8|0;$d(c,b,d-2|0);h=jc(e+48|0,c);Ab(c);m:{if(!p){break m}c=v[h>>2];v[23588]=0;c=S(178,c|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break l}if(!c){break m}v[23588]=0;c=W(226,n|0,j&65535,64)|0;d=v[23588];v[23588]=0;if((d|0)==1){break l}l=0;if(!c){break m}while(1){if((l|0)==64){break m}c=Yb(v[n>>2],j);s=Cf(v[c>>2],v[v[c+48>>2]+12>>2],l);n:{o:while(1){v[23588]=0;c=S(206,h|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break i}if(!c){break n}d=c&31;if(d>>>0>=x[q>>1]){break n}f=B(d,6)+s|0;if(c&32){v[23588]=0;R(260,e+8|0,h|0);d=v[23588];v[23588]=0;if((d|0)==1){break i}g=Nc(e+8|0);d=w[e+8|0];if(d){d=(d&127)-1|0;t[e+8|0]=d;d=(B((d&240)>>>4|0,12)+(d&15)|0)+13|0;t[f|0]=d;m=gB(d)&m}t[f+1|0]=w[g|0]}if(!(c&64)){continue}t[f+2|0]=0;t[f+3|0]=0;g=f+5|0;while(1){c=v[h>>2];v[23588]=0;c=W(156,c|0,v[e+56>>2],2)|0;d=v[23588];v[23588]=0;if((d|0)==1){break i}if(!c){continue o}o=w[f+5|0];c=w[f+3|0];v[23588]=0;R(260,e+8|0,h|0);d=v[23588];v[23588]=0;if((d|0)!=1){i=w[Nc(e+8|0)|0];t[g|0]=i;d=w[(w[e+8|0]&31)+26560|0];t[f+3|0]=d;p:{q:{r:{s:{t:{switch(d-2|0){case 0:case 1:if(i>>>0<224){break r}d=223;if(v[r>>2]!=1){break s}break r;case 11:t[e+32|0]=64;y=g,z=w[Wb(g,e+32|0)|0],t[y|0]=z;if(!gU(v[k+88>>2])){break r}t[f+2|0]=1;t[f+4|0]=w[g|0];t[f+3|0]=c;t[g|0]=o;d=c;break q;case 17:u:{switch(((i&240)>>>4|0)-8|0){case 0:t[f+3|0]=2;t[g|0]=i&15|224;break p;case 1:t[f+3|0]=3;t[g|0]=i&15|224;break p;default:break u}}if(tu(v[k+84>>2],19)){break r}Vu(f);break r;case 13:d=v[k+84>>2];if(tu(d,15)){break r}if(!tu(d,19)){break r}t[f+3|0]=19;t[g|0]=i&15|144;break p;case 18:d=145;if((i|0)==1){break s}if((i&240)==128){if(tu(v[k+84>>2],20)){break r}t[f+3|0]=19;break p}t[f+3|0]=0;break p;case 4:case 5:break t;default:break q}}d=i&240;if(!d){break r}}t[g|0]=d}d=w[f+3|0]}if((d&255)!=20){break p}d=w[g|0];if(w[f+2|0]|(d&240)!=128){break p}t[f+2|0]=2;t[f+4|0]=(((d&15)<<6|8)>>>0)/15;t[f+3|0]=c;t[g|0]=o}if(!(w[e+8|0]&32)){continue o}continue}break}break}break i}l=l+1|0;continue}}Ab(h)}j=j+1|0;continue}break}break i}c=v[a+480208>>2]&-8454145|(x[a+480188>>1]==4?m&1?8454144:0:0)}v[a+480208>>2]=c;f=1;if(!(w[e+253|0]|w[e+254|0]<<8|(w[e+255|0]<<16|w[e+256|0]<<24))){break a}if(!cd(b,w[e+249|0]|w[e+250|0]<<8|(w[e+251|0]<<16|w[e+252|0]<<24))){break a}uB(a+1298332|0,b,w[e+253|0]|w[e+254|0]<<8|(w[e+255|0]<<16|w[e+256|0]<<24),4);break a}d=P()|0;O()|0;Ab(h);break b}u[f+484412>>1]=64;g=w[e+93|0]|w[e+94|0]<<8|(w[e+95|0]<<16|w[e+96|0]<<24);v[k>>2]=g;d=w[e+105|0];if(d&2){h=f+484414|0;u[h>>1]=x[h>>1]|1;v[k>>2]=g>>>1}v[f+484384>>2]=w[e+97|0]|w[e+98|0]<<8|(w[e+99|0]<<16|w[e+100|0]<<24);v[f+484388>>2]=(w[e+101|0]|w[e+102|0]<<8|(w[e+103|0]<<16|w[e+104|0]<<24))-1;if(d&1){g=f+484414|0;u[g>>1]=x[g>>1]|2}v:{w:{if(!(d&4)){break w}g=w[e+108|0];if((g|0)==255){break w}t[e+8|0]=g;t[e+32|0]=64;y=f+484410|0,z=w[Wb(e+8|0,e+32|0)|0]<<2,u[y>>1]=z;break v}g=f+484414|0;u[g>>1]=x[g>>1]|32768}x:{if(d&8){d=f+484414|0;g=x[d>>1]|32;u[d>>1]=g;j=f+484408|0;f=w[e+109|0];if(f>>>0<=15){v[e+32>>2]=256;v[e+8>>2]=f<<4|8;h=v[sd(e+8|0,e+32|0)>>2]}else{h=128}u[j>>1]=h;u[d>>1]=g&65279|((f|0)==16)<<8;break x}u[f+484408>>1]=128}i=i+1|0;d=x[l>>1];continue}}d=P()|0;O()|0;yb(e+48|0);break b}d=P()|0;O()|0;ac(e+8|0)}T(d|0);L()}jb=e+272|0;return f|0}function _aa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=jb+-64|0;jb=g;d=v[b>>2];v[23588]=0;f=S(178,d|0)|0;d=v[23588];v[23588]=0;a:{b:{c:{d:{if((d|0)==1){break d}e:{f:{if(f){l=Sb(g+48|0);v[23588]=0;e=(c|0)!=0;f=W(822,l|0,b|0,e|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break e}d=4;g:{h:{i:{j:{if(f){break j}v[23588]=0;f=W(823,l|0,b|0,e|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break e}d=5;if(f){break j}v[23588]=0;f=W(824,l|0,b|0,e|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break e}d=6;if(f){break j}f=0;v[23588]=0;e=W(825,l|0,b|0,e|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break e}d=3;if(!e){break i}}if(!c){d=1;f=0;break h}f=v[l>>2];if(!oc(f,v[l+4>>2])){uv(b,f+12|0)}f=d}d=31552;k:{while(1){e=d;if((e|0)!=32092){h=v[e+8>>2];i=(h>>1)+a|0;d=v[e+4>>2];d=h&1?v[v[i>>2]+d>>2]:d;v[23588]=0;h=W(d|0,i|0,b|0,c|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break c}d=e+12|0;if(!h){continue}break k}break}v[a+480180>>2]=0;v[a+480184>>2]=0}if(!c){d=(e|0)!=32092;f=0;break h}if(!(v[a+480184>>2]|!f)){v[a+480184>>2]=f}v[23588]=0;f=1;R(765,a+1298264|0,1);e=v[23588];v[23588]=0;d=1;if((e|0)==1){break g}}JM(l);if(f){break f}break a}break c}v[23588]=0;R(246,a|0,0);d=v[23588];v[23588]=0;if((d|0)==1){break d}v[23588]=0;R(765,a+1298264|0,1);d=v[23588];v[23588]=0;if((d|0)==1){break d}v[a+1074304>>2]=19988498}d=0;while(1){if((d|0)==127){d=1;while(1){f=d&65535;if(f>>>0>x[a+480190>>1]){f=0;i=a+480180|0;d=0;l:{while(1){e=d&65535;if(e>>>0>x[a+480192>>1]){m:{u[a+480192>>1]=f;d=a+480204|0;if(y[a+480204>>2]>=1e4){break m}v[d>>2]=125e4;break l}}else{e=v[((e<<2)+a|0)+900380>>2];if(e){h=v[i>>2];wc(e,65536);wc(e+4|0,64);wc(e+8|0,256);Ef(e+28|0,16384);vf(e+30|0,128);vf(e+31|0,17);if(w[e+16|0]>=4){t[e+16|0]=0}if(w[e+17|0]>=5){t[e+17|0]=0}if(w[e+18|0]>=3){t[e+18|0]=0}vf(e+19|0,64);vf(e+20|0,100);j=224;f=t[e+26|0];n:{if((f|0)>=-32){j=32;if((f|0)<33){break n}}t[e+26|0]=j}vf(e+23|0,64);vf(e+24|0,64);Fz(e+48|0,64);Fz(e+68|0,64);Fz(e+88|0,(h|0)==4096?255:64);h=e+108|0;j=0;while(1){o:{if((j|0)==128){if(!Ho(w[e+14|0])){t[e+14|0]=5}if(w[e+34|0]>=251){t[e+34|0]=0}break o}f=Kb(h,j);if((w[f|0]-121&255)>>>0<=135){t[f|0]=j+1}j=j+1|0;continue}break}f=d}d=d+1|0;continue}break}wc(d,65535e4)}if(!v[a+480196>>2]){v[a+480196>>2]=6}e=a+480216|0;f=a+480220|0;d=v[a+480216>>2];if(!(d|w[a+480224|0]!=2)){v[e>>2]=1;d=1}if(y[a+480220>>2]<d>>>0){v[f>>2]=d}wc(e,65536);wc(f,65536);wc(a+480200|0,256);p:{f=a+480248|0;if(!oc(v[f>>2],v[a+480252>>2])){d=v[e>>2];v[23588]=0;R(826,f|0,d|0);d=v[23588];v[23588]=0;if((d|0)==1){break p}}v[a+1074416>>2]=v[a+480196>>2];v[a+1074420>>2]=v[a+480204>>2];d=v[a+480220>>2];f=a+1074408|0;v[f>>2]=v[a+480216>>2];v[f+4>>2]=d;v[a+1074456>>2]=v[a+480200>>2];Wy(a+1074376|0);d=a+1074446|0;u[d>>1]=0;u[d+2>>1]=0;u[d+4>>1]=0;u[d+6>>1]=65535;v[a+1074392>>2]=-2;d=a+1074384|0;v[d>>2]=0;v[d+4>>2]=0;v[a+1074380>>2]=0;d=a+1074424|0;v[d>>2]=0;v[d+4>>2]=0;v[a+1074432>>2]=0;d=a+1074396|0;v[d>>2]=0;v[d+4>>2]=0;if(Jm(v[a+480180>>2])){v[23588]=0;Q(265,a+1074312|0,7)|0;d=v[23588];v[23588]=0;if((d|0)==1){break p}}u[a+480276>>1]=0;Mp(a);o=g,p=Eb(v[a+484360>>2]),v[o+48>>2]=p;f=Eb(v[a+484364>>2]);while(1){e=v[g+48>>2];if(!Ob(e,f)){q:{r:{l=v[a+480180>>2];if(l){bt(a+8|0,wq(a));if(v[a+1074308>>2]){v[23588]=0;Y(827,a|0);d=v[23588];v[23588]=0;if((d|0)==1){break p}}n=Sb(g+48|0);s:{if((c&12)!=12){break s}i=a+906300|0;h=a+1298464|0;d=0;t:{u:{v:{w:{x:{y:{while(1){if((d|0)==250){break s}z:{k=Ld(i,d);e=k+16|0;A:{if(!xi(v[e>>2],v[k+20>>2])){break A}v[23588]=0;R(828,k|0,a|0);c=v[23588];v[23588]=0;B:{if((c|0)!=1){m=v[k>>2];if(!m){break B}f=v[k+148>>2];c=v[v[m>>2]+56>>2];v[23588]=0;R(c|0,m|0,f|0);c=v[23588];v[23588]=0;if((c|0)!=1){break A}}a=P()|0;O()|0;break q}j=Eb(v[n>>2]);f=Eb(v[n+4>>2]);m=jb-16|0;jb=m;v[m+8>>2]=j;while(1){C:{if(!Ob(j,f)){break C}c=v[j>>2];if((w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24))==(w[k+20|0]|w[k+21|0]<<8|(w[k+22|0]<<16|w[k+23|0]<<24))){c=(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))==(w[k+16|0]|w[k+17|0]<<8|(w[k+18|0]<<16|w[k+19|0]<<24))}else{c=0}if(c){break C}j=v[Ke(m+8|0)>>2];continue}break}jb=m+16|0;if(Ob(j,Eb(v[n+4>>2]))){break A}v[23588]=0;v[g+32>>2]=e;R(829,n|0,g+32|0);c=v[23588];v[23588]=0;if((c|0)==1){break z}v[23588]=0;f=Q(1,g+16|0,17666)|0;c=v[23588];v[23588]=0;if((c|0)==1){break y}v[23588]=0;R(830,g|0,k|0);c=v[23588];v[23588]=0;if((c|0)==1){break x}v[23588]=0;U(2,g+32|0,f|0,g|0);c=v[23588];v[23588]=0;if((c|0)==1){break w}c=v[h>>2];v[23588]=0;U(376,c|0,2,g+32|0);c=v[23588];v[23588]=0;if((c|0)==1){break v}zb(g+32|0);zb(g);zb(f)}d=d+1|0;continue}break}a=P()|0;O()|0;break q}a=P()|0;O()|0;break q}a=P()|0;O()|0;break t}a=P()|0;O()|0;break u}a=P()|0;O()|0;zb(g+32|0)}zb(g)}zb(f);break q}c=w[a+1074368|0];v[23588]=0;R(831,a|0,c|0);a=v[23588];v[23588]=0;if((a|0)==1){break r}vc(n)}d=(l|0)!=0;break a}a=P()|0;O()|0}vc(n);break b}v[23588]=0;Y(832,e|0);d=v[23588];v[23588]=0;if((d|0)!=1){if(Qc(v[e>>2],v[e+4>>2])>>>0<=x[e+28>>1]){Ue(e,0)}Az(g+48|0);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}h=B(f,104)+a|0;i=h+484380|0;D:{if(Zd(v[i>>2],v[h+484400>>2])){tj(i,a);break D}e=h+484414|0;f=x[e>>1];if(f&16384){break D}v[i>>2]=0;v[i+4>>2]=0;v[i+16>>2]=0;v[i+8>>2]=0;v[i+12>>2]=0;u[e>>1]=f&65505}f=h+484412|0;if(x[f>>1]>=65){u[f>>1]=64}E:{F:{if(!(w[h+484415|0]&2)){break F}if(!ik(v[a+1298300>>2])){break F}v[23588]=0;Y(833,a|0);f=v[23588];v[23588]=0;if((f|0)==1){break E}}d=d+1|0;continue}break}a=P()|0;O()|0;break b}e=(d<<5)+a|0;Ef(e+480286|0,64);f=e+480284|0;if(x[f>>1]>=257){u[f>>1]=128}f=e+480288|0;if(w[f|0]>=251){t[f|0]=0}eo((B(d,872)+a|0)+1074992|0,a,d&65535,134217728);d=d+1|0;continue}}break c}a=P()|0;O()|0;break b}a=P()|0;O()|0;JM(l)}Ab(b);T(a|0);L()}Ab(b);jb=g- -64|0;return d|0}function B1(a,b,c,d,e,f){a=a|0;b=+b;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,C=0,E=0,F=0;n=jb-560|0;jb=n;v[n+44>>2]=0;o(+b);g=j(1)|0;j(0)|0;a:{if((g|0)<0){x=1;A=5299;b=-b;o(+b);g=j(1)|0;j(0)|0;break a}if(e&2048){x=1;A=5302;break a}x=e&1;A=x?5305:5300;F=!x}b:{if((g&2146435072)==2146435072){d=x+3|0;Gf(a,32,c,d,e&-65537);sf(a,A,x);f=f&32;sf(a,b!=b?f?9928:13743:f?11058:14109,3);Gf(a,32,c,d,e^8192);i=(c|0)<(d|0)?d:c;break b}z=n+16|0;c:{d:{e:{b=RH(b,n+44|0);b=b+b;if(b!=0){g=v[n+44>>2];v[n+44>>2]=g-1;u=f|32;if((u|0)!=97){break e}break c}u=f|32;if((u|0)==97){break c}l=v[n+44>>2];m=(d|0)<0?6:d;break d}l=g-29|0;v[n+44>>2]=l;b=b*268435456;m=(d|0)<0?6:d}r=(n+48|0)+((l|0)<0?0:288)|0;h=r;while(1){if(b<4294967296&b>=0){d=~~b>>>0}else{d=0}v[h>>2]=d;h=h+4|0;b=(b-+(d>>>0))*1e9;if(b!=0){continue}break}f:{if((l|0)<=0){d=l;g=h;k=r;break f}k=r;d=l;while(1){d=(d|0)<29?d:29;g=h-4|0;g:{if(k>>>0>g>>>0){break g}i=0;while(1){q=v[g>>2];p=d&31;C=i;if((d&63)>>>0>=32){i=q<<p;q=0}else{i=(1<<p)-1&q>>>32-p;q=q<<p}p=C+q|0;i=i+E|0;i=p>>>0<q>>>0?i+1|0:i;i=Oka(p,i,1e9,0);q=Lka(i,mb,-1e9,0)+p|0;v[g>>2]=q;g=g-4|0;if(k>>>0<=g>>>0){continue}break}if(!i){break g}k=k-4|0;v[k>>2]=i}while(1){g=h;if(k>>>0<g>>>0){h=g-4|0;if(!v[h>>2]){continue}}break}d=v[n+44>>2]-d|0;v[n+44>>2]=d;h=g;if((d|0)>0){continue}break}}if((d|0)<0){y=((m+25>>>0)/9|0)+1|0;p=(u|0)==102;while(1){d=0-d|0;i=(d|0)<9?d:9;h:{if(g>>>0<=k>>>0){h=v[k>>2];break h}q=1e9>>>i|0;E=-1<<i^-1;d=0;h=k;while(1){C=d;d=v[h>>2];v[h>>2]=C+(d>>>i|0);d=B(q,d&E);h=h+4|0;if(h>>>0<g>>>0){continue}break}h=v[k>>2];if(!d){break h}v[g>>2]=d;g=g+4|0}d=i+v[n+44>>2]|0;v[n+44>>2]=d;k=(!h<<2)+k|0;h=p?r:k;g=g-h>>2>(y|0)?h+(y<<2)|0:g;if((d|0)<0){continue}break}}d=0;i:{if(g>>>0<=k>>>0){break i}d=B(r-k>>2,9);h=10;i=v[k>>2];if(i>>>0<10){break i}while(1){d=d+1|0;h=B(h,10);if(i>>>0>=h>>>0){continue}break}}h=(m-((u|0)==102?0:d)|0)-((u|0)==103&(m|0)!=0)|0;if((h|0)<(B(g-r>>2,9)-9|0)){i=h+9216|0;p=(i|0)/9|0;l=((((l|0)<0?4:292)+n|0)+(p<<2)|0)-4048|0;h=10;i=i+B(p,-9)|0;if((i|0)<=7){while(1){h=B(h,10);i=i+1|0;if((i|0)!=8){continue}break}}p=v[l>>2];y=(p>>>0)/(h>>>0)|0;i=B(y,h);q=l+4|0;j:{if((i|0)==(p|0)&(q|0)==(g|0)){break j}p=p-i|0;k:{if(!(y&1)){b=9007199254740992;if(!(t[l-4|0]&1)|((h|0)!=1e9|k>>>0>=l>>>0)){break k}}b=9007199254740994}s=(g|0)==(q|0)?1:1.5;q=h>>>1|0;s=p>>>0<q>>>0?.5:(q|0)==(p|0)?s:1.5;if(!(w[A|0]!=45|F)){s=-s;b=-b}v[l>>2]=i;if(b+s==b){break j}d=h+i|0;v[l>>2]=d;if(d>>>0>=1e9){while(1){v[l>>2]=0;l=l-4|0;if(l>>>0<k>>>0){k=k-4|0;v[k>>2]=0}d=v[l>>2]+1|0;v[l>>2]=d;if(d>>>0>999999999){continue}break}}d=B(r-k>>2,9);h=10;i=v[k>>2];if(i>>>0<10){break j}while(1){d=d+1|0;h=B(h,10);if(i>>>0>=h>>>0){continue}break}}h=l+4|0;g=g>>>0>h>>>0?h:g}while(1){h=g;i=g>>>0<=k>>>0;if(!i){g=h-4|0;if(!v[g>>2]){continue}}break}l:{if((u|0)!=103){l=e&8;break l}g=m?m:1;l=(g|0)>(d|0)&(d|0)>-5;m=(l?d^-1:-1)+g|0;f=(l?-1:-2)+f|0;l=e&8;if(l){break l}g=-9;m:{if(i){break m}p=v[h-4>>2];if(!p){break m}i=10;g=0;if((p>>>0)%10|0){break m}while(1){l=g;g=g+1|0;i=B(i,10);if(!((p>>>0)%(i>>>0)|0)){continue}break}g=l^-1}i=B(h-r>>2,9);if((f&-33)==70){l=0;g=(g+i|0)-9|0;g=(g|0)>0?g:0;m=(g|0)>(m|0)?m:g;break l}l=0;g=((d+i|0)+g|0)-9|0;g=(g|0)>0?g:0;m=(g|0)>(m|0)?m:g}i=-1;u=l|m;if(((u?2147483645:2147483646)|0)<(m|0)){break b}p=(((u|0)!=0)+m|0)+1|0;q=f&-33;n:{if((q|0)==70){if((2147483647-p|0)<(d|0)){break b}g=(d|0)>0?d:0;break n}g=d>>31;g=Dn((g^d)-g|0,0,z);if((z-g|0)<=1){while(1){g=g-1|0;t[g|0]=48;if((z-g|0)<2){continue}break}}y=g-2|0;t[y|0]=f;t[g-1|0]=(d|0)<0?45:43;g=z-y|0;if((g|0)>(2147483647-p|0)){break b}}d=g+p|0;if((d|0)>(x^2147483647)){break b}f=d+x|0;Gf(a,32,c,f,e);sf(a,A,x);Gf(a,48,c,f,e^65536);o:{p:{q:{if((q|0)==70){g=n+16|0;d=g|8;l=g|9;i=k>>>0>r>>>0?r:k;k=i;while(1){g=Dn(v[k>>2],0,l);r:{if((i|0)!=(k|0)){if(n+16>>>0>=g>>>0){break r}while(1){g=g-1|0;t[g|0]=48;if(n+16>>>0<g>>>0){continue}break}break r}if((g|0)!=(l|0)){break r}t[n+24|0]=48;g=d}sf(a,g,l-g|0);k=k+4|0;if(r>>>0>=k>>>0){continue}break}if(u){sf(a,16736,1)}if((m|0)<=0|h>>>0<=k>>>0){break q}while(1){g=Dn(v[k>>2],0,l);if(g>>>0>n+16>>>0){while(1){g=g-1|0;t[g|0]=48;if(n+16>>>0<g>>>0){continue}break}}sf(a,g,(m|0)<9?m:9);g=m-9|0;k=k+4|0;if(h>>>0<=k>>>0){break p}d=(m|0)>9;m=g;if(d){continue}break}break p}s:{if((m|0)<0){break s}i=h>>>0>k>>>0?h:k+4|0;g=n+16|0;d=g|8;r=g|9;h=k;while(1){g=Dn(v[h>>2],0,r);if((r|0)==(g|0)){t[n+24|0]=48;g=d}t:{if((h|0)!=(k|0)){if(n+16>>>0>=g>>>0){break t}while(1){g=g-1|0;t[g|0]=48;if(n+16>>>0<g>>>0){continue}break}break t}sf(a,g,1);g=g+1|0;if(!(l|m)){break t}sf(a,16736,1)}C=g;g=r-g|0;sf(a,C,(g|0)>(m|0)?m:g);m=m-g|0;h=h+4|0;if(i>>>0<=h>>>0){break s}if((m|0)>=0){continue}break}}Gf(a,48,m+18|0,18,0);sf(a,y,z-y|0);break o}g=m}Gf(a,48,g+9|0,9,0)}Gf(a,32,c,f,e^8192);i=(c|0)<(f|0)?f:c;break b}m=(f<<26>>31&9)+A|0;u:{if(d>>>0>11){break u}g=12-d|0;s=16;while(1){s=s*16;g=g-1|0;if(g){continue}break}if(w[m|0]==45){b=-(s+(-b-s));break u}b=b+s-s}l=x|2;k=f&32;h=v[n+44>>2];g=h>>31;g=Dn((g^h)-g|0,0,z);if((z|0)==(g|0)){t[n+15|0]=48;g=n+15|0}r=g-2|0;t[r|0]=f+15;t[g-1|0]=(h|0)<0?45:43;i=e&8;h=n+16|0;while(1){f=h;if(D(b)<2147483648){g=~~b}else{g=-2147483648}t[h|0]=k|w[g+77088|0];b=(b-+(g|0))*16;h=f+1|0;if(!(!(i|(d|0)>0)&b==0|(h-(n+16|0)|0)!=1)){t[f+1|0]=46;h=f+2|0}if(b!=0){continue}break}i=-1;p=z-r|0;f=p+l|0;if((2147483645-f|0)<(d|0)){break b}v:{w:{if(!d){break w}k=h-(n+16|0)|0;if((k-2|0)>=(d|0)){break w}g=d+2|0;break v}k=h-(n+16|0)|0;g=k}d=g+f|0;Gf(a,32,c,d,e);sf(a,m,l);Gf(a,48,c,d,e^65536);sf(a,n+16|0,k);Gf(a,48,g-k|0,0,0);sf(a,r,p);Gf(a,32,c,d,e^8192);i=(c|0)<(d|0)?d:c}jb=n+560|0;return i|0}function Bfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=jb-272|0;jb=e;yc(b);d=jb-16|0;jb=d;f=e+120|0;kR(d+8|0,f);g=v[d+12>>2];mc(d,v[b>>2],v[b+8>>2],v[d+8>>2],v[d+12>>2]);h=v[d+4>>2];if((h|0)==(g|0)){Zb(b,v[d+12>>2])}jb=d+16|0;d=(g|0)==(h|0);if(!d){jR(f)}a:{b:{if(!d){break b}if(!lR(e+120|0)){break b}if(!c){i=1;break b}Ad(a,4194304);d=e+32|0;g=xc(d,17003);Ib(a+1298344|0,g);zb(g);g=xc(d,10087);Ib(a+1298356|0,g);zb(g);v[a+1298404>>2]=5;n=a,o=Cd(x[e+198>>1],x[e+200>>1],127),u[n+480188>>1]=o;g=w[e+189|0];v[a+480228>>2]=(g|0)==255?48:g;v[a+480196>>2]=w[e+187|0];v[a+480204>>2]=B(w[e+188|0],1e4);g=e+96|0;pf(g,e+120|4,59,3);Ec(d,g);Ac(a+1298308|0,d);yb(d);d=x[e+202>>1]|x[e+204>>1]<<16;c:{if(d>>>0<5){break c}if(!cd(b,d-4|0)){break c}if(!Fh(b,14209)){break c}so(Vb(v[a+484360>>2],w[a+484376|0]),b,x[e+192>>1],65535,65535)}d:{d=x[e+206>>1]|x[e+208>>1]<<16;if(d>>>0<5){break d}if(!cd(b,d-4|0)){break d}if(!Fh(b,13738)){break d}d=0;while(1){if((d|0)==32){break d}g=(d<<5)+a|0;df(g+480280|0);n=g+480284|0,o=((((Le(b)^-1)&15)<<8|8)>>>0)/15|0,u[n>>1]=o;d=d+1|0;continue}}d=x[e+214>>1]|x[e+216>>1]<<16;e:{if(d>>>0<5){break e}if(!cd(b,d-4|0)){break e}if(!Fh(b,14066)){break e}d=e+32|0;$d(d,b,x[e+196>>1]<<6);k=c&2;h=a+480190|0;g=jc(e+96|0,d);Ab(d);j=e+45|0;d=0;f:{while(1){if(x[e+196>>1]<=(d&65535)>>>0){break f}v[23588]=0;f=Q(661,g|0,e+32|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break a}if(!f){break f}f=w[e+77|0]|w[e+78|0]<<8;u[e+30>>1]=f;g:{h:{if((f-1&65535)>>>0>3998){break h}f=B(f,104)+a|0;i=f+484380|0;if(Zd(v[i>>2],v[f+484400>>2])){break h}n=h,o=x[ke(h,e+30|0)>>1],u[n>>1]=o;v[23588]=0;R(662,e+32|0,i|0);f=v[23588];v[23588]=0;if((f|0)==1){break g}XT(e,1,j);v[23588]=0;R(222,e+16|0,e|0);f=v[23588];v[23588]=0;if((f|0)==1){break a}f=e+16|0;Cc(((x[e+30>>1]<<5)+a|0)+946304|0,f);yb(f);if(!k){break h}v[23588]=0;Q(155,b|0,w[e+69|0]|w[e+70|0]<<8|(w[e+71|0]<<16|w[e+72|0]<<24))|0;f=v[23588];v[23588]=0;if((f|0)==1){break g}i=1;l=e+16|0;f=w[e+79|0];m=Zc(l,f&4?16:8,1,0,0);i:{j:{if(f&8){break j}i=2;if(f&16){break j}if(f&127){break i}}cg(m,i)}v[23588]=0;W(219,l|0,(B(x[e+30>>1],104)+a|0)+484380|0,b|0)|0;f=v[23588];v[23588]=0;if((f|0)!=1){break h}break a}d=d+1|0;continue}break}break a}Ab(g)}i=1;if(!(c&1)){break b}k:{c=x[e+210>>1]|x[e+212>>1]<<16;if(c>>>0<5){break k}if(!cd(b,c-4|0)){break k}if(!Fh(b,13588)){break k}k=a+484344|0;wg(k,x[e+194>>1]);f=0;while(1){if(x[e+194>>1]<=f>>>0){break k}if(!wA(b,e+16|0)){break k}l:{d=x[e+16>>1];if(d>>>0>3){c=e+96|0;$d(c,b,(d+15&131056)-4|0);g=jc(e+32|0,c);Ab(c);v[23588]=0;c=W(226,k|0,f&65535,w[e+18|0])|0;d=v[23588];v[23588]=0;if((d|0)==1){break l}h=0;m:{if(!c){break m}while(1){n:{c=v[g>>2];v[23588]=0;d=W(156,c|0,v[e+40>>2],1)|0;c=v[23588];v[23588]=0;o:{if((c|0)!=1){c=w[e+18|0];if(!(d&c>>>0>(h&255)>>>0)){break n}v[23588]=0;d=S(206,g|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break a}if(d){break o}h=h+1|0;continue}break a}c=v[a+484344>>2];u[e+96>>1]=d&31;u[e>>1]=x[a+480188>>1]-1;c=Yb(c,f);c=id(v[c>>2],v[v[c+48>>2]+12>>2],h,x[Vc(e+96|0,e)>>1]);if(d&128){v[23588]=0;R(260,e+96|0,g|0);j=v[23588];v[23588]=0;if((j|0)==1){break a}t[c|0]=w[e+96|0]+36;n=c,o=w[Nc(e+96|0)|0],t[n+1|0]=o}if(d&64){t[c+2|0]=1;v[23588]=0;j=S(206,g|0)|0;l=v[23588];v[23588]=0;if((l|0)==1){break a}t[e+96|0]=j;t[e|0]=64;n=c,o=w[Wb(e+96|0,e)|0],t[n+4|0]=o}if(!(d&32)){continue}v[23588]=0;R(260,e+96|0,g|0);d=v[23588];v[23588]=0;p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{if((d|0)!=1){d=w[Nc(e+96|0)|0];t[c+5|0]=d;switch(w[e+96|0]-1|0){case 71:break q;case 70:break r;case 69:break s;case 60:break t;case 59:break u;case 52:break v;case 51:break w;case 50:break x;case 49:break y;case 42:break z;case 41:break A;case 40:break B;case 39:break C;case 30:break D;case 29:break E;case 22:break F;case 21:break G;case 20:break H;case 19:break I;case 16:break J;case 15:break K;case 14:break L;case 13:break M;case 12:break N;case 11:break O;case 10:break P;case 9:break Q;case 3:break R;case 2:break S;case 1:break T;case 0:break U;default:break p}}break a}t[c+3|0]=11;t[c+5|0]=d<<4|15;continue}t[c+3|0]=11;t[c+5|0]=d<<4;continue}t[c+3|0]=11;t[c+5|0]=d|240;continue}t[c+3|0]=11;t[c+5|0]=d&15;continue}t[c+3|0]=2;t[c+5|0]=d|240;continue}t[c+3|0]=2;continue}t[c+3|0]=3;t[c+5|0]=d|240;continue}t[c+3|0]=3;continue}t[c+3|0]=4;continue}t[c+3|0]=20;t[c+5|0]=d|16;continue}t[c+3|0]=6;t[c+5|0]=d<<4;continue}t[c+3|0]=6;t[c+5|0]=d&15;continue}t[c+3|0]=5;continue}t[c+3|0]=20;t[c+5|0]=d|48;continue}t[c+3|0]=7;t[c+5|0]=d<<4;continue}t[c+3|0]=7;t[c+5|0]=d&15;continue}t[c+3|0]=8;continue}t[c+3|0]=20;t[c+5|0]=d|64;continue}t[c+3|0]=10;v[23588]=0;d=S(206,g|0)|0;j=v[23588];v[23588]=0;if((j|0)!=1){t[c+5|0]=d;v[23588]=0;Q(188,g|0,1)|0;c=v[23588];v[23588]=0;if((c|0)!=1){continue}}break a}t[c+3|0]=15;t[c+5|0]=d&15;continue}t[c+3|0]=20;t[c+5|0]=d|192;continue}t[c+3|0]=20;t[c+5|0]=d|208;continue}t[c+3|0]=12;continue}t[c+3|0]=14;continue}t[c+3|0]=20;t[c+5|0]=d|176;continue}t[c+3|0]=20;t[c+5|0]=d|224;continue}t[c+3|0]=16;continue}t[c+3|0]=17;continue}t[c+3|0]=1;continue}t[c+3|0]=20;t[c+5|0]=d&15|32;continue}t[c+3|0]=20;t[c+5|0]=d&15|128;continue}t[c+3|0]=0;continue}break}if((c|0)==64){break m}ze(Yb(v[k>>2],f),Eh(Te(Ne(e+96|0,14,0),c-1|0)))}Ab(g)}f=f+1|0;continue}break}break a}c=x[e+218>>1]|x[e+220>>1]<<16;if(!c){break b}cd(b,c);uB(a+1298332|0,b,Rg(b),4)}jb=e+272|0;return i|0}a=P()|0;O()|0;Ab(g);T(a|0);L()}function oja(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;k=jb-128|0;jb=k;t[k+127|0]=d;a:{if(!c|(e|0)<0&c>>>0>=176){break a}t[b+5|0]=d;t[k+8|0]=15;l=k+127|0;p=k+8|0;j=p;o=w[Wb(l,j)|0];t[k+8|0]=14;l=w[Wb(l,j)|0];v[k+8>>2]=d+31>>>5;v[k+120>>2]=14;r=k+120|0;n=v[sd(j,r)>>2];v[k+8>>2]=d+127>>>7;v[k+120>>2]=14;q=c&15;j=q<<8|d;p=sd(p,r);b:{switch((c>>>4|0)-2|0){case 0:t[b+2|0]=1;t[b+4|0]=j>>>2;break a;case 1:t[b+2|0]=1;if(!j){t[b+4|0]=0;break a}s=b,y=sg(dB(j)>>>2|0),t[s+4|0]=y;break a;case 2:t[b+3|0]=9;t[b+5|0]=j>>>4;break a;case 3:t[b+3|0]=23;t[b+5|0]=j+1>>>5;break a;case 4:t[b+3|0]=23;if(j){a=sg(dB(j)>>>5|0)}else{a=0}t[b+5|0]=a;break a;case 5:t[b+5|0]=q;t[b+3|0]=15;break a;case 6:t[b+3|0]=15;if((e|0)>=0){if(w[b+2|0]){break a}t[b+2|0]=2;s=b,y=Hc(((q<<6|7)>>>0)/15|0,0),t[s+4|0]=y;break a}t[b+2|0]=1;t[b+5|0]=q;t[b+4|0]=d+3>>>2;break a;case 7:t[b+3|0]=10;c:{if((e|0)>5){break c}if(!j){t[b+5|0]=1;break a}c=uq(a,f,g);if(!c){break c}a=Gi(a,c);c=x[a+34>>1];if(c&1){j=j>>>1|0;v[k+120>>2]=j}if(!(c&2)){break c}c=v[a>>2];if(c>>>0>=j<<8>>>0){break c}v[k+120>>2]=v[a+4>>2]+8>>>8;wc(k+120|0,c-1>>>8|0);j=v[k+120>>2]}t[b+5|0]=j;if(w[b+2|0]|j>>>0<256){break a}t[b+2|0]=15;v[k+116>>2]=j>>>8;cB(k+8|0);v[k+112>>2]=9;s=b,y=v[Jb(k+116|0,k+112|0)>>2],t[s+4|0]=y;break a;default:break b}}j=v[p>>2];d:{switch(c-160|0){default:e:{switch(c-1|0){case 0:case 1:case 2:case 3:case 6:case 10:case 14:Of(b,c,d);f:{switch(w[b+3|0]-16|0){case 1:v[h>>2]=B(w[b+5|0],1e4);break a;case 0:break f;default:break a}}a=w[b+5|0];if(!a){break a}v[i>>2]=a;break a;case 4:t[b+3|0]=4;if(w[b+2|0]){break a}t[b+4|0]=0;t[b+2|0]=8;break a;case 5:t[b+3|0]=5;if(w[b+2|0]){break a}t[b+4|0]=0;t[b+2|0]=11;break a;case 7:if(!_c(w[b|0])|!d){break a}t[b+3|0]=35;t[b+5|0]=(d>>>1&120|128)-(d<<3&120);e=a+480192|0;if(x[e>>1]){break a}u[k+8>>1]=255;c=x[Vc(a+480190|0,k+8|0)>>1];u[e>>1]=c;b=1;while(1){d=b&65535;if(d>>>0>(c&65535)>>>0){break a}c=Pu(a,d,d);if(c){t[c+33|0]=2;d=(d<<5)+a|0;f=d+946304|0;g=v[f+4>>2];v[c+492>>2]=v[f>>2];v[c+496>>2]=g;f=d+946312|0;g=v[f+4>>2];v[c+500>>2]=v[f>>2];v[c+504>>2]=g;f=d+946320|0;g=v[f+4>>2];v[c+508>>2]=v[f>>2];v[c+512>>2]=g;d=d+946328|0;f=v[d+4>>2];v[c+516>>2]=v[d>>2];v[c+520>>2]=f;Lj(c,127,1);Kj(c,0,1)}b=b+1|0;c=x[e>>1];continue};case 8:t[b+3|0]=19;t[b+5|0]=o|208;break a;case 9:t[b+3|0]=25;break a;case 11:if(d>>>0>2){break a}t[b+3|0]=19;t[b+5|0]=d|64;break a;case 12:t[b+3|0]=14;break a;case 13:if(d>>>0>2){break a}t[b+3|0]=19;t[b+5|0]=d|112;break a;case 15:t[b+3|0]=1;break a;case 16:case 17:t[b+3|0]=19;t[b+5|0]=l|c<<4;break a;case 18:t[b+3|0]=15;break a;case 19:t[b+3|0]=11;t[b+5|0]=l<<4;break a;case 20:t[b+5|0]=l;t[b+3|0]=11;break a;case 23:t[b+3|0]=6;t[b+5|0]=l<<4;break a;case 24:t[b+5|0]=l;t[b+3|0]=6;break a;case 27:t[b+3|0]=7;t[b+5|0]=l<<4;break a;case 28:break e;default:break a}}t[b+5|0]=l;t[b+3|0]=7;break a;case 0:if(!d){break a}t[b+3|0]=24;t[b+5|0]=n<<4;break a;case 1:if(!d){break a}t[b+5|0]=n;t[b+3|0]=24;break a;case 4:t[b+3|0]=11;t[b+5|0]=l<<4|15;break a;case 5:t[b+3|0]=11;t[b+5|0]=l|240;break a;case 6:if(!d){break a}t[b+3|0]=24;t[b+5|0]=n<<4|15;break a;case 7:if(!d){break a}t[b+3|0]=24;t[b+5|0]=n|240;break a;case 8:if(!d){break a}t[b+3|0]=16;v[i>>2]=d;break a;case 9:if((e|0)>5){break a}a=v[h>>2];if(a>>>0<1e4){break a}t[b+3|0]=17;m=122925/(+(a>>>0)/1e4)+ +((d<<1)-256|0);s=b,y=sk(245850/(m+m)),t[s+5|0]=y;break a;case 10:t[b+3|0]=19;t[b+5|0]=o|224;break a;case 12:t[b+3|0]=28;t[b+5|0]=o|16;break a;case 13:t[b+3|0]=28;t[b+5|0]=o|32;break a;case 14:t[b+3|0]=29;t[b+5|0]=l<<3&240;break a;case 15:t[b+3|0]=29;t[b+5|0]=(l&254)>>>1;break a;case 16:t[b+3|0]=18;break a;case 17:t[b+3|0]=19;t[b+5|0]=o|176;break a;case 18:case 19:t[b+3|0]=20;t[b+5|0]=d?120:119;break a;case 20:t[b+3|0]=20;t[b+5|0]=d?125:123;break a;case 21:t[b+3|0]=20;t[b+5|0]=d?122:121;break a;case 22:t[b+3|0]=20;t[b+5|0]=d?126:123;break a;case 26:t[b+3|0]=10;t[b+5|0]=d+15>>>4;break a;case 27:t[b+5|0]=1;t[b+3|0]=10;break a;case 30:case 31:if(!d|(!g|!f)){break a}o=v[h>>2];if(o>>>0<1e4){break a}l=v[i>>2];if(!l){break a}i=uq(a,f,g);if(!i){break a}j=Gi(a,i);n=x[j+34>>1];g:{if(!(n&2)){i=v[j>>2];break g}i=v[j+8>>2]-((e|0)<6?v[j+4>>2]:0)|0;if(!(n&4)){break g}i=i<<((e|0)>5)}if(!i|(e|0)<6&i>>>0<1024){break a}n=v[j+24>>2];if(!n){break a}h:{if(x[a+480192>>1]<g>>>0){break h}a=v[((g<<2)+a|0)+900380>>2];if(!a){break h}m=+(w[Kb(a+108|0,f-1|0)|0]-f|0)}a=(c|0)==190;m=mi(m/12+(a?(e|0)<6?+t[j+37|0]/-1536:-0:-0))*+(n>>>0);if(a){t[b+3|0]=17;a=sk(m*.5*(+(B(d,l)>>>0)*2.5)/+(i>>>0));t[b+5|0]=a;v[h>>2]=B(a,1e4);break a}m=su(lK(+(i>>>0)/m/(+(B(d,l)>>>0)*2.5/(+(o>>>0)/1e4)))*12+61,1,120);i:{if(m<4294967296&m>=0){a=~~m>>>0;break i}a=0}c=_c(w[b|0]);t[b|0]=a;m=(m-H(m))*64+128;j:{if(m<4294967296&m>=0){a=~~m>>>0;break j}a=0}t[b+5|0]=a;if((a|0)!=128){t[b+3|0]=35}if(c){break a}if(!w[b+2|0]){t[b+4|0]=9;t[b+2|0]=11;break a}t[b+5|0]=255;t[b+3|0]=4;break a;case 32:a=d>>>4|0;if(a-1>>>0>1){break a}t[b+3|0]=20;t[b+5|0]=a-99;break a;case 34:t[b+3|0]=21;t[b+5|0]=d<<2;break a;case 35:t[b+3|0]=21;s=b,y=sg(dB(d<<4)>>>6|0),t[s+5|0]=y;break a;case 36:case 38:t[b+3|0]=22;t[b+5|0]=j<<4;break a;case 37:case 39:t[b+5|0]=j;t[b+3|0]=22;break a;case 40:t[b+3|0]=22;t[b+5|0]=l<<4|15;break a;case 2:case 3:case 11:case 23:case 24:case 25:case 28:case 29:case 33:break a;case 41:break d}}t[b+3|0]=22;t[b+5|0]=l|240}jb=k+128|0}function Mea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=jb-208|0;jb=d;yc(c);a:{if(!uo(c,d+192|0)){break a}if(Rb(d+192|0,13769,4)){break a}f=d+200|0;if(Rb(f,14142,4)){if(Rb(f,14246,4)){break a}}e=jb-32|0;jb=e;i=d+176|0;g=Sb(i);b:{c:{d:{e:{f:{while(1){h=v[c+8>>2];j=v[c>>2];v[23588]=0;h=W(156,j|0,h|0,8)|0;j=v[23588];v[23588]=0;if((j|0)==1){break d}if(!h){break e}v[23588]=0;R(787,e|0,c|0);h=v[23588];v[23588]=0;if((h|0)!=1){v[23588]=0;R(788,g|0,e|0);h=v[23588];v[23588]=0;if((h|0)==1){break f}zd(e);continue}break}a=P()|0;O()|0;break c}a=P()|0;O()|0;zd(e);break c}jb=e+32|0;break b}a=P()|0;O()|0}Yd(g);T(a|0);L()}v[23588]=0;U(717,d+152|0,i|0,1129270605);c=v[23588];v[23588]=0;g:{h:{i:{j:{k:{l:{m:{if((c|0)!=1){v[23588]=0;c=Q(718,d+152|0,d+128|0)|0;e=v[23588];v[23588]=0;n:{o:{if((e|0)!=1){if(!c){break g}if(!bc(x[d+130>>1]|x[d+132>>1]<<16)){break g}if((Hb(x[d+128>>1])-3&65535)>>>0<65534){break g}if((Hb(x[d+134>>1])-65&65535)>>>0<65472){break g}v[d+124>>2]=1162760014;c=1;if(!Rb(f,14246,4)){v[23588]=0;c=Q(606,d+152|0,d+124|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break o}if(!c){break g}c=v[d+124>>2]!=1936684916}v[23588]=0;U(717,d+104|0,d+176|0,1397968452);e=v[23588];v[23588]=0;p:{q:{if((e|0)!=1){v[23588]=0;k=Q(719,d+104|0,d+96|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break p}if(k){break q}break h}c=P()|0;O()|0;break j}f=((Hb(x[d+134>>1])-1|0)/8|0)-1|0;g=f<<3;e=g&31;g=Zc(d+88|0,(f>>>0<7?(g&63)>>>0>=32?4196360>>>e|0:((1<<e)-1&4196360)<<32-e|136321040>>>e:8)&255,(Hb(x[d+128>>1])|0)==2?2:1,c,0);c=v[d+124>>2];r:{if((c|0)!=544694642){s:{t:{if(!((c|0)==842222662|(c|0)==842230886|(c|0)==875973702)){if((c|0)==2002873461){break s}if((c|0)==1463897153){break t}if((c|0)==1463897173){break s}if((c|0)==2002873441){break t}if((c|0)!=875981926){break r}}cg(g,3);break r}cg(g,17);wd(g,16);break r}cg(g,16);wd(g,16);break r}cg(g,1)}c=v[d+96>>2];v[23588]=0;c=W(156,v[d+104>>2],v[d+112>>2],bc(c)|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break l}if(c){c=v[d+96>>2];v[23588]=0;Q(188,d+104|0,bc(c)|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break l}}rt(a,b);v[23588]=0;c=B(b,104)+a|0;i=c+484380|0;R(277,i|0,0);e=v[23588];v[23588]=0;u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{if((e|0)==1){break D}r=i,s=bc(x[d+130>>1]|x[d+132>>1]<<16),v[r>>2]=s;j=c+484404|0;c=w[d+138|0]|w[d+139|0]<<8|(w[d+140|0]<<16|w[d+141|0]<<24);f=c<<24|c<<8&16711680|(c>>>8&65280|c>>>24);h=30-w[d+137|0]|0;e=0;while(1){c=f;if(h&255){f=c>>>1|0;h=h-1|0;e=c;continue}break}v[j>>2]=c+(e&1);v[23588]=0;W(219,g|0,i|0,d+104|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break D}v[23588]=0;U(717,d- -64|0,d+176|0,1296126539);c=v[23588];v[23588]=0;if((c|0)==1){break C}v[23588]=0;c=S(178,v[d+64>>2])|0;e=v[23588];v[23588]=0;if((e|0)==1){break B}if(!c){break u}v[23588]=0;U(717,d+16|0,d+176|0,1229869908);c=v[23588];v[23588]=0;if((c|0)==1){break A}v[23588]=0;c=Q(720,d+16|0,d+40|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break z}Ab(d+16|0);if(!c){break u}v[23588]=0;f=S(271,d- -64|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break y}e=Sb(d+16|0);v[23588]=0;R(721,e|0,f|0);c=v[23588];v[23588]=0;if((c|0)==1){break w}c=0;while(1){if((c|0)==(f|0)){break x}v[23588]=0;g=Q(722,d- -64|0,d|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break w}if(!g){break x}v[23588]=0;R(723,e|0,d|0);g=v[23588];v[23588]=0;if((g|0)==1){break w}v[23588]=0;Q(188,d- -64|0,w[d+6|0]|1)|0;g=v[23588];v[23588]=0;if((g|0)==1){break w}c=c+1|0;continue}}c=P()|0;O()|0;break k}c=P()|0;O()|0;break k}c=P()|0;O()|0;break m}c=P()|0;O()|0;break m}c=P()|0;O()|0;Ab(d+16|0);break m}c=P()|0;O()|0;break m}c=Hb(x[d+48>>1]);if(c){f=(B(b,104)+a|0)+484414|0;u[f>>1]=x[f>>1]&65511|((c|0)==2)<<4|8}c=Hb(x[d+54>>1]);if(c){f=(B(b,104)+a|0)+484414|0;u[f>>1]=x[f>>1]&65529|((c|0)==2?4:2)|2}r=d,s=Eb(v[e>>2]),v[r>>2]=s;c=B(b,104)+a|0;g=c+484388|0;h=c+484384|0;j=c+484396|0;l=c+484392|0;m=Eb(v[e+4>>2]);n=x[d+50>>1];o=x[d+52>>1];p=x[d+56>>1];q=x[d+58>>1];while(1){c=v[d>>2];if(!Ob(c,m)){break v}f=Hb(w[c|0]|w[c+1|0]<<8);if((f|0)==(Hb(n)|0)){r=l,s=bc(w[c+2|0]|w[c+3|0]<<8|(w[c+4|0]<<16|w[c+5|0]<<24)),v[r>>2]=s;f=Hb(w[c|0]|w[c+1|0]<<8)}if((Hb(o)|0)==(f|0)){r=j,s=bc(w[c+2|0]|w[c+3|0]<<8|(w[c+4|0]<<16|w[c+5|0]<<24)),v[r>>2]=s;f=Hb(w[c|0]|w[c+1|0]<<8)}if((Hb(p)|0)==(f|0)){r=h,s=bc(w[c+2|0]|w[c+3|0]<<8|(w[c+4|0]<<16|w[c+5|0]<<24)),v[r>>2]=s;f=Hb(w[c|0]|w[c+1|0]<<8)}if((f|0)==(Hb(q)|0)){r=g,s=bc(w[c+2|0]|w[c+3|0]<<8|(w[c+4|0]<<16|w[c+5|0]<<24)),v[r>>2]=s}v[d>>2]=v[d>>2]+7;continue}}c=P()|0;O()|0;mO(e);break m}Ck(i);mO(e)}v[23588]=0;U(717,d+16|0,d+176|0,1312902469);c=v[23588];v[23588]=0;if((c|0)==1){break n}v[23588]=0;c=S(178,v[d+16>>2])|0;e=v[23588];v[23588]=0;E:{if((e|0)==1){break E}F:{if(c){v[23588]=0;c=S(160,v[d+16>>2])|0;e=v[23588];v[23588]=0;if((e|0)==1){break E}v[23588]=0;U(314,d+16|0,((b<<5)+a|0)+946304|0,c|0);b=v[23588];v[23588]=0;if((b|0)!=1){break F}break E}v[23588]=0;c=Q(55,d|0,21619)|0;e=v[23588];v[23588]=0;if((e|0)==1){break E}Cc(((b<<5)+a|0)+946304|0,c);yb(c)}Dz(i,v[a+480180>>2]);tj(i,a);Ab(d+16|0);Ab(d- -64|0);break h}c=P()|0;O()|0;Ab(d+16|0);break m}c=P()|0;O()|0;break k}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break m}c=P()|0;O()|0;break i}Ab(d- -64|0);break k}c=P()|0;O()|0}Ab(d+104|0)}Ab(d+152|0)}Yd(d+176|0);T(c|0);L()}Ab(d+104|0)}Ab(d+152|0);Yd(d+176|0)}jb=d+208|0;return k|0}function lfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0;e=jb-224|0;jb=e;yc(b);a:{if(!Yt(b,e+160|0)){break a}if(!OQ(e+160|0)){break a}if(!Pb(v[b>>2],v[b+8>>2],Dc(NQ(e+160|0),mb))){break a}if(!c){d=1;break a}Ad(a,256);f=e+144|0;Cj(f,2,e+160|0);d=e+48|0;Ec(d,f);Ac(a+1298308|0,d);yb(d);f=x[e+210>>1];v[a+480260>>2]=64;v[a+480264>>2]=32767;u[a+480188>>1]=4;u[a+480190>>1]=f;Nb(a+1074312|0,107,1);f=w[e+203|0];f=f?f:96;k=Vz(f);v[a+480196>>2]=f>>>4;v[a+480204>>2]=k;t[e+48|0]=64;A=a,C=w[Wb(e+202|0,d)|0]<<2,v[A+480200>>2]=C;d=0;b:{c:{d:{e:{f:{g:{while(1){if((d|0)==4){h:{k=Sb(e+144|0);m=Sb(e+128|0);v[23588]=0;Q(155,b|0,x[e+192>>1]<<4)|0;d=v[23588];v[23588]=0;i:{if((d|0)==1){break i}v[23588]=0;W(217,b|0,k|0,x[e+208>>1])|0;d=v[23588];v[23588]=0;if((d|0)==1){break i}v[23588]=0;Q(155,b|0,x[e+194>>1]<<4)|0;d=v[23588];v[23588]=0;if((d|0)==1){break i}v[23588]=0;W(217,b|0,m|0,x[e+210>>1])|0;d=v[23588];v[23588]=0;if((d|0)==1){break i}v[23588]=0;Q(155,b|0,(x[e+196>>1]<<4)+32|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break i}d=a+484376|0;f=w[d|0];i=v[a+484360>>2];v[23588]=0;R(324,Vb(i,f)|0,x[e+212>>1]);f=v[23588];v[23588]=0;if((f|0)==1){break i}d=Vb(v[a+484360>>2],w[d|0]);A=e,C=Eb(v[d>>2]),v[A+48>>2]=C;d=Eb(v[d+4>>2]);j:{while(1){f=v[e+48>>2];if(!Ob(f,d)){d=0;if(!QQ(Vb(v[a+484360>>2],w[a+484376|0]))){break b}i=c&2;j=e+48|1;d=1;break j}v[23588]=0;i=S(206,b|0)|0;j=v[23588];v[23588]=0;k:{if((j|0)==1){break k}u[f>>1]=i;v[23588]=0;Q(188,b|0,4)|0;f=v[23588];v[23588]=0;if((f|0)==1){break k}Re(e+48|0);continue}break}d=P()|0;O()|0;break c}l:{m:{n:{o:{while(1){f=d&65535;if(f>>>0>x[e+210>>1]){break l}g=cc(v[m>>2],f-1|0);g=w[g|0]|w[g+1|0]<<8;v[23588]=0;g=Q(155,b|0,g<<4)|0;h=v[23588];v[23588]=0;p:{if((h|0)!=1){if(g){break p}d=0;break b}d=P()|0;O()|0;break c}v[23588]=0;Q(670,b|0,e+48|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break o}v[23588]=0;g=(B(f,104)+a|0)+484380|0;U(671,e+48|0,g|0,0);h=v[23588];v[23588]=0;if((h|0)==1){break o}h=e+16|0;tk(h,2,j);v[23588]=0;R(222,e+32|0,h|0);h=v[23588];v[23588]=0;if((h|0)==1){break n}h=((f<<5)+a|0)+946304|0;f=e+32|0;Cc(h,f);yb(f);q:{r:{if(!i|!v[e+64>>2]){break r}f=bR(e+48|0);v[23588]=0;f=Q(155,b|0,f|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break m}if(!f){break r}f=e+32|0;aR(f,w[e+78|0],w[e+79|0],1);v[23588]=0;W(219,f|0,g|0,b|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break q}}d=d+1|0;continue}break}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}t[e+15|0]=1;d=v[k>>2];s:{if(oc(d,v[k+4>>2])|x[e+188>>1]==26){break s}f=w[d|0]|w[d+1|0]<<8;d=0;v[23588]=0;f=Q(155,b|0,f<<4)|0;i=v[23588];v[23588]=0;if((i|0)==1){break h}if(!f){break b}v[23588]=0;d=S(194,b|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break h}if((d|0)!=x[e+188>>1]){break s}t[e+15|0]=0}n=c&1;if(n){v[23588]=0;R(225,a+484344|0,x[e+208>>1]);c=v[23588];v[23588]=0;if((c|0)==1){break h}}h=a+484344|0;c=e+48|0;p=c|5;q=c|4;r=c|2;s=c|1;y=a+480188|0;f=0;while(1){t:{if(!n|x[e+208>>1]<=f>>>0){break t}v[23588]=0;c=W(226,h|0,f&65535,64)|0;d=v[23588];v[23588]=0;if((d|0)==1){break g}if(!c){break t}c=cc(v[k>>2],f);c=w[c|0]|w[c+1|0]<<8;v[23588]=0;c=Q(155,b|0,c<<4)|0;d=v[23588];v[23588]=0;if((d|0)==1){break g}d=0;if(!c){break b}if(!w[e+15|0]){v[23588]=0;c=S(194,b|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break g}if(c>>>0>2112){break b}}u[e+16>>1]=65535;v[e+32>>2]=63;u:while(1){c=Yb(v[h>>2],f);z=Cf(v[c>>2],v[v[c+48>>2]+12>>2],d);v:while(1){c=d;while(1){if(c>>>0<=63){v[23588]=0;i=S(206,b|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break f}if(!i){d=64;if(c>>>0>62){continue v}d=c+1|0;continue u}d=i&31;j=B(d,6)+z|0;l=tg(e+48|0);g=d>>>0<x[y>>1];o=g?j:l;if(i&32){v[23588]=0;R(260,e|0,b|0);d=v[23588];v[23588]=0;w:{x:{y:{if((d|0)!=1){l=Nc(e);d=w[e|0];if(d>>>0>239){break y}d=$Q((B(d>>>4|0,12)+(d&15)|0)+37|0);break x}d=P()|0;O()|0;break c}z:{switch(d-254|0){case 0:break x;case 1:break z;default:break w}}d=0}t[o|0]=d}t[(g?j+1|0:s)|0]=w[l|0]}if(i&64){v[23588]=0;d=S(206,b|0)|0;l=v[23588];v[23588]=0;if((l|0)==1){break e}t[e|0]=d;t[(g?j+2|0:r)|0]=1;t[e+14|0]=64;A=g?j+4|0:q,C=w[Wb(e,e+14|0)|0],t[A|0]=C}if(!(i&128)){continue}v[23588]=0;R(260,e|0,b|0);d=v[23588];v[23588]=0;if((d|0)==1){break d}A=g?j+5|0:p,C=w[Nc(e)|0],t[A|0]=C;PQ(o,w[e|0],c,255,e+16|0,e+32|0);continue}break}break}break}c=x[e+16>>1];if((c|0)!=65535){ze(Yb(v[h>>2],f),Lm(Te(Ne(e+48|0,12,c&255),v[e+32>>2])))}f=f+1|0;continue}break}v[23588]=0;b=Q(1,e+48|0,6091)|0;c=v[23588];v[23588]=0;A:{B:{C:{if((c|0)!=1){Ib(a+1298344|0,b);zb(b);v[23588]=0;b=Q(1,e+32|0,5277)|0;c=v[23588];v[23588]=0;if((c|0)==1){break C}Ib(a+1298356|0,b);zb(b);v[a+1298404>>2]=5;v[23588]=0;R(673,e|0,4408);b=v[23588];v[23588]=0;if((b|0)==1){break B}v[23588]=0;U(305,e+16|0,e|0,e+15|0);b=v[23588];v[23588]=0;if((b|0)==1){break A}b=a+1298368|0;a=e+16|0;Ib(b,a);zb(a);ac(e);d=1;break b}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;ac(e);break c}d=P()|0;O()|0;break c}}else{f=(d<<5)+a|0;df(f+480280|0);u[f+480284>>1]=d&1?64:192;d=d+1|0;continue}break}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0}nd(m);nd(k);T(d|0);L()}nd(m);nd(k)}jb=e+224|0;return d|0}function via(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;f=jb-224|0;jb=f;if(Fh(b,13784)){if(d){t[d|0]=1}k=a+480204|0;n=a+480216|0;o=a+480220|0;p=a+480224|0;l=a+1074368|0;s=a+480228|0;z=a+480232|0;q=a+480200|0;m=a+480268|0;A=a+1298320|0;C=a+480248|0;D=mu(a+1074312|0);E=a+480180|0;F=a+484376|0;G=a+480190|0;a:{b:{c:{d:{e:{f:{g:{h:{while(1){if(!Pb(v[b>>2],v[b+8>>2],7)){break a}e=Bg(b);g=Rg(b);if((e|0)==(w[21595]|w[21596]<<8|(w[21597]<<16|w[21598]<<24))){yg(b,6);break a}if(!(e&1616928864)|e&-2139062144){break a}if(!Pb(v[b>>2],v[b+8>>2],g)){break a}d=f+176|0;$d(d,b,g);h=jc(f+200|0,d);Ab(d);i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{if((e|0)!=1127099950){if((e|0)==1129797166){break v}if((e|0)==1130917459){break o}if((e|0)==1145525806){break t}d=z;if((e|0)==1448301654){break s}if((e|0)==1196316499){break m}if((e|0)==1213486401){break p}if((e|0)==1280530262){break u}if((e|0)==1297303086){break l}if((e|0)==1347243310){break w}if((e|0)==1347244882){break q}if((e|0)!=1380340804){if((e|0)==1380986414){break r}d=n;if((e|0)==1380991534){break s}d=o;if((e|0)==1380994350){break s}if((e|0)==1397052739){break n}d=s;if((e|0)==1397768494){break s}if((e|0)==1414344238){break k}if((e|0)!=1146367534){break j}v[23588]=0;U(440,h|0,g|0,f+176|0);d=v[23588];v[23588]=0;if((d|0)==1){break i}v[k>>2]=B(v[f+176>>2],1e4)+(y[k>>2]%1e4|0);break j}v[23588]=0;U(440,h|0,g|0,f+176|0);d=v[23588];v[23588]=0;if((d|0)!=1){d=v[k>>2];v[k>>2]=d-((d>>>0)%1e4|0)+y[f+176>>2]%1e4;break j}e=P()|0;O()|0;break b}if(c){break j}v[23588]=0;u[f+176>>1]=0;U(441,h|0,g|0,f+176|0);d=v[23588];v[23588]=0;if((d|0)!=1){H=a,I=Cd(x[f+176>>1],x[a+480188>>1],127),u[H+480188>>1]=I;break j}e=P()|0;O()|0;break b}v[23588]=0;U(442,h|0,g|0,l|0);d=v[23588];v[23588]=0;if((d|0)!=1){break j}break c}v[23588]=0;v[f+176>>2]=0;U(440,h|0,g|0,f+176|0);d=v[23588];v[23588]=0;if((d|0)!=1){v[a+1074304>>2]=v[f+176>>2];break j}e=P()|0;O()|0;break b}v[23588]=0;v[f+176>>2]=0;U(440,h|0,g|0,f+176|0);d=v[23588];v[23588]=0;if((d|0)==1){break h}d=v[f+176>>2];if(!d){break j}v[a+1074308>>2]=d;break j}d=q}v[23588]=0;U(440,h|0,g|0,d|0);d=v[23588];v[23588]=0;if((d|0)==1){break c}break j}if(v[E>>2]==4){break j}v[23588]=0;U(441,h|0,g|0,f+176|0);d=v[23588];v[23588]=0;if((d|0)!=1){Ue(Vb(v[a+484360>>2],w[F|0]),x[f+176>>1]);break j}e=P()|0;O()|0;break b}v[23588]=0;U(443,h|0,g|0,m|0);d=v[23588];v[23588]=0;if((d|0)==1){break c}if(Ho(w[m|0])){break j}t[m|0]=5;break j}d=Lb(f+176|0);e=v[h>>2];v[23588]=0;e=S(160,e|0)|0;g=v[23588];v[23588]=0;x:{if((g|0)==1){break x}v[23588]=0;U(444,h|0,d|0,e|0);e=v[23588];v[23588]=0;if((e|0)==1){break x}v[23588]=0;U(11,f+160|0,0,d|0);e=v[23588];v[23588]=0;if((e|0)==1){break x}e=f+160|0;Ib(A,e);zb(e);yb(d);break j}e=P()|0;O()|0;yb(d);break b}if(g&1|g>>>0>126){break j}d=64;u[f+176>>1]=(g>>>1|0)- -64;u[f+160>>1]=127;e=x[Vc(f+176|0,f+160|0)>>1];i=e>>>0>64?e:64;while(1){if((d|0)==(i|0)){break j}v[23588]=0;R(260,f+176|0,h|0);e=v[23588];v[23588]=0;if((e|0)==1){break g}e=w[f+176|0];y:{if((e|0)==255){break y}j=w[Nc(f+176|0)|0];g=(d<<5)+a|0;r=g+480284|0;u[r>>1]=128;u[g+480286>>1]=j;g=g+480280|0;j=(e&128)<<3;v[g>>2]=j;e=e&127;if(e>>>0<65){u[r>>1]=e<<2;break y}if((e|0)!=100){break y}v[g>>2]=j|256}d=d+1|0;continue}}if(g>>>0<3){break j}v[23588]=0;d=S(194,h|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break f}if(!d|d>>>0>x[G>>1]){break j}d=(B(d,104)+a|0)+484448|0;g=wT(d);while(1){if((d|0)==(g|0)){break j}e=v[h>>2];v[23588]=0;i=W(156,e|0,v[f+208>>2],4)|0;e=v[23588];v[23588]=0;z:{if((e|0)!=1){e=268435456;if(!i){break z}v[23588]=0;e=S(157,h|0)|0;i=v[23588];v[23588]=0;if((i|0)!=1){break z}}e=P()|0;O()|0;break b}v[d>>2]=e;d=d+4|0;continue}}if(g>>>0<3){break j}v[23588]=0;R(445,f|0,h|0);d=v[23588];v[23588]=0;A:{B:{C:{D:{if((d|0)!=1){v[23588]=0;U(446,f+176|0,v[f>>2],v[f+4>>2]);d=v[23588];v[23588]=0;if((d|0)==1){break D}v[23588]=0;d=Q(89,f+16|0,f+176|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break C}yb(f+176|0);hc(f);e=v[h>>2];v[23588]=0;S(160,e|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break A}v[23588]=0;U(447,d|0,C|0,d|0);e=v[23588];v[23588]=0;if((e|0)==1){break A}rf(d);break j}e=P()|0;O()|0;break b}e=P()|0;O()|0;break B}e=P()|0;O()|0;yb(f+176|0)}hc(f);break b}e=P()|0;O()|0;rf(d);break b}e=0;g=mu(D);E:while(1){d=v[h>>2];v[23588]=0;d=W(156,d|0,v[f+208>>2],1)|0;i=v[23588];v[23588]=0;if((i|0)==1){break d}if(!(d&e>>>0<118)){break j}v[23588]=0;i=S(206,h|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break e}d=0;while(1){if((d|0)==8){continue E}F:{if(!(i>>>d&1)|e>>>0>117){break F}v[23588]=0;W(264,g|0,e|0,1)|0;j=v[23588];v[23588]=0;if((j|0)!=1){break F}e=P()|0;O()|0;break b}e=e+1|0;d=d+1|0;continue}}}v[23588]=0;U(448,h|0,g|0,p|0);d=v[23588];v[23588]=0;if((d|0)==1){break c}}Ab(h);continue}break}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0}Ab(h);T(e|0);L()}b=v[a+8>>2];Po(k,B(v[b+20>>2],1e4),B(v[b+24>>2],1e4));if(w[a+480224|0]>=3){t[p|0]=0}if(w[l|0]>=6){t[l|0]=0}wc(q,256);wc(n,65536);wc(o,65536)}jb=f+224|0}function PH(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,y=0,z=0,C=0,D=0,E=0,F=0,G=0;j=jb-80|0;jb=j;v[j+76>>2]=b;E=j+55|0;s=j+56|0;a:{b:{c:{d:{e:while(1){k=b;if((2147483647-p|0)<(h|0)){break d}p=h+p|0;f:{g:{h:{h=k;i=w[h|0];if(i){while(1){i:{b=i&255;j:{if(!b){b=h;break j}if((b|0)!=37){break i}i=h;while(1){if(w[i+1|0]!=37){b=i;break j}h=h+1|0;m=w[i+2|0];b=i+2|0;i=b;if((m|0)==37){continue}break}}h=h-k|0;D=2147483647-p|0;if((h|0)>(D|0)){break d}if(a){sf(a,k,h)}if(h){continue e}v[j+76>>2]=b;h=b+1|0;q=-1;i=t[b+1|0];if(!(!$j(i)|w[b+2|0]!=36)){q=i-48|0;x=1;h=b+3|0}v[j+76>>2]=h;n=0;i=t[h|0];b=i-32|0;k:{if(b>>>0>31){m=h;break k}m=h;b=1<<b;if(!(b&75913)){break k}while(1){m=h+1|0;v[j+76>>2]=m;n=b|n;i=t[h+1|0];b=i-32|0;if(b>>>0>=32){break k}h=m;b=1<<b;if(b&75913){continue}break}}l:{if((i|0)==42){b=t[m+1|0];m:{if(!(!$j(b)|w[m+2|0]!=36)){v[((b<<2)+e|0)-192>>2]=10;i=m+3|0;x=1;b=v[((t[m+1|0]<<3)+d|0)-384>>2];break m}if(x){break h}i=m+1|0;if(!a){v[j+76>>2]=i;x=0;r=0;break l}b=v[c>>2];v[c>>2]=b+4;x=0;b=v[b>>2]}r=b;v[j+76>>2]=i;if((r|0)>=0){break l}r=0-r|0;n=n|8192;break l}r=OH(j+76|0);if((r|0)<0){break d}i=v[j+76>>2]}h=0;l=-1;n:{if(w[i|0]!=46){b=i;C=0;break n}if(w[i+1|0]==42){b=t[i+2|0];o:{if(!(!$j(b)|w[i+3|0]!=36)){v[((b<<2)+e|0)-192>>2]=10;b=i+4|0;l=v[((t[i+2|0]<<3)+d|0)-384>>2];break o}if(x){break h}b=i+2|0;l=0;if(!a){break o}i=v[c>>2];v[c>>2]=i+4;l=v[i>>2]}v[j+76>>2]=b;C=(l^-1)>>>31|0;break n}v[j+76>>2]=i+1;l=OH(j+76|0);b=v[j+76>>2];C=1}while(1){o=h;m=28;y=b;h=t[b|0];if(h-123>>>0<4294967238){break c}b=y+1|0;h=w[(h+B(o,58)|0)+76559|0];if(h-1>>>0<8){continue}break}v[j+76>>2]=b;p:{q:{if((h|0)!=27){if(!h){break c}if((q|0)>=0){v[(q<<2)+e>>2]=h;h=(q<<3)+d|0;i=v[h+4>>2];v[j+64>>2]=v[h>>2];v[j+68>>2]=i;break q}if(!a){break f}NH(j- -64|0,h,c,g);break p}if((q|0)>=0){break c}}h=0;if(!a){continue e}}i=n&-65537;n=n&8192?i:n;q=0;z=5289;m=s;r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{h=t[y|0];h=o?(h&15)==3?h&-33:h:h;switch(h-88|0){case 11:break r;case 9:case 13:case 14:case 15:break s;case 27:break x;case 12:case 17:break A;case 23:break B;case 0:case 32:break C;case 24:break D;case 22:break E;case 29:break F;case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 25:case 26:case 28:case 30:case 31:break g;default:break G}}H:{switch(h-65|0){case 0:case 4:case 5:case 6:break s;case 2:break v;case 1:case 3:break g;default:break H}}if((h|0)==83){break w}break g}o=v[j+64>>2];i=v[j+68>>2];z=5289;break z}h=0;I:{switch(o&255){case 0:v[v[j+64>>2]>>2]=p;continue e;case 1:v[v[j+64>>2]>>2]=p;continue e;case 2:k=v[j+64>>2];v[k>>2]=p;v[k+4>>2]=p>>31;continue e;case 3:u[v[j+64>>2]>>1]=p;continue e;case 4:t[v[j+64>>2]]=p;continue e;case 6:v[v[j+64>>2]>>2]=p;continue e;case 7:break I;default:continue e}}k=v[j+64>>2];v[k>>2]=p;v[k+4>>2]=p>>31;continue e}l=l>>>0>8?l:8;n=n|8;h=120}k=s;F=h&32;o=v[j+64>>2];i=v[j+68>>2];if(o|i){while(1){k=k-1|0;t[k|0]=F|w[(o&15)+77088|0];G=!i&o>>>0>15|(i|0)!=0;y=i;i=i>>>4|0;o=(y&15)<<28|o>>>4;if(G){continue}break}}if(!(n&8)|!(v[j+64>>2]|v[j+68>>2])){break y}z=(h>>>4|0)+5289|0;q=2;break y}h=s;k=v[j+68>>2];i=k;o=v[j+64>>2];if(i|o){while(1){h=h-1|0;t[h|0]=o&7|48;y=!i&o>>>0>7|(i|0)!=0;k=i;i=i>>>3|0;o=(k&7)<<29|o>>>3;if(y){continue}break}}k=h;if(!(n&8)){break y}h=s-k|0;l=(h|0)<(l|0)?l:h+1|0;break y}h=v[j+68>>2];i=h;o=v[j+64>>2];if((h|0)<0){i=0-(i+((o|0)!=0)|0)|0;o=0-o|0;v[j+64>>2]=o;v[j+68>>2]=i;q=1;z=5289;break z}if(n&2048){q=1;z=5290;break z}q=n&1;z=q?5291:5289}k=Dn(o,i,s)}if((l|0)<0?C:0){break d}n=C?n&-65537:n;i=v[j+64>>2];h=v[j+68>>2];if(!((i|h)!=0|l)){k=s;m=k;l=0;break g}h=!(h|i)+(s-k|0)|0;l=(h|0)<(l|0)?l:h;break g}h=v[j+64>>2];k=h?h:17037;h=l>>>0<2147483647?l:2147483647;m=Vs(k,0,h);h=m?m-k|0:h;m=h+k|0;if((l|0)>=0){n=i;l=h;break g}n=i;l=h;if(w[m|0]){break d}break g}if(l){i=v[j+64>>2];break u}h=0;Gf(a,32,r,0,n);break t}v[j+12>>2]=0;v[j+8>>2]=v[j+64>>2];i=j+8|0;v[j+64>>2]=i;l=-1}h=0;J:{while(1){k=v[i>>2];if(!k){break J}k=MH(j+4|0,k);m=(k|0)<0;if(!(m|k>>>0>l-h>>>0)){i=i+4|0;h=h+k|0;if(l>>>0>h>>>0){continue}break J}break}if(m){break b}}m=61;if((h|0)<0){break c}Gf(a,32,r,h,n);if(!h){h=0;break t}m=0;i=v[j+64>>2];while(1){k=v[i>>2];if(!k){break t}k=MH(j+4|0,k);m=k+m|0;if(m>>>0>h>>>0){break t}sf(a,j+4|0,k);i=i+4|0;if(h>>>0>m>>>0){continue}break}}Gf(a,32,r,h,n^8192);h=(h|0)<(r|0)?r:h;continue e}if((l|0)<0?C:0){break d}m=61;h=nb[f|0](a,A[j+64>>3],r,l,n,h)|0;if((h|0)>=0){continue e}break c}t[j+55|0]=v[j+64>>2];l=1;k=E;n=i;break g}i=w[h+1|0];h=h+1|0;continue}}if(a){break a}if(!x){break f}h=1;while(1){a=v[(h<<2)+e>>2];if(a){NH((h<<3)+d|0,a,c,g);p=1;h=h+1|0;if((h|0)!=10){continue}break a}break}p=1;if(h>>>0>=10){break a}while(1){if(v[(h<<2)+e>>2]){break h}h=h+1|0;if((h|0)!=10){continue}break}break a}m=28;break c}o=m-k|0;l=(l|0)>(o|0)?l:o;if((l|0)>(2147483647-q|0)){break d}m=61;i=l+q|0;h=(i|0)<(r|0)?r:i;if((D|0)<(h|0)){break c}Gf(a,32,h,i,n);sf(a,z,q);Gf(a,48,h,i,n^65536);Gf(a,48,l,o,0);sf(a,k,o);Gf(a,32,h,i,n^8192);continue}break}p=0;break a}m=61}v[116064]=m}p=-1}jb=j+80|0;return p}function Ria(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0;e=jb-1360|0;jb=e;yc(b);g=jb-16|0;jb=g;j=e+784|0;ET(g+8|0,j);i=v[g+12>>2];mc(g,v[b>>2],v[b+8>>2],v[g+8>>2],v[g+12>>2]);l=v[g+4>>2];if((l|0)==(i|0)){Zb(b,v[g+12>>2])}jb=g+16|0;g=(i|0)==(l|0);if(!g){DT(j)}a:{if(!g){break a}if(!GT(e+784|0)){break a}if(!Pb(v[b>>2],v[b+8>>2],Dc(FT(x[e+818>>1],x[e+820>>1]),mb))){break a}if(!c){d=1;break a}q=Gc(e+776|0);b:{while(1){if((d|0)!=32){g=(d<<5)+a|0;i=g+480280|0;df(i);j=(e+784|0)+(d<<4)|0;u[g+480284>>1]=((w[j+78|0]<<8&65280)>>>0)/255;m=e+512|0;tk(m,1,j- -64|0);l=e+112|0;Ec(l,m);Gl(g+480289|0,l);yb(l);c:{d:{switch(w[j+79|0]){case 0:k=f+1|0;break c;case 1:v[i>>2]=1024;k=d+1|0;break c;case 2:break d;default:break b}}v[i>>2]=1024;g=e+112|0;Rc(g,q,d);oo(g)}f=f+1|0;d=d+1|0;continue}break}Ad(a,33554432);u[a+480188>>1]=k&255;d=e+112|0;f=xc(d,6776);Ib(a+1298344|0,f);zb(f);d=xc(d,11062);Ib(a+1298356|0,d);zb(d);v[a+1298404>>2]=5;e:{if(w[e+863|0]){break e}d=1;f=1;while(1){if((d|0)==16){while(1){if((f|0)==16){break e}d=((f<<5)+a|0)+480280|0;v[d>>2]=v[d>>2]&-1025;f=f+1|0;continue}}g=d<<4;d=d+1|0;if(w[(e+g|0)+863|0]==1){continue}break}}d=e+512|0;Me(d,1,e+784|0);f=e+112|0;Ec(f,d);Ac(a+1298308|0,f);yb(f);v[a+480208>>2]=v[a+480208>>2]&-17|x[e+822>>1]<<4&16;v[a+480196>>2]=w[e+832|0];v[a+480204>>2]=B(w[e+833|0],1e4);v[a+480200>>2]=w[e+834|0]<<2;v[a+480228>>2]=w[e+835|0];f=x[e+820>>1];u[a+480190>>1]=0;u[a+480192>>1]=f;ev(b,d);Vq(Vb(v[a+484360>>2],w[a+484376|0]),d,x[e+816>>1],65535,255);o=c&1;if(o){wg(a+484344|0,x[e+818>>1])}m=a+484344|0;s=a+480188|0;f:{while(1){g:{if(x[e+818>>1]<=h>>>0){l=c&2;q=e+108|0;m=a+480192|0;g=1;c=0;h:while(1){if(x[m>>1]<=(c&65535)>>>0){d=32;break b}c=c+1|0;f=Pu(a,c&65535,0);i=!f;d=jb-16|0;jb=d;k=e+112|0;fc(d+8|0,k,384);h=v[d+12>>2];mc(d,v[b>>2],v[b+8>>2],v[d+8>>2],v[d+12>>2]);j=v[d+4>>2];if((j|0)==(h|0)){Zb(b,v[d+12>>2])}jb=d+16|0;d=(h|0)==(j|0);if(!d){Tb(k,0,384)}if(!d|i){continue}k=g&65535;h=jb-32|0;jb=h;i=e+112|0;Me(h,1,i);d=h+16|0;Ec(d,h);Cc(f+492|0,d);yb(d);i:{if(!(w[i+378|0]|w[i+379|0]<<8)){break i}j=f+236|0;d=0;while(1){v[h+16>>2]=120;v[h>>2]=116;if(y[Jb(h+16|0,h)>>2]<=d>>>0){break i}z=cc(j,d+12|0),A=k+w[(d+i|0)+32|0]|0,u[z>>1]=A;d=d+1|0;continue}}d=w[i+376|0]|w[i+377|0]<<8;t[f+33|0]=1;v[f>>2]=d;XA(i,f+48|0,0);XA(i,f+68|0,1);XA(i,f+88|0,2);d=w[f+100|0];if(d&1){t[f+100|0]=d|16}if(!(v[f>>2]|t[f+60|0]&1)){v[f>>2]=32767}jb=h+32|0;d=0;while(1){f=x[e+490>>1];if(f>>>0<=d>>>0){g=f+g|0;continue h}JU(b,e+48|0);j:{k:{if(Rb(q,15502,4)){break k}f=d+g|0;k=f&65535;if(k>>>0>3999){break k}u[a+480190>>1]=f;i=jb-32|0;jb=i;j=B(k,104)+a|0;f=j+484380|0;md(f,0);Zh(i,1,e+48|0);h=i+16|0;Ec(h,i);Be(f+43|0,h);yb(h);p=w[e+64|0]|w[e+65|0]<<8|(w[e+66|0]<<16|w[e+67|0]<<24);v[f>>2]=p;n=w[e+68|0]|w[e+69|0]<<8|(w[e+70|0]<<16|w[e+71|0]<<24);v[f+4>>2]=n;o=w[e+72|0]|w[e+73|0]<<8|(w[e+74|0]<<16|w[e+75|0]<<24);v[f+8>>2]=o;v[f+24>>2]=w[e+76|0]|w[e+77|0]<<8|(w[e+78|0]<<16|w[e+79|0]<<24);u[f+30>>1]=w[e+80|0]<<2;u[f+28>>1]=w[e+81|0];h=w[e+96|0];if(h&1){u[f+34>>1]=x[f+34>>1]|2;h=w[e+96|0]}if(h&2){u[f+34>>1]=x[f+34>>1]|4;h=w[e+96|0]}if(h&4){v[f+8>>2]=o>>>1;v[f+4>>2]=n>>>1;v[f>>2]=p>>>1;u[f+34>>1]=x[f+34>>1]|1;h=w[e+96|0]}if(h&8){u[f+34>>1]=x[f+34>>1]|32}jb=i+32|0;h=jb-16|0;jb=h;ov(h+8|0,j+484423|0);i=e+24|0;ar(i,v[h+8>>2],v[h+12>>2]);jb=h+16|0;Cc(((k<<5)+a|0)+946304|0,i);yb(i);h=v[e+64>>2];if(!h){break k}$d(e,b,h);h=jc(e+24|0,e);Ab(e);if(l){i=Zc(e,u[j+484414>>1]&1?16:8,1,0,0);v[23588]=0;W(219,i|0,f|0,h|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break j}}Ab(h)}d=d+1|0;continue}break}break}a=P()|0;O()|0;Ab(h);break f}f=Rg(b);p=Rg(b);d=e+48|0;$d(d,b,f-4|0);j=jc(e+112|0,d);Ab(d);l:{m:{if(!o){break m}v[23588]=0;d=W(226,m|0,h&65535,p|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break l}if(!d){break m}k=0;i=tg(e+24|0);while(1){if(k>>>0>=p>>>0){break m}v[23588]=0;l=S(206,j|0)|0;d=v[23588];v[23588]=0;n:{if((d|0)!=1){if(l){break n}k=k+1|0;continue}break g}f=i;n=l&31;if(n>>>0<x[s>>1]){d=Yb(v[m>>2],h);f=id(v[d>>2],v[v[d+48>>2]+12>>2],k,n)}if(l&32){v[23588]=0;R(260,e+48|0,j|0);d=v[23588];v[23588]=0;if((d|0)==1){break g}g=w[e+48|0];t[f|0]=g;z=f,A=w[Nc(e+48|0)|0],t[z+1|0]=A;o:{p:{if((g|0)==160){d=255;break p}if((g|0)==255){d=0;break p}d=0;g=(B(g>>>4|0,12)+(g&15)|0)+13|0;if(CT(g)){break o}}g=d}t[f|0]=g}d=l&192;q:{if(!d){break q}if((d|0)==192){v[23588]=0;R(349,e+48|0,j|0);d=v[23588];v[23588]=0;if((d|0)!=1){d=e+48|0;g=Nc(d);l=Se(d);d=Li(d);YA(e,w[e+48|0],w[g|0]);g=Nc(e);r=e+504|0;YA(r,w[l|0],w[d|0]);Ao(e+496|0,f,w[e|0],w[g|0],w[e+504|0],w[Nc(r)|0]);break q}break g}v[23588]=0;R(260,e+48|0,j|0);d=v[23588];v[23588]=0;r:{s:{if((d|0)!=1){YA(e,w[e+48|0],w[Nc(e+48|0)|0]);g=w[Nc(e)|0];d=w[e|0];if((d|0)!=13){break s}t[f+2|0]=1;d=f+4|0;break r}break g}t[f+3|0]=d;d=f+5|0}t[d|0]=g}Rc(e+48|0,q,n);if(!Bb(v[v[e+48>>2]>>2],v[e+52>>2])){continue}if(!zV(w[f+3|0],w[f+5|0])){continue}t[f+3|0]=0;continue}}Ab(j);h=h+1|0;continue}}break}a=P()|0;O()|0;Ab(j)}T(a|0);L()}d=d>>>0>31}jb=e+1360|0;return d|0}function Cga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0;e=jb-1824|0;jb=e;yc(b);d=jb-16|0;jb=d;j=e+1224|0;XR(d+8|0,j);f=v[d+12>>2];mc(d,v[b>>2],v[b+8>>2],v[d+8>>2],v[d+12>>2]);i=v[d+4>>2];if((i|0)==(f|0)){Zb(b,v[d+12>>2])}jb=d+16|0;d=(f|0)==(i|0);if(!d){WR(j)}a:{if(!d){break a}if(!YR(e+1224|0)){break a}if(!iA(b,16,0)){break a}v[e+1216>>2]=v[e+1240>>2];d=v[e+1228>>2];v[e+1200>>2]=v[e+1224>>2];v[e+1204>>2]=d;d=e+1232|0;f=v[d+4>>2];v[e+1208>>2]=v[d>>2];v[e+1212>>2]=f;Ad(a,1);Nb(Nb(Zf(a+1074312|0,83),84,1),85,1);u[a+480188>>1]=4;v[e+1196>>2]=0;u[a+480190>>1]=15;cd(b,20);i=a+480188|0;g=1;n=1;while(1){b:{if((g|0)==16){d=e+1064|0;eS(b,d);f=a+484360|0;j=a+484376|0;Hq(Vb(v[f>>2],w[j|0]),d|2,128);g=0;m=dS(b,Vb(v[f>>2],w[j|0]),w[e+1064|0],k,i,0,1);if(!(w[e+1064|0]?1:w[e+1065|0]|m>>>0>1)){break a}if(cf(b)+65536>>>0<(m<<10)+k>>>0){break a}if(c){break b}g=1;break a}f=B(g,104)+a|0;j=f+484380|0;d=((g<<5)+a|0)+946304|0;jA(b,e+24|0,j,d,1);m=v[j>>2];c:{if(!w[Kb(d,0)|0]){break c}d:{if(Rb(d,16738,3)){if(Rb(d,16742,3)){break d}}if(w[Kb(d,5)|0]==58){break c}}n=0}d=Hb(x[e+52>>1]);if(d>>>0>=2){l=d<<1;d=Hb(x[e+50>>1]);v[f+484388>>2]=l+d;v[f+484384>>2]=d;Ck(j)}e:{if(Hb(x[e+46>>1])>>>0<=4999){if(Hb(x[e+50>>1])>>>0<1e4){break e}}v[e+1064>>2]=5;z=e,A=v[Oe(e+1196|0,e+1064|0)>>2],v[z+1196>>2]=A}k=k+m|0;g=g+1|0;continue}break}g=w[e+1065|0];if(!g){t[e+1065|0]=120;g=120}f:{if(!Rb(e+1200|0,14890,6)){t[e+1065|0]=120;v[a+480204>>2]=125e4;break f}v[a+480204>>2]=125e4;if((g|0)==120){break f}z=a,A=Pe(1773447.5/(+(240-g|0)*122)*1e4),v[z+480204>>2]=A;if(v[e+1196>>2]>=2){v[e+24>>2]=n?4:5;z=e,A=v[Oe(e+1196|0,e+24|0)>>2],v[z+1196>>2]=A;break f}v[e+24>>2]=n?1:2;z=e,A=v[Oe(e+1196|0,e+24|0)>>2],v[z+1196>>2]=A}v[a+480228>>2]=64;v[a+480260>>2]=452;v[a+480264>>2]=3424;v[a+480208>>2]=v[a+480208>>2]|2097152;f=e+1048|0;Cj(f,3,e+1200|0);d=e+24|0;Ec(d,f);Ac(a+1298308|0,d);yb(d);nh(a,0);r=v[b+8>>2];s=a+484376|0;while(1){g:{h:{if((p&65535)>>>0<m>>>0){d=Vb(v[a+484360>>2],w[s|0]);d=Ob(cA(Eb(v[d>>2]),Eb(v[d+4>>2]),p),Eb(v[d+4>>2]));VR(b,e+24|0);if(d){h=gA(e+24|0,0)+h|0;if(h>>>0>512){break h}}k=0;d=0;j=0;i:while(1){if((j|0)==64){break g}g=0;y=Jd(e+24|0,j);while(1){f=d;if((g|0)==4){j=j+1|0;continue i}else{o=Db(y,g);l=w[Kb(o,2)|0]&15;i=w[Kb(o,3)|0];d=0;j:{if(!(f&255)){break j}if(Rb(o,26884,4)){break j}d=f+1|0;if((d&255)>>>0<33){break j}v[e+1196>>2]=6}k:{l:{m:{switch(l-1|0){case 0:case 1:f=v[e+1196>>2];if((f|0)==1&i>>>0>=32){break l}l=(l|0)!=1;if(!(l|!i|i>>>0>2)){v[e+1048>>2]=2;z=e,A=v[Oe(e+1196|0,e+1048|0)>>2],v[z+1196>>2]=A;break k}if(l|(i|0)!=55&(i|0)!=71){break k}if((f|0)<=2){break l}break k;case 10:v[e+1196>>2]=6;break k;case 11:case 12:case 13:v[e+1048>>2]=2;z=e,A=v[Oe(e+1196|0,e+1048|0)>>2],v[z+1196>>2]=A;if((l|0)!=13){break k}k=((i|j)!=0)+k|0;d=1;break k;case 14:break m;default:break k}}v[e+1048>>2]=3;z=e,A=v[Oe(e+1196|0,e+1048|0)>>2],v[z+1196>>2]=A;break k}v[e+1196>>2]=n}g=g+1|0;continue}}}}if(!(v[e+1196>>2]!=6|m+32>>>0>=q>>>0)){v[e+1196>>2]=5}cd(b,r);o=c&1;if(o){wg(a+484344|0,m)}l=a+484344|0;k=0;while(1){if((k|0)==(m|0)){g=21619;d=v[e+1196>>2];if(d>>>0<7){g=v[(d<<2)+26896>>2]}d=e+24|0;f=xc(d,8264);Ib(a+1298344|0,f);zb(f);d=xc(d,10706);Ib(a+1298356|0,d);zb(d);Ql(a+1298368|0,g);v[a+1298404>>2]=14;if(!(c&2)){break h}g=1;while(1){if((g|0)==16){break h}c=B(g,104)+a|0;d=c+484384|0;Zb(b,v[d>>2]);f=v[d>>2];v[d>>2]=0;d=c+484380|0;v[d>>2]=v[d>>2]-f;c=c+484388|0;v[c>>2]=v[c>>2]-f;c=e+24|0;Zc(c,8,1,1,0);vg(c,d,b);g=g+1|0;continue}}VR(b,e+24|0);n:{if(!o){break n}if(!oh(l,k&65535,64)){break n}j=0;v[e+1048>>2]=0;o:while(1){if((j|0)==64){break n}g=0;d=Yb(v[l>>2],k);q=id(v[d>>2],v[v[d+48>>2]+12>>2],j,0);r=Jd(e+24|0,j);while(1)if((g|0)==4){j=j+1|0;continue o}else{d=Db(r,g);d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[e+4>>2]=d;v[e+8>>2]=d;h=e+16|0;d=q+B(g,6)|0;xu(h,e+4|0,d);f=w[e+16|0];i=Nc(h);h=w[i|0];if(!((f|0)!=14?h:0)){t[(e+1048|0)+g|0]=0}n=(e+1048|0)+g|0;p:{if(f|h){q:{h=w[n|0];if(h){r:{if(h>>>0>=16){t[d+2|0]=3;h=h>>>4|0;break r}t[d+2|0]=4}t[d+4|0]=h;f=w[e+16|0]}s:{t:{u:{v:{switch((f&255)-12|0){case 1:h=v[e+1196>>2];if((h|0)!=6){t[e+16|0]=10;break t}t[i|0]=0;break u;case 0:t[i|0]=w[i|0]&127;break u;case 2:h=w[i|0];if(h>>>0<=1){f=14;if(v[e+1196>>2]>3){break s}}t[e+16|0]=10;t[n|0]=w[i|0];break u;case 3:break v;default:break u}}t[i|0]=w[i|0]&15}h=v[e+1196>>2]}if((h|0)<2){break q}h=w[i|0];f=w[e+16|0]}Of(d,f,h&255);break p}f=w[i|0];t[d+5|0]=f;w:{switch(w[e+16|0]){case 0:if(w[i|0]<=2){t[d+3|0]=0;break p}t[d+3|0]=1;break p;case 1:t[d+3|0]=1;break p;case 2:h=f&15;if(h){t[d+3|0]=2;t[d+5|0]=h;break p}if(f>>>0<16){break p}t[d+3|0]=3;t[d+5|0]=(f&240)>>>4;break p;default:break w}}t[d+3|0]=0;break p}t[n|0]=0}g=g+1|0;continue}}}k=k+1|0;continue}}g=(p&65535)>>>0>=m>>>0;break a}if((k-1&255)>>>0<2){v[e+1196>>2]=6}p=p+1|0;q=(k&255)+q|0;continue}}jb=e+1824|0;return g|0}function pfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=jb-352|0;jb=d;cd(b,60);f=15;a:{if(!Fh(b,14094)){cd(b,124);f=31;if(!Fh(b,15357)){break a}}Ad(a,536870912);u[a+480190>>1]=f;yc(b);b:{while(1){if(x[a+480190>>1]>g>>>0){e=Bo(b);v[(d+224|0)+(g<<2)>>2]=e;g=g+1|0;if(e>>>0<=131072){continue}break b}break}v[a+480260>>2]=56;v[a+480264>>2]=13696;v[a+480196>>2]=6;g=0;u[a+480192>>1]=0;u[a+480188>>1]=4;v[a+480228>>2]=64;nh(a,1);Zb(b,4);e=Gj(b);if(e>>>0<178){break a}p=a,q=Pe(1776930/+(e>>>0)*1e4),v[p+480204>>2]=q;Zb(b,14);f=0;n=1;c:while(1){m=n&65535;if(m>>>0<=x[a+480190>>1]){$R(b,d+56|0);g=v[((m<<2)+d|0)+220>>2];l=jb-16|0;jb=l;h=(B(m,104)+a|0)+484380|0;md(h,1);v[h>>2]=g;t[h+37|0]=w[d+80|0]<<4;t[l+15|0]=w[d+81|0];t[l+14|0]=64;p=h,q=w[Wb(l+15|0,l+14|0)|0]<<2,u[p+30>>1]=q;d:{if(!g){break d}e=Hb(w[d+84|0]|w[d+85|0]<<8);j=Hb(w[d+82|0]|w[d+83|0]<<8);v[h+4>>2]=j;e=(e<<1)+j|0;v[h+8>>2]=e;if(g>>>0<=j>>>0){j=g-1|0;v[h+4>>2]=j}if(e>>>0>g>>>0){v[h+8>>2]=g;e=g}if(!(!(e>>>0<4|e>>>0<j>>>0)&e-j>>>0>3)){v[h+4>>2]=0;v[h+8>>2]=0;break d}if(e>>>0<=j>>>0){break d}u[h+34>>1]=x[h+34>>1]|2}jb=l+16|0;g=0;while(1)if((g|0)==22){if(f>>>0>127){break b}e=d+192|0;Hl(e,3,d+56|0);g=d+208|0;Ec(g,e);Cc(((m<<5)+a|0)+946304|0,g);n=n+1|0;yb(g);continue c}else{e=(d+56|0)+g|0;if((w[e|0]-1&255)>>>0<=30){t[e|0]=32;f=f+1|0}g=g+1|0;continue}}break}l=1;e:{f:{g:{f=a+946336|0;g=Mc(d+56|0,13961);if(!WQ(f,g)){v[23588]=0;e=Q(55,d+208|0,13972)|0;h=v[23588];v[23588]=0;if((h|0)==1){break g}l=WQ(f,e);yb(e)}yb(g);g=0;e=d+56|0;f=_R(b,e);if(!f){eA(e)}if(!f){break a}e=w[d+56|0];if(!ZQ(e)){break a}if(!c){break e}u[d+54>>1]=0;while(1)if((e|0)==(g|0)){g=a+484360|0;f=a+484376|0;i=Vb(v[g>>2],w[f|0]);h=w[d+57|0];Ue(i,e>>>0>h>>>0?h:0);Hq(Vb(v[g>>2],w[f|0]),d+56|2,w[d+56|0]);if(x[a+480190>>1]==31){Zb(b,4)}v[d+48>>2]=0;v[d+44>>2]=0;v[d+40>>2]=0;t[d+39|0]=0;m=c&1;if(m){wg(a+484344|0,x[d+54>>1])}n=a+484344|0;h=0;while(1){h:{i:{j:{if(x[d+54>>1]<=h>>>0){if(!(c&2)){break j}g=1;while(1){f=x[a+480190>>1];c=g&65535;if(f>>>0<c>>>0){break i}c=(B(c,104)+a|0)+484380|0;if(v[c>>2]){vg(Zc(d+192|0,8,1,0,0),c,b)}g=g+1|0;continue}}k:{if(m){j=0;if(oh(n,h&65535,64)){break k}}Zb(b,1024);break h}l:while(1){if((j|0)==64){break h}g=0;e=Yb(v[n>>2],h);o=id(v[e>>2],v[v[e+48>>2]+12>>2],j,0);while(1)if((g|0)==4){j=j+1|0;continue l}else{f=d+192|0;Sm(f,b);e=B(g,6)+o|0;m:{n:{o:{p:{if(w[Kb(f,0)|0]!=255){break p}t[(d+48|0)+g|0]=0;t[(d+40|0)+g|0]=0;f=Kb(d+192|0,1);i=w[f|0];if((i|0)==252&l){t[f|0]=254;break n}switch(i-252|0){case 1:break m;case 2:break n;case 0:break o;default:break p}}f=v[d+192>>2];v[d+32>>2]=f;v[d+12>>2]=f;f=d+16|0;xu(f,d+12|0,e);i=Nc(f);f=w[e|0];q:{if(!f){break q}t[(d+40|0)+g|0]=0;t[(d+48|0)+g|0]=f;if(f>>>0>48){break q}t[d+31|0]=8;p=d,q=w[jf(d+39|0,d+31|0)|0],t[p+39|0]=q}f=w[i|0];r:{if(!(f|w[d+16|0])){break r}t[e+5|0]=f;s:{t:{switch(w[d+16|0]-1|0){case 0:t[e+3|0]=1;break r;case 1:if(f&240){t[e+3|0]=3;t[e+5|0]=f>>>4;break r}f=f&15;if(f){t[e+3|0]=2;t[e+5|0]=f;break r}t[e+3|0]=0;break r;case 2:if(w[(d+40|0)+g|0]){t[e+3|0]=0;break r}t[e+3|0]=19;t[e+5|0]=0;break r;case 3:if(w[(d+40|0)+g|0]){t[e+3|0]=0;break r}t[e+3|0]=19;t[e+5|0]=1;break r;case 4:if(!w[e+1|0]){break s}t[d+31|0]=63;t[d+30|0]=w[e+5|0]+(x[(B(w[e+1|0],104)+a|0)+484410>>1]>>>2|0);f=w[Wb(d+31|0,d+30|0)|0];t[e+3|0]=13;t[e+5|0]=f;if(!w[(d+40|0)+g|0]){break r}t[e+4|0]=w[e+5|0];t[e+2|0]=1;t[e+3|0]=0;break r;case 5:i=w[e+1|0];if(i){t[e+3|0]=13;i=x[(B(i,104)+a|0)+484410>>1]>>>2|0;f=f>>>0>i>>>0?0:i-f|0;t[e+5|0]=f;if(!w[(d+40|0)+g|0]){break r}t[e+4|0]=f;t[e+2|0]=1}t[e+3|0]=0;break r;case 6:i=f&15;t[(d+40|0)+g|0]=i;k=w[(d+48|0)+g|0];f=k-(f>>>4|0)|0;t[(d+44|0)+g|0]=f;f=VQ(i,f&255,k);t[e+3|0]=3;t[e+5|0]=f;break r;case 7:i=f&15;t[(d+40|0)+g|0]=i;k=f>>>4|0;f=w[(d+48|0)+g|0];k=k+f|0;t[(d+44|0)+g|0]=k;f=VQ(i,f,k&255);t[e+3|0]=2;t[e+5|0]=f;break r;case 8:break t;default:break s}}t[d+31|0]=8;p=d,q=w[jf(d+39|0,d+31|0)|0],t[p+39|0]=q}t[e+3|0]=0}if(w[e+3|0]){break m}i=w[(d+40|0)+g|0];if(!i){break m}k=(d+44|0)+g|0;f=w[k|0];if(f){t[(d+48|0)+g|0]=f;t[e|0]=f;t[e+5|0]=i;t[k|0]=0}t[e+3|0]=4;break m}t[e+3|0]=14;t[d+39|0]=9;break m}t[e+3|0]=13}g=g+1|0;continue}}}f=x[a+480190>>1]}u:{v:{w:{if((f&65535)==15){b=d+16|0;Rf(b,4421);v[23588]=0;U(305,d+192|0,b|0,d+39|0);b=v[23588];v[23588]=0;if((b|0)==1){break u}b=d+192|0;Ib(a+1298344|0,b);zb(b);ac(d+16|0);break w}v[23588]=0;b=Q(1,d+192|0,12242)|0;c=v[23588];v[23588]=0;if((c|0)==1){break v}Ib(a+1298344|0,b);zb(b)}Ql(a+1298356|0,x[a+480190>>1]==15?5285:15085);v[a+1298404>>2]=14;break e}f=P()|0;O()|0;break f}f=P()|0;O()|0;ac(d+16|0);break f}h=h+1|0;continue}}else{u[d+192>>1]=w[(d+g|0)+58|0]+1;p=d,q=x[ke(d+54|0,d+192|0)>>1],u[p+54>>1]=q;g=g+1|0;continue}}f=P()|0;O()|0;yb(g)}T(f|0);L()}g=1;break a}g=0}jb=d+352|0;return g|0}function tI(a,b,c,d,e,f){var g=0,h=C(0),i=0,j=0,k=C(0),l=C(0),m=C(0),n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,w=0,x=0,y=0,A=C(0),D=C(0),E=0,F=0,G=0,H=C(0),I=C(0),J=C(0),K=C(0),L=C(0),M=C(0),N=C(0),O=C(0),P=0,Q=0;F=(d|0)>0?d:0;while(1){if((s|0)!=(F|0)){G=B(s,2304)+b|0;v=0;q=(c|0)>0?c:0;n=jb-128|0;x=n+96|0;y=n- -64|0;E=n+32|0;while(1){if((q|0)!=(v|0)){o=G+(v<<2)|0;w=0;i=n;p=i;j=0;while(1){if((j|0)!=8){k=z[B(15-j|0,72)+o>>2];g=B(j,72)+o|0;h=z[g+1152>>2];l=C(k+h);m=z[g>>2];A=z[B(31-j|0,72)+o>>2];D=C(m+A);z[p>>2]=l+D;g=B(j,12);k=C(C(k-h)*z[g+71280>>2]);h=C(C(m-A)*z[g+71284>>2]);z[p+64>>2]=k+h;m=C(D-l);l=z[g+71288>>2];z[p+32>>2]=m*l;z[p+96>>2]=C(h-k)*l;p=p+4|0;j=j+1|0;continue}break}while(1){if((w|0)!=4){l=z[i+8>>2];m=z[i+20>>2];h=C(l+m);A=z[i+4>>2];D=z[i+24>>2];H=C(A+D);k=C(h+H);I=z[i+12>>2];J=z[i+16>>2];K=C(I+J);L=z[i>>2];M=z[i+28>>2];N=C(L+M);O=C(K+N);z[i>>2]=k+O;z[i+16>>2]=C(O-k)*C(.7071067690849304);k=C(N-K);h=C(C(k+C(H-h))*C(.7071067690849304));z[i+24>>2]=C(k-h)*C(1.3065630197525024);z[i+8>>2]=C(k+h)*C(.5411961078643799);k=C(L-M);h=C(l-m);l=C(A-D);m=C(C(h+l)*C(.7071067690849304));A=C(k+m);D=C(C(I-J)+h);h=C(l+k);l=C(D-C(h*C(.1989123672246933)));h=C(C(l*C(.3826834261417389))+h);z[i+28>>2]=C(A-h)*C(2.562915563583374);z[i+4>>2]=C(A+h)*C(.509795606136322);k=C(k-m);h=C(l-C(h*C(.1989123672246933)));z[i+20>>2]=C(k+h)*C(.8999761939048767);z[i+12>>2]=C(k-h)*C(.601344883441925);i=i+32|0;w=w+1|0;continue}break}i=0;while(1){if((i|0)!=7){p=i<<2;z[o>>2]=z[p+n>>2];k=z[p+x>>2];i=i+1|0;j=i<<2;h=z[j+x>>2];z[o+72>>2]=C(z[p+y>>2]+k)+h;z[o+144>>2]=z[p+E>>2]+z[j+E>>2];z[o+216>>2]=h+C(k+z[j+y>>2]);o=o+288|0;continue}break}z[o>>2]=z[n+28>>2];k=z[n+124>>2];z[o+72>>2]=z[n+92>>2]+k;h=z[n+60>>2];z[o+216>>2]=k;z[o+144>>2]=h;v=v+1|0;continue}break}s=s+1|0;continue}break}E=tc(f,a,3840);G=d<<5;s=0;while(1){if((c|0)>(s|0)){i=jb-32|0;jb=i;o=E+(s<<8)|0;v=(s<<2)+b|0;z[o+4080>>2]=z[v+1152>>2];f=d-1|0;w=v+B(f,2304)|0;z[o+4084>>2]=z[w+1152>>2];z[o+4088>>2]=z[v>>2];z[o+4092>>2]=z[w>>2];z[o+4336>>2]=z[v+1156>>2];z[o+4340>>2]=z[w+1156>>2];z[o+4344>>2]=z[v+4>>2];z[o+4348>>2]=z[w+4>>2];x=(B(s,G)<<1)+e|0;y=x+(f<<1)|0;qs(y,d,o+244|0);f=d<<6;qs(f+y|0,d,o+500|0);qs(x,d,o+240|0);qs(f+x|0,d,o+496|0);F=o+3840|0;p=14;n=71376;while(1){if((p|0)>=0){g=p<<4;j=g+F|0;f=B(31-p|0,72);z[j>>2]=z[f+v>>2];z[j+4>>2]=z[f+w>>2];f=f|4;z[j+8>>2]=z[f+v>>2];z[j+12>>2]=z[f+w>>2];f=B(p,72);q=f+76|0;z[j+256>>2]=z[q+v>>2];z[j+260>>2]=z[q+w>>2];f=f+72|0;z[j-248>>2]=z[f+v>>2];z[j-244>>2]=z[f+w>>2];q=p<<2;t=g+o|0;k=z[n+4>>2];h=z[n>>2];f=0;while(1){if((f|0)!=4){g=f<<2;l=z[g+j>>2];m=z[g+t>>2];z[g+(i+16|0)>>2]=C(l*h)-C(k*m);z[i+g>>2]=C(l*k)+C(h*m);f=f+1|0;continue}break}j=F+(q<<2)|0;q=j-3584|0;t=j-256|0;k=z[n+12>>2];h=z[n+8>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=z[g+t>>2];m=z[g+q>>2];z[r>>2]=z[r>>2]+C(C(l*k)+C(h*m));g=g+(i+16|0)|0;z[g>>2]=C(C(m*k)-C(h*l))+z[g>>2];f=f+1|0;continue}break}q=j-3328|0;t=j-512|0;k=z[n+20>>2];h=z[n+16>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=z[g+t>>2];m=z[g+q>>2];z[r>>2]=z[r>>2]+C(C(l*k)+C(h*m));g=g+(i+16|0)|0;z[g>>2]=C(C(l*h)-C(k*m))+z[g>>2];f=f+1|0;continue}break}q=j-3072|0;t=j-768|0;k=z[n+28>>2];h=z[n+24>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=z[g+t>>2];m=z[g+q>>2];z[r>>2]=z[r>>2]+C(C(l*k)+C(h*m));g=g+(i+16|0)|0;z[g>>2]=C(C(m*k)-C(h*l))+z[g>>2];f=f+1|0;continue}break}q=j-2816|0;t=j-1024|0;k=z[n+36>>2];h=z[n+32>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=z[g+t>>2];m=z[g+q>>2];z[r>>2]=z[r>>2]+C(C(l*k)+C(h*m));g=g+(i+16|0)|0;z[g>>2]=C(C(l*h)-C(k*m))+z[g>>2];f=f+1|0;continue}break}q=j-2560|0;t=j-1280|0;k=z[n+44>>2];h=z[n+40>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=z[g+t>>2];m=z[g+q>>2];z[r>>2]=z[r>>2]+C(C(l*k)+C(h*m));g=g+(i+16|0)|0;z[g>>2]=C(C(m*k)-C(h*l))+z[g>>2];f=f+1|0;continue}break}q=j-2304|0;t=j-1536|0;k=z[n+52>>2];h=z[n+48>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=z[g+t>>2];m=z[g+q>>2];z[r>>2]=z[r>>2]+C(C(l*k)+C(h*m));g=g+(i+16|0)|0;z[g>>2]=C(C(l*h)-C(k*m))+z[g>>2];f=f+1|0;continue}break}g=j-2048|0;q=j-1792|0;k=z[n+60>>2];h=z[n+56>>2];f=0;while(1){if((f|0)!=4){j=f<<2;t=j+i|0;l=z[j+q>>2];m=z[g+j>>2];z[t>>2]=z[t>>2]+C(C(l*k)+C(h*m));j=j+(i+16|0)|0;z[j>>2]=C(C(m*k)-C(h*l))+z[j>>2];f=f+1|0;continue}break}f=B(15-p|0,d)<<1;P=f+y|0,Q=hj(z[i+20>>2]),u[P>>1]=Q;j=B(p+17|0,d)<<1;P=j+y|0,Q=hj(z[i+4>>2]),u[P>>1]=Q;P=f+x|0,Q=hj(z[i+16>>2]),u[P>>1]=Q;P=j+x|0,Q=hj(z[i>>2]),u[P>>1]=Q;f=B(47-p|0,d)<<1;P=f+y|0,Q=hj(z[i+28>>2]),u[P>>1]=Q;j=B(p+49|0,d)<<1;P=j+y|0,Q=hj(z[i+12>>2]),u[P>>1]=Q;P=f+x|0,Q=hj(z[i+24>>2]),u[P>>1]=Q;P=j+x|0,Q=hj(z[i+8>>2]),u[P>>1]=Q;p=p-1|0;n=n- -64|0;continue}break}jb=i+32|0;s=s+2|0;continue}break}b=c<<6;a:{if((d|0)==1){s=0;while(1){if(s>>>0>959){break a}z[(s<<2)+a>>2]=z[E+(b+s<<2)>>2];s=s+2|0;continue}}tc(a,E+(b<<2)|0,3840)}}function sja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;g=jb-288|0;jb=g;yc(b);e=jb-16|0;jb=e;h=g+80|0;dU(e+8|0,h);f=v[e+12>>2];mc(e,v[b>>2],v[b+8>>2],v[e+8>>2],v[e+12>>2]);i=v[e+4>>2];if((i|0)==(f|0)){Zb(b,v[e+12>>2])}jb=e+16|0;e=(f|0)==(i|0);if(!e){cU(h)}a:{if(!e){break a}if(!fU(g+80|0)){break a}if(!Pb(v[b>>2],v[b+8>>2],Dc(eU(g+80|0),mb))){break a}b:{if(!c){break b}Ad(a,16777216);$f(a);v[a+480208>>2]=v[a+480208>>2]|16777216;d=g+56|0;vq(d,32);f=g- -64|0;h=v[f+4>>2];e=a+1074320|0;v[e>>2]=v[f>>2];v[e+4>>2]=h;e=v[g+60>>2];v[a+1074312>>2]=v[g+56>>2];v[a+1074316>>2]=e;Nb(a+1074312|0,114,1);s=a+480188|0,y=Hb(x[g+280>>1]),u[s>>1]=y;nh(a,1);e=xc(d,8501);Ib(a+1298368|0,e);zb(e);e=g+32|0;Rf(e,3927);v[23588]=0;U(362,d|0,e|0,w[g+83|0]);d=v[23588];v[23588]=0;c:{if((d|0)!=1){d=g+56|0;Ib(a+1298344|0,d);zb(d);e=g+32|0;ac(e);f=xc(d,10710);Ib(a+1298356|0,f);zb(f);v[a+1298404>>2]=12;Me(e,3,g+80|4);Ec(d,e);Ac(a+1298308|0,d);yb(d);f=160;while(1){d:{d=f;if(!d){d=0;break d}f=d-1|0;if(w[(g+f|0)+116|0]==32){continue}}break}bU(a+1298332|0,g+116|0,d,4);o=a+480190|0;d=Hb(x[g+276>>1]);u[o>>1]=d;l=1;while(1){e:{f:{g:{h:{i:{e=d&65535;d=l&65535;if(e>>>0<d>>>0){f=a+484360|0;e=a+484376|0;Ue(Vb(v[f>>2],w[e|0]),Hb(x[g+284>>1]));d=g+32|0;$d(d,b,512);j=jc(g+56|0,d);Ab(d);d=w[e|0];f=v[f>>2];h=x[g+282>>1];v[23588]=0;U(274,Vb(f,d)|0,j|0,Hb(h)|0);d=v[23588];v[23588]=0;if((d|0)!=1){break i}d=P()|0;O()|0;break h}h=B(d,104)+a|0;i=h+484380|0;md(i,1);to(i);bV(b,((d<<5)+a|0)+946304|0,w[g+83|0]==1?32:28);n=1;d=w[g+83|0];if(d>>>0>=3){Zb(b,14);d=eB(b);if((d|0)>=0){e=h+484414|0;u[e>>1]=x[e>>1]|32;s=h+484408|0,y=Dc((((d&65535)<<8)+2047>>>0)/4095|0,0),u[s>>1]=y}d=w[g+83|0]}if((d&255)>>>0>=2){n=Gj(b);s=h+484404|0,y=Gj(b),v[s>>2]=y}d=g+56|0;f=jb-16|0;jb=f;j:{if(!Pb(v[b>>2],v[b+8>>2],12)){v[f>>2]=0;e=d;j=3;while(1){if(j){k=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);t[e|0]=k;t[e+1|0]=k>>>8;t[e+2|0]=k>>>16;t[e+3|0]=k>>>24;j=j-1|0;e=e+4|0;continue}break}break j}Cq(f+8|0,d);td(f,b,v[f+8>>2],v[f+12>>2])}jb=f+16|0;e=ic(d);d=Fb(d);k=bc(v[g+56>>2]);v[i>>2]=k;m=h+484384|0;j=bc(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24));v[m>>2]=j;p=h+484388|0;q=bc(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))+j|0;v[p>>2]=q;f=h+484414|0;if(j){e=x[f>>1];break f}e=x[f>>1];if(bc(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))>>>0>=3){break f}d=e&-3;break e}d=Eb(v[Vb(v[a+484360>>2],w[e|0])>>2]);f=Eb(v[Vb(v[a+484360>>2],w[e|0])+4>>2]);e=jb-16|0;jb=e;k:{if(!Ob(d,f)){break k}v[e+8>>2]=d;while(1){h=v[Re(e+8|0)>>2];if(!Ob(h,f)){break k}d=Dk(x[d>>1],x[h>>1])?h:d;continue}}jb=e+16|0;d=x[d>>1];v[23588]=0;n=a+484344|0;p=d+1&65535;R(225,n|0,p|0);d=v[23588];v[23588]=0;if((d|0)!=1){d=w[g+83|0];v[g+24>>2]=v[a+480204>>2];v[g+20>>2]=v[a+480196>>2];o=d>>>0<4?4:5;q=c&1;k=a+480188|0;h=0;while(1){if((h|0)==(p|0)){if(!(c&2)){break g}d=1;c=a+480190|0;while(1){e=d&65535;if(e>>>0>x[c>>1]){break g}e=B(e,104)+a|0;f=Zc(g+8|0,u[e+484414>>1]&1?16:8,1,1,0);v[23588]=0;W(219,f|0,e+484380|0,b|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){d=d+1|0;continue}break}d=P()|0;O()|0;break h}l:{if(!q){break l}d=x[g+278>>1];e=v[b+8>>2];f=x[k>>1];i=v[b>>2];v[23588]=0;d=W(156,i|0,e|0,B(f,B(Hb(d),o))|0)|0;e=v[23588];v[23588]=0;m:{n:{if((e|0)==1){break n}if(!d){break l}d=x[g+278>>1];v[23588]=0;d=W(226,n|0,h&65535,Hb(d)|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break n}if(!d){break l}d=x[k>>1];t[g+19|0]=0;e=de(g+8|0,0,g+19|0);v[23588]=0;i=W(363,g+32|0,d|0,e|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break m}e=0;o:while(1){if(Hb(x[g+278>>1])>>>0<=e>>>0){nd(i);break l}d=0;f=Yb(v[n>>2],h);r=Cf(v[f>>2],v[v[f+48>>2]+12>>2],e);while(1){if(x[k>>1]<=d>>>0){e=e+1|0;continue o}t[g+12|0]=0;v[g+8>>2]=0;v[23588]=0;U(364,b|0,g+8|0,o|0);f=v[23588];v[23588]=0;p:{if((f|0)==1){break p}l=B(d,6)+r|0;f=w[g+8|0];if((f-24&255)>>>0<=59){f=f+13|0;t[l|0]=f;s=cc(v[i>>2],d),y=f,t[s|0]=y}m=w[g+9|0];q:{if(!m){f=cc(v[i>>2],d);break q}t[l+1|0]=m;f=cc(v[i>>2],d);t[f+1|0]=m}m=w[f+1|0];f=w[f|0];v[23588]=0;Ca(365,a|0,l|0,w[g+10|0],w[g+11|0],0-w[g+83|0]|0,f|0,m|0,g+24|0,g+20|0);f=v[23588];v[23588]=0;if((f|0)==1){break p}if(w[g+12|0]){t[l+2|0]=1;t[l+4|0]=w[g+12|0]+1>>>2}d=d+1|0;continue}break}break}d=P()|0;O()|0;nd(i);break h}d=P()|0;O()|0;break h}d=P()|0;O()|0;break h}h=h+1|0;continue}}d=P()|0;O()|0}Ab(j);break c}Ab(j);break b}d=e|2}u[f>>1]=d;if((n|0)==2){u[f>>1]=d|1;v[i>>2]=k>>>1;v[m>>2]=j>>>1;v[p>>2]=q>>>1}s=h+484410|0,y=Gj(b),u[s>>1]=y;d=eB(b);if(d){Al(i,+(d|0)/96)}t[h+484417|0]=d<<4;l=l+1|0;d=x[o>>1];continue}}d=P()|0;O()|0;ac(g+32|0)}T(d|0);L()}d=1}jb=g+288|0;return d|0}function Cea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0;i=jb-208|0;jb=i;yc(b);a:{if(!jB(b,i+160|0)){break a}if(!_P(i+160|0)){break a}b:{if(!c){break b}if(!Pb(v[b>>2],v[b+8>>2],Dc(ZP(w[i+207|0]),mb))){break a}Ad(a,128);d=i+144|0;Me(d,2,i+175|0);h=i+72|0;Ec(h,d);Ac(a+1298308|0,h);yb(h);e=xc(h,8413);Ib(a+1298344|0,e);zb(e);e=xc(h,6059);Ib(a+1298356|0,e);zb(e);e=xc(d,17505);v[23588]=0;U(724,h|0,e|0,v[(w[i+174|0]<<2)+26860>>2]);h=v[23588];v[23588]=0;c:{if((h|0)!=1){h=i+72|0;Ib(a+1298368|0,h);zb(h);zb(e);v[a+480208>>2]=12;v[a+1298404>>2]=5;BB(a+1298332|0,b,w[i+207|0]<<5,32,0);l=a+480190|0;d=Le(b);u[l>>1]=d;h=1;while(1){j=h&65535;if(j>>>0>(d&65535)>>>0){so(Vb(v[a+484360>>2],w[a+484376|0]),b,256,255,254);h=0;d=Le(b);if(d>>>0>=127){break a}g=a+480188|0;u[g>>1]=d+1;e=Le(b);while(1)if(x[g>>1]<=h>>>0){o=a+484344|0;q=e+1|0;wg(o,q);d=0;while(1){d:{g=d&65535;if(g>>>0>e>>>0){r=a+480188|0;e:while(1){y=s&65535;h=x[r>>1];if(y>>>0>=h>>>0){e=go(i+8|0);t[e+16|0]=0;u[e+14>>1]=0;u[e+12>>1]=h;v[23588]=0;R(726,e|0,h|0);h=v[23588];v[23588]=0;if((h|0)==1){a=P()|0;O()|0;Ve(e);T(a|0);L()}v[23588]=0;U(725,i+32|0,o|0,e|0);d=v[23588];v[23588]=0;h=1;if((d|0)==1){break d}Ve(i+32|0);Ve(e);if(!(c&2)){break a}c=a+480190|0;while(1){d=h&65535;if(d>>>0>x[c>>1]){break b}d=B(d,104)+a|0;vg(Zc(i+72|0,u[d+484414>>1]&1?16:8,1,0,0),d+484380|0,b);h=h+1|0;continue}}n=0;e=tg(i+72|0);f:while(1){g:{if((n|0)!=(q|0)){if(Pb(v[b>>2],v[b+8>>2],5)){break g}}s=s+1|0;continue e}d=0;h=Yb(v[o>>2],n);h=id(v[h>>2],v[v[h+48>>2]+12>>2],0,y);while(1){h:{i:{if(d>>>0>63){break i}l=w[i+174|0];g=jb-32|0;jb=g;p=1;f=Le(b);if((f|0)==252){p=Le(b);f=Le(b)}t[e|0]=(f-1&255)>>>0<60?f+36|0:0;f=g+24|0;Sm(f,b);k=Nc(f);j=Se(f);f=Li(f);t[e+1|0]=w[g+24|0];m=g+16|0;XP(m,w[k|0]&15,w[j|0],l);j=Nc(m);m=g+8|0;XP(m,w[k|0]>>>4|0,w[f|0],l);l=Nc(m);f=w[g+16|0];m=(f|0)!=10;k=w[g+8|0];j:{if(!(m|(k|0)!=10)){j=w[j|0];f=w[l|0];t[e+3|0]=10;j=j|f<<8;t[e+5|0]=j>>>6;if(j>>>0<16384){break j}t[e+2|0]=15;t[e+4|0]=f>>>6;break j}k:{l:{m:{n:{o:{if(!m){k=w[j|0];m=k<<2;z=j,A=Ll(m),t[z|0]=A;if(k>>>0<64){break o}f=w[g+8|0];if(Ji(f)>>>0>=Jz(10)>>>0){break n}t[e+5|0]=m;t[e+2|0]=15;t[e+3|0]=10;t[e+4|0]=k>>>6;break j}if((k|0)==10){f=w[l|0];k=f<<2;z=l,A=Ll(k),t[z|0]=A;if(f>>>0<64){break o}if(Ji(w[g+16|0])>>>0>=Jz(10)>>>0){break o}t[e+5|0]=k;t[e+2|0]=15;t[e+3|0]=10;t[e+4|0]=f>>>6;break j}if((f|0)!=(k|0)){break o}t[g+8|0]=0;break m}f=w[g+8|0]}if((f|0)==13){break l}if(f){break k}f=w[g+16|0]}if((f|0)==13){break k}}Ii(g+16|0,g+8|0);Ii(j,l)}Uu(g+8|0,l,g+16|0,j);Ao(g,e,w[g+16|0],w[j|0],w[g+8|0],w[l|0])}jb=g+32|0;f=d+p|0;d=f>>>0>64?64-d|0:p;if(!d){break i}while(1){if(!d){break h}g=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);t[h|0]=g;t[h+1|0]=g>>>8;t[h+2|0]=g>>>16;t[h+3|0]=g>>>24;g=w[e+4|0]|w[e+5|0]<<8;t[h+4|0]=g;t[h+5|0]=g>>>8;d=d-1|0;h=B(x[r>>1],6)+h|0;continue}}n=n+1|0;continue f}d=f>>>0<64?f:64;continue}}}}d=d+1|0;h=0;if(oh(o,g,64)){continue}break a}break}d=P()|0;O()|0;Ve(e);break c}else{d=(h<<5)+a|0;df(d+480280|0);d=d+480284|0;p:{if(w[i+174|0]>=51){f=(Le(b)<<4|8)&248;break p}f=h&1?192:64}u[d>>1]=f;h=h+1|0;continue}}else{q:{if(w[i+174|0]>=52){d=i+72|0;if(!NU(b,d)){EB(d)}break q}e=jb-32|0;jb=e;v[e+28>>2]=64;v[e+8>>2]=66;f=v[b>>2];g=v[b+8>>2];d=v[Jb(e+28|0,e+8|0)>>2];if(!Pb(f,g,d)){d=cf(b)}f=e+8|0;n=i+72|0;Fu(f,n);g=gc(e+16|0,v[e+8>>2],d);mc(e,v[b>>2],v[b+8>>2],v[g>>2],v[g+4>>2]);Fu(f,n);Tb(v[e+8>>2]+d|0,0,66-d|0);Zb(b,v[e+28>>2]);jb=e+32|0;u[i+136>>1]=x[i+134>>1];u[i+134>>1]=8363}g=jb-32|0;jb=g;e=(B(j,104)+a|0)+484380|0;md(e,0);to(e);d=i+72|0;tk(g,2,d+32|0);f=g+16|0;Ec(f,g);Be(e+43|0,f);yb(f);f=w[d+56|0]|w[d+57|0]<<8|(w[d+58|0]<<16|w[d+59|0]<<24);n=w[d+52|0]|w[d+53|0]<<8|(w[d+54|0]<<16|w[d+55|0]<<24);r:{if(f>>>0<=n>>>0){break r}v[e>>2]=f-n;v[e+12>>2]=w[d+44|0]|w[d+45|0]<<8|(w[d+46|0]<<16|w[d+47|0]<<24);v[g+16>>2]=w[d+48|0]|w[d+49|0]<<8|(w[d+50|0]<<16|w[d+51|0]<<24);z=e,A=v[Jb(g+16|0,e)>>2],v[z+16>>2]=A;u[e+30>>1]=w[d+60|0];v[e+24>>2]=w[d+62|0]|w[d+63|0]<<8;f=w[d+64|0]|w[d+65|0]<<8;if(f){Al(e,+(f<<16>>16)/393216)}f=w[d+61|0];if(f&8){u[e+34>>1]=x[e+34>>1]|8;f=w[d+61|0]}if(f&16){u[e+34>>1]=x[e+34>>1]|16;f=w[d+61|0]}if(!(f&4)){break r}u[e+34>>1]=x[e+34>>1]|1;v[e+12>>2]=v[e+12>>2]>>>1;v[e+16>>2]=v[e+16>>2]>>>1}jb=g+32|0;e=i+56|0;Me(e,2,d);d=i+144|0;Ec(d,e);Cc(((j<<5)+a|0)+946304|0,d);h=h+1|0;yb(d);d=x[l>>1];continue}}}d=P()|0;O()|0;zb(e)}T(d|0);L()}h=1}jb=i+208|0;return h|0}function Oea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=jb-144|0;jb=d;yc(c);a:{b:{c:{d:{if(!uo(c,d+128|0)){break d}if(Rb(d+128|0,13769,4)){break d}g=d+136|0;e:{if(!Rb(g,13422,4)){break e}if(!Rb(g,13480,4)){break e}if(Rb(g,14204,4)){break d}}e=jb-32|0;jb=e;l=Sb(d+112|0);f:{g:{h:{i:{j:{while(1){k=v[c+8>>2];h=v[c>>2];v[23588]=0;k=W(156,h|0,k|0,8)|0;h=v[23588];v[23588]=0;if((h|0)==1){break h}if(!k){break i}v[23588]=0;R(791,e|0,c|0);k=v[23588];v[23588]=0;if((k|0)!=1){v[23588]=0;R(792,l|0,e|0);k=v[23588];v[23588]=0;if((k|0)==1){break j}zd(e);continue}break}a=P()|0;O()|0;break g}a=P()|0;O()|0;zd(e);break g}jb=e+32|0;break f}a=P()|0;O()|0}Yd(l);T(a|0);L()}v[23588]=0;k=S(174,d+88|0)|0;c=v[23588];v[23588]=0;k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{if((c|0)!=1){l=Zc(d+80|0,8,1,1,0);if(Rb(g,14204,4)){break t}v[23588]=0;U(711,d+56|0,d+112|0,1296581714);c=v[23588];v[23588]=0;if((c|0)==1){break q}v[23588]=0;U(711,d+32|0,d+112|0,1296318804);c=v[23588];v[23588]=0;if((c|0)==1){break c}c=d+32|0;e=gd(k,c);Ab(c);c=0;v[23588]=0;g=S(712,d+56|0)|0;i=v[23588];v[23588]=0;f=1;if((i|0)==1){break c}i=0;if(!g){break u}e=v[e>>2];v[23588]=0;e=S(178,e|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break c}i=0;if(!e){break u}v[23588]=0;i=S(279,d+56|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break c}v[23588]=0;g=S(271,d+56|0)|0;c=v[23588];v[23588]=0;w:{if((c|0)==1){break w}v[23588]=0;Q(188,d+56|0,2)|0;c=v[23588];v[23588]=0;if((c|0)==1){break w}v[23588]=0;c=S(279,d+56|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){break v}}break c}f=P()|0;O()|0;break a}v[23588]=0;R(627,d+32|0,d+56|0);e=v[23588];v[23588]=0;if((e|0)==1){break c}e=WT(d+32|0);j=Hb(x[d+32>>1]);if(!j){break u}c=(c>>>0)/(j>>>0)|0;f=d+32|0;j=ic(f);h=Se(f);f=1;j=Hb(w[j|0]|w[j+1|0]<<8);if((j|0)!=(Hb(w[h|0]|w[h+1|0]<<8)+1|0)){break u}if((j|0)==2){Jo(l,2)}x:{if((g|0)!=16){if((g|0)!=8){break u}y:{switch(Hb(w[e|0]|w[e+1|0]<<8)|0){case 0:cg(l,1);break x;case 2:cg(l,17);break x;case 3:break y;default:break u}}cg(l,16);break x}if(Hb(w[e|0]|w[e+1|0]<<8)){break u}wd(l,16)}f=0}Ab(d+56|0);j=0;if(!f){break s}f=0;break k}v[23588]=0;U(711,d+56|0,d+112|0,1447576658);c=v[23588];v[23588]=0;z:{A:{if((c|0)!=1){v[23588]=0;U(711,d+32|0,d+112|0,1128808782);c=v[23588];v[23588]=0;if((c|0)==1){break A}v[23588]=0;U(711,d+8|0,d+112|0,1112491097);c=v[23588];v[23588]=0;if((c|0)==1){break m}c=d+8|0;h=gd(k,c);Ab(c);c=v[h>>2];v[23588]=0;m=S(178,c|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break z}c=0;e=0;B:{if(!m){break B}v[23588]=0;m=S(178,v[d+56>>2])|0;c=v[23588];v[23588]=0;if((c|0)==1){break z}c=0;e=0;if(!m){break B}v[23588]=0;m=Q(713,d+56|0,d+8|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break z}c=0;e=0;if(!m){break B}c=Rb(g,13422,4);v[23588]=0;e=S(279,d+32|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break m}if(c){p=l,q=v[Zc(d,16,1,0,0)>>2],v[p>>2]=q}if((e|0)==6){Jo(l,3)}i=v[h>>2];v[23588]=0;g=v[d+24>>2];h=x[d+20>>1];n=v[d+12>>2];m=v[d+8>>2];i=S(160,i|0)|0;j=v[23588];v[23588]=0;o=1;if((j|0)==1){break m}e=B((e|0)==6?2:1,c?2:1);i=(i>>>0)/(e>>>0)|0;j=bc(g);c=Hb(h);n=(bc(n)>>>0)/(e>>>0)|0;e=(bc(m)>>>0)/(e>>>0)|0}Ab(d+32|0);Ab(d+56|0);if(o){break r}break k}f=P()|0;O()|0;break b}f=P()|0;O()|0;break l}break m}e=0}rt(a,b);v[23588]=0;f=B(b,104)+a|0;g=f+484380|0;R(277,g|0,0);h=v[23588];v[23588]=0;if((h|0)==1){break p}v[g>>2]=i;h=e+n|0;v[f+484388>>2]=h;v[f+484384>>2]=e;if(!(h>>>0<=e+4>>>0|h>>>0>i>>>0)){e=(B(b,104)+a|0)+484414|0;u[e>>1]=x[e>>1]|2}e=B(b,104)+a|0;v[e+484404>>2]=c?c:22050;c=j>>>8|0;u[e+484410>>1]=(j&16776960)>>>0>65536?256:c&65535?c:256;Dz(g,v[a+480180>>2]);v[23588]=0;U(711,d+56|0,d+112|0,1312902469);c=v[23588];v[23588]=0;if((c|0)==1){break o}v[23588]=0;c=S(178,v[d+56>>2])|0;e=v[23588];v[23588]=0;if((e|0)==1){break n}C:{D:{if(c){v[23588]=0;c=S(160,v[d+56>>2])|0;e=v[23588];v[23588]=0;if((e|0)==1){break n}v[23588]=0;U(325,d+56|0,((b<<5)+a|0)+946304|0,c|0);b=v[23588];v[23588]=0;if((b|0)!=1){break D}break n}v[23588]=0;c=Q(55,d+32|0,21619)|0;e=v[23588];v[23588]=0;if((e|0)==1){break C}Cc(((b<<5)+a|0)+946304|0,c);yb(c)}v[23588]=0;W(219,l|0,g|0,k|0)|0;b=v[23588];v[23588]=0;f=1;if((b|0)==1){break n}tj(g,a);Ab(d+56|0);break k}break n}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;Ab(d+56|0);break b}f=P()|0;O()|0;Ab(d+32|0)}Ab(d+56|0);break b}Ab(k);Yd(d+112|0)}jb=d+144|0;return f|0}f=P()|0;O()|0;Ab(d+56|0)}Ab(k)}Yd(d+112|0);T(f|0);L()}function Id(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;k=jb-96|0;jb=k;t=h;u=i&65535;m=(e^i)&-2147483648;l=e&65535;p=l;A=l;K=i>>>16&32767;L=e>>>16&32767;a:{b:{if(K-32767>>>0>4294934529&L-32767>>>0>=4294934530){break b}l=e&2147483647;j=d;if(!(!d&(l|0)==2147418112?!(b|c):l>>>0<2147418112)){o=d;m=e|32768;break a}e=i&2147483647;if(!(!h&(e|0)==2147418112?!(f|g):e>>>0<2147418112)){o=h;m=i|32768;b=f;c=g;break a}if(!(b|j|(l^2147418112|c))){if(!(f|h|(e|g))){m=2147450880;b=0;c=0;break a}m=m|2147418112;b=0;c=0;break a}if(!(f|h|(e^2147418112|g))){d=b|j;e=c|l;b=0;c=0;if(!(d|e)){m=2147450880;break a}m=m|2147418112;break a}if(!(b|j|(c|l))){b=0;c=0;break a}if(!(f|h|(e|g))){b=0;c=0;break a}if((l|0)==65535|l>>>0<65535){j=b;h=!(d|p);i=h<<6;l=E(h?b:d)+32|0;b=E(h?c:p);b=i+((b|0)==32?l:b)|0;Kf(k+80|0,j,c,d,p,b-15|0);s=16-b|0;d=v[k+88>>2];A=v[k+92>>2];c=v[k+84>>2];b=v[k+80>>2]}if(e>>>0>65535){break b}e=!(t|u);h=e<<6;i=E(e?f:t)+32|0;e=E(e?g:u);e=h+((e|0)==32?i:e)|0;Kf(k- -64|0,f,g,t,u,e-15|0);s=(s-e|0)+16|0;t=v[k+72>>2];u=v[k+76>>2];f=v[k+64>>2];g=v[k+68>>2]}e=f;j=g<<15|e>>>17;h=e<<15;e=j;p=h&-32768;q=c;B=Lka(p,0,c,0);c=mb;x=c;C=e;i=0;j=Lka(e,0,b,i);e=j+B|0;h=mb+c|0;h=e>>>0<j>>>0?h+1|0:h;c=e;j=e;n=Lka(b,i,p,i);l=0+n|0;e=mb+e|0;e=l>>>0<n>>>0?e+1|0:e;y=l;n=l;l=e;D=(j|0)==(e|0)&r>>>0>n>>>0|e>>>0<j>>>0;r=d;M=Lka(p,i,d,0);H=mb;e=Lka(q,i,C,i);d=e+M|0;j=mb+H|0;n=d;d=d>>>0<e>>>0?j+1|0:j;e=t;j=u<<15|e>>>17;z=e<<15|g>>>17;g=j;j=Lka(z,0,b,i);e=j+n|0;f=mb+d|0;I=e;f=e>>>0<j>>>0?f+1|0:f;u=f;e=f;f=(h|0)==(x|0)&c>>>0<B>>>0|h>>>0<x>>>0;c=h+I|0;f=e+f|0;B=c;f=c>>>0<h>>>0?f+1|0:f;t=f;c=f;F=A|65536;A=w;N=Lka(p,i,F,w);J=mb;h=Lka(r,o,C,i);f=h+N|0;e=mb+J|0;O=f;e=f>>>0<h>>>0?e+1|0:e;w=e;G=g|-2147483648;x=0;g=Lka(G,x,b,i);b=g+f|0;f=mb+e|0;f=b>>>0<g>>>0?f+1|0:f;P=b;e=Lka(z,o,q,i);b=b+e|0;p=f;j=f+mb|0;Q=b;g=b>>>0<e>>>0?j+1|0:j;f=0;b=f+B|0;e=c+Q|0;e=b>>>0<f>>>0?e+1|0:e;R=b;c=b;b=b+D|0;D=e;f=b>>>0<c>>>0?e+1|0:e;c=f;s=((L+K|0)+s|0)-16383|0;j=Lka(G,x,q,i);h=mb;i=Lka(F,A,C,i);e=i+j|0;f=mb+h|0;f=e>>>0<i>>>0?f+1|0:f;i=(f|0)==(h|0)&e>>>0<j>>>0|f>>>0<h>>>0;h=e;q=i;i=Lka(z,o,r,o);e=i+e|0;j=mb+f|0;j=e>>>0<i>>>0?j+1|0:j;i=(f|0)==(j|0)&e>>>0<h>>>0|f>>>0>j>>>0;f=q+i|0;h=0;h=f>>>0<i>>>0?1:h;q=Lka(G,x,F,A);i=q+f|0;f=mb+h|0;f=i>>>0<q>>>0?f+1|0:f;q=e;h=j;C=i;e=(d|0)==(u|0)&n>>>0>I>>>0|d>>>0>u>>>0;d=e+((d|0)==(H|0)&n>>>0<M>>>0|d>>>0<H>>>0)|0;j=0;j=d>>>0<e>>>0?1:j;i=d;d=q+d|0;e=h+j|0;e=d>>>0<i>>>0?e+1|0:e;n=d;i=e;e=(e|0)==(h|0)&d>>>0<q>>>0|e>>>0<h>>>0;d=C+e|0;h=d>>>0<e>>>0?f+1|0:f;q=d;j=Lka(z,o,F,A);e=mb;r=Lka(G,x,r,o);d=r+j|0;f=mb+e|0;f=d>>>0<r>>>0?f+1|0:f;r=d;d=f;f=(e|0)==(f|0)&j>>>0>r>>>0|e>>>0>f>>>0;z=d+q|0;e=f+h|0;e=d>>>0>z>>>0?e+1|0:e;h=0;d=h+n|0;f=i+r|0;f=d>>>0<h>>>0?f+1|0:f;h=f;j=(i|0)==(f|0)&d>>>0<n>>>0|f>>>0<i>>>0;i=j+z|0;n=i;i=i>>>0<j>>>0?e+1|0:e;r=d;e=d;d=h;j=(p|0)==(w|0)&O>>>0>P>>>0|p>>>0<w>>>0;f=j+((w|0)==(J|0)&O>>>0<N>>>0|w>>>0<J>>>0)|0;h=0;j=f+((g|0)==(p|0)&P>>>0>Q>>>0|g>>>0<p>>>0)|0;f=g+e|0;e=d+j|0;e=f>>>0<g>>>0?e+1|0:e;g=f;h=(d|0)==(e|0)&f>>>0<r>>>0|d>>>0>e>>>0;d=h+n|0;f=i;f=d>>>0<h>>>0?f+1|0:f;h=e;n=d;i=(t|0)==(D|0)&B>>>0>R>>>0|t>>>0>D>>>0;d=i+((t|0)==(u|0)&B>>>0<I>>>0|t>>>0<u>>>0)|0;j=0;j=d>>>0<i>>>0?1:j;i=d;d=d+g|0;e=e+j|0;e=d>>>0<i>>>0?e+1|0:e;h=(e|0)==(h|0)&d>>>0<g>>>0|e>>>0<h>>>0;g=n+h|0;f=g>>>0<h>>>0?f+1|0:f;h=g;i=f;c:{if(f&65536){s=s+1|0;break c}w=l>>>31|0;f=i<<1|h>>>31;h=g<<1|e>>>31;i=f;f=e<<1|d>>>31;d=d<<1|c>>>31;e=f;g=y;f=l<<1|g>>>31;y=g<<1;l=f;f=c<<1|b>>>31;b=b<<1|w;c=f}if((s|0)>=32767){m=m|2147418112;b=0;c=0;break a}d:{if((s|0)<=0){f=1-s|0;if(f>>>0>=128){b=0;c=0;break a}g=s+127|0;Kf(k+48|0,y,l,b,c,g);Kf(k+32|0,d,e,h,i,g);Em(k+16|0,y,l,b,c,f);Em(k,d,e,h,i,f);y=v[k+32>>2]|v[k+16>>2]|(v[k+48>>2]|v[k+56>>2]|(v[k+52>>2]|v[k+60>>2]))!=0;l=v[k+36>>2]|v[k+20>>2];b=v[k+40>>2]|v[k+24>>2];c=v[k+44>>2]|v[k+28>>2];d=v[k>>2];e=v[k+4>>2];f=v[k+8>>2];g=v[k+12>>2];break d}f=h;g=i&65535|s<<16}o=f|o;m=g|m;if(!(!b&(c|0)==-2147483648?!(l|y):(c|0)>0|(c|0)>=0)){b=d+1|0;j=b?e:e+1|0;c=j;f=(e|0)==(j|0)&b>>>0<d>>>0|e>>>0>j>>>0;d=f+o|0;e=m;o=d;m=d>>>0<f>>>0?e+1|0:e;break a}if(b|y|(c^-2147483648|l)){b=d;c=e;break a}j=m;c=d&1;b=c+d|0;f=b>>>0<c>>>0?e+1|0:e;c=f;e=(e|0)==(f|0)&b>>>0<d>>>0|e>>>0>f>>>0;d=e+o|0;o=d;m=d>>>0<e>>>0?j+1|0:j}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=o;v[a+12>>2]=m;jb=k+96|0}function Zfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=jb-144|0;jb=g;yc(b);a:{b:{c:{d:{e:{if(!BR(b,14090)){break e}k=Sb(g+128|0);j=Sb(g+112|0);v[23588]=0;v[g+104>>2]=0;v[g+108>>2]=0;R(246,a|0,32768);d=v[23588];v[23588]=0;if((d|0)==1){break b}v[23588]=0;d=Q(1,g+88|0,8129)|0;i=v[23588];v[23588]=0;if((i|0)==1){break c}Ib(a+1298344|0,d);zb(d);v[23588]=0;d=Q(1,g+72|0,6063)|0;i=v[23588];v[23588]=0;if((i|0)==1){break d}Ib(a+1298356|0,d);zb(d);v[a+1298404>>2]=14;m=a+484376|0;i=a+480280|0;while(1){d=v[b+8>>2];f=v[b>>2];v[23588]=0;d=W(156,f|0,d|0,8)|0;f=v[23588];v[23588]=0;f:{g:{h:{if((f|0)!=1){i:{j:{k:{l:{m:{n:{if(!d){break n}v[23588]=0;d=Q(626,b|0,g- -64|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break m}if(!d){break n}d=v[g+68>>2];v[23588]=0;U(190,g+16|0,b|0,bc(d)|0);d=v[23588];v[23588]=0;if((d|0)==1){break l}d=g+16|0;f=jc(g+40|0,d);Ab(d);d=v[f>>2];v[23588]=0;d=S(178,d|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break j}if(d){break k}Ab(f)}if(x[a+480188>>1]){break i}i=0;break g}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}o:{p:{q:{r:{s:{t:{u:{d=bc(v[g+64>>2]);if((d|0)!=1397769541){if((d|0)==1346458708){break t}if((d|0)==1346522948){break s}if((d|0)==1347175758){break u}if((d|0)!=1396788560){if((d|0)==1396854596){break r}if((d|0)==1397507406){break f}if((d|0)!=1129140036){break p}if(x[a+480188>>1]){break f}d=v[f>>2];v[23588]=0;d=S(160,d|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break j}if(d>>>0<8){break f}d=0;v[23588]=0;R(627,g+16|0,f|0);e=v[23588];v[23588]=0;if((e|0)==1){break j}while(1)if((d|0)==4){if(c){break f}i=1;break o}else{e=x[a+480188>>1];h=cc(g+16|0,d);v:{if(!Hb(w[h|0]|w[h+1|0]<<8)){h=(d&3)-1|0;break v}h=g+104|0;o=Kb(h,e),p=1,t[o|0]=p;o=Kb(h,x[a+480188>>1]+1|0),p=255,t[o|0]=p;df(i+(x[a+480188>>1]<<5)|0);h=x[a+480188>>1];e=h+1|0;u[a+480188>>1]=e;l=i+(h<<5)|0;h=(d&3)-1|0;u[l+4>>1]=h>>>0<2?192:64}df(i+((e&65535)<<5)|0);e=x[a+480188>>1];u[a+480188>>1]=e+1;u[(i+(e<<5)|0)+4>>1]=h>>>0<2?192:64;d=d+1|0;continue}}if(x[a+480190>>1]){break f}v[23588]=0;R(628,f|0,a|0);d=v[23588];v[23588]=0;if((d|0)!=1){break f}break j}d=v[f>>2];v[23588]=0;d=S(160,d|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break j}if(d>>>0<2){break f}v[23588]=0;d=S(271,f|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break j}o=a,p=Cd(d,1,255),v[o+480196>>2]=p;break f}d=v[f>>2];v[23588]=0;d=S(160,d|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break j}if(d>>>0<2){break f}v[23588]=0;n=S(271,f|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){break f}break j}d=w[m|0];e=v[a+484360>>2];h=v[f>>2];v[23588]=0;h=S(160,h|0)|0;l=v[23588];v[23588]=0;if((l|0)==1){break j}v[23588]=0;ea(340,Vb(e,d)|0,f|0,h|0,255,254);d=v[23588];v[23588]=0;if((d|0)==1){break j}break f}d=k;if(Bf(v[d>>2],v[d+4>>2])>>>0>=256){break f}break q}if(Bf(v[j>>2],v[j+4>>2])>>>0>3998){break f}d=v[f>>2];v[23588]=0;e=S(160,d|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break j}d=j;if(!e){break f}}v[23588]=0;R(629,d|0,f|0);d=v[23588];v[23588]=0;if((d|0)!=1){break f}break j}if(!(d&-2139062144)){break f}i=0}Ab(f);break g}a=P()|0;O()|0;Ab(f);break a}v[a+480200>>2]=256;v[a+480204>>2]=125e4;v[a+480260>>2]=452;v[a+480264>>2]=3424;v[a+480228>>2]=48;v[a+480232>>2]=48;b=w[a+484376|0];d=v[a+484360>>2];v[23588]=0;R(324,Vb(d,b)|0,n&65535);b=v[23588];v[23588]=0;if((b|0)==1){break b}w:{if(!(c&1)){break w}b=v[k+4>>2];i=v[k>>2];d=0;v[23588]=0;R(225,a+484344|0,Bf(i,b)&65535);b=v[23588];v[23588]=0;if((b|0)==1){break b}while(1){f=v[k>>2];b=d&65535;if(Bf(f,v[k+4>>2])>>>0<=b>>>0){break w}v[23588]=0;i=v[g+108>>2];e=v[g+104>>2];v[g+8>>2]=e;v[g+12>>2]=i;v[g>>2]=e;v[g+4>>2]=i;X(630,Og(f,b)|0,b|0,a|0,g|0);b=v[23588];v[23588]=0;if((b|0)!=1){d=d+1|0;continue}break}a=P()|0;O()|0;break a}f=c&2;i=1;d=1;b=0;while(1){if(x[a+480190>>1]<=d>>>0){break g}if(!f|Bf(v[j>>2],v[j+4>>2])>>>0<=b>>>0){break g}c=(B(d,104)+a|0)+484380|0;Ko(c);x:{if(v[c>>2]){e=v[Og(v[j>>2],b)>>2];v[23588]=0;e=S(160,e|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break h}wc(c,e);e=Zc(g+40|0,8,1,1,0);h=v[j>>2];v[23588]=0;W(219,e|0,c|0,Og(h,b)|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break x}b=b+1|0}d=d+1|0;continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}Uc(j);Uc(k);break e}Ab(f);continue}}jb=g+144|0;return i|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}Uc(j);Uc(k);T(a|0);L()}function iN(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;h=jb-16|0;jb=h;a:{if(!_c(d&255)){break a}m=a+1074376|0;j=(m+B(b,872)|0)+616|0;b:{g=x[a+480192>>1];if(!(e?1:!(v[a+480180>>2]&17825824)|!g)){break b}if(pj(v[j+656>>2])){break b}c=B(b,872)+a|0;d=c+1075068|0;if(!v[d>>2]){break a}c=v[c+1075080>>2];if(c&1024){break a}e=B(b,872)+a|0;g=e+1075012|0;e=e+1075016|0;if(!(v[g>>2]|v[e>>2])){break a}c:{if(!(c&512)){break c}c=v[a+1298300>>2];if(!Ed(c)){break c}qj(c,b,0);break a}c=Hy(a,b);if((c|0)==65535){break a}i=B(c,872);c=a+1074992|0;a=i+c|0;Rp(a,j);t[a+831|0]=0;t[a+805|0]=0;u[a+786>>1]=b+1;v[a+88>>2]=v[a+88>>2]&-918529;io(a+788|0);v[a+696>>2]=0;v[a+88>>2]=v[a+88>>2]|2101248;v[d>>2]=0;v[j>>2]=0;v[j+4>>2]=0;a=c+B(b,872)|0;v[a+92>>2]=0;v[a+96>>2]=0;v[g>>2]=0;v[e>>2]=0;break a}e=B(b,872)+a|0;k=v[e+1075096>>2];c=c>>>0>g>>>0?0:c;g=v[(c?((c<<2)+a|0)+900380|0:e+1075648|0)>>2];d:{if(!g){break d}l=d-1|0;c=x[cc(g+236|0,l)>>1];f=a+1074312|0;Cb(h+8|0,f,104);e:{if(Bb(v[v[h+8>>2]>>2],v[h+12>>2])){Cb(h,f,34);if(Bb(v[v[h>>2]>>2],v[h+4>>2])){break e}}d=w[Kb(g+108|0,l)|0]}if((c-1&65535)>>>0<=3998){k=(B(c,104)+a|0)+484380|0;break d}Cb(h+8|0,f,43);if(!Bb(v[v[h+8>>2]>>2],v[h+12>>2])){break d}if(!uj(w[g+31|0])){break a}}if(w[e+1075081|0]&4){break a}o=b>>>0>256?b:256;l=a+1074312|0;p=b+1|0;q=a+480188|0;c=b;f:{while(1){if((c|0)==(o|0)){g:{e=0;c=0;if(!pj(v[j+656>>2])){break f}c=0;if(!_c(w[(B(b,872)+a|0)+1075789|0])){break f}d=Ol(a,m,b,2,1)-1|0;c=0;if((d&255)>>>0>249){break f}e=v[Ld(a+906300|0,d)>>2];if(e){break g}e=0;c=0;break f}}else{h:{if((b|0)!=(c|0)&x[q>>1]>c>>>0){break h}e=B(c,872)+a|0;if(x[e+1075778>>1]!=(p|0)&(b|0)!=(c|0)){break h}n=e+1075648|0;f=v[n>>2];if(!f){break h}i:{j:{k:{l:{m:{n:{o:{switch(w[f+17|0]-1|0){case 0:if(!d){break h}i=w[e+1075789|0]==(d|0)&(f|0)==(g|0);if(!g){break n}if(i){break k}break h;case 1:if(!k|v[e+1075096>>2]!=(k|0)){break h}if((f|0)==(g|0)){break i}Cb(h+8|0,l,104);if(!Bb(v[v[h+8>>2]>>2],v[h+12>>2])){break i}break h;case 3:break m;case 2:break o;default:break h}}if(g){break l}i=(f|0)==(g|0)}if(i){break i}break h}if(!g){break h}i=w[g+34|0];if(!i){break h}if((i|0)==w[f+34|0]){break j}break h}if((f|0)!=(g|0)){break h}}if(!w[g+34|0]){break i}}if(!w[e+1075789|0]|w[f+18|0]>2){break i}sm(a,c&65535,w[e+1075793|0]|256,0)}f=e+1074992|0;p:{q:{switch(w[v[n>>2]+18|0]){case 0:Un(a,f);v[e+1075680>>2]=0;if(!(w[e+1075081|0]&2)){break p}f=v[a+1298300>>2];if(!Ed(f)){break p}qj(f,c&65535,1);break p;case 1:Un(a,f);if(!(w[e+1075081|0]&2)){break p}f=v[a+1298300>>2];if(!Ed(f)){break p}hk(f,c&65535);break p;case 2:break q;default:break p}}i=e+1075080|0;f=v[i>>2];v[i>>2]=f|4096;if(!(f&512)){break p}if(!Ed(v[a+1298300>>2])){break p}Cb(h+8|0,l,105);if(Bb(v[v[h+8>>2]>>2],v[h+12>>2])){break p}hk(v[a+1298300>>2],c&65535)}if(v[e+1075680>>2]){break h}v[e+1075688>>2]=0;e=e+1075080|0;v[e>>2]=v[e>>2]|2101248}c=c+1|0;continue}break}c=nb[v[v[e>>2]+104>>2]](e,w[(B(b,872)+a|0)+1075793|0],b)|0}if(!(xi(v[j+8>>2],v[j+12>>2])?1:c)){break a}g=Hy(a,b);if((g|0)==65535){break a}f=B(g,872)+a|0;d=f+1075080|0;k=f+1074992|0;r:{if(!(w[f+1075081|0]&2)){break r}i=v[a+1298300>>2];if(!Ed(i)){break r}qj(i,g,1)}k=Rp(k,j);v[d>>2]=v[d>>2]&-917505;t[f+1075823|0]=0;i=x[a+480188>>1];t[f+1075797|0]=0;u[f+1075778>>1]=b>>>0<i>>>0?b+1|0:0;s:{if(!(c&(e|0)!=0)){break s}c=w[(B(b,872)+a|0)+1075790|0];if(c>>>0>3|(c|0)==1){break s}sm(a,b,255,0);t[(B(b,872)+a|0)+1075792|0]=0}t:{u:{switch(w[(B(b,872)+a|0)+1075790|0]){case 2:Un(a,k);if(!(w[d+1|0]&2)){break t}c=v[a+1298300>>2];if(!Ed(c)){break t}hk(c,b);Cb(h+8|0,l,105);if(!Bb(v[v[h+8>>2]>>2],v[h+12>>2])){break t}sz(v[a+1298300>>2],b,g);break t;case 0:v[(B(g,872)+a|0)+1075688>>2]=0;c=v[d>>2];v[d>>2]=c|4096;if(!(c&512)){break t}c=v[a+1298300>>2];if(!Ed(c)){break t}qj(c,b,1);break t;case 3:c=v[d>>2];v[d>>2]=c|4096;if(!(c&512)){break t}if(!Ed(v[a+1298300>>2])){break t}Cb(h+8|0,l,105);c=v[a+1298300>>2];if(Bb(v[v[h+8>>2]>>2],v[h+12>>2])){sz(c,b,g);break t}hk(c,b);break t;case 1:break u;default:break t}}if(!(w[d+1|0]&2)){break t}c=v[a+1298300>>2];if(!Ed(c)){break t}sz(c,b,g)}if(!v[(B(g,872)+a|0)+1075680>>2]){v[(B(g,872)+a|0)+1075688>>2]=0;v[d>>2]=v[d>>2]|2101248}a=B(b,872)+a|0;v[a+1075068>>2]=0;v[j>>2]=0;v[j+4>>2]=0;a=a+1075084|0;v[a>>2]=0;v[a+4>>2]=0}jb=h+16|0}function gW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=jb-112|0;jb=f;yc(b);a:{if(!Sq(b,11694)){break a}if(!Zu(b,f+96|0)){break a}if(!mC(w[f+97|0])){break a}if(!Pb(v[b>>2],v[b+8>>2],Dc(lC(f+96|0),mb))){break a}if(!Zb(b,w[f+105|0]|w[f+106|0]<<8)){break a}b:{if(!c){break b}Ad(a,4096);v[a+480208>>2]=12;u[a+480188>>1]=(w[f+98|0]&31)+1;e=a+480190|0;u[e>>1]=w[f+99|0];nh(a,1);d=f+24|0;i=xc(d,8436);Ib(a+1298344|0,i);zb(i);i=xc(d,7053);Ib(a+1298356|0,i);zb(i);i=jb-16|0;jb=i;g=xc(i,4250);$c(f,g);zb(g);jb=i+16|0;v[23588]=0;X(229,d|0,f|0,w[f+97|0],f+96|0);d=v[23588];v[23588]=0;c:{if((d|0)!=1){d=f+24|0;Ib(a+1298368|0,d);zb(d);ac(f);v[a+1298404>>2]=5;d=w[f+99|0];i=f+80|0;v[i>>2]=0;v[i+4>>2]=0;nk(i+8|0,0);if(d){Zq(i,d);YC(i,d,0)}d=1;d:{while(1){g=d&65535;if(g>>>0>x[e>>1]){v[23588]=0;Q(230,b|0,a+1298308|0)|0;g=v[23588];v[23588]=0;d=1;e:{if((g|0)==1){break e}g=a+480190|0;while(1){e=d&65535;if(e>>>0>x[g>>1]){d=0;g=a+480188|0;f:{while(1){if(x[g>>1]<=d>>>0){d=0;v[23588]=0;g=a+484344|0;R(225,g|0,x[f+100>>1]);e=v[23588];v[23588]=0;if((e|0)==1){break e}break f}e=(d<<5)+a|0;df(e+480280|0);v[23588]=0;R(231,b|0,e+480289|0);e=v[23588];v[23588]=0;if((e|0)!=1){d=d+1|0;continue}break}b=P()|0;O()|0;break d}g:{h:{i:{j:{while(1){if(x[f+100>>1]<=d>>>0){v[23588]=0;e=S(194,b|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break h}if(!e){break i}d=v[b+8>>2];g=v[b>>2];v[23588]=0;d=W(156,g|0,d|0,e|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break h}if(d){break j}break i}v[23588]=0;e=Q(232,b|0,f+24|0)|0;h=v[23588];v[23588]=0;k:{if((h|0)==1){break k}v[23588]=0;h=W(226,g|0,d&65535,64)|0;j=v[23588];v[23588]=0;if((j|0)==1){break k}if((e&h)==1){e=v[g>>2];v[23588]=0;R(233,Yb(e,d)|0,f+24|0);e=v[23588];v[23588]=0;if((e|0)==1){break k}}d=d+1|0;continue}break}b=P()|0;O()|0;break d}g=Sb(f+24|0);v[23588]=0;U(234,b|0,g|0,e|0);d=v[23588];v[23588]=0;l:{if((d|0)!=1){d=Lb(f);v[23588]=0;R(46,d|0,e|0);e=v[23588];v[23588]=0;m:{if((e|0)==1){break m}k=f,l=Eb(v[g>>2]),v[k+48>>2]=l;h=Eb(v[g+4>>2]);while(1){n:{e=v[f+48>>2];if(!Ob(e,h)){v[23588]=0;X(235,f+48|0,5,6,d|0);e=v[23588];v[23588]=0;if((e|0)==1){break n}h=f+48|0;e=Ac(d,h);yb(h);h=Lc(e);j=Gb(e);v[23588]=0;ea(236,a+1298332|0,h|0,j|0,76,0);h=v[23588];v[23588]=0;if((h|0)==1){break m}yb(e);hc(g);break i}o:{e=w[e|0];if(e&128){k=f,l=yh(d),v[k+64>>2]=l;j=v[lj(f+72|0,f- -64|0)>>2];v[23588]=0;X(237,d|0,j|0,e&127,32);e=v[23588];v[23588]=0;if((e|0)!=1){break o}break m}v[23588]=0;R(47,d|0,e<<24>>24);e=v[23588];v[23588]=0;if((e|0)!=1){break o}break m}Ge(f+48|0);continue}break}}b=P()|0;O()|0;yb(d);break l}b=P()|0;O()|0}hc(g);break d}d=w[a+484376|0];g=v[a+484360>>2];v[23588]=0;U(238,Vb(g,d)|0,b|0,x[f+102>>1]);d=v[23588];v[23588]=0;if((d|0)==1){break h}e=c&1;h=a+484348|0;d=0;while(1){p:{q:{if(x[f+100>>1]>d>>>0){g=v[b+8>>2];j=v[b>>2];v[23588]=0;g=W(156,j|0,g|0,4)|0;j=v[23588];v[23588]=0;if((j|0)==1){break p}if(g){break q}}if(!(c&2)){break g}g=a+480190|0;d=1;while(1){c=d&65535;if(c>>>0>x[g>>1]){break g}e=B(c,104)+a|0;h=x[e+484414>>1];Cb(f+24|0,v[i>>2],c-1|0);c=Zc(f,h&1?16:8,1,0,Bb(v[v[f+24>>2]>>2],v[f+28>>2])?6:0);v[23588]=0;W(219,c|0,e+484380|0,b|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){d=d+1|0;continue}break}b=P()|0;O()|0;break d}v[23588]=0;g=S(157,b|0)|0;j=v[23588];v[23588]=0;r:{s:{if((j|0)!=1){v[23588]=0;U(190,f|0,b|0,g|0);g=v[23588];v[23588]=0;if((g|0)==1){break s}g=jc(f+24|0,f);Ab(f);if(!e){break r}j=v[a+484344>>2];if(!xe(j,v[h>>2],d&65535)){break r}v[23588]=0;U(239,Yb(j,d)|0,0,g|0);j=v[23588];v[23588]=0;if((j|0)!=1){break r}b=P()|0;O()|0;Ab(g);break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}Ab(g);d=d+1|0;continue}break}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}Ve(i);break b}v[23588]=0;Q(240,b|0,((e<<5)+a|0)+946304|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){d=d+1|0;continue}break}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}v[23588]=0;R(241,b|0,f+24|0);h=v[23588];v[23588]=0;t:{if((h|0)==1){break t}v[23588]=0;R(242,f+24|0,(B(g,104)+a|0)+484380|0);h=v[23588];v[23588]=0;if((h|0)==1){break t}h=w[f+40|0];Cb(f,v[i>>2],g-1|0);Ye(f,(h&3)!=0);d=d+1|0;continue}break}b=P()|0;O()|0}Ve(i);break c}b=P()|0;O()|0;ac(f)}T(b|0);L()}d=1}jb=f+112|0;return d|0}function T9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=C(0),j=0,k=0,l=0;e=jb-336|0;jb=e;d=-1;a:{b:{c:{if(!Zk(v[(v[v[b>>2]-12>>2]+b|0)+16>>2])){b=Zl(e+224|0,b);v[23588]=0;d=Q(449,e+208|0,13921)|0;f=v[23588];v[23588]=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((f|0)!=1){v[23588]=0;v[e+192>>2]=83886084;v[e+196>>2]=0;U(450,b|0,d|0,e+192|0);f=v[23588];v[23588]=0;if((f|0)==1){break A}_b(d);t[e+207|0]=0;v[23588]=0;d=Q(449,e+192|0,14706)|0;f=v[23588];v[23588]=0;if((f|0)==1){break z}v[23588]=0;U(451,b|0,e+207|0,d|0);f=v[23588];v[23588]=0;if((f|0)==1){break y}_b(d);v[23588]=0;f=w[e+207|0];d=Q(449,e+176|0,15771)|0;g=v[23588];v[23588]=0;if((g|0)==1){break x}v[23588]=0;f=f?0:c;X(880,b|0,a+40|0,d|0,f|0);c=v[23588];v[23588]=0;if((c|0)==1){break w}_b(d);u[e+174>>1]=65535;v[23588]=0;c=Q(449,e+160|0,15441)|0;d=v[23588];v[23588]=0;if((d|0)==1){break v}v[23588]=0;W(479,b|0,e+174|0,c|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break u}_b(c);u[e+158>>1]=0;v[23588]=0;c=Q(449,e+144|0,15334)|0;d=v[23588];v[23588]=0;if((d|0)==1){break t}v[23588]=0;W(479,b|0,e+158|0,c|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break s}_b(c);u[a>>1]=x[e+158>>1];v[23588]=0;c=Q(449,e+128|0,15016)|0;d=v[23588];v[23588]=0;if((d|0)==1){break r}v[23588]=0;X(881,b|0,a+52|0,c|0,f|0);d=v[23588];v[23588]=0;if((d|0)==1){break q}_b(c);v[23588]=0;c=Q(449,e+112|0,14946)|0;d=v[23588];v[23588]=0;if((d|0)==1){break p}v[23588]=0;U(872,b|0,a+36|0,c|0);d=v[23588];v[23588]=0;if((d|0)==1){break o}_b(c);v[23588]=0;c=Q(449,e+96|0,15448)|0;d=v[23588];v[23588]=0;if((d|0)==1){break n}v[23588]=0;h=a+4|0;U(882,b|0,h|0,c|0);d=v[23588];v[23588]=0;if((d|0)==1){break m}_b(c);v[23588]=0;c=Q(449,e+80|0,15336)|0;d=v[23588];v[23588]=0;if((d|0)==1){break l}v[23588]=0;f=a+28|0;U(883,b|0,f|0,c|0);d=v[23588];v[23588]=0;if((d|0)==1){break k}_b(c);v[23588]=0;c=Q(449,e- -64|0,15191)|0;d=v[23588];v[23588]=0;if((d|0)==1){break j}v[23588]=0;U(883,b|0,a+30|0,c|0);d=v[23588];v[23588]=0;if((d|0)==1){break i}_b(c);v[23588]=0;c=Q(449,e+48|0,14988)|0;d=v[23588];v[23588]=0;if((d|0)==1){break h}v[23588]=0;U(884,b|0,a+32|0,c|0);d=v[23588];v[23588]=0;if((d|0)==1){break g}_b(c);u[e+46>>1]=0;v[23588]=0;c=Q(449,e+32|0,14925)|0;d=v[23588];v[23588]=0;if((d|0)==1){break c}v[23588]=0;W(479,b|0,e+46|0,c|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break f}_b(c);i=GL(z[a+32>>2]);z[a+32>>2]=i;d=-1;if(!pm(i)){break d}k=e,l=Eb(v[a+4>>2]),v[k+24>>2]=l;c=Eb(v[a+8>>2]);while(1){g=v[e+24>>2];if(!Ob(g,c)){break e}if(!pm(z[g>>2])){break d}Ke(e+24|0);continue}}a=P()|0;O()|0;break a}a=P()|0;O()|0;_b(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;_b(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;_b(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;_b(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;_b(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;_b(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;_b(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;_b(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;_b(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;_b(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;_b(c);break a}a=P()|0;O()|0;_b(c);break a}if(Kk(w[b|0])){break d}c=x[f>>1];if((c-301&65535)>>>0<64935){break d}g=x[a>>1];if(g>>>0>3|(g|0)==2){break d}j=u[a+30>>1];if((j|0)<0){break d}k=e,l=Ei(v[a+36>>2]),v[k+24>>2]=l;v[e+16>>2]=0;k=a,l=v[Ij(e+24|0,e+16|0,43824)>>2],v[k+36>>2]=l;if(uc(v[a+4>>2],v[a+8>>2])>>>0>32767){break d}B:{C:{switch(g-1|0){case 2:f=u[e+46>>1];if((f|0)<=0){break d}u[e+14>>1]=j;z[e+24>>2]=z[a+32>>2];v[23588]=0;u[e+16>>1]=c;u[e+18>>1]=(c+f|0)-1;a=fa(885,a|0,e+14|0,e+24|0,e+16|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){if(a){break B}break d}a=P()|0;O()|0;break a;case 0:g=u[e+46>>1];if((g|0)<=0){break d}z[e+24>>2]=z[a+32>>2];v[23588]=0;u[e+16>>1]=c;u[e+18>>1]=(c+g|0)-1;a=ja(886,a|0,h|0,e+24|0,e+16|0,f|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){if(a){break B}break d}a=P()|0;O()|0;break a;default:break C}}v[23588]=0;Y(887,a|0);a=v[23588];v[23588]=0;if((a|0)==1){break b}}d=1}kh(b)}jb=e+336|0;return d|0}a=P()|0;O()|0;break a}a=P()|0;O()|0}kh(b);T(a|0);L()}function Ax(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;l=jb-48|0;jb=l;v[l+44>>2]=0;if(i?1:d|g|h){j=g?l+44|0:0;a:{if(!j){break a}k=v[j>>2];if(!k){break a}Mb(k);v[j>>2]=0}v[23588]=0;Z(105);k=v[23588];v[23588]=0;b:{c:{if((k|0)==1){m=Xa(92948,48944,49e3,62688,93136,93240,93188,93080,93068,93384,93352,93320,93308,93532,0)|0;d:{e:{n=O()|0;if((n|0)==(da(92948)|0)){k=_(m|0)|0;v[23588]=0;R(1053,j|0,k|0);j=v[23588];v[23588]=0;k=277;if((j|0)==1){break e}break b}if((da(48944)|0)==(n|0)){k=_(m|0)|0;v[23588]=0;R(1053,j|0,k|0);j=v[23588];v[23588]=0;k=358;if((j|0)!=1){break b}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){break c}break d}if((da(49e3)|0)==(n|0)){k=_(m|0)|0;v[23588]=0;R(1053,j|0,k|0);j=v[23588];v[23588]=0;k=359;if((j|0)!=1){break b}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){break c}break d}if((da(62688)|0)==(n|0)){k=_(m|0)|0;v[23588]=0;R(1053,j|0,k|0);j=v[23588];v[23588]=0;k=357;if((j|0)!=1){break b}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){break c}break d}if((da(93136)|0)==(n|0)){k=_(m|0)|0;v[23588]=0;R(1053,j|0,k|0);j=v[23588];v[23588]=0;k=300;if((j|0)!=1){break b}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){break c}break d}if((da(93240)|0)==(n|0)){k=_(m|0)|0;v[23588]=0;R(1053,j|0,k|0);j=v[23588];v[23588]=0;k=299;if((j|0)!=1){break b}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){break c}break d}if((da(93188)|0)==(n|0)){k=_(m|0)|0;v[23588]=0;R(1053,j|0,k|0);j=v[23588];v[23588]=0;k=298;if((j|0)!=1){break b}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){break c}break d}if((da(93080)|0)==(n|0)){k=_(m|0)|0;v[23588]=0;R(1053,j|0,k|0);j=v[23588];v[23588]=0;k=297;if((j|0)!=1){break b}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){break c}break d}if((da(93068)|0)==(n|0)){k=_(m|0)|0;v[23588]=0;R(1053,j|0,k|0);j=v[23588];v[23588]=0;k=296;if((j|0)!=1){break b}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){break c}break d}if((da(93384)|0)==(n|0)){k=_(m|0)|0;v[23588]=0;R(1053,j|0,k|0);j=v[23588];v[23588]=0;k=289;if((j|0)!=1){break b}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){break c}break d}if((da(93352)|0)==(n|0)){k=_(m|0)|0;v[23588]=0;R(1053,j|0,k|0);j=v[23588];v[23588]=0;k=288;if((j|0)!=1){break b}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){break c}break d}if((da(93320)|0)==(n|0)){k=_(m|0)|0;v[23588]=0;R(1053,j|0,k|0);j=v[23588];v[23588]=0;k=287;if((j|0)!=1){break b}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){break c}break d}if((da(93308)|0)==(n|0)){k=_(m|0)|0;v[23588]=0;R(1053,j|0,k|0);j=v[23588];v[23588]=0;k=286;if((j|0)!=1){break b}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){break c}break d}o=da(93532)|0;k=257;m=_(m|0)|0;if((n|0)!=(o|0)){break b}v[23588]=0;R(1053,j|0,m|0);j=v[23588];v[23588]=0;k=267;if((j|0)!=1){break b}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)==1){break d}break c}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){break c}}V(0)|0;O()|0;Ub()}L()}T(a|0);L()}$()}m=!g;if(d){j=nb[d|0](k,e)|0}else{j=3}if(!(m|!(j&2))){v[g+16>>2]=k;m=g;g=v[l+44>>2];p=m,q=fg(g?g:21619),v[p+20>>2]=q}if(h){v[h>>2]=k}if(i){g=v[l+44>>2];p=i,q=fg(g?g:21619),v[p>>2]=q}g=v[l+44>>2];if(g){Mb(g);v[l+44>>2]=0}f:{if(!(j&1)){break f}v[23588]=0;R(1051,l+32|0,a|0);g=v[23588];v[23588]=0;g:{h:{if((g|0)!=1){i:{if(f){g=v[f+24>>2];v[23588]=0;R(1052,g|0,l+32|0);g=v[23588];v[23588]=0;if((g|0)!=1){break i}break h}g=Lc(l+32|0);if(b){v[23588]=0;R(b|0,g|0,c|0);g=v[23588];v[23588]=0;if((g|0)==1){break h}break i}Ns(g,l)}yb(l+32|0);break f}g=V(0)|0;O()|0;break g}g=V(0)|0;O()|0;yb(l+32|0)}_(g|0)|0;v[l+28>>2]=f;v[l+24>>2]=e;v[l+20>>2]=d;v[l+16>>2]=c;v[l+12>>2]=b;v[l+8>>2]=a?a:21619;v[l+4>>2]=254;v[l>>2]=9134;pK(17835,l);Ls(93888);$()}jb=l+48|0}function yja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0;e=jb-352|0;jb=e;yc(b);f=jb-16|0;jb=f;lU(f+8|0,e+128|0);h=v[f+12>>2];mc(f,v[b>>2],v[b+8>>2],v[f+8>>2],v[f+12>>2]);i=v[f+4>>2];if((i|0)==(h|0)){Zb(b,v[f+12>>2])}jb=f+16|0;a:{b:{c:{d:{e:{f:{g:{if((h|0)!=(i|0)){break g}if(!nU(e+128|0)){break g}if(!Pb(v[b>>2],v[b+8>>2],Dc(mU(w[e+344|0],w[e+345|0]),mb))){break g}if(!c){d=1;break g}Ad(a,2);$f(a);v[a+480188>>2]=524296;s=a,z=Pe(455e3),v[s+480204>>2]=z;Nb(a+1074312|0,110,1);v[a+480208>>2]=v[a+480208>>2]|16777216;f=e+96|0;Me(f,2,e+159|0);d=e+112|0;Ec(d,f);Ac(a+1298308|0,d);yb(d);d=0;h:{i:{while(1){if((d|0)==8){j:{d=Vb(v[a+484360>>2],w[a+484376|0]);o=w[e+344|0];n=o+1|0;so(d,b,n,65535,65535);f=Sb(e+112|0);v[23588]=0;U(234,b|0,f|0,n|0);d=v[23588];v[23588]=0;if((d|0)==1){break j}s=e,z=Eb(v[f>>2]),v[s+96>>2]=z;d=Eb(v[f+4>>2]);while(1){h=v[e+96>>2];p=Ob(h,d);if(p){if((w[h|0]-9&255)>>>0<248){break h}Ge(e+96|0);continue}break}s=a,z=w[Kb(v[f>>2],0)|0],v[s+480196>>2]=z;d=w[e+343|0];i=w[e+345|0];h=Sb(e+96|0);v[23588]=0;m=i+1|0;U(234,b|0,h|0,m|0);i=v[23588];v[23588]=0;k:{if((i|0)==1){break k}v[23588]=0;i=a+484344|0;R(225,i|0,m|0);g=v[23588];v[23588]=0;if((g|0)==1){break k}q=d+1|0;if(!(c&1)){break i}c=0;while(1){if((c|0)==(m|0)){break i}d=w[Kb(v[h>>2],c)|0];v[23588]=0;d=W(226,i|0,d|0,q|0)|0;g=v[23588];v[23588]=0;l:{if((g|0)!=1){if(!d){break i}j=0;k=Yb(v[i>>2],w[Kb(v[h>>2],c)|0]);m:while(1){r=j&65535;if(r>>>0>7){break l}j=j+1|0;d=0;while(1){if(y[k+12>>2]<=d>>>0){continue m}v[23588]=0;g=S(206,b|0)|0;l=v[23588];v[23588]=0;n:{o:{if((l|0)!=1){if(!(g&128)){break o}d=(g&127)+d|0;break n}d=P()|0;O()|0;break b}l=id(v[k>>2],v[v[k+48>>2]+12>>2],d,r);if((g|0)==1){t[l|0]=254;break n}if((g-1&255)>>>0>96){break n}t[l+1|0]=j;t[l|0]=g+12}d=d+1|0;continue}}}d=P()|0;O()|0;break b}c=c+1|0;continue}}d=P()|0;O()|0;break b}}else{i=e+112|0;f=(e+128|0)+B(d,19)|0;iB(i,f+63|0);h=e+96|0;Ec(h,i);Gl(((d<<5)+a|0)+480289|0,h);yb(h);d=d+1|0;g=B(d,104)+a|0;j=g+484380|0;md(j,2);t[e+107|0]=0;h=w[f+78|0]|w[f+79|0]<<8|(w[f+80|0]<<16|w[f+81|0]<<24);t[e+103|0]=h;t[e+104|0]=h>>>8;t[e+105|0]=h>>>16;t[e+106|0]=h>>>24;h=w[f+75|0]|w[f+76|0]<<8|(w[f+77|0]<<16|w[f+78|0]<<24);f=w[f+71|0]|w[f+72|0]<<8|(w[f+73|0]<<16|w[f+74|0]<<24);v[e+8>>2]=v[e+104>>2];v[e+96>>2]=f;v[e+100>>2]=h;f=v[e+100>>2];v[e>>2]=v[e+96>>2];v[e+4>>2]=f;Fl(j,1,e);v[g+484404>>2]=8215;f=e+80|0;Ec(f,i);Cc(((d<<5)+a|0)+946304|0,f);yb(f);continue}break}d=P()|0;O()|0;break a}j=o+1|0;c=a+484376|0;d=0;p:{q:{while(1){if((d|0)==(j|0)){v[23588]=0;b=Q(1,e+80|0,8576)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break p}d=P()|0;O()|0;break b}b=w[c|0];g=v[a+484360>>2];v[23588]=0;k=d&65535;b=Q(311,Vb(g,b)|0,k|0)|0;g=v[23588];v[23588]=0;if((g|0)!=1){r:{s:{if(b){b=Vb(v[a+484360>>2],w[c|0]);break s}v[23588]=0;g=Q(359,i|0,q|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break q}if((g|0)==65535){break r}b=Vb(v[a+484360>>2],w[c|0]);s=cc(v[b>>2],d),z=g,u[s>>1]=z}b=hB(Eb(v[Yb(v[i>>2],x[cc(v[b>>2],d)>>1])+4>>2]),1);g=w[b+5|0];l=w[Kb(v[f>>2],(d+1>>>0)%(n>>>0)|0)|0];if((g|0)==(l|0)){break r}t:{if(w[b+3|0]!=16){break t}g=w[c|0];m=v[a+484360>>2];v[23588]=0;g=Q(360,Vb(m,g)|0,k|0)|0;k=v[23588];v[23588]=0;if((k|0)==1){break c}if((g|0)==65535){break t}b=hB(Eb(v[Yb(v[i>>2],g)+4>>2]),1)}t[b+5|0]=l;t[b+3|0]=16}d=d+1|0;continue}break}d=P()|0;O()|0;break b}d=P()|0;O()|0;break b}Ib(a+1298344|0,b);zb(b);v[23588]=0;b=Q(1,e- -64|0,6052)|0;c=v[23588];v[23588]=0;if((c|0)==1){break f}Ib(a+1298356|0,b);zb(b);b=e+16|0;Cj(b,2,e+139|0);v[23588]=0;R(222,e+32|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break e}v[23588]=0;U(11,e+48|0,5,e+32|0);b=v[23588];v[23588]=0;if((b|0)==1){break d}b=e+48|0;Ib(a+1298368|0,b);zb(b);yb(e+32|0);v[a+1298404>>2]=5;hc(h)}hc(f);d=p^1}jb=e+352|0;return d|0}d=P()|0;O()|0;break b}d=P()|0;O()|0;break b}d=P()|0;O()|0;yb(e+32|0);break b}d=P()|0;O()|0}hc(h)}hc(f);T(d|0);L()}function gK(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=jb-272|0;jb=f;g=v[b+4>>2];a:{if(!g){break a}h=v[b>>2];i=w[cl(h,g)|0];if((i|0)==33){e=1}else{if((i|0)!=63){break a}e=0}jl(f+96|0,h,g,g-1|0);g=v[f+100>>2];v[b>>2]=v[f+96>>2];v[b+4>>2]=g}g=f+96|0;Wd(g);h=v[f+96>>2];Wd(f+248|0);i=bl(h,v[f+252>>2],b);Wd(g);g=v[b+4>>2];h=v[b>>2];b:{c:{d:{e:{if((i|0)==v[f+100>>2]){a=qc(f+264|0,21619);i=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=i;if(Pc(h,g,f+8|0)){e=ba(8)|0;v[23588]=0;c=Kh(f+248|0,c,d);a=v[23588];v[23588]=0;f:{g:{h:{if((a|0)!=1){v[23588]=0;U(967,f+96|0,17598,c|0);a=v[23588];v[23588]=0;if((a|0)==1){break h}a=0;b=rc(e,f+96|0);v[23588]=0;U(119,b|0,62688,956);b=v[23588];v[23588]=0;if((b|0)!=1){break b}b=P()|0;O()|0;yb(f+96|0);break g}b=P()|0;O()|0;break f}b=P()|0;a=1;O()|0}yb(c);if(!a){break c}}ca(e|0);break c}if(!e){break e}e=ba(8)|0;a=v[b+4>>2];b=v[b>>2];v[23588]=0;g=Kh(f+216|0,b,a);a=v[23588];v[23588]=0;i:{j:{k:{l:{m:{n:{o:{p:{q:{if((a|0)!=1){v[23588]=0;U(967,f+232|0,17634,g|0);a=v[23588];v[23588]=0;if((a|0)==1){break q}v[23588]=0;R(969,f+248|0,f+232|0);b=v[23588];v[23588]=0;a=1;if((b|0)==1){break p}v[23588]=0;c=Kh(f+200|0,c,d);a=v[23588];v[23588]=0;if((a|0)==1){break o}v[23588]=0;U(971,f+96|0,f+248|0,c|0);b=v[23588];v[23588]=0;a=1;if((b|0)==1){break n}a=rc(e,f+96|0);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(f+96|0);a=0;break m}b=P()|0;O()|0;break i}b=P()|0;a=1;O()|0;break j}b=P()|0;O()|0;break k}b=P()|0;a=1;O()|0;break l}b=P()|0;O()|0}yb(c)}yb(f+248|0)}yb(f+232|0)}yb(g);if(!a){break c}}ca(e|0);break c}b=qc(f+192|0,21619);e=v[b+4>>2];v[f+88>>2]=v[b>>2];v[f+92>>2]=e;if(Pc(h,g,f+88|0)){e=ba(8)|0;v[23588]=0;c=Kh(f+248|0,c,d);a=v[23588];v[23588]=0;r:{s:{t:{if((a|0)!=1){v[23588]=0;U(967,f+96|0,17598,c|0);a=v[23588];v[23588]=0;if((a|0)==1){break t}a=0;b=rc(e,f+96|0);v[23588]=0;U(119,b|0,62688,956);b=v[23588];v[23588]=0;if((b|0)!=1){break b}b=P()|0;O()|0;yb(f+96|0);break s}b=P()|0;O()|0;break r}b=P()|0;a=1;O()|0}yb(c);if(!a){break c}}ca(e|0);break c}b=qc(f+184|0,12273);e=v[b+4>>2];v[f+80>>2]=v[b>>2];v[f+84>>2]=e;if(Pc(h,g,f+80|0)){b=qc(f+176|0,5604);e=v[b+4>>2];v[f+32>>2]=v[b>>2];v[f+36>>2]=e;b=c;e=d;if(Pc(b,e,f+32|0)){v[a+52>>2]=0;break e}g=qc(f+168|0,11205);h=v[g+4>>2];v[f+24>>2]=v[g>>2];v[f+28>>2]=h;if(Pc(b,e,f+24|0)){v[a+52>>2]=1;break e}g=qc(f+160|0,9166);h=v[g+4>>2];v[f+16>>2]=v[g>>2];v[f+20>>2]=h;if(Pc(b,e,f+16|0)){v[a+52>>2]=2;break e}e=ba(8)|0;v[23588]=0;c=Kh(f+248|0,c,d);a=v[23588];v[23588]=0;u:{v:{w:{if((a|0)!=1){v[23588]=0;U(967,f+96|0,14577,c|0);a=v[23588];v[23588]=0;if((a|0)==1){break w}a=0;b=rc(e,f+96|0);v[23588]=0;U(119,b|0,62688,956);b=v[23588];v[23588]=0;if((b|0)!=1){break b}b=P()|0;O()|0;yb(f+96|0);break v}b=P()|0;O()|0;break u}b=P()|0;a=1;O()|0}yb(c);if(!a){break c}}ca(e|0);break c}b=qc(f+152|0,11442);e=v[b+4>>2];v[f+72>>2]=v[b>>2];v[f+76>>2]=e;if(!Pc(h,g,f+72|0)){break e}b=qc(f+144|0,15561);e=v[b+4>>2];v[f+64>>2]=v[b>>2];v[f+68>>2]=e;b=0;x:{e=c;c=d;if(Pc(e,c,f- -64|0)){break x}b=qc(f+136|0,15566);d=v[b+4>>2];v[f+56>>2]=v[b>>2];v[f+60>>2]=d;b=1;if(Pc(e,c,f+56|0)){break x}b=qc(f+128|0,12547);d=v[b+4>>2];v[f+48>>2]=v[b>>2];v[f+52>>2]=d;b=2;if(Pc(e,c,f+48|0)){break x}b=qc(f+120|0,9230);d=v[b+4>>2];v[f+40>>2]=v[b>>2];v[f+44>>2]=d;b=3;if(Pc(e,c,f+40|0)){break x}a=ba(8)|0;v[23588]=0;c=Q(55,f+96|0,11478)|0;b=v[23588];v[23588]=0;if((b|0)==1){break d}a=rc(a,c);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(c);break c}v[a+56>>2]=b;a=v[a+24>>2];if(!v[a+24668>>2]){break e}c=a+24664|0;d=v[c+4>>2];v[f+112>>2]=v[c>>2];v[f+116>>2]=d;c=a+24656|0;d=v[c+4>>2];v[f+104>>2]=v[c>>2];v[f+108>>2]=d;c=v[a+24652>>2];v[f+96>>2]=v[a+24648>>2];v[f+100>>2]=c;j=f,k=MJ(b),v[j+116>>2]=k;if(!xx(f+96|0,a+24648|0)){break e}py(a,f+96|0)}jb=f+272|0;return}b=P()|0;O()|0;ca(a|0)}T(b|0)}L()}function SH(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0,C=0;i=jb-560|0;jb=i;g=c;c=(c-3|0)/24|0;s=(c|0)>0?c:0;k=g+B(s,-24)|0;o=v[(e<<2)+73776>>2];j=d-1|0;if((o+j|0)>=0){g=d+o|0;c=s-j|0;while(1){A[(i+320|0)+(h<<3)>>3]=(c|0)<0?0:+v[(c<<2)+73792>>2];c=c+1|0;h=h+1|0;if((g|0)!=(h|0)){continue}break}}q=k-24|0;g=0;t=(o|0)>0?o:0;h=(d|0)<=0;while(1){a:{if(h){f=0;break a}n=g+j|0;c=0;f=0;while(1){f=A[(c<<3)+a>>3]*A[(i+320|0)+(n-c<<3)>>3]+f;c=c+1|0;if((d|0)!=(c|0)){continue}break}}A[(g<<3)+i>>3]=f;c=(g|0)==(t|0);g=g+1|0;if(!c){continue}break}z=47-k|0;u=48-k|0;C=k-25|0;g=o;b:{while(1){f=A[(g<<3)+i>>3];c=0;h=g;l=(g|0)<=0;if(!l){while(1){n=(i+480|0)+(c<<2)|0;m=f*5.960464477539063e-8;c:{if(D(m)<2147483648){j=~~m;break c}j=-2147483648}m=+(j|0);f=m*-16777216+f;d:{if(D(f)<2147483648){j=~~f;break d}j=-2147483648}v[n>>2]=j;h=h-1|0;f=A[(h<<3)+i>>3]+m;c=c+1|0;if((g|0)!=(c|0)){continue}break}}f=Uj(f,q);f=f+H(f*.125)*-8;e:{if(D(f)<2147483648){n=~~f;break e}n=-2147483648}f=f-+(n|0);f:{g:{h:{w=(q|0)<=0;i:{if(!w){h=(g<<2)+i|0;j=v[h+476>>2];c=j>>u;r=h;h=j-(c<<u)|0;v[r+476>>2]=h;n=c+n|0;j=h>>z;break i}if(q){break h}j=v[((g<<2)+i|0)+476>>2]>>23}if((j|0)<=0){break f}break g}j=2;if(f>=.5){break g}j=0;break f}c=0;h=0;if(!l){while(1){r=(i+480|0)+(c<<2)|0;x=v[r>>2];l=16777215;j:{k:{if(h){break k}l=16777216;if(x){break k}h=0;break j}v[r>>2]=l-x;h=1}c=c+1|0;if((g|0)!=(c|0)){continue}break}}l:{if(w){break l}c=8388607;m:{switch(C|0){case 1:c=4194303;break;case 0:break m;default:break l}}l=(g<<2)+i|0;v[l+476>>2]=v[l+476>>2]&c}n=n+1|0;if((j|0)!=2){break f}f=1-f;j=2;if(!h){break f}f=f-Uj(1,q)}if(f==0){c=1;l=0;h=g;n:{if((g|0)<=(o|0)){break n}while(1){h=h-1|0;l=v[(i+480|0)+(h<<2)>>2]|l;if((h|0)>(o|0)){continue}break}if(!l){break n}k=q;while(1){k=k-24|0;g=g-1|0;if(!v[(i+480|0)+(g<<2)>>2]){continue}break}break b}while(1){h=c;c=c+1|0;if(!v[(i+480|0)+(o-h<<2)>>2]){continue}break}h=g+h|0;while(1){j=d+g|0;g=g+1|0;A[(i+320|0)+(j<<3)>>3]=v[(s+g<<2)+73792>>2];c=0;f=0;if((d|0)>0){while(1){f=A[(c<<3)+a>>3]*A[(i+320|0)+(j-c<<3)>>3]+f;c=c+1|0;if((d|0)!=(c|0)){continue}break}}A[(g<<3)+i>>3]=f;if((g|0)<(h|0)){continue}break}g=h;continue}break}f=Uj(f,24-k|0);o:{if(f>=16777216){d=(i+480|0)+(g<<2)|0;m=f*5.960464477539063e-8;p:{if(D(m)<2147483648){c=~~m;break p}c=-2147483648}f=+(c|0)*-16777216+f;q:{if(D(f)<2147483648){a=~~f;break q}a=-2147483648}v[d>>2]=a;g=g+1|0;break o}if(D(f)<2147483648){c=~~f}else{c=-2147483648}k=q}v[(i+480|0)+(g<<2)>>2]=c}f=Uj(1,k);if((g|0)>=0){d=g;while(1){a=d;A[(a<<3)+i>>3]=f*+v[(i+480|0)+(a<<2)>>2];d=a-1|0;f=f*5.960464477539063e-8;if(a){continue}break}a=0;h=g;while(1){d=a>>>0>t>>>0?t:a;c=0;f=0;while(1){f=A[(c<<3)+76560>>3]*A[(c+h<<3)+i>>3]+f;k=(c|0)!=(d|0);c=c+1|0;if(k){continue}break}A[(i+160|0)+(g-h<<3)>>3]=f;h=h-1|0;c=(a|0)!=(g|0);a=a+1|0;if(c){continue}break}}r:{s:{t:{switch(e|0){case 3:u:{if((g|0)<=0){break u}d=(i+160|0)+(g<<3)|0;f=A[d>>3];c=g;while(1){m=f;e=i+160|0;a=c-1|0;h=e+(a<<3)|0;y=A[h>>3];f=y+f;A[e+(c<<3)>>3]=m+(y-f);A[h>>3]=f;e=c>>>0>1;c=a;if(e){continue}break}if((g|0)<2){break u}f=A[d>>3];c=g;while(1){m=f;d=i+160|0;a=c-1|0;e=d+(a<<3)|0;p=A[e>>3];f=p+f;A[d+(c<<3)>>3]=m+(p-f);A[e>>3]=f;d=c>>>0>2;c=a;if(d){continue}break}p=0;while(1){p=p+A[(i+160|0)+(g<<3)>>3];a=(g|0)>2;g=g-1|0;if(a){continue}break}}f=A[i+160>>3];if(j){break s}A[b>>3]=f;f=A[i+168>>3];A[b+16>>3]=p;A[b+8>>3]=f;break r;case 0:f=0;if((g|0)>=0){while(1){a=g;g=g-1|0;f=f+A[(i+160|0)+(a<<3)>>3];if(a){continue}break}}A[b>>3]=j?-f:f;break r;case 1:case 2:break t;default:break r}}f=0;if((g|0)>=0){d=g;while(1){a=d;d=a-1|0;f=f+A[(i+160|0)+(a<<3)>>3];if(a){continue}break}}A[b>>3]=j?-f:f;f=A[i+160>>3]-f;c=1;if((g|0)>0){while(1){f=f+A[(i+160|0)+(c<<3)>>3];a=(c|0)!=(g|0);c=c+1|0;if(a){continue}break}}A[b+8>>3]=j?-f:f;break r}A[b>>3]=-f;f=A[i+168>>3];A[b+16>>3]=-p;A[b+8>>3]=-f}jb=i+560|0;return n&7}function xM(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;k=jb-16|0;jb=k;a:{b:{c:{if(!_c(c)|!d|v[b+480180>>2]!=16777216|x[b+480192>>1]<d>>>0){break c}d=v[((d<<2)+b|0)+900380>>2];if(!d){break c}e=v[d+44>>2];if(!e){break c}u[k+14>>1]=c-61;c=jb+-64|0;jb=c;d:{e:{d=u[e+28>>1];h=k+14|0;b=u[h>>1];if((d|0)<=(b|0)){if((b|0)<=(uc(v[e+4>>2],v[e+8>>2])+d<<16)-65536>>16){break e}}Lb(a);break d}f:{d=x[e+30>>1];if(!d){b=e+52|0;d=Xx(b,h);if(!Hg(d,wf(b))){break f}Ik(a,vd(d)+4|0);break d}b=On(b,d<<16>>16);u[c+62>>1]=b;d=Lb(a);g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{a=e+52|0;f=Xx(a,c+62|0);t:{if(Hg(f,wf(a))){v[23588]=0;R(135,d|0,vd(f)+4|0);a=v[23588];v[23588]=0;if((a|0)==1){break t}a=u[e+30>>1];b=u[h>>1];v[23588]=0;l=c,m=Wx(b,a)+5|0,v[l+32>>2]=m;R(132,c+48|0,c+32|0);a=v[23588];v[23588]=0;u:{if((a|0)!=1){v[23588]=0;Q(98,d|0,c+48|0)|0;a=v[23588];v[23588]=0;if((a|0)==1){break u}zb(c+48|0);break d}a=P()|0;O()|0;break g}a=P()|0;O()|0;zb(c+48|0);break g}if(u[e+30>>1]>26){break q}v[23588]=0;b=W(527,c+32|0,1,(b<<24)+1090519040>>24)|0;a=v[23588];v[23588]=0;if((a|0)==1){break s}v[23588]=0;U(11,c+48|0,0,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break r}a=c+48|0;f=Ib(d,a);zb(a);yb(b);v[23588]=0;Q(133,f|0,14600)|0;a=v[23588];v[23588]=0;if((a|0)!=1){break p}}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;yb(b);break g}v[23588]=0;a=b<<16>>16;v[c+28>>2]=(a|0)%16;R(840,c+32|0,c+28|0);f=v[23588];v[23588]=0;if((f|0)==1){break o}v[23588]=0;v[c+12>>2]=((a|0)/16<<16>>16)%16;R(840,c+16|0,c+12|0);a=v[23588];v[23588]=0;if((a|0)==1){break n}v[23588]=0;U(2,c+48|0,c+32|0,c+16|0);a=v[23588];v[23588]=0;if((a|0)==1){break m}a=c+48|0;f=Ib(d,a);zb(a);zb(c+16|0);zb(c+32|0);if(b<<16>>16<256){break p}v[23588]=0;U(8,c|0,0,f|0);a=v[23588];v[23588]=0;if((a|0)==1){break k}b=c+32|0;g=he(c);j=yh(c);i=he(c);a=jb-32|0;jb=a;v[a+16>>2]=j;v[a+24>>2]=g;v[a+8>>2]=i;while(1){if(yi(a+24|0,a+16|0)){g=a+24|0;j=Pp(t[v[g>>2]]);i=a+8|0;t[v[i>>2]]=j;Ge(g);Ge(i);continue}break}jb=a+32|0;$c(b,c);v[23588]=0;U(11,c+48|0,0,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break j}a=c+48|0;Ib(f,a);zb(a);yb(c+32|0);yb(c)}a=u[e+30>>1];b=u[h>>1];v[23588]=0;l=c,m=Wx(b,a)+5|0,v[l+16>>2]=m;R(132,c+48|0,c+16|0);a=v[23588];v[23588]=0;if((a|0)==1){break i}v[23588]=0;Q(98,d|0,c+48|0)|0;a=v[23588];v[23588]=0;if((a|0)==1){break h}zb(c+48|0);break d}a=P()|0;O()|0;break g}a=P()|0;O()|0;break l}a=P()|0;O()|0;zb(c+16|0)}zb(c+32|0);break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;yb(c+32|0);yb(c);break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;zb(c+48|0)}break a}d=jb-16|0;jb=d;f=jb-32|0;jb=f;e=of(f+16|0,1,0);v:{w:{x:{while(1){j=f+8|0;b=zc(e);i=Gb(e)+b|0;g=u[h>>1];if(!((b|0)==(i|0)|(g|0)>=0)){t[b|0]=45;g=0-(g&65535)&65535;b=b+1|0}Bx(j,b,i,g&65535);if(!v[f+12>>2]){break x}b=ch(Gb(e));v[23588]=0;R(59,e|0,b|0);b=v[23588];v[23588]=0;if((b|0)!=1){continue}break}break w}b=v[f+8>>2];h=zc(e);v[23588]=0;R(60,e|0,b-h|0);b=v[23588];v[23588]=0;y:{if((b|0)!=1){v[23588]=0;R(72,d|0,e|0);b=v[23588];v[23588]=0;if((b|0)!=1){break y}break w}break w}yb(e);jb=f+32|0;break v}a=P()|0;O()|0;yb(e);T(a|0);L()}v[23588]=0;R(71,a|0,d|0);a=v[23588];v[23588]=0;z:{if((a|0)!=1){zb(d);jb=d+16|0;break z}a=P()|0;O()|0;break a}}jb=c- -64|0;break b}e=v[b>>2];b=jb-32|0;jb=b;A:{if(Kp(c)){v[b+16>>2]=v[8028];d=v[8027];v[b+8>>2]=v[8026];v[b+12>>2]=d;d=v[8025];v[b>>2]=v[8024];v[b+4>>2]=d;xc(a,(b+(c<<2)|0)-1004|0);break A}if(_c(c)){d=Lb(b);v[23588]=0;c=c-1|0;f=(c|0)/12|0;c=Q(841,d|0,e+(B(f,-12)+c<<16>>16<<2)|0)|0;e=v[23588];v[23588]=0;B:{if((e|0)==1){break B}v[23588]=0;c=Q(842,c|0,f+48&255)|0;e=v[23588];v[23588]=0;if((e|0)==1){break B}v[23588]=0;Q(3,a|0,c|0)|0;a=v[23588];v[23588]=0;if((a|0)==1){break B}zb(c);break A}a=P()|0;O()|0;break a}if(!c){xc(a,16730);break A}xc(a,14571)}jb=b+32|0}jb=k+16|0;return}zb(d);T(a|0);L()}function m$(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;h=jb+-64|0;jb=h;v[h+56>>2]=b;v[e>>2]=0;fd(h,d);v[23588]=0;i=S(1136,h|0)|0;j=v[23588];v[23588]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((j|0)!=1){$b(h);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=P()|0;O()|0;$b(h);T(a|0);L()}jG(a,f+24|0,h+56|0,c,e,i);break b}iG(a,f+16|0,h+56|0,c,e,i);break b}g=a;i=b;a=nb[v[v[a+8>>2]+12>>2]](a+8|0)|0;b=zc(a);k=h,l=Yj(g,i,c,d,e,f,b,b+(Gb(a)<<2)|0),v[k+56>>2]=l;break b}a=Wi(h+56|0,c,e,i,2);b=v[e>>2];B:{if(!(b&4|a-1>>>0>30)){v[f+12>>2]=a;break B}v[e>>2]=b|4}break b}g=v[20767];v[h+24>>2]=v[20766];v[h+28>>2]=g;g=v[20765];v[h+16>>2]=v[20764];v[h+20>>2]=g;g=v[20763];v[h+8>>2]=v[20762];v[h+12>>2]=g;g=v[20761];v[h>>2]=v[20760];v[h+4>>2]=g;k=h,l=Yj(a,b,c,d,e,f,h,h+32|0),v[k+56>>2]=l;break b}g=v[20775];v[h+24>>2]=v[20774];v[h+28>>2]=g;g=v[20773];v[h+16>>2]=v[20772];v[h+20>>2]=g;g=v[20771];v[h+8>>2]=v[20770];v[h+12>>2]=g;g=v[20769];v[h>>2]=v[20768];v[h+4>>2]=g;k=h,l=Yj(a,b,c,d,e,f,h,h+32|0),v[k+56>>2]=l;break b}a=Wi(h+56|0,c,e,i,2);b=v[e>>2];C:{if(!(b&4|(a|0)>23)){v[f+8>>2]=a;break C}v[e>>2]=b|4}break b}a=Wi(h+56|0,c,e,i,2);b=v[e>>2];D:{if(!(b&4|a-1>>>0>11)){v[f+8>>2]=a;break D}v[e>>2]=b|4}break b}a=Wi(h+56|0,c,e,i,3);b=v[e>>2];E:{if(!(b&4|(a|0)>365)){v[f+28>>2]=a;break E}v[e>>2]=b|4}break b}a=Wi(h+56|0,c,e,i,2);b=v[e>>2];F:{if(!(b&4|(a|0)>12)){v[f+16>>2]=a-1;break F}v[e>>2]=b|4}break b}a=Wi(h+56|0,c,e,i,2);b=v[e>>2];G:{if(!(b&4|(a|0)>59)){v[f+4>>2]=a;break G}v[e>>2]=b|4}break b}a=h+56|0;b=jb-16|0;jb=b;v[b+8>>2]=c;while(1){H:{if(!cs(a,b+8|0)){break H}if(!Wk(i,1,Xk(v[a>>2]))){break H}Bn(a);continue}break}if(_j(a,b+8|0)){v[e>>2]=v[e>>2]|2}jb=b+16|0;break b}b=h+56|0;a=nb[v[v[a+8>>2]+8>>2]](a+8|0)|0;I:{if((Gb(a)|0)==(0-Gb(a+12|0)|0)){v[e>>2]=v[e>>2]|4;break I}c=Rr(b,c,a,a+24|0,i,e,0);b=v[f+8>>2];if(!((c|0)!=(a|0)|(b|0)!=12)){v[f+8>>2]=0;break I}if(!((c-a|0)!=12|(b|0)>11)){v[f+8>>2]=b+12}}break b}g=tc(h,83104,44);k=g,l=Yj(a,b,c,d,e,f,g,g+44|0),v[k+56>>2]=l;break b}v[h+16>>2]=v[20792];g=v[20791];v[h+8>>2]=v[20790];v[h+12>>2]=g;g=v[20789];v[h>>2]=v[20788];v[h+4>>2]=g;k=h,l=Yj(a,b,c,d,e,f,h,h+20|0),v[k+56>>2]=l;break b}a=Wi(h+56|0,c,e,i,2);b=v[e>>2];J:{if(!(b&4|(a|0)>60)){v[f>>2]=a;break J}v[e>>2]=b|4}break b}g=v[20803];v[h+24>>2]=v[20802];v[h+28>>2]=g;g=v[20801];v[h+16>>2]=v[20800];v[h+20>>2]=g;g=v[20799];v[h+8>>2]=v[20798];v[h+12>>2]=g;g=v[20797];v[h>>2]=v[20796];v[h+4>>2]=g;k=h,l=Yj(a,b,c,d,e,f,h,h+32|0),v[k+56>>2]=l;break b}a=Wi(h+56|0,c,e,i,1);b=v[e>>2];K:{if(!(b&4|(a|0)>6)){v[f+24>>2]=a;break K}v[e>>2]=b|4}break b}a=nb[v[v[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}g=a;i=b;a=nb[v[v[a+8>>2]+24>>2]](a+8|0)|0;b=zc(a);k=h,l=Yj(g,i,c,d,e,f,b,b+(Gb(a)<<2)|0),v[k+56>>2]=l;break b}hG(f+20|0,h+56|0,c,e,i);break b}a=Wi(h+56|0,c,e,i,4);if(!(w[e|0]&4)){v[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}v[e>>2]=v[e>>2]|4;break b}a=jb-16|0;jb=a;v[a+8>>2]=c;b=6;c=h+56|0;L:{M:{if(_j(c,a+8|0)){break M}b=4;if((un(i,Xk(v[c>>2]))|0)!=37){break M}b=2;if(!_j(Bn(c),a+8|0)){break L}}v[e>>2]=v[e>>2]|b}jb=a+16|0}a=v[h+56>>2]}jb=h- -64|0;return a|0}function N9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=C(0),n=0,o=0,p=0;d=jb-128|0;jb=d;g=-1;a:{b:{c:{d:{e:{f:{if(!Yg(v[v[b>>2]-12>>2]+b|0)){break f}e=d+112|0;me(e,b);f=v[e+8>>2];i=v[e+12>>2];e=d+104|0;Sj(e);b=Uk(b,e,8);if(Rb(e,16706,8)){a=Xg(d+88|0,f,i);c=v[a+12>>2];v[d+16>>2]=v[a+8>>2];v[d+20>>2]=c;c=v[a+4>>2];v[d+8>>2]=v[a>>2];v[d+12>>2]=c;Xj(b,d+8|0);break f}u[d+86>>1]=0;Vf(b,d+86|0);l=u[d+86>>1];if((l-4&65535)>>>0<65534){break f}e=d+78|0;Sj(e);b=Uk(b,e,8);if(Rb(e,14251,8)){break f}u[d+76>>1]=0;Vf(b,d+76|0);i=u[d+76>>1];if((i-5&65535)>>>0<65534){break f}g:{h:{i:{if(i>>>0<=3){e=Lb(d+112|0);v[23588]=0;f=W(483,b|0,e|0,65535)|0;k=v[23588];v[23588]=0;if((k|0)==1){break b}if(!f){break h}v[23588]=0;U(11,d- -64|0,c|0,e|0);f=v[23588];v[23588]=0;if((f|0)!=1){break i}break b}e=Lb(d+112|0);v[23588]=0;f=Q(485,b|0,e|0)|0;k=v[23588];v[23588]=0;if((k|0)==1){break c}if(!f){break g}v[23588]=0;U(11,d- -64|0,c|0,e|0);f=v[23588];v[23588]=0;if((f|0)==1){break c}}f=d- -64|0;Ib(a+40|0,f);zb(f);yb(e);u[d+62>>1]=0;Vf(b,d+62|0);u[d+60>>1]=0;Vf(b,d+60|0);u[a>>1]=x[d+60>>1];u[d+58>>1]=0;j:{if((i|0)<=3){v[d+112>>2]=0;ok(b,d+112|0);e=v[d+112>>2];if(e>>>0>65535){break f}f=Cl(e);u[d+58>>1]=f;break j}Vf(b,d+58|0);f=x[d+58>>1]}k=a+52|0;n=f&65535;i=(i|0)>3;f=0;k:{l:{m:{while(1){if((f&65535)>>>0>=n>>>0){break l}e=Lb(d+112|0);v[23588]=0;u[d+40>>1]=0;R(891,b|0,d+40|0);h=v[23588];v[23588]=0;if((h|0)==1){break e}n:{if(!i){v[23588]=0;h=W(483,b|0,e|0,65535)|0;j=v[23588];v[23588]=0;if((j|0)==1){break e}if(h){break n}yb(e);break f}v[23588]=0;h=Q(485,b|0,e|0)|0;j=v[23588];v[23588]=0;if((j|0)==1){break e}if(!h){break k}}v[23588]=0;U(11,d- -64|0,c|0,e|0);h=v[23588];v[23588]=0;if((h|0)!=1){v[23588]=0;h=Q(888,k|0,d+40|0)|0;j=v[23588];v[23588]=0;if((j|0)==1){break m}j=h;h=d- -64|0;Ib(j,h);zb(h);yb(e);f=f+1|0;continue}break}g=P()|0;O()|0;break d}g=P()|0;O()|0;zb(d- -64|0);break d}c=d- -64|0;Sj(c);b=Uk(b,c,8);if(Rb(c,14195,8)){break f}c=x[a>>1];if(c>>>0>3|(c|0)==2){break f}c=a+4|0;o:{if((l|0)<=2){if(DL(b,c)){break o}break f}if(!CL(b,c)){break f}}o=d,p=Eb(v[a+4>>2]),v[o+112>>2]=p;c=Eb(v[a+8>>2]);while(1){e=v[d+112>>2];if(Ob(e,c)){if(!pm(z[e>>2])){break f}Ke(d+112|0);continue}break}c=a+16|0;p:{if((l|0)<=2){if(DL(b,c)){break p}break f}if(!CL(b,c)){break f}}o=d,p=Eb(v[a+16>>2]),v[o+112>>2]=p;c=Eb(v[a+20>>2]);while(1){e=v[d+112>>2];if(Ob(e,c)){if(!pm(z[e>>2])){break f}Ke(d+112|0);continue}break}o=a,p=uc(v[a+16>>2],v[a+20>>2]),v[o+36>>2]=p;u[d+56>>1]=0;Vf(b,d+56|0);c=x[d+56>>1];u[a+28>>1]=c;if((c-201&65535)>>>0<65135){break f}u[d+54>>1]=0;Vf(b,d+54|0);c=u[d+54>>1];u[a+30>>1]=c;if((c|0)<0){break f}v[d+48>>2]=0;Dp(b,d+48|0);m=GL(z[d+48>>2]);z[a+32>>2]=m;if(!pm(m)){break f}c=d+40|0;Sj(c);Uk(b,c,8);if(Rb(c,16697,8)){break f}b=uc(v[a+4>>2],v[a+8>>2]);if(b>>>0>32767){break f}c=u[a+30>>1];e=x[a>>1];if(!(e?!(z[a+32>>2]<=C(0))&(c|0)>0:1)){break f}q:{switch(e-1|0){case 0:case 2:if(b>>>0<c>>>0){break f}break;default:break q}}b=0;c=v[a+36>>2];if(c){b=c-1|0;v[a+36>>2]=b}o=d,p=Ei(b),v[o+112>>2]=p;v[d+32>>2]=0;o=a,p=v[Ij(d+112|0,d+32|0,43824)>>2],v[o+36>>2]=p;Ep(a);g=1;if(x[a>>1]!=3){break f}c=u[a+30>>1];if((c-u[a+28>>1]|0)>(OL(uc(v[a+4>>2],v[a+8>>2]))|0)){break f}g=a+32|0;e=Sb(d+112|0);b=0;while(1){r:{if(c<<16>>16<=(b|0)){b=x[a+28>>1];u[d+32>>1]=b;o=d,p=(uc(v[a+4>>2],v[a+8>>2])+b|0)-1|0,u[o+34>>1]=p;v[23588]=0;u[d+30>>1]=0;ja(886,a|0,e|0,g|0,d+32|0,d+30|0)|0;a=v[23588];v[23588]=0;g=1;if((a|0)==1){break r}vc(e);break f}c=u[a+28>>1];f=v[a+4>>2];v[23588]=0;R(892,e|0,Db(f,b-c|0)|0);c=v[23588];v[23588]=0;if((c|0)!=1){b=b+1|0;c=x[a+30>>1];continue}}break}g=P()|0;O()|0;vc(e);break a}yb(e);break f}yb(e);break f}yb(e)}jb=d+128|0;return g|0}g=P()|0;O()|0}yb(e);break a}g=P()|0;O()|0;yb(e);break a}g=P()|0;O()|0;yb(e)}T(g|0);L()}function yfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0;e=jb-752|0;jb=e;yc(b);d=jb-16|0;jb=d;h=e+144|0;gR(d+8|0,h);f=v[d+12>>2];mc(d,v[b>>2],v[b+8>>2],v[d+8>>2],v[d+12>>2]);g=v[d+4>>2];if((g|0)==(f|0)){Zb(b,v[d+12>>2])}jb=d+16|0;d=(f|0)==(g|0);if(!d){fR(h)}a:{if(!d){break a}if(!iR(e+144|0)){break a}if(!Pb(v[b>>2],v[b+8>>2],Dc(hR(x[e+178>>1]),mb))){break a}if(!c){n=1;break a}Ad(a,262144);f=e+104|0;Hi(f,2,e+144|0);d=e+24|0;Ec(d,f);Ac(a+1298308|0,d);yb(d);h=xc(d,8277);Ib(a+1298344|0,h);zb(h);d=xc(d,10075);Ib(a+1298356|0,d);zb(d);d=jb-16|0;jb=d;i=f;f=xc(d,4196);$c(i,f);zb(f);jb=d+16|0;t[e+8|0]=w[e+174|0];v[23588]=0;t[e+127|0]=w[e+173|0];R(663,e+128|0,e+127|0);d=v[23588];v[23588]=0;b:{c:{d:{if((d|0)!=1){v[23588]=0;X(250,e+24|0,e+104|0,e+8|0,e+128|0);d=v[23588];v[23588]=0;if((d|0)!=1){d=e+24|0;Ib(a+1298368|0,d);zb(d);zb(e+128|0);f=e+104|0;ac(f);v[a+480208>>2]=12;v[a+1298404>>2]=5;h=a+480188|0;u[h>>1]=x[e+182>>1];u[e+24>>1]=x[e+178>>1];u[e+104>>1]=3999;A=a,C=x[Vc(d,f)>>1],u[A+480190>>1]=C;qU(Vb(v[a+484360>>2],w[a+484376|0]),e+240|0,x[e+176>>1]);d=0;while(1)if(x[h>>1]<=d>>>0){d=e+24|0;$d(d,b,B(x[e+178>>1],80));h=c&2;l=jc(e+104|0,d);Ab(d);g=e+72|0;d=0;e:{f:{while(1){if(x[a+480190>>1]<=d>>>0){n=1;if(c&1){break f}break b}v[23588]=0;R(664,l|0,e+24|0);f=v[23588];v[23588]=0;if((f|0)==1){break e}f=e+8|0;Hi(f,2,g);v[23588]=0;R(222,e+128|0,f|0);f=v[23588];v[23588]=0;if((f|0)==1){break e}d=d+1|0;f=e+128|0;Cc(((d<<5)+a|0)+946304|0,f);yb(f);v[23588]=0;i=f;f=(B(d,104)+a|0)+484380|0;U(665,i|0,e+24|0,f|0);j=v[23588];v[23588]=0;g:{if((j|0)==1){break g}if(!h|!v[f>>2]){continue}v[23588]=0;j=Q(155,b|0,x[e+42>>1]|x[e+44>>1]<<16)|0;i=v[23588];v[23588]=0;if((i|0)==1){break g}if(!j){continue}v[23588]=0;W(219,e+128|0,f|0,b|0)|0;f=v[23588];v[23588]=0;if((f|0)!=1){continue}}break}break e}v[23588]=0;m=a+484344|0;R(225,m|0,x[e+180>>1]);c=v[23588];v[23588]=0;if((c|0)==1){break e}c=e+24|0;r=c|4;s=c|2;o=c|3;y=c|5;z=c|1;p=a+480188|0;a=0;while(1){if(x[e+180>>1]<=a>>>0){break b}v[23588]=0;c=W(226,m|0,a&65535,64)|0;d=v[23588];v[23588]=0;if((d|0)==1){break e}h:{if(!c){break h}c=(a<<1)+e|0;c=w[c+496|0]|w[c+497|0]<<8;if(!c){break h}v[23588]=0;c=Q(155,b|0,c<<4)|0;d=v[23588];v[23588]=0;if((d|0)==1){break e}if(!c){break h}j=0;c=Yb(v[m>>2],a);c=id(v[c>>2],v[v[c+48>>2]+12>>2],0,0);while(1){if(j>>>0>63){break h}d=v[b+8>>2];f=v[b>>2];v[23588]=0;d=W(156,f|0,d|0,1)|0;f=v[23588];v[23588]=0;i:{if((f|0)!=1){if(!d){break h}v[23588]=0;h=S(206,b|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break e}if(h){break i}j=j+1|0;c=B(x[p>>1],6)+c|0;continue}break e}u[e+28>>1]=0;v[e+24>>2]=0;f=h&31;d=B(f,6)+c|0;i=tg(e+24|0);f=f>>>0<x[p>>1];i=f?d:i;j:{if(!(h&32)){break j}v[23588]=0;R(260,e+128|0,b|0);g=v[23588];v[23588]=0;if((g|0)==1){break e}g=w[e+128|0];t[i|0]=g;A=f?d+1|0:z,C=w[Nc(e+128|0)|0],t[A|0]=C;k:{if(g){if((g|0)==254){break k}if(g>>>0<121){break j}}g=0}t[i|0]=g}l:{if(!(h&64)){break l}v[23588]=0;R(260,e+128|0,b|0);g=v[23588];v[23588]=0;if((g|0)==1){break e}g=f?d+5|0:y;q=Nc(e+128|0);t[g|0]=w[q|0];k=w[e+128|0];m:{if(k>>>0<=15){Of(i,k,w[q|0]);break m}t[(f?d+3|0:o)|0]=k>>>0<=23?w[k+26999|0]:0}i=f?d+3|0:o;k=w[i|0];if((k|0)!=23){if((k|0)!=9){break l}t[i|0]=20;t[e+8|0]=w[g|0]>>>3;t[e+127|0]=1;A=g,C=w[jf(e+8|0,e+127|0)|0]-1&15|128,t[A|0]=C;break l}t[e+8|0]=64;A=g,C=w[Wb(g,e+8|0)|0]<<1,t[A|0]=C}if(!(h&128)){continue}t[(f?d+2|0:s)|0]=1;v[23588]=0;h=S(206,b|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break e}t[(f?d+4|0:r)|0]=h;continue}}a=a+1|0;continue}}d=P()|0;O()|0;Ab(l);break c}else{f=(d<<5)+a|0;df(f+480280|0);u[f+480284>>1]=(w[(d+e|0)+208|0]<<4|4)&244;d=d+1|0;continue}}d=P()|0;O()|0;zb(e+128|0);break d}d=P()|0;O()|0}ac(e+104|0)}T(d|0);L()}Ab(l)}jb=e+752|0;return n|0}function bja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0;g=jb-48|0;jb=g;a:{b:{if(!c){break b}f=Gh(a,b);a=Eb(v[d>>2]);v[g+40>>2]=a;d=Eb(v[d+4>>2]);while(1){if(!Ob(a,d)){break b}yc(a);c:{if((Gj(a)|0)==(c|0)){Zb(a,20);d=Gj(a);k=Xf(g+24|0);c=zl(g+16|0,0,b?32:64);v[23588]=0;R(393,f|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break c}o=(b|0)==2?4096:(b|0)==1?2048:16384;c=24;d=d+24|0;p=1;l=1;d:{while(1){h=o;while(1){e=v[a+8>>2];i=v[a>>2];v[23588]=0;e=W(156,i|0,e|0,1)|0;i=v[23588];v[23588]=0;e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((i|0)!=1){if(!e){break d}e=v[f+4>>2];i=v[f>>2];m=v[a+8>>2];v[23588]=0;v[g+16>>2]=m;m=Q(394,k|0,g+16|0)|0;q=v[23588];v[23588]=0;if((q|0)==1){break a}y=m,z=_d(i,e),v[y>>2]=z;v[23588]=0;e=S(206,a|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break a}q:{switch(e-128|0){case 3:case 4:case 7:case 8:break e;case 5:case 6:case 9:case 10:break h;case 2:break i;case 1:break j;case 0:break k;default:break q}}r:{switch(e|0){case 0:break g;case 5:break l;case 4:break m;case 3:break n;case 2:break o;case 1:break p;default:break r}}s:{switch(e-160|0){case 3:case 4:break e;case 5:case 6:break h;case 2:break i;case 1:break j;case 0:break k;default:break s}}switch(e-192|0){case 2:break i;case 1:break j;case 0:break k;default:break e}}break a}if(w[f+12|0]&4){break e}v[23588]=0;e=S(271,a|0)|0;i=v[23588];v[23588]=0;t:{if((i|0)==1){break t}v[23588]=0;v[g+16>>2]=e;e=Q(394,k|0,g+16|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break t}t[f+15|0]=v[e>>2];y=f,z=_d(v[f>>2],v[f+4>>2])-1|0,t[y+16|0]=z;t[f+12|0]=w[f+12|0]|4;break e}break a}v[23588]=0;e=S(271,a|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break a}u[g+16>>1]=e;u[g+14>>1]=1;e=x[ke(g+16|0,g+14|0)>>1];h=B(e,B(r<<16>>16,l))+h|0;u:{if(e>>>0<2){break u}y=g,z=Cl((e+x[Aj(v[f+4>>2])>>1]|0)-1|0),u[y+16>>1]=z;e=pu(b,h);v[23588]=0;t[g+14|0]=e;U(395,f|0,g+16|0,g+14|0);e=v[23588];v[23588]=0;if((e|0)!=1){break u}break a}y=g,z=Cl(x[Aj(v[f+4>>2])>>1]+1|0),u[y+16>>1]=z;e=pu(b,h);v[23588]=0;t[g+14|0]=e;U(395,f|0,g+16|0,g+14|0);e=v[23588];v[23588]=0;if((e|0)!=1){break e}break a}v[23588]=0;j=S(206,a|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break a}s=v[a+8>>2];break e}v[23588]=0;e=S(271,a|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break a}e=c+e|0;v[g+16>>2]=e;if(!(!(j&255)|e>>>0<s>>>0)){j=j-1|0;if(!(j&255)){break f}v[23588]=0;Q(155,a|0,e|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){break e}break a}if(!(j&255)){break f}v[23588]=0;e=Q(396,k|0,g+16|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break a}t[f+13|0]=v[e>>2];y=f,z=_d(v[f>>2],v[f+4>>2])-1|0,t[y+14|0]=z;t[f+12|0]=w[f+12|0]|2;break e}p=0;n=1;break e}v[23588]=0;h=S(271,a|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break a}e=pu(b,h);y=Aj(v[f+4>>2]),z=e,t[y+2|0]=z;break e}v[23588]=0;r=S(397,a|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){break e}break a}v[23588]=0;e=S(206,a|0)|0;l=v[23588];v[23588]=0;if((l|0)!=1){t[g+16|0]=e;t[g+14|0]=1;l=w[jf(g+16|0,g+14|0)|0];break e}break a}v[23588]=0;Q(188,a|0,1)|0;e=v[23588];v[23588]=0;if((e|0)==1){break a}break e}n=1;if(c>>>0<d>>>0){break e}break d}j=0}if(!n|c>>>0>=d>>>0){continue}break}v[23588]=0;c=Q(155,a|0,d|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break a}if(!c){break d}c=v[a+8>>2];h=v[a>>2];v[23588]=0;c=W(156,h|0,c|0,2)|0;h=v[23588];v[23588]=0;if((h|0)==1){break a}if(!c){break d}h=w[f+12|0];v:{if(!(!(h&4)&p)){c=v[f+4>>2];break v}c=v[f+4>>2];e=v[f>>2];t[f+12|0]=h|4;h=_d(e,c)-1|0;t[f+15|0]=h;t[f+16|0]=h}y=g,z=Cl(x[Aj(c)>>1]+1|0),u[y+16>>1]=z;c=pu(b,o);v[23588]=0;t[g+14|0]=c;U(395,f|0,g+16|0,g+14|0);c=v[23588];v[23588]=0;if((c|0)!=1){n=1;t[f+17|0]=w[f+16|0]+1;c=d;continue}break}break a}t[f+12|0]=w[f+12|0]|1;PT(k);break b}a=v[Mf(g+40|0)>>2];continue}break}break a}jb=g+48|0;return}a=P()|0;O()|0;PT(k);T(a|0);L()}function KV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=jb-3056|0;jb=e;yc(b);f=jb-16|0;jb=f;h=e+1096|0;SB(f+8|0,h);i=v[f+12>>2];j=b;mc(f,v[b>>2],v[b+8>>2],v[f+8>>2],v[f+12>>2]);b=v[f+4>>2];if((b|0)==(i|0)){Zb(j,v[f+12>>2])}jb=f+16|0;b=(b|0)==(i|0);if(!b){RB(h)}a:{if(!b){break a}if(!TB(e+1096|0)){break a}b:{if(!c){break b}if(!Pb(v[j>>2],v[j+8>>2],Dc(1024,0))){break a}QB(j,e+576|0);QB(j,e- -64|0);while(1){if((g|0)!=128){b=g<<2;f=v[b+(e+576|0)>>2];if(f>>>0>16777215){break a}b=v[b+(e- -64|0)>>2];if(b-4097>>>0<4294963202){break a}g=g+1|0;if(sr(v[j>>2],(b+f|0)+2978|0)){continue}break a}break}Ad(a,2);$f(a);b=e+40|0;d=xc(b,13794);Ib(a+1298344|0,d);zb(d);d=xc(b,14723);Ib(a+1298356|0,d);zb(d);b=xc(b,15464);Ib(a+1298368|0,b);zb(b);v[a+1298404>>2]=5;b=w[e+1096|0];v[a+480204>>2]=143e4;v[a+480196>>2]=b;Ue(Vb(v[a+484360>>2],w[a+484376|0]),w[e+1097|0]);v[a+480188>>2]=4194317;Nb(a+1074312|0,95,1);v[a+480208>>2]=v[a+480208>>2]|16777216;d=0;g=0;while(1){if((g|0)==4){c:{while(1){d:{if((d|0)==32){g=0;break d}b=d+1|0;g=B(b,104)+a|0;i=g+484380|0;md(i,2);h=e+16|0;Zh(h,1,(B(d,13)+e|0)+1098|0);f=e+40|0;Ec(f,h);Cc(((b<<5)+a|0)+946304|0,f);yb(f);d=(e+1096|0)+(d<<4)|0;f=w[d+422|0]|w[d+423|0]<<8|(w[d+424|0]<<16|w[d+425|0]<<24);v[i>>2]=f;h=f;f=w[d+430|0]|w[d+431|0]<<8|(w[d+432|0]<<16|w[d+433|0]<<24);if(h>>>0>=f>>>0){d=w[d+426|0]|w[d+427|0]<<8|(w[d+428|0]<<16|w[d+429|0]<<24);u[g+484414>>1]=2;v[g+484388>>2]=f;v[g+484384>>2]=d}v[g+484404>>2]=8287;d=b;continue}break}while(1){if((g|0)!=32){d=g+33|0;f=(B(d,104)+a|0)+484380|0;md(f,2);i=e+16|0;Zh(i,1,(B(g,13)+e|0)+2026|0);b=e+40|0;Ec(b,i);Cc(((d<<5)+a|0)+946304|0,b);yb(b);v[e+48>>2]=0;v[e+40>>2]=0;v[e+44>>2]=0;d=(e+1096|0)+B(g,11)|0;o=Kb(b,0),p=w[d+1347|0],t[o|0]=p;o=Kb(b,1),p=w[d+1352|0],t[o|0]=p;o=Kb(b,2),p=w[d+1348|0],t[o|0]=p;o=Kb(b,3),p=w[d+1353|0],t[o|0]=p;o=Kb(b,4),p=w[d+1349|0],t[o|0]=p;o=Kb(b,5),p=w[d+1354|0],t[o|0]=p;o=Kb(b,6),p=w[d+1350|0],t[o|0]=p;o=Kb(b,7),p=w[d+1355|0],t[o|0]=p;o=Kb(b,8),p=w[d+1351|0],t[o|0]=p;o=Kb(b,9),p=w[d+1356|0],t[o|0]=p;o=Kb(b,10),p=w[d+1346|0],t[o|0]=p;v[e+8>>2]=v[e+48>>2];b=v[e+44>>2];v[e>>2]=v[e+40>>2];v[e+4>>2]=b;Fl(f,1,e);g=g+1|0;continue}break}Vq(Vb(v[a+484360>>2],w[a+484376|0]),e+2794|0,256,255,65535);l=a+484344|0;wg(l,128);m=c&1;f=0;while(1){e:{f:{if((f|0)!=128){b=f<<2;cd(j,v[b+(e+576|0)>>2]+2978|0);d=e+16|0;$d(d,j,v[b+(e- -64|0)>>2]);b=jc(e+40|0,d);Ab(d);if(!m){break e}v[23588]=0;d=W(226,l|0,f&65535,64)|0;g=v[23588];v[23588]=0;if((g|0)==1){break c}if(!d){break e}g=0;i=Yb(v[l>>2],f);while(1){if(g>>>0>63){break e}g:{while(1){h:{d=v[b>>2];v[23588]=0;d=W(156,d|0,v[e+48>>2],1)|0;h=v[23588];v[23588]=0;if((h|0)==1){break h}if(!d){break e}v[23588]=0;d=S(206,b|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break c}if(d>>>0>12){break g}h=id(v[i>>2],v[v[i+48>>2]+12>>2],g,d);v[23588]=0;R(260,e+16|0,b|0);k=v[23588];v[23588]=0;if((k|0)==1){break c}k=w[e+16|0];d=d>>>0>3;t[h|0]=((k&15)+(d?13:37)|0)+B(k>>>4&7,12);k=Nc(e+16|0);t[h+1|0]=((w[k|0]>>>4|0)+(d?33:1)|0)+(w[e+16|0]>>>3&16);PB(h,w[k|0],d);continue}break}break c}h=d-32|0;if((h&255)>>>0<=12){h=id(v[i>>2],v[v[i+48>>2]+12>>2],g,h&65535);v[23588]=0;k=S(206,b|0)|0;n=v[23588];v[23588]=0;if((n|0)==1){break c}PB(h,k,d>>>0>35);continue}if((d|0)!=64){if((d|0)!=96){break f}if(!g){break e}o=id(v[i>>2],v[v[i+48>>2]+12>>2],g-1|0,0),p=14,t[o+3|0]=p;break e}v[23588]=0;d=S(206,b|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break c}g=d+g|0;continue}}d=1;if(!(c&2)){break a}while(1){if((d|0)==33){break b}vg(Zc(e+40|0,8,1,0,1),(B(d,104)+a|0)+484380|0,j);d=d+1|0;continue}}Ab(b);d=0;break a}Ab(b);f=f+1|0;continue}}}else{u[((g<<5)+a|0)+480284>>1]=g&1?192:64;g=g+1|0;continue}break}a=P()|0;O()|0;Ab(b);T(a|0);L()}d=1}jb=e+3056|0;return d|0}function xga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=jb-208|0;jb=d;yc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if(!uo(b,d+192|0)){break l}if(!TR(d+192|0)){break l}g=Ih(d+168|0);h=Lb(d+152|0);Bu(d+88|0);v[23588]=0;f=Q(595,b|0,d+80|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break h}m:{if(!f){break m}m=d,n=bc(bc(v[d+84>>2])-4|0),v[m+84>>2]=n;while(1){f=bc(bc(v[d+84>>2])-8|0);v[d+84>>2]=f;n:{if(c){break n}if((bc(v[d+80>>2])|0)!=1347699796){break n}j=1;break m}v[23588]=0;U(190,d+56|0,b|0,bc(f)|0);f=v[23588];v[23588]=0;if((f|0)==1){break d}e=d+56|0;f=jc(d,e);Ab(e);e=v[f>>2];v[23588]=0;i=S(178,e|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break b}o:{if(!i){break o}p:{e=bc(v[d+80>>2]);if((e|0)!=1129139796){if((e|0)!=1229866575){if((e|0)==1347699796){break p}if((e|0)!=1447383635){break o}v[23588]=0;Q(188,f|0,4)|0;e=v[23588];v[23588]=0;if((e|0)==1){break b}v[23588]=0;e=S(596,f|0)|0;k=v[23588];v[23588]=0;if((k|0)==1){break b}if(!e){break o}e=bc(v[d+84>>2]);if(e>>>0<7){break o}v[23588]=0;U(597,f|0,h|0,e-6|0);e=v[23588];v[23588]=0;if((e|0)==1){break b}break o}v[23588]=0;l=Q(598,f|0,d+88|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){break o}break b}uv(g,f);break o}v[23588]=0;j=W(599,a|0,f|0,c|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break b}}Ab(f);if(i){v[23588]=0;f=Q(595,b|0,d+80|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break i}if(f){continue}}break}if(rh(v[h+4>>2],w[h+11|0])){v[23588]=0;b=Q(1,d+56|0,14842)|0;c=v[23588];v[23588]=0;if((c|0)==1){break g}Ib(h,b);zb(b)}q:{if(!(j&l&1)){break q}b=x[d+130>>1];v[23588]=0;b=Hb(b)&256;W(264,a+1074312|0,5,!b|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break f}c=Hb(x[d+126>>1]);if(c){u[d>>1]=64;u[d+40>>1]=c;m=a,n=x[Vc(d,d+40|0)>>1],v[m+480228>>2]=n}c=!b;b=Hb(x[d+128>>1]);if(!(c|!b)){v[a+480204>>2]=B(b,1e4)}if(w[d+88|0]){b=d+40|0;Me(b,2,d+88|0);v[23588]=0;R(222,d|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break e}Ac(a+1298308|0,d);yb(d)}c=x[d+134>>1];if(!iq(c,1,12)){break q}f=x[d+132>>1];if(!iq(f,1,31)){break q}e=x[d+138>>1];if(!iq(e,0,23)){break q}i=x[d+140>>1];if(!iq(i,0,59)){break q}k=x[d+142>>1];if(!iq(k,0,59)){break q}b=xo(d);m=b,n=Hb(x[d+136>>1])+1900|0,v[m>>2]=n;m=b,n=Hb(c),v[m+4>>2]=n;m=b,n=Hb(f),v[m+8>>2]=n;m=b,n=Hb(e),v[m+12>>2]=n;m=b,n=Hb(i),v[m+16>>2]=n;m=b,n=Hb(k),v[m+24>>2]=n;v[b+28>>2]=0;v[23588]=0;R(434,a+1298408|0,b|0);b=v[23588];v[23588]=0;if((b|0)!=1){break q}a=P()|0;O()|0;break a}if(j&1){b=v[g>>2];v[23588]=0;b=S(178,b|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break h}if(b){b=Lb(d);v[23588]=0;U(268,g|0,b|0,32);c=v[23588];v[23588]=0;if((c|0)==1){break c}if(xq(b,13687)){v[23588]=0;U(11,d+40|0,14,b|0);c=v[23588];v[23588]=0;if((c|0)==1){break c}c=d+40|0;Ib(a+1298320|0,c);zb(c)}c=v[g+8>>2];f=v[g>>2];v[23588]=0;c=Q(600,f|0,c|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break c}if(!c){v[23588]=0;c=S(202,g|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break c}v[23588]=0;ea(313,a+1298332|0,g|0,c|0,40,0);c=v[23588];v[23588]=0;if((c|0)==1){break c}}yb(b)}v[23588]=0;b=Q(1,d+40|0,17493)|0;c=v[23588];v[23588]=0;if((c|0)==1){break k}v[23588]=0;U(477,d|0,b|0,h|0);c=v[23588];v[23588]=0;if((c|0)==1){break j}Ib(a+1298368|0,d);zb(d);zb(b)}v[a+480208>>2]=v[a+480208>>2]|2097152;v[23588]=0;a=W(264,a+1074312|0,84,1)|0;b=v[23588];v[23588]=0;if((b|0)==1){break h}v[23588]=0;a=W(264,a|0,83,1)|0;b=v[23588];v[23588]=0;if((b|0)==1){break h}v[23588]=0;Q(265,a|0,85)|0;a=v[23588];v[23588]=0;if((a|0)==1){break h}}zb(h);Ab(g)}jb=d+208|0;return j&1}a=P()|0;O()|0;break a}a=P()|0;O()|0;zb(b);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(b);break a}a=P()|0;O()|0;Ab(f)}zb(h);Ab(g);T(a|0);L()}function fga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;e=jb-256|0;jb=e;yc(b);a:{if(!dV(b,e+184|0)){break a}if(!JR(e+184|0)){break a}if(!Pb(v[b>>2],v[b+8>>2],Dc(IR(e+184|0),mb))){break a}b:{if(!c){break b}Ad(a,16);f=e+24|0;Cj(f,2,e+184|4);d=e+48|0;Ec(d,f);Ac(a+1298308|0,d);yb(d);l=a+480190|0;u[l>>1]=w[e+214|0];u[a+480188>>1]=w[e+217|0];g=xc(d,8325);Ib(a+1298344|0,g);zb(g);g=xc(d,10079);Ib(a+1298356|0,g);zb(g);Rf(f,4214);g=w[e+187|0];v[e>>2]=g>>>4;v[23588]=0;v[e+180>>2]=g&15;X(302,d|0,f|0,e|0,e+180|0);d=v[23588];v[23588]=0;c:{d:{e:{if((d|0)!=1){d=e+48|0;Ib(a+1298368|0,d);zb(d);ac(e+24|0);v[a+1298404>>2]=5;g=1;while(1){j=g&65535;if(j>>>0>x[l>>1]){g=0;d=a+480188|0;while(1)if(x[d>>1]<=g>>>0){f=e+48|0;d=jb-16|0;jb=d;h=b;f:{if(!Pb(v[b>>2],v[b+8>>2],128)){b=0;while(1){if((b|0)!=128){Ch(b+f|0);b=b+1|0;continue}break}break f}$S(d+8|0,f);td(d,h,v[d+8>>2],v[d+12>>2])}jb=d+16|0;gv(Vb(v[a+484360>>2],w[a+484376|0]),f,w[e+211|0]+1|0);b=w[e+216|0];$d(e,h,B(x[e+208>>1],192));i=jc(e+24|0,e);Ab(e);n=c&1;if(n){v[23588]=0;R(225,a+484344|0,w[e+210|0]+1|0);d=v[23588];v[23588]=0;if((d|0)==1){break d}}o=b?b:64;p=a+484344|0;q=a+480188|0;while(1){if(w[e+210|0]<m>>>0){b=x[e+212>>1];if(b){v[23588]=0;ea(313,a+1298332|0,h|0,b|0,39,1);b=v[23588];v[23588]=0;if((b|0)==1){break d}}if(!(c&2)){break e}g=1;b=a+480190|0;while(1){c=g&65535;if(c>>>0>x[b>>1]){break e}c=B(c,104)+a|0;d=Zc(e,u[c+484414>>1]&1?16:8,1,0,1);v[23588]=0;W(219,d|0,c+484380|0,h|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){g=g+1|0;continue}break}break d}g:{h:{if(n){v[23588]=0;b=W(226,p|0,m&65535,o|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break d}k=0;if(b){break h}}v[23588]=0;Q(188,h|0,64)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break g}break d}while(1){d=k&65535;if(d>>>0>31){break g}v[23588]=0;b=S(194,h|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break d}i:{if(!b|b>>>0>x[e+208>>1]|d>>>0>=x[q>>1]){break i}v[23588]=0;Q(155,i|0,B(b,192)-192|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break d}l=0;b=Yb(v[p>>2],m);g=id(v[b>>2],v[v[b+48>>2]+12>>2],0,d);while(1){if((l|0)==(o|0)){break i}v[23588]=0;R(534,e|0,i|0);b=v[23588];v[23588]=0;if((b|0)!=1){j=Nc(e);d=Se(e);b=w[e|0];if(b>>>0>=4){t[g|0]=(b>>>2|0)+37;b=w[e|0]}t[g+1|0]=b<<4&48|w[j|0]>>>4;b=w[d|0];d=0;f=0;j:{k:{l:{m:{n:{o:{j=w[j|0]&15;switch(j-8|0){case 0:break l;case 6:break n;case 2:break o;default:break m}}b=(b&240?-16:15)&b;j=10;break k}j=14;r=(b+16&240)>>>4|0;if(r>>>0>8){break k}if(1<<r&435){break l}break k}d=j;f=b}j=d;b=f;if(!((d|b)&255)){break j}}Of(g,j,b&255)}l=l+1|0;g=B(x[q>>1],6)+g|0;continue}break}break d}k=k+1|0;continue}}m=m+1|0;continue}}else{f=(g<<5)+a|0;df(f+480280|0);u[f+480284>>1]=(w[(e+g|0)+218|0]<<4|8)&248;g=g+1|0;continue}}else{f=e+48|0;FC(b,f);h=jb-16|0;jb=h;d=(B(j,104)+a|0)+484380|0;md(d,0);u[h+14>>1]=w[f+35|0]<<2;u[h+12>>1]=256;s=d,y=x[Vc(h+14|0,h+12|0)>>1],u[s+30>>1]=y;i=w[f+22|0]|w[f+23|0]<<8|(w[f+24|0]<<16|w[f+25|0]<<24);p:{if(i>>>0<3){break p}v[d>>2]=i;v[d+4>>2]=w[f+26|0]|w[f+27|0]<<8|(w[f+28|0]<<16|w[f+29|0]<<24);v[h+8>>2]=w[f+30|0]|w[f+31|0]<<8|(w[f+32|0]<<16|w[f+33|0]<<24);v[h+4>>2]=1;s=d,y=v[Yc(h+8|0,h+4|0)>>2]-1|0,v[s+8>>2]=y;wc(d+8|0,i);k=v[d+8>>2];i=v[d+4>>2];q:{if(k>>>0<=i+4>>>0){v[d+4>>2]=0;v[d+8>>2]=0;k=0;i=0;break q}u[d+34>>1]=x[d+34>>1]|2;k=k>>>1|0;i=i>>>1|0}t[d+37|0]=w[f+34|0];s=d,y=Xu(0,t[f+34|0]<<4),v[s+24>>2]=y;if(!(t[f+36|0]&1)){break p}v[d+8>>2]=k;v[d+4>>2]=i;u[d+34>>1]=x[d+34>>1]|1;v[d>>2]=v[d>>2]>>>1}jb=h+16|0;Hl(e,2,f);d=e+24|0;Ec(d,e);Cc(((j<<5)+a|0)+946304|0,d);g=g+1|0;yb(d);continue}}}g=P()|0;O()|0;ac(e+24|0);break c}v[a+480260>>2]=64;v[a+480264>>2]=32767;Ab(i);break b}g=P()|0;O()|0;Ab(i)}T(g|0);L()}g=1}jb=e+256|0;return g|0}function ak(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;k=1;o(+b);f=j(1)|0;d=j(0)|0;a:{b:{m=f&2147483647;g=d;c:{if(!(m|d)){break c}o(+a);d=j(1)|0;t=j(0)|0;if(!t&(d|0)==1072693248){break c}q=d&2147483647;if(!(!(q>>>0>2146435072|(q|0)==2146435072&(t|0)!=0|m>>>0>2146435072)&(!g|(m|0)!=2146435072))){return a+b}d:{e:{f:{r=0;g:{if((d|0)>0|(d|0)>=0){break g}r=2;if(m>>>0>1128267775){break g}r=0;if(m>>>0<1072693248){break g}h=m>>>20|0;if(m>>>0<1094713344){break f}e=1075-h|0;h=g>>>e|0;r=0;if((g|0)!=h<<e){break g}r=2-(h&1)|0}e=r;if(!g){break e}break d}if(g){break d}g=1043-h|0;h=m>>>g|0;e=0;if((m|0)!=h<<g){break e}e=2-(h&1)|0}if((m|0)==2146435072){if(!(q-1072693248|t)){break c}if(q>>>0>=1072693248){return(f|0)>0|(f|0)>=0?b:0}return(f|0)>0|(f|0)>=0?0:-b}if((m|0)==1072693248){if((f|0)>0|(f|0)>=0){return a}return 1/a}if((f|0)==1073741824){return a*a}if((f|0)!=1071644672|(d|0)<0){break d}return K(a)}c=D(a);h:{if(t){break h}i:{if((d|0)<0){if((d|0)==-2147483648|(d|0)==-1074790400){break i}if((d|0)!=-1048576){break h}break i}if(!d|(d|0)==2146435072){break i}if((d|0)!=1072693248){break h}}k=(f|0)<0?1/c:c;if((d|0)>0|(d|0)>=0){break c}if(!(q-1072693248|e)){a=k-k;return a/a}return(e|0)==1?-k:k}j:{if((d|0)>0|(d|0)>=0){break j}k:{switch(e|0){case 0:a=a-a;return a/a;case 1:break k;default:break j}}k=-1}l:{if(m>>>0>=1105199105){if(m>>>0>=1139802113){if(q>>>0<=1072693247){return(f|0)<0?N:0}return(f|0)>0?N:0}if(q>>>0<=1072693246){return(f|0)<0?k*1e300*1e300:k*1e-300*1e-300}if(q>>>0>=1072693249){return(f|0)>0?k*1e300*1e300:k*1e-300*1e-300}a=c+-1;c=a*1.9259629911266175e-8+a*a*(.5-a*(a*-.25+.3333333333333333))*-1.4426950408889634;i=c;c=a*1.4426950216293335;o(+(i+c));e=j(1)|0;j(0)|0;l(0,0);l(1,e|0);a=+n();c=i-(a-c);break l}a=c*9007199254740992;g=q>>>0<1048576;c=g?a:c;o(+a);e=j(1)|0;j(0)|0;h=g?e:q;d=h&1048575;e=d|1072693248;h=(h>>20)+(g?-1076:-1023)|0;g=0;m:{if(d>>>0<235663){break m}if(d>>>0<767610){g=1;break m}e=d|1071644672;h=h+1|0}d=g<<3;w=A[d+3536>>3];o(+c);j(1)|0;q=0;l(0,j(0)|q);l(1,e|0);p=+n();s=A[d+3520>>3];i=p-s;u=1/(s+p);c=i*u;o(+c);m=j(1)|0;j(0)|0;l(0,0);l(1,m|0);a=+n();x=a;l(0,q|0);l(1,((g<<18)+(e>>>1|0)|0)+537395200|0);v=a*a;y=i;i=+n();p=u*(y-a*i-a*(p-(i-s)));i=p*(c+a);a=c*c;s=i+a*a*(a*(a*(a*(a*(a*.20697501780033842+.23066074577556175)+.272728123808534)+.33333332981837743)+.4285714285785502)+.5999999999999946);o(+(v+3+s));e=j(1)|0;j(0)|0;l(0,0);l(1,e|0);a=+n();i=x*a;c=p*a+c*(s-(a+-3-v));o(+(i+c));e=j(1)|0;j(0)|0;l(0,0);l(1,e|0);a=+n();c=w+(a*-7.028461650952758e-9+(c-(a-i))*.9617966939259756);i=c;p=A[d+3552>>3];c=a*.9617967009544373;s=+(h|0);o(+(p+(i+c)+s));e=j(1)|0;j(0)|0;l(0,0);l(1,e|0);a=+n();c=i-(a-s-p-c)}l(0,0);l(1,f|0);p=+n();c=(b-p)*a+c*b;b=a*p;a=c+b;o(+a);d=j(1)|0;e=j(0)|0;n:{f=d;if((d|0)>=1083179008){if(e|f-1083179008){break b}if(!(c+8008566259537294e-32>a-b)){break n}break b}if((f&2147482624)>>>0<1083231232){break n}if(e|f+1064252416){break a}if(!(c<=a-b)){break n}break a}g=0;h=f&2147483647;if(h>>>0>=1071644673){e=f+(1048576>>>(h>>>20|0)-1022|0)|0;f=e>>>20&2047;g=(e&1048575|1048576)>>>1043-f|0;g=(d|0)<0?0-g|0:g;l(0,0);l(1,e&-1048576>>f-1023);b=b-+n();o(+(c+b));d=j(1)|0;j(0)|0}l(0,0);l(1,d|0);a=+n();p=a*.6931471824645996;c=(c-(a-b))*.6931471805599453+a*-1.904654299957768e-9;a=p+c;b=a*a;b=a-b*(b*(b*(b*(b*4.1381367970572385e-8+-16533902205465252e-22)+6613756321437934e-20)+-.0027777777777015593)+.16666666666666602);i=a*b/(b+-2);b=a;a=c-(a-p);a=b-(i-(b*a+a))+1;o(+a);e=j(1)|0;d=j(0)|0;e=(g<<20)+e|0;o:{if((e|0)<=1048575){a=Uj(a,g);break o}l(0,d|0);l(1,e|0);a=+n()}k=k*a}return k}return k*1e300*1e300}return k*1e-300*1e-300}function Pia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=jb-736|0;jb=h;a:{b:{if(d>>>0<=511){a=jb-16|0;jb=a;e=h+56|0;fc(a+8|0,e,554);d=v[a+12>>2];mc(a,v[b>>2],v[b+8>>2],v[a+8>>2],v[a+12>>2]);f=v[a+4>>2];if((f|0)==(d|0)){Zb(b,v[a+12>>2])}jb=a+16|0;a=(d|0)==(f|0);if(!a){Tb(e,0,554)}if(!a){break b}d=jb-32|0;jb=d;c:{a=h+56|0;if(Rb(a,13951,4)){break c}br(d,a+32|0);b=d+16|0;Ec(b,d);Cc(c+492|0,b);yb(b);Zh(d,1,a+4|0);Ec(b,d);Cc(c+524|0,b);yb(b);b=w[a+24|0]|w[a+25|0]<<8;v[c+4>>2]=64;v[c+8>>2]=128;v[c>>2]=b<<6;t[c+16|0]=w[a+26|0];t[c+17|0]=w[a+27|0];f=c+108|0;g=c+236|0;b=0;while(1)if((b|0)==120){b=w[c+60|0]&-2|t[a+17|0]&1;t[c+60|0]=b;b=b&-3|w[a+17|0]&2;t[c+60|0]=b;t[c+60|0]=b&251|w[a+17|0]&4;g=c+61|0;t[g|0]=w[a+18|0];i=c+62|0;t[i|0]=w[a+19|0];j=c+63|0;t[j|0]=w[a+20|0];k=c- -64|0;t[k|0]=w[a+21|0];f=c+48|0;Qg(f,25);e=v[c+48>>2];b=0;while(1){d:{if((b|0)!=25){l=Db(e,b);m=b<<1;n=w[(a+m|0)+504|0];u[l>>1]=n;if((n|0)!=255){break d}Qg(f,b);e=v[f>>2]}b=jf(g,i);a=_d(e,v[c+52>>2]);if(a>>>0<=w[b|0]){t[c+60|0]=w[c+60|0]&253}if(a>>>0>w[jf(j,k)|0]){break c}t[c+60|0]=w[c+60|0]&251;break c}t[l+2|0]=w[(a+(m|1)|0)+504|0];b=b+1|0;continue}}else{i=a+(b<<1)|0;e=w[i- -64|0];o=cc(g,b),p=w[i+65|0],u[o>>1]=p;o=Kb(f,b),p=(e>>>0<120?e:b)+1|0,t[o|0]=p;b=b+1|0;continue}}jb=d+32|0;break b}i=v[b+8>>2];d=jb-32|0;jb=d;v[d+28>>2]=674;v[d+8>>2]=674;e=v[b>>2];g=v[b+8>>2];f=v[Jb(d+28|0,d+8|0)>>2];if(!Pb(e,g,f)){f=cf(b)}j=d+8|0;e=h+56|0;BT(j,e);g=gc(d+16|0,v[d+8>>2],f);mc(d,v[b>>2],v[b+8>>2],v[g>>2],v[g+4>>2]);BT(j,e);Tb(v[d+8>>2]+f|0,0,674-f|0);Zb(b,v[d+28>>2]);jb=d+32|0;f=v[a+480180>>2];a=0;d=jb-32|0;jb=d;if(!Rb(e,13951,4)){br(d,e+32|0);a=d+16|0;Ec(a,d);Cc(c+492|0,a);yb(a);Zh(d,1,e+4|0);Ec(a,d);Cc(c+524|0,a);yb(a);v[c>>2]=(w[e+20|0]|w[e+21|0]<<8)<<5;v[c+4>>2]=w[e+24|0]>>>1;wc(c+4|0,64);g=w[e+25|0]&127;v[c+8>>2]=g>>>0>64?128:g<<2;t[c+15|0]=w[c+15|0]&254|((w[e+25|0]^-1)&128)>>>7;t[d+16|0]=w[e+26|0];t[d|0]=100;o=c,p=w[Wb(a,d)|0],t[o+20|0]=p;t[d+16|0]=w[e+27|0];t[d|0]=64;o=c,p=w[Wb(a,d)|0],t[o+19|0]=p;t[c+16|0]=w[e+17|0];t[c+17|0]=w[e+18|0];t[c+18|0]=w[e+19|0];t[c+26|0]=w[e+22|0];t[c+27|0]=w[e+23|0];a=w[e+58|0];Lj(c,a&127,a>>>7|0);a=w[e+59|0];Kj(c,a&127,a>>>7|0);e:{f:{g:{h:{i:{j:{a=w[e+28|0]|w[e+29|0]<<8;switch(a-529|0){case 1:case 2:break h;case 0:case 3:break i;default:break j}}if((a|0)==544){break i}if((a|0)!=514){break h}}a=w[e+61|0];if((a|0)==255){break g}if(a>>>0<=128){t[c+30|0]=a}a=w[e+62|0]|w[e+63|0]<<8;if(a>>>0<129){break f}break e}a=t[e+61|0];if((a|0)<0){break g}t[c+30|0]=a+1}a=w[e+62|0];a=a<<24>>24>=0?a+1|0:0;g=t[e+63|0];if((g|0)<0){break f}a=((g&255)<<7)+a|0}u[c+28>>1]=a}a=t[e+60|0];t[c+31|0]=a;if((a|0)<0){t[c+31|0]=0;t[c+34|0]=a^128}a=0;f=f&16777216?240:25;rv(e+304|0,c+48|0,0,f);rv(e+386|0,c+68|0,32,f);rv(e+468|0,c+88|0,32,f);t[c+100|0]=w[c+100|0]&239|w[e+468|0]>>>3&16;g=c+108|0;j=c+236|0;while(1){if((a|0)!=120){k=e+(a<<1)|0;f=w[k- -64|0];o=cc(j,a),p=w[k+65|0],u[o>>1]=p;o=Kb(g,a),p=(f>>>0<120?f:a)+1|0,t[o|0]=p;a=a+1|0;continue}break}a=554}jb=d+32|0;d=0;k:{if(!a){break k}d=e+550|0;l:{if(Rb(d,13427,4)){if(Rb(d,13779,4)){break l}}d=c+236|0;a=0;while(1){if((a|0)!=120){f=cc(d,a);u[f>>1]=x[f>>1]|w[(a+e|0)+554|0]<<8;a=a+1|0;continue}break}a=674}d=a}cd(b,d+i|0);if(!Fh(b,13956)){break b}d=h+8|0;$d(d,b,Bg(b));a=jc(h+32|0,d);Ab(d);b=v[a>>2];v[23588]=0;S(160,b|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break a}v[23588]=0;b=Q(402,a|0,13702)|0;d=v[23588];v[23588]=0;if((d|0)==1){break a}if(b){v[23588]=0;b=S(206,a|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break a}t[c+34|0]=b>>>0>250?0:b}Ab(a)}jb=h+736|0;return}b=P()|0;O()|0;Ab(a);T(b|0);L()}function s$(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;h=jb-32|0;jb=h;v[h+24>>2]=b;v[e>>2]=0;i=h+8|0;fd(i,d);v[23588]=0;i=S(19,i|0)|0;j=v[23588];v[23588]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((j|0)!=1){$b(h+8|0);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=P()|0;O()|0;$b(h+8|0);T(a|0);L()}mG(a,f+24|0,h+24|0,c,e,i);break b}lG(a,f+16|0,h+24|0,c,e,i);break b}g=a;i=b;a=nb[v[v[a+8>>2]+12>>2]](a+8|0)|0;b=Lc(a);k=h,l=Zj(g,i,c,d,e,f,b,Gb(a)+b|0),v[k+24>>2]=l;break b}a=Xi(h+24|0,c,e,i,2);b=v[e>>2];B:{if(!(b&4|a-1>>>0>30)){v[f+12>>2]=a;break B}v[e>>2]=b|4}break b}v[h+8>>2]=623865125;v[h+12>>2]=2032480100;k=h,l=Zj(a,b,c,d,e,f,h+8|0,h+16|0),v[k+24>>2]=l;break b}v[h+8>>2]=623728933;v[h+12>>2]=1680158061;k=h,l=Zj(a,b,c,d,e,f,h+8|0,h+16|0),v[k+24>>2]=l;break b}a=Xi(h+24|0,c,e,i,2);b=v[e>>2];C:{if(!(b&4|(a|0)>23)){v[f+8>>2]=a;break C}v[e>>2]=b|4}break b}a=Xi(h+24|0,c,e,i,2);b=v[e>>2];D:{if(!(b&4|a-1>>>0>11)){v[f+8>>2]=a;break D}v[e>>2]=b|4}break b}a=Xi(h+24|0,c,e,i,3);b=v[e>>2];E:{if(!(b&4|(a|0)>365)){v[f+28>>2]=a;break E}v[e>>2]=b|4}break b}a=Xi(h+24|0,c,e,i,2);b=v[e>>2];F:{if(!(b&4|(a|0)>12)){v[f+16>>2]=a-1;break F}v[e>>2]=b|4}break b}a=Xi(h+24|0,c,e,i,2);b=v[e>>2];G:{if(!(b&4|(a|0)>59)){v[f+4>>2]=a;break G}v[e>>2]=b|4}break b}a=h+24|0;b=jb-16|0;jb=b;v[b+8>>2]=c;while(1){H:{if(!op(a,b+8|0)){break H}c=Yk(v[a>>2]);if(!uh(v[i+8>>2],1,c)){break H}em(a);continue}break}if(cj(a,b+8|0)){v[e>>2]=v[e>>2]|2}jb=b+16|0;break b}b=h+24|0;a=nb[v[v[a+8>>2]+8>>2]](a+8|0)|0;I:{if((Gb(a)|0)==(0-Gb(a+12|0)|0)){v[e>>2]=v[e>>2]|4;break I}c=Tr(b,c,a,a+24|0,i,e,0);b=v[f+8>>2];if(!((c|0)!=(a|0)|(b|0)!=12)){v[f+8>>2]=0;break I}if(!((c-a|0)!=12|(b|0)>11)){v[f+8>>2]=b+12}}break b}g=w[83016]|w[83017]<<8|(w[83018]<<16|w[83019]<<24);t[h+15|0]=g;t[h+16|0]=g>>>8;t[h+17|0]=g>>>16;t[h+18|0]=g>>>24;g=w[83013]|w[83014]<<8|(w[83015]<<16|w[83016]<<24);v[h+8>>2]=w[83009]|w[83010]<<8|(w[83011]<<16|w[83012]<<24);v[h+12>>2]=g;k=h,l=Zj(a,b,c,d,e,f,h+8|0,h+19|0),v[k+24>>2]=l;break b}t[h+12|0]=w[83024];v[h+8>>2]=w[83020]|w[83021]<<8|(w[83022]<<16|w[83023]<<24);k=h,l=Zj(a,b,c,d,e,f,h+8|0,h+13|0),v[k+24>>2]=l;break b}a=Xi(h+24|0,c,e,i,2);b=v[e>>2];J:{if(!(b&4|(a|0)>60)){v[f>>2]=a;break J}v[e>>2]=b|4}break b}v[h+8>>2]=624576549;v[h+12>>2]=1394948685;k=h,l=Zj(a,b,c,d,e,f,h+8|0,h+16|0),v[k+24>>2]=l;break b}a=Xi(h+24|0,c,e,i,1);b=v[e>>2];K:{if(!(b&4|(a|0)>6)){v[f+24>>2]=a;break K}v[e>>2]=b|4}break b}a=nb[v[v[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}g=a;i=b;a=nb[v[v[a+8>>2]+24>>2]](a+8|0)|0;b=Lc(a);k=h,l=Zj(g,i,c,d,e,f,b,Gb(a)+b|0),v[k+24>>2]=l;break b}kG(f+20|0,h+24|0,c,e,i);break b}a=Xi(h+24|0,c,e,i,4);if(!(w[e|0]&4)){v[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}v[e>>2]=v[e>>2]|4;break b}a=jb-16|0;jb=a;v[a+8>>2]=c;b=6;c=h+24|0;L:{M:{if(cj(c,a+8|0)){break M}b=4;if((wn(i,Yk(v[c>>2]))|0)!=37){break M}b=2;if(!cj(em(c),a+8|0)){break L}}v[e>>2]=v[e>>2]|b}jb=a+16|0}a=v[h+24>>2]}jb=h+32|0;return a|0}function IK(){var a=0,b=0,c=0,d=0,e=0,f=0;if(w[468304]){return v[117075]}b=Ud(469944);v[b>>2]=83224;c=b+8|0;v[c>>2]=0;v[c+4>>2]=0;e=Gc(c+8|0),f=0,t[e+128|0]=f;if(sh(1073741823)>>>0<=29){bd();L()}a=QF(sw(c),30);v[c>>2]=a;v[c+4>>2]=a;e=Fb(c),f=a+120|0,v[e>>2]=f;Bt(c,30);v[23588]=0;d=Q(55,b+152|0,14249)|0;a=v[23588];v[23588]=0;a:{b:{c:{if((a|0)!=1){Kc(c);Ud(469616);v[117404]=85812;v[23588]=0;Y(1177,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}Ud(469624);v[117406]=85844;v[23588]=0;Y(1178,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}a=Ud(469632);t[a+12|0]=0;v[a+8>>2]=0;v[a>>2]=83244;v[a+8>>2]=83296;v[23588]=0;Y(1179,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}Ud(469648);v[117412]=84760;v[23588]=0;Y(1180,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}Ud(469656);v[117414]=84908;v[23588]=0;Y(1181,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}v[23588]=0;Z(1182);a=v[23588];v[23588]=0;if((a|0)==1){break c}v[23588]=0;Y(1183,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}Ud(469680);v[117420]=85056;v[23588]=0;Y(1184,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}Ud(469688);v[117422]=85288;v[23588]=0;Y(1185,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}Ud(469696);v[117424]=85172;v[23588]=0;Y(1186,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}Ud(469704);v[117426]=85404;v[23588]=0;Y(1187,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}a=Ud(469712);u[a+8>>1]=11310;v[a>>2]=84376;Lb(a+12|0);v[23588]=0;Y(1188,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}a=Ud(469736);v[a+8>>2]=46;v[a+12>>2]=44;v[a>>2]=84416;Lb(a+16|0);v[23588]=0;Y(1189,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}Ud(469768);v[117442]=85876;v[23588]=0;Y(1190,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}Ud(469776);v[117444]=86120;v[23588]=0;Y(1191,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}Ud(469784);v[117446]=86332;v[23588]=0;Y(1192,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}Ud(469792);v[117448]=86564;v[23588]=0;Y(1193,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}Ud(469800);v[117450]=87548;v[23588]=0;Y(1194,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}Ud(469808);v[117452]=87696;v[23588]=0;Y(1195,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}Ud(469816);v[117454]=87812;v[23588]=0;Y(1196,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}Ud(469824);v[117456]=87928;v[23588]=0;Y(1197,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}Ud(469832);v[117458]=88044;v[23588]=0;Y(1198,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}Ud(469840);v[117460]=88208;v[23588]=0;Y(1199,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}Ud(469848);v[117462]=88372;v[23588]=0;Y(1200,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}Ud(469856);v[117464]=88536;v[23588]=0;Y(1201,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}Ud(469864);v[117468]=89792;v[117468]=86812;v[117466]=86764;v[23588]=0;Y(1202,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}Ud(469880);v[117472]=89828;v[117472]=87076;v[117470]=87028;v[23588]=0;Y(1203,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}v[23588]=0;Z(1204);a=v[23588];v[23588]=0;if((a|0)==1){break c}v[23588]=0;Y(1205,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}v[23588]=0;Z(1206);a=v[23588];v[23588]=0;if((a|0)==1){break c}v[23588]=0;Y(1207,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}Ud(469928);v[117482]=88700;v[23588]=0;Y(1208,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}Ud(469936);v[117484]=88820;v[23588]=0;Y(1209,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break c}break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;yb(d)}TF(c);T(b|0);L()}v[117074]=469944;t[468304]=1;v[117075]=468296;return 468296}function cN(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=jb-16|0;jb=f;g=a+1074376|0;h=B(b,872);e=(g+h|0)+616|0;d=c&15;a:{b:{switch((c&240)-16>>>4|0){case 0:a=(a+h|0)+1075080|0;v[a>>2]=v[a>>2]&-1048577|((d|0)!=0)<<20;break a;case 1:if(!(w[a+480209|0]&16)){break a}if(vj(v[e+656>>2])){a=B(b,872)+a|0;u[a+1075764>>1]=d-8;a=a+1075843|0;t[a|0]=w[a|0]|64;break a}if(v[a+480180>>2]!=64){b=B(b,872)+a|0;u[b+1075764>>1]=d<<28>>24;c=x[(d<<1)+33280>>1];v[b+1075696>>2]=c;e=b+1075692|0;if(!v[e>>2]){break a}l=e,m=eh(a,w[b+1075789|0],d<<28>>24,c),v[l>>2]=m;break a}a=B(b,872)+a|0;b=v[a+1075096>>2];if(!b){break a}v[a+1075696>>2]=v[b+24>>2]+B(d,80);break a;case 2:if(v[a+480180>>2]==2){t[(B(b,872)+a|0)+1075814|0]=c&3;break a}Cb(f+8|0,a+1074312|0,21);if(Bb(v[v[f+8>>2]>>2],v[f+12>>2])){t[(B(b,872)+a|0)+1075814|0]=d>>>0<4?d:0;break a}t[(B(b,872)+a|0)+1075814|0]=c&7;break a;case 3:if(v[a+480180>>2]==2){t[(B(b,872)+a|0)+1075817|0]=c&3;break a}Cb(f+8|0,a+1074312|0,21);if(Bb(v[v[f+8>>2]>>2],v[f+12>>2])){t[(B(b,872)+a|0)+1075817|0]=d>>>0<4?d:0;break a}t[(B(b,872)+a|0)+1075817|0]=c&7;break a;case 4:Cb(f+8|0,a+1074312|0,21);if(Bb(v[v[f+8>>2]>>2],v[f+12>>2])){a=B(b,872)+a|0;t[a+1075813|0]=0;t[a+1075820|0]=d>>>0<4?d:0;break a}t[(B(b,872)+a|0)+1075820|0]=c&7;break a;case 5:if(v[a+1074392>>2]|!(w[a+480209|0]&16)){break a}a=a+1074400|0;v[a>>2]=v[a>>2]+d;break a;case 6:if(!(w[a+480209|0]&16)){break a}if(d>>>0<=2){d=x[a+480188>>1];h=d>>>0>256?d:256;i=a+906300|0;j=b+1|0;k=(c&15)-1|0;while(1){if((d|0)==(h|0)){break a}c=B(d,872)+a|0;c:{if(x[c+1075778>>1]!=(j|0)){break c}d:{e:{switch(k|0){case 0:Un(a,c+1074992|0);if(!(w[c+1075081|0]&2)){break d}e=v[a+1298300>>2];if(!Ed(e)){break d}hk(e,d&65535);break d;case 1:g=c+1075080|0;e=v[g>>2];v[g>>2]=e|4096;if(!(e&512)){break d}e=v[a+1298300>>2];if(!Ed(e)){break d}hk(e,d&65535);break d;default:break e}}v[c+1075688>>2]=0;g=c+1075080|0;e=v[g>>2];v[g>>2]=e|4096;if(!(e&512)){break d}e=v[a+1298300>>2];if(!Ed(e)){break d}qj(e,d&65535,1)}e=v[c+1075648>>2];if(!e){break c}g=w[e+34|0];if(!g){break c}g=v[Ld(i,g-1|0)>>2];if(!g){break c}nb[v[v[g>>2]+96>>2]](g,e,w[c+1075789|0]|256,0,b)}d=d+1|0;continue}}wP(e,d,v[a+480180>>2]);break a;case 7:if(!(w[a+480209|0]&16)){break a}um(a,e,d,4);break a;case 8:b=e;c=v[a+480208>>2];f:{if(!(c&4096)){break f}g:{switch(d&15){case 0:v[b+88>>2]=v[b+88>>2]&-257;break f;case 1:v[b+692>>2]=128;v[b+88>>2]=v[b+88>>2]|256;break f;case 8:v[b+88>>2]=v[b+88>>2]&-25165825|16777216;break f;case 9:v[b+88>>2]=v[b+88>>2]&-25165825|8388608;break f;case 10:v[a+480208>>2]=c&-16385;break f;case 11:v[a+480208>>2]=c|16384;break f;case 12:v[a+480208>>2]=c&-8193;break f;case 13:v[a+480208>>2]=c|8192;break f;case 14:v[b+88>>2]=v[b+88>>2]&-129;break f;case 15:break g;default:break f}}h:{if(v[b>>2]|v[b+4>>2]){break h}a=v[b+76>>2];if(!a){break h}if(!(l=_c(w[b+788|0]),m=1,n=w[b+88|0]&2,n?l:m)){break h}v[b>>2]=-1;v[b+4>>2]=a-1}v[b+88>>2]=v[b+88>>2]|128}break a;case 9:if(!(w[a+480209|0]&16)){break a}c=B(b,872)+a|0;t[c+1075828|0]=d;Cb(f+8|0,a+1074312|0,35);if(Bb(v[v[f+8>>2]>>2],v[f+12>>2])){break a}if(!_c(w[c+1075780|0])){break a}b=v[(B(b,872)+a|0)+1075068>>2];a=d<<16;if(b>>>0<=a>>>0){break a}v[e+4>>2]=a;break a;case 10:if(!(w[a+480209|0]&16)){break a}Yy(a,g,e,d);break a;case 11:i:{if(d){break i}d=1;c=v[a+480180>>2];if(c&16777248){break i}d=0;if((c|0)==2){break a}}Cb(f+8|0,a+1074312|0,30);Gy(a,b,d,Bb(v[v[f+8>>2]>>2],v[f+12>>2])|v[a+480180>>2]==2);break a;case 14:break b;default:break a}}if(v[a+480180>>2]==2){break a}t[(B(b,872)+a|0)+1075836|0]=d}jb=f+16|0}function nea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=jb-192|0;jb=e;a:{b:{if(Pb(v[c>>2],v[c+8>>2],8)){Zb(c,4);while(1){if(gu(v[c>>2],v[c+8>>2])){break b}m=jb-288|0;jb=m;f=RO(m);h=jb-384|0;jb=h;i=tc(f,RO(h+96|0),282);f=0;c:{d:{e:{f:{g:{if(Fh(c,13593)){yg(c,4);l=je(h+72|0,c);v[23588]=0;j=Q(759,l|0,i|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break g}h:{if(!j){break h}j=v[l+8>>2];g=v[l>>2];k=w[i+26|0];v[23588]=0;j=W(156,g|0,j|0,k|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break g}if(!j){break h}j=0;i:{while(1){if(w[i+26|0]<=f>>>0){g=v[l+8>>2];k=v[l>>2];f=0;v[23588]=0;j=j&65535;g=W(156,k|0,g|0,j|0)|0;k=v[23588];v[23588]=0;if((k|0)==1){break e}if(!g){break h}v[23588]=0;Q(188,l|0,j|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break e}yg(l,SO(i));f=Gc(h- -64|0);g=h+96|0;oz(g);v[23588]=0;R(760,l|0,g|0);g=v[23588];v[23588]=0;if((g|0)!=1){u[h+118>>1]=0;u[h+120>>1]=0;f=pz(f,h+96|0,h+123|0);g=w[i+26|0];v[23588]=0;Q(188,l|0,g|0)|0;g=v[23588];v[23588]=0;if((g|0)!=1){break i}}f=P()|0;O()|0;break d}v[23588]=0;g=S(198,l|0)|0;k=v[23588];v[23588]=0;if((k|0)!=1){t[(f+i|0)+27|0]=g;f=f+1|0;j=g+j|0;continue}break}f=P()|0;O()|0;break d}k=f;f=i+27|0;k=pz(k,f,f+w[i+26|0]|0);v[23588]=0;U(190,h+16|0,l|0,j|0);f=v[23588];v[23588]=0;if((f|0)==1){break f}g=h+16|0;j=jc(h+40|0,g);Ab(g);f=0;v[23588]=0;R(560,g|0,j|0);g=v[23588];v[23588]=0;if((g|0)==1){f=P()|0;O()|0;Ab(j);break d}g=h+16|0;hC(h+8|0,g);n=k;k=v[h+8>>2];k=pz(n,k,Kb(k,v[h+12>>2]));Tc(g);Ab(j);if(v[k>>2]!=(w[i+22|0]|w[i+23|0]<<8|(w[i+24|0]<<16|w[i+25|0]<<24))){break h}f=SO(i);v[23588]=0;Q(188,c|0,f|0)|0;i=v[23588];v[23588]=0;f=1;if((i|0)==1){break e}}Ab(l)}jb=h+384|0;break c}f=P()|0;O()|0;break d}f=P()|0;O()|0;break d}f=P()|0;O()|0}Ab(l);T(f|0);L()}jb=m+288|0;if(f){continue}break}}yc(c);vg(b,a,c);a=1;break a}t[d|0]=1;yc(c);f=Bg(c);d=e+144|0;$d(d,c,cf(c));h=jc(e+168|0,d);Ab(d);b=x[a+34>>1]&-66|w[b|0]>15|(w[b+1|0]!=1)<<6;u[a+34>>1]=b;v[a>>2]=f>>>(b&1)>>>(b>>>6&1);v[e+140>>2]=0;v[e+136>>2]=0;v[23588]=0;R(560,d|0,h|0);b=v[23588];v[23588]=0;j:{k:{l:{m:{if((b|0)!=1){c=Ie(e+144|0);d=v[e+144>>2];i=qA(c,Ei(d),e+140|0,e+136|0);v[23588]=0;b=v[e+140>>2];Q(188,h|0,b|0)|0;f=v[23588];v[23588]=0;if((f|0)!=1){if(!i){break j}Ng(a);l=b+c|0;b=d-b|0;d=v[e+136>>2];c=0;while(1){n:{if(d){if(!b|(d|0)!=1){break k}d=v[a>>2];if(d>>>0>c>>>0){break n}break k}d=v[a>>2];if(d>>>0<=c>>>0){break k}}if(!Zd(d,v[a+20>>2])){break k}v[e+132>>2]=0;v[e+128>>2]=0;j=vS(i,l,Ei(b),e+132|0,e+124|0,e+128|0);v[23588]=0;Q(188,h|0,j|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break m}ai(e+128|0,Ei(v[a>>2]-c|0));d=v[e+128>>2];o:{if((d|0)<=0){break o}f=v[e+132>>2];k=x[a+34>>1];if((Kd(k)|0)!=(f|0)){break o}m=B(c,f);g=v[a+20>>2];if(k&1){v[e+120>>2]=d;v[e+104>>2]=d;v[e+56>>2]=d;v[e+40>>2]=d;v[e+100>>2]=f;v[e+96>>2]=v[e+124>>2];v[e+116>>2]=f;v[e+112>>2]=g+(m<<1);v[23588]=0;f=v[e+100>>2];v[e+32>>2]=v[e+96>>2];v[e+36>>2]=f;f=v[e+116>>2];v[e+48>>2]=v[e+112>>2];v[e+52>>2]=f;R(561,e+48|0,e+32|0);f=v[23588];v[23588]=0;if((f|0)!=1){break o}break m}v[e+88>>2]=d;v[e+72>>2]=d;v[e+24>>2]=d;v[e+8>>2]=d;v[e+68>>2]=f;v[e+64>>2]=v[e+124>>2];v[e+84>>2]=f;v[e+80>>2]=g+m;v[23588]=0;f=v[e+68>>2];v[e>>2]=v[e+64>>2];v[e+4>>2]=f;f=v[e+84>>2];v[e+16>>2]=v[e+80>>2];v[e+20>>2]=f;R(562,e+16|0,e|0);f=v[23588];v[23588]=0;if((f|0)==1){break m}}b=b-j|0;l=j+l|0;c=c+d|0;d=uS(i);continue}}break m}c=P()|0;O()|0;break l}c=P()|0;O()|0;Tc(e+144|0)}Ab(h);T(c|0);L()}tS(i)}Tc(e+144|0);Ab(h);a=(i|0)!=0}jb=e+192|0;return a|0}function pba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,y=0,z=0,A=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;i=jb-32|0;jb=i;s=v[a+4>>2];e=af(v[a+8>>2],b);y=v[e>>2];a:{if(y+1>>>0<2){break a}j=(B(b,872)+s|0)+616|0;if(!(I=1,J=xi(v[j+8>>2],v[j+12>>2]),K=w[e+4|0],K?I:J)){break a}h=B(b,872)+s|0;if(!v[h+720>>2]){break a}g=v[h+704>>2]&2;e=v[(g?h+700|0:h+692|0)>>2];k=v[h+700>>2];f=v[h+696>>2];Cb(i+8|0,v[a>>2]+1074312|0,31);z=Bb(v[v[i+8>>2]>>2],v[i+12>>2]);m=kf(v[h+624>>2],v[h+628>>2],c);q=m;l=w[h+704|0]&128;m=l?0-m|0:m;n=mb;l=l?0-(n+((q|0)!=0)|0)|0:n;q=e;D=g?A:0;e=f;r=g?e:0;n=k-e|0;F=n<<1;G=h+1316|0;o=h+1467|0;E=h+1362|0;A=(w[E|0]&17)!=1;b:{c:{while(1){if((p|0)!=(y|0)){d:{if(d>>>0>p>>>0){f=(w[E|0]&17)==1;break d}v[v[a+4>>2]+16>>2]=p-d;t[o|0]=w[o|0]&254|(d|0)==(p|0);f=v[a>>2];k=v[a+4>>2];e=Yb(v[f+484344>>2],x[k+70>>1]);e=id(v[e>>2],v[v[e+48>>2]+12>>2],v[k+48>>2],b);g=w[e+3|0];e:{f:{switch(w[e+2|0]-11|0){case 0:k=i+8|0;Zy(k,f,g,w[e+4|0],0);k=Se(k);kt(v[a>>2],v[a+4>>2],b,x[i+8>>1]);f=1;if(!w[k|0]){break e}break d;case 1:u=w[e+4|0];Cb(i+8|0,f+1074312|0,12);Uy(f,k,b,u<<2&252,Bb(v[v[i+8>>2]>>2],v[i+12>>2]));break e;case 2:break f;default:break e}}u=w[e+4|0];Cb(i+8|0,f+1074312|0,12);Ty(f,k,b,u<<2&252,Bb(v[v[i+8>>2]>>2],v[i+12>>2]))}f=1;g:{h:{i:{j:{k:{switch(g-2|0){default:if(g-38>>>0<4){break h}if((g|0)==19){break j}if((g|0)!=28){break g}e=w[e+5|0];f=e&240;if((f|0)==32){break i}if((f|0)!=16){break g}Sy(v[a>>2],j,e&15);break g;case 2:kt(v[a>>2],v[a+4>>2],b,w[e+5|0]);break g;case 4:kt(v[a>>2],v[a+4>>2],b,0);break g;case 0:e=w[e+5|0];g=v[a>>2];if(!e&(t[g+480180|0]&1)){break d}Uy(g,v[a+4>>2],b,e,0);break g;case 1:break k;case 3:break d}}e=w[e+5|0];g=v[a>>2];if(!e&(t[g+480180|0]&1)){break d}Ty(g,v[a+4>>2],b,e,0);break g}f=w[e+5|0];e=f&15;if(!(v[v[a>>2]+480180>>2]&1048580?1:e)){break g}f=f&240;if((f|0)!=32){if((f|0)!=16){break g}Ry(v[a>>2],j,e);break g}Qy(v[a>>2],j,e);break g}Py(v[a>>2],j,e&15);break g}DN(v[a>>2],j,w[e+5|0],(g|0)==38|(g|0)==40,(g&254)==40)}f=1}v[i+28>>2]=v[G>>2];if(z){jt(v[a>>2],j)}if(!A){CN(v[a>>2],j,i+28|0);f=1}if(!z){jt(v[a>>2],j)}v[i+24>>2]=0;BN(j,i+24|0);l:{if(w[h+705|0]&2){break l}m:{if(!f){if(!w[af(v[a+8>>2],b)+4|0]){break m}}if(w[o|0]&96){xP(j,C(1),0,v[a>>2]);e=w[o|0];t[o|0]=(e&64?-65:-33)&e}_y(i+8|0,v[a>>2],j,v[i+28>>2],0);e=v[i+12>>2];v[h+624>>2]=v[i+8>>2];v[h+628>>2]=e;I=af(v[a+8>>2],b),J=0,t[I+4|0]=J;e=kf(v[h+624>>2],v[h+628>>2],c);f=w[h+704|0]&128;m=f?0-e|0:e;g=mb;l=f?0-(g+((e|0)!=0)|0)|0:g}Qb(j,m,l);k=v[j>>2];e=v[j+4>>2];if((k>>>0<H>>>0&(e|0)<=(q|0)|(e|0)<(q|0))&((e|0)>=(r|0)&k>>>0>=D>>>0|(e|0)>(r|0)|((l|0)>0|(l|0)>=0))){break l}g=v[h+704>>2];if(!(g&2)){break c}if(g&4){f=v[h+696>>2];if(k>>>0<D>>>0&(e|0)<=(r|0)|(e|0)<(r|0)){I=j,J=Sg(0,f<<1,k,e),v[I>>2]=J;e=mb;v[j+4>>2]=e;v[h+704>>2]=g^128;g=m;m=0-g|0;l=0-(((g|0)!=0)+l|0)|0}Cb(i+8|0,v[a>>2]+1074312|0,33);e=(e-f>>>0)%(F-Bb(v[v[i+8>>2]>>2],v[i+12>>2])>>>0)|0;n:{if(e>>>0<n>>>0){f=e+v[h+696>>2]|0;break n}f=v[h+700>>2]+(n-e|0)|0}v[j+4>>2]=f;f=v[h+704>>2];if((f&128)>>>7^e>>>0<n>>>0){break l}v[h+704>>2]=f^128;e=m;m=0-e|0;l=0-(((e|0)!=0)+l|0)|0;break l}f=e;g=v[h+700>>2];if(e>>>0>=g+n>>>0){f=g+((f-g>>>0)%(n>>>0)|0)|0}while(1){e=f;f=e-n|0;if(e>>>0>=g>>>0){continue}break}v[j>>2]=k;v[j+4>>2]=e}p=p+1|0;continue}break}v[v[a+4>>2]+16>>2]=0;break b}v[v[a+4>>2]+16>>2]=0;zP(j);v[(B(b,872)+s|0)+1324>>2]=0}I=af(v[a+8>>2],b),J=0,v[I>>2]=J}jb=i+32|0}function Aja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;e=jb-976|0;jb=e;yc(b);d=jb-16|0;jb=d;h=e+872|0;tU(d+8|0,h);f=v[d+12>>2];mc(d,v[b>>2],v[b+8>>2],v[d+8>>2],v[d+12>>2]);g=v[d+4>>2];if((g|0)==(f|0)){Zb(b,v[d+12>>2])}jb=d+16|0;d=(f|0)==(g|0);if(!d){sU(h)}a:{if(!d){break a}if(!vU(e+872|0)){break a}if(!Pb(v[b>>2],v[b+8>>2],Dc(uU(w[e+919|0]|w[e+920|0]<<8),mb))){break a}if(!c){l=1;break a}Ad(a,512);v[a+480228>>2]=32;u[a+480188>>1]=16;v[a+480196>>2]=w[e+947|0];v[a+480208>>2]=16;v[a+480200>>2]=256;v[a+480204>>2]=8e5;Nb(a+1074312|0,7,1);d=e+96|0;f=xc(d,8184);Ib(a+1298344|0,f);zb(f);f=xc(d,8872);Ib(a+1298356|0,f);zb(f);v[a+1298404>>2]=5;f=e+16|0;rU(f,e+872|4);Ec(d,f);Ac(a+1298308|0,d);yb(d);d=0;while(1){if((d|0)==16){b:{d=x[e+968>>1];if(d){BB(a+1298332|0,b,d,132,0)}d=jb-16|0;jb=d;h=e+96|0;fc(d+8|0,h,771);f=v[d+12>>2];mc(d,v[b>>2],v[b+8>>2],v[d+8>>2],v[d+12>>2]);g=v[d+4>>2];if((g|0)==(f|0)){Zb(b,v[d+12>>2])}jb=d+16|0;l=(f|0)==(g|0);if(!l){Tb(h,0,771)}if(!l){break a}d=a+484360|0;f=a+484376|0;qU(Vb(v[d>>2],w[f|0]),e+96|0,w[e+353|0]);Ue(Vb(v[d>>2],w[f|0]),w[e+354|0]);cd(b,w[e+919|0]|w[e+920|0]<<8);o=a+484344|0;p=c&1;h=0;while(1){c:{if((h|0)==256){if(!(c&2)){break a}yV(b,e- -64|0);d=0;while(1){if((d|0)==64){break a}if(!(w[e- -64+(d>>>3)|0]>>>(d&7)&1)){d=d+1|0;continue}if(!jB(b,e+16|0)){break a}d=d+1|0;u[a+480190>>1]=d;Me(e,1,e+16|0);h=e+72|0;Ec(h,e);Cc(((x[a+480190>>1]<<5)+a|0)+946304|0,h);yb(h);c=(B(d,104)+a|0)+484380|0;md(c,0);i=w[e+48|0]|w[e+49|0]<<8|(w[e+50|0]<<16|w[e+51|0]<<24);v[c>>2]=i;f=w[e+54|0]|w[e+55|0]<<8|(w[e+56|0]<<16|w[e+57|0]<<24);v[c+4>>2]=f;g=w[e+58|0]|w[e+59|0]<<8|(w[e+60|0]<<16|w[e+61|0]<<24);v[c+24>>2]=16726;v[c+8>>2]=g;u[c+30>>1]=w[e+53|0]<<4;if(t[e+62|0]&1){g=g>>>1|0;v[c+8>>2]=g;f=f>>>1|0;v[c+4>>2]=f;v[c>>2]=i>>>1}if(!(!(w[e+63|0]&8)|f>>>0>=g>>>0)){u[c+34>>1]=x[c+34>>1]|2}Zc(h,t[e+62|0]&1?16:8,1,0,0);vg(h,c,b);continue}}d:{d=(h<<1)+e|0;g=w[d+355|0]|w[d+356|0]<<8;if(g){f=e+72|0;$d(f,b,g);i=jc(e+16|0,f);Ab(f);n=((w[d+355|0]|w[d+356|0]<<8)-2|0)/64|0;e:{if(!p){break e}v[23588]=0;d=W(226,o|0,h&65535,n|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break d}if(!d){break e}v[23588]=0;d=S(206,i|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break b}v[23588]=0;Q(188,i|0,1)|0;f=v[23588];v[23588]=0;if((f|0)==1){break b}q=d?d>>>0<n-2>>>0?d+1|0:-1:-1;f=0;f:while(1){g:{d=Yb(v[o>>2],h);if((f|0)==(n|0)){break g}m=0;r=Cf(v[d>>2],v[v[d+48>>2]+12>>2],f);while(1){if((m|0)==16){f=f+1|0;continue f}v[23588]=0;R(349,e+72|0,i|0);d=v[23588];v[23588]=0;if((d|0)==1){break c}d=B(m,6)+r|0;j=e+72|0;g=Se(j);j=Li(j);k=w[e+72|0];if((k-1&255)>>>0<=71){t[d|0]=k+36;s=d,y=w[Nc(e+72|0)|0]+1|0,t[s+1|0]=y}if((w[g|0]-1&255)>>>0<=15){t[d+2|0]=1;t[d+4|0]=((w[g|0]<<6)+-64>>>0)/15}k=w[j|0];g=k&15;t[d+5|0]=g;h:{i:{switch((w[j|0]>>>4|0)-1|0){case 0:case 1:t[d+5|0]=k|240;break h;case 2:t[d+5|0]=g<<2;break h;case 3:t[d+5|0]=(6/(g+1>>>0)|0)+1;break h;case 5:case 6:t[d+5|0]=g<<3;break h;case 9:t[d+4|0]=(g<<2)+4;t[d+2|0]=1;break h;case 10:t[d+5|0]=g|128;break h;case 11:break i;default:break h}}t[d+5|0]=(6/(g+1>>>0)|0)+1|13}t[d+3|0]=w[(w[j|0]>>>4|0)+26368|0];m=m+1|0;continue}}break}ze(d,Eh(Te(Ne(e+72|0,14,0),q)))}Ab(i)}h=h+1|0;continue}}break}}}else{f=(d<<5)+a|0;h=f+480280|0;df(h);g=h;h=(e+872|0)+d|0;v[g>>2]=!w[h+50|0]<<10;u[f+480284>>1]=(w[h+76|0]<<4|8)&248;d=d+1|0;continue}break}a=P()|0;O()|0;Ab(i);T(a|0);L()}jb=e+976|0;return l|0}function xW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=jb-576|0;jb=e;yc(b);d=jb-16|0;jb=d;f=e+72|0;OC(d+8|0,f);g=v[d+12>>2];mc(d,v[b>>2],v[b+8>>2],v[d+8>>2],v[d+12>>2]);j=v[d+4>>2];if((j|0)==(g|0)){Zb(b,v[d+12>>2])}jb=d+16|0;d=(g|0)==(j|0);if(!d){NC(f)}a:{if(!d){break a}if(!QC(e+72|0)){break a}b:{if(!c){break b}if(!Pb(v[b>>2],v[b+8>>2],Dc(PC(w[e+182|0],w[e+183|0]),mb))){break a}Ad(a,64);v[a+480204>>2]=78e4;v[a+480260>>2]=112;v[a+480264>>2]=13696;v[a+480196>>2]=4;u[a+480188>>1]=8;Nb(a+1074312|0,7,1);d=e+40|0;g=xc(d,14613);Ib(a+1298344|0,g);zb(g);d=xc(d,14646);Ib(a+1298356|0,d);zb(d);Ql(a+1298368|0,Rb(e+72|0,11074,2)?14641:14613);v[a+1298404>>2]=5;f=w[e+182|0];u[a+480190>>1]=f;g=1;while(1){j=g&65535;if(j>>>0<=f>>>0){f=jb-16|0;jb=f;d=e+40|0;fc(f+8|0,d,25);l=v[f+12>>2];mc(f,v[b>>2],v[b+8>>2],v[f+8>>2],v[f+12>>2]);i=v[f+4>>2];if((i|0)==(l|0)){Zb(b,v[f+12>>2])}jb=f+16|0;if((i|0)!=(l|0)){t[d|0]=0;t[d+1|0]=0;t[d+2|0]=0;t[d+3|0]=0;t[d+4|0]=0;t[d+5|0]=0;t[d+6|0]=0;t[d+7|0]=0;t[d+24|0]=0;t[d+16|0]=0;t[d+17|0]=0;t[d+18|0]=0;t[d+19|0]=0;t[d+20|0]=0;t[d+21|0]=0;t[d+22|0]=0;t[d+23|0]=0;t[d+8|0]=0;t[d+9|0]=0;t[d+10|0]=0;t[d+11|0]=0;t[d+12|0]=0;t[d+13|0]=0;t[d+14|0]=0;t[d+15|0]=0}if((w[e+53|0]|w[e+54|0]<<8|(w[e+55|0]<<16|w[e+56|0]<<24))>>>0>67108863){break a}f=(B(j,104)+a|0)+484380|0;md(f,0);v[f+24>>2]=8363;l=e+40|0;d=l;i=w[d+13|0]|w[d+14|0]<<8|(w[d+15|0]<<16|w[d+16|0]<<24);v[f>>2]=i;k=w[d+17|0]|w[d+18|0]<<8|(w[d+19|0]<<16|w[d+20|0]<<24);v[f+4>>2]=k;d=w[d+21|0]|w[d+22|0]<<8|(w[d+23|0]<<16|w[d+24|0]<<24);d=d>>>0>i>>>0?k?d:0:d;v[f+8>>2]=d;if(d){u[f+34>>1]=2;Ck(f)}f=e+8|0;Zh(f,2,l);d=e+24|0;Ec(d,f);Cc(((j<<5)+a|0)+946304|0,d);g=g+1|0;yb(d);f=x[a+480190>>1];continue}break}g=e+24|0;h=e+72|2;bg(g,3,h,36);d=e+40|0;Ec(d,g);Ac(a+1298308|0,d);yb(d);g=0;MC(a+1298332|0,h,108,36,0);d=a+484360|0;h=a+484376|0;gv(Vb(v[d>>2],w[h|0]),e+185|0,128);d=Vb(v[d>>2],w[h|0]);h=w[e+184|0];if(x[cc(v[d>>2],h)>>1]<w[e+183|0]){Ue(d,h)}while(1)if((g|0)==8){j=a+484344|0;wg(j,w[e+183|0]);n=c&1;f=0;while(1){if(w[e+183|0]<=f>>>0){h=1;if(!(c&2)){break a}c=Zc(e+40|0,8,1,0,1);g=1;while(1){d=g&65535;if(d>>>0>x[a+480190>>1]){break b}vg(c,(B(d,104)+a|0)+484380|0,b);g=g+1|0;continue}}c:{d:{if(n){if(oh(j,f&65535,64)){break d}}Zb(b,1536);break c}v[e+24>>2]=-1;v[e+28>>2]=-1;l=0;e:while(1){if((l|0)==64){d=(e+72|0)+f|0;g=w[d+369|0];if(g>>>0<63){ze(Yb(v[j>>2],f),Eh(Te(Ne(e+40|0,14,0),g)))}ze(Yb(v[j>>2],f),Eh(Ne(e+40|0,16,w[d+241|0])));break c}g=0;d=Yb(v[j>>2],f);h=Cf(v[d>>2],v[v[d+48>>2]+12>>2],l);while(1){if((g|0)==8){l=l+1|0;continue e}d=e+40|0;Wq(d,b);i=Nc(d);k=Se(d);i=w[i|0];d=w[e+40|0];if(d>>>0<=253){t[h|0]=(d>>>2|0)+37;t[h+1|0]=(d<<4&48|i>>>4)+1;t[(e+24|0)+g|0]=255;d=w[e+40|0]}if((d&255)!=255){t[h+2|0]=1;t[h+4|0]=(((i&15)<<6|8)>>>0)/15}d=w[k|0];if((d|0)!=255){t[(e+24|0)+g|0]=d}i=(e+24|0)+g|0;f:{g:{if(d&15?0:(d|0)!=48){break g}k=w[i|0];if((k|0)==255){break f}m=k<<24>>24;d=m&15;t[h+5|0]=d;h:{if((m|0)<0){break h}k=k>>>4|0;t[h+3|0]=w[k+26152|0];i:{switch(k-3|0){case 0:t[h+5|0]=d|32;break g;case 1:t[h+5|0]=d|m<<4;break f;case 2:break g;case 3:break i;default:break f}}j:{switch(d|0){case 0:t[h+5|0]=79;break f;case 1:break j;default:break h}}t[h+5|0]=244;break f}t[h+3|0]=0;break f}t[i|0]=255}h=h+6|0;g=g+1|0;continue}}}f=f+1|0;continue}}else{d=(g<<5)+a|0;df(d+480280|0);u[d+480284>>1]=g&1?208:48;g=g+1|0;continue}}h=1}jb=e+576|0;return h|0}function $n(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0;f=jb-96|0;jb=f;q=lz(v[a+24>>2],w[a+32|0]);s=sj(q);c=s;e=v[a>>2];d=xd(e,v[a+4>>2]);a:{if(c>>>0>d>>>0){i=jb-32|0;jb=i;c=c-d|0;d=v[Fb(a)>>2];e=v[a+4>>2];b:{if(c>>>0<=(d-e|0)/12>>>0){e=jb-16|0;jb=e;c=Pt(e,a,c);d=v[c+4>>2];h=v[c+8>>2];while(1){if((d|0)==(h|0)){kc(c);jb=e+16|0}else{sO(d);d=d+12|0;v[c+4>>2]=d;continue}break}break b}d=Fb(a);d=Hk(i+8|0,jn(a,xd(v[a>>2],e)+c|0),xd(v[a>>2],v[a+4>>2]),d);h=jb-16|0;jb=h;e=CQ(h,d+8|0,c);c=v[e>>2];while(1){if(v[e+4>>2]!=(c|0)){sO(c);c=v[e>>2]+12|0;v[e>>2]=c;continue}break}Td(e);jb=h+16|0;h=v[a>>2];c=v[a+4>>2];e=d+4|0;while(1){if((c|0)!=(h|0)){c=c-12|0;Xz(v[e>>2]-12|0,c);v[e>>2]=v[e>>2]-12;continue}break}pc(a,e);pc(a+4|0,d+8|0);pc(Fb(a),Bc(d));v[d>>2]=v[d+4>>2];c=v[d+4>>2];while(1){e=v[d+8>>2];if((e|0)!=(c|0)){e=e-12|0;v[d+8>>2]=e;Ve(e);continue}break}c=v[d>>2];if(c){_o(d);Mb(c)}}jb=i+32|0;break a}if(d>>>0>c>>>0){yO(a,e+B(c,12)|0)}}if(b){c=a+12|0;Wp(c,Sd(c));z=Fb(c),A=0,v[z>>2]=A;d=c;c=ic(c);v[d>>2]=c;v[c>>2]=0;v[a+28>>2]=0}i=Sb(f+80|0);c=v[a+24>>2];c=tt(v[c+484344>>2],v[c+484348>>2]);v[23588]=0;h=W(604,f- -64|0,c|0,30220)|0;c=v[23588];v[23588]=0;c:{if((c|0)!=1){e=a+12|0;d:{while(1){if((k|0)==(s|0)){nd(h);hc(i);jb=f+96|0;return}c=v[a+24>>2];m=x[cc(v[q>>2],k)>>1];d=DO(c,m);v[f+60>>2]=d;c=Md(v[a>>2],k);e:{f:{if(b){v[23588]=0;t[f+40|0]=0;U(766,c|0,d|0,f+40|0);d=v[23588];v[23588]=0;if((d|0)!=1){break f}d=P()|0;O()|0;break d}v[23588]=0;R(726,c|0,d|0);d=v[23588];v[23588]=0;if((d|0)==1){break e}}v[23588]=0;d=Q(311,q|0,k&65535)|0;g=v[23588];v[23588]=0;if((g|0)==1){break e}g:{if(!d){break g}v[f+40>>2]=b?0:v[c+4>>2];r=v[Jb(f+40|0,f+60|0)>>2];o=wf(e);c=x[cc(v[h>>2],m)>>1];if((c|0)!=65535){d=BO(e,x[xm(f+40|0,c,r)>>1],v[f+44>>2]);h:{if(Hg(d,wf(e))){c=BO(e,x[xm(f+40|0,x[cc(v[h>>2],m)>>1],v[f+60>>2])>>1],v[f+44>>2]);break h}c=wf(e)}v[f+56>>2]=d;while(1){i:{if(!Hg(d,c)){break g}g=Sb(f+40|0);d=gn(vd(d)+8|0);v[23588]=0;R(767,g|0,d|0);d=v[23588];v[23588]=0;if((d|0)!=1){d=nk(f+24|0,o);j=xm(f+16|0,k,v[vd(v[f+56>>2])+4>>2]);d=v[d>>2];v[23588]=0;d=fa(768,e|0,d|0,j|0,g|0)|0;j=v[23588];v[23588]=0;if((j|0)==1){break i}v[f+32>>2]=d;o=v[Kg(f+32|0)>>2];qe(g);d=v[Kg(f+56|0)>>2];continue}}break}d=P()|0;O()|0;qe(g);break d}p=Yb(v[v[a+24>>2]+484344>>2],m);c=Pg(v[v[p+48>>2]+12>>2]);v[23588]=0;t[f+40|0]=0;U(749,i|0,c|0,f+40|0);c=v[23588];v[23588]=0;if((c|0)!=1){n=v[f+60>>2];j:while(1){k:{if((n|0)==(r|0)){if(r){break g}z=cc(v[h>>2],m),A=k,u[z>>1]=A;break g}g=1;j=0;c=v[v[p+48>>2]+12>>2];n=n-1|0;d=Cf(v[p>>2],c,n);while(1){if(g>>>0<16&Pg(c)>>>0>j>>>0){y=Kb(v[i>>2],j);c=w[y|0];l:{m:{n:{switch(w[d+3|0]-19|0){case 1:l=w[d+5|0];if((l&240)==176){break m}break l;case 0:break n;default:break l}}l=w[d+5|0];if((l&240)!=96){break l}}t[y|0]=l&15;l=w[Kb(v[i>>2],j)|0];c=l?l:c}c=c&255;g=B(c?c+1|0:1,g);d=d+6|0;j=j+1|0;c=v[v[p+48>>2]+12>>2];continue}else{o:{if(g>>>0<=1){continue j}c=Sb(f+40|0);v[23588]=0;R(767,c|0,g|0);d=v[23588];v[23588]=0;if((d|0)==1){break o}d=nk(f+8|0,o);g=xm(f+16|0,k,n);d=v[d>>2];v[23588]=0;o=fa(768,e|0,d|0,g|0,c|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break k}qe(c);continue j}}break}}break}d=P()|0;O()|0;qe(c);break d}d=P()|0;O()|0;break d}k=k+1|0;continue}break}d=P()|0;O()|0}nd(h);break c}d=P()|0;O()|0}hc(i);T(d|0);L()}function $ja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;d=jb-336|0;jb=d;yc(b);a:{if(!uo(b,d+320|0)){break a}if(!LU(d+320|0)){break a}if(!Rb(d+320|0,14118,4)){Zb(b,4)}if(!ci(b,d+312|0)){break a}if(Rb(d+312|0,14094,4)){break a}if(!c){n=1;break a}WB(b,d+120|0,v[d+316>>2]);if(x[d+156>>1]>128|x[d+162>>1]>16|(x[d+160>>1]>256|x[d+154>>1]>128)){break a}Ad(a,8192);f=d+32|0;e=xc(f,6542);Ib(a+1298344|0,e);zb(e);e=xc(f,10091);Ib(a+1298356|0,e);zb(e);v[a+1298404>>2]=5;e=d+96|0;Hi(e,2,d+120|0);Ec(f,e);Ac(a+1298308|0,f);yb(f);u[d+32>>1]=x[d+162>>1];u[d+96>>1]=1;g=x[ke(f,e)>>1];u[a+480188>>1]=g;v[a+480196>>2]=w[d+166|0];v[a+480204>>2]=B(w[d+167|0],1e4);t[d+32|0]=w[d+164|0];t[d+96|0]=64;e=w[Wb(f,e)|0];v[a+480200>>2]=e<<2;if(!e){v[a+480200>>2]=256}e=w[d+165|0];b:{if((e|0)==128){v[d+32>>2]=256/(g>>>0);v[d+96>>2]=128;l=v[Jb(d+32|0,d+96|0)>>2];break b}l=e&127}v[a+480228>>2]=l;f=0;while(1){if((f|0)==16){g=a+484376|0;gv(Vb(v[a+484360>>2],w[g|0]),d+184|0,x[d+156>>1]);e=x[d+154>>1];if(e>>>0<x[d+156>>1]){Ue(Vb(v[a+484360>>2],w[g|0]),e)}q=c&2;o=a+484344|0;n=1;r=c&1;l=d+68|0;m=a+480190|0;f=a+480188|0;while(1){if(!ci(b,d+312|0)){break a}c=d+32|0;$d(c,b,v[d+316>>2]);h=jc(d+96|0,c);Ab(c);c:{d:{if(!(Rb(d+312|0,13490,4)|!r)){v[23588]=0;g=p&65535;e=W(226,o|0,g|0,64)|0;c=v[23588];v[23588]=0;if((c|0)==1){break d}if(!e){break c}v[23588]=0;Q(188,h|0,2)|0;c=v[23588];v[23588]=0;if((c|0)==1){break d}Ej(d+32|0);j=0;e:{while(1){c=v[h>>2];v[23588]=0;e=W(156,c|0,v[d+104>>2],1)|0;c=v[23588];v[23588]=0;f:{if((c|0)!=1){if(!(e&j>>>0<64)){break e}v[23588]=0;k=S(206,h|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break d}if(k){break f}j=j+1|0;continue}break d}i=d+32|0;e=k&15;if(e>>>0<x[f>>1]){c=Yb(v[o>>2],g);i=id(v[c>>2],v[v[c+48>>2]+12>>2],j,e)}g:{if(!(k&128)){break g}v[23588]=0;e=S(206,h|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break d}if(!e){break g}t[i|0]=e>>>0<109?e+12|0:e}if(k&64){v[23588]=0;e=S(206,h|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break d}t[i+1|0]=e}if(k&32){t[i+2|0]=1;v[23588]=0;e=S(206,h|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break d}t[d+16|0]=e;t[d|0]=64;s=i,y=w[Wb(d+16|0,d)|0],t[s+4|0]=y}if(!(k&16)){continue}v[23588]=0;R(260,d+16|0,h|0);c=v[23588];v[23588]=0;if((c|0)!=1){e=Nc(d+16|0);h:{i:{j:{k:{l:{c=w[d+16|0];switch(c-17|0){case 2:break k;case 0:case 1:break l;default:break j}}c=c&15;break i}t[d+16|0]=33;t[e|0]=145;c=w[d+16|0];break h}if(c>>>0<17){break h}c=(c&240)==32?9:-1}t[d+16|0]=c}Of(i,c&255,w[e|0]);continue}break}break d}p=p+1|0;break c}if(Rb(d+312|0,13495,4)){break c}c=x[m>>1];if(!Xh(c)){break c}e=c+1|0;u[m>>1]=e;v[23588]=0;R(319,h|0,d+32|0);c=v[23588];v[23588]=0;m:{if((c|0)==1){break m}v[23588]=0;e=(B(e&65535,104)+a|0)+484380|0;R(320,d+32|0,e|0);c=v[23588];v[23588]=0;if((c|0)==1){break m}Hi(d,2,l);v[23588]=0;R(222,d+16|0,d|0);c=v[23588];v[23588]=0;if((c|0)==1){break m}c=d+16|0;Cc(((x[m>>1]<<5)+a|0)+946304|0,c);yb(c);if(!q){break c}j=w[d+45|0]|w[d+46|0]<<8;i=2;c=d+16|0;g=Zc(c,8,1,0,1);n:{if(!(j&64)){i=0;if(!(j&2)){break n}}cg(g,i)}if(j&4){wd(g,16)}v[23588]=0;W(219,c|0,e|0,h|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break c}}}a=P()|0;O()|0;Ab(h);T(a|0);L()}Ab(h);continue}}g=(f<<5)+a|0;df(g+480280|0);e=w[(d+f|0)+168|0];if(e>>>0<=128){u[g+480284>>1]=e<<1}f=f+1|0;continue}}jb=d+336|0;return n|0}function nfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=jb-192|0;jb=e;yc(b);a:{if(!jB(b,e+144|0)){break a}if(!TQ(e+144|0)){break a}if(!Pb(v[b>>2],v[b+8>>2],Dc(SQ(w[e+175|0],w[e+177|0]),mb))){break a}b:{if(!c){break b}Ad(a,256);g=e+32|0;Cj(g,2,e+144|0);d=e- -64|0;Ec(d,g);Ac(a+1298308|0,d);yb(d);f=xc(d,15297);Ib(a+1298344|0,f);zb(f);d=xc(d,10070);Ib(a+1298356|0,d);zb(d);Rf(g,4274);v[23588]=0;R(249,e+128|0,e+175|0);d=v[23588];v[23588]=0;c:{d:{if((d|0)!=1){v[23588]=0;X(672,e- -64|0,e+32|0,e+174|0,e+128|0);d=v[23588];v[23588]=0;if((d|0)!=1){d=e- -64|0;Ib(a+1298368|0,d);zb(d);zb(e+128|0);ac(e+32|0);v[a+1298404>>2]=5;d=Nb(a+1074312|0,107,1);v[a+480260>>2]=64;v[a+480264>>2]=32767;v[a+480188>>2]=2031620;Nb(d,107,1);f=w[e+176|0];d=w[e+175|0];if(d>>>0<=20){g=((f&255)>>>0)/10|0;f=g<<4|B(g,-10)+f}g=(f&255?f:96)&255;f=Vz(g);v[a+480196>>2]=g>>>4;v[a+480204>>2]=f;f=0;if(d>>>0>=11){t[e+64|0]=64;o=a,p=w[Wb(e+178|0,e- -64|0)|0]<<2,v[o+480200>>2]=p}while(1)if((f|0)==4){f=1;while(1){if((f|0)!=32){Xt(b,e+32|0);d=w[e+44|0];if(d?(d|0)!=46:0){break c}h=jb-32|0;jb=h;d=(B(f,104)+a|0)+484380|0;md(d,0);k=e+32|0;g=k;tk(h,2,g);i=h+16|0;Ec(i,h);Be(d+43|0,i);yb(i);v[d+24>>2]=w[g+24|0]|w[g+25|0]<<8;t[h+16|0]=w[g+22|0];t[h|0]=64;o=d,p=w[Wb(i,h)|0]<<2,u[o+30>>1]=p;i=w[g+16|0]|w[g+17|0]<<8;v[d>>2]=i;j=w[g+18|0]|w[g+19|0]<<8;v[d+4>>2]=j;g=w[g+20|0]|w[g+21|0]<<8;v[d+8>>2]=g;e:{if(i>>>0<=1){v[d>>2]=0;break e}if((g|0)==65535|i>>>0<=j>>>0|g>>>0<=j>>>0){break e}u[d+34>>1]=2;o=d,p=v[Jb(d+8|0,d)>>2],v[o+8>>2]=p}jb=h+32|0;g=e+16|0;tk(g,2,k);d=e+128|0;Ec(d,g);Cc(((f<<5)+a|0)+946304|0,d);yb(d);u[((f<<1)+e|0)+62>>1]=x[e+46>>1];f=f+1|0;continue}break}d=a+484360|0;g=a+484376|0;so(Vb(v[d>>2],w[g|0]),b,w[e+175|0]?128:64,65535,65535);f=0;if(!QQ(Vb(v[d>>2],w[g|0]))){break a}m=c&1;if(m){wg(a+484344|0,w[e+177|0])}i=a+484344|0;while(1){if(w[e+177|0]<=l>>>0){f=1;if(!(c&2)){break a}c=Zc(e+32|0,8,1,0,0);while(1){if((f|0)==32){break b}d=B(f,104)+a|0;g=d+484380|0;f:{if(!v[g>>2]|!x[d+484410>>1]){break f}d=x[((f<<1)+e|0)+62>>1];if(d>>>0<4){break f}if(!cd(b,d<<4)){break f}vg(c,g,b)}f=f+1|0;continue}}f=0;g:{h:{if(m){if(oh(i,l&65535,64)){break h}}while(1){if((f|0)==256){break g}if((Le(b)+2&255)>>>0<=252){Zb(b,3)}f=f+1|0;continue}}o=e,p=Eb(v[Yb(v[i>>2],l)>>2]),v[o+128>>2]=p;u[e+14>>1]=65535;v[e+16>>2]=63;h=0;i:while(1){f=0;if((h|0)==64){d=x[e+14>>1];if((d|0)==65535){break g}ze(Yb(v[i>>2],l),Lm(Te(Ne(e+32|0,12,d&255),v[e+16>>2])));break g}while(1){j:{k:{l:{if((f&65535)>>>0<=3){d=0;j=0;k=0;n=0;m:{n:{o:{p:{g=Le(b);switch(g-251|0){case 1:break j;case 0:break n;case 2:break p;default:break o}}t[v[e+128>>2]]=254;break j}d=e+32|0;Wq(d,b);j=w[Kb(d,0)|0];k=w[Kb(d,1)|0];n=w[Kb(d,2)|0];d=254;if((g|0)==254){break m}if(g>>>0>=96){break l}d=g}d=(B(d>>>4|0,12)+(d&15)|0)+37|0}g=d;d=v[e+128>>2];t[d|0]=g;break k}h=h+1|0;continue i}d=v[e+128>>2]}t[d+1|0]=(j&248)>>>3;g=k>>>1&120|j&7;if(g>>>0<=64){t[d+4|0]=g;t[d+2|0]=1}t[d+5|0]=n;PQ(d,k&15,h,w[e+175|0],e+14|0,e+16|0)}f=f+1|0;bA(e+128|0);continue}}}l=l+1|0;continue}}else{d=(f<<5)+a|0;df(d+480280|0);u[d+480284>>1]=f&1?64:192;f=f+1|0;continue}}f=P()|0;O()|0;zb(e+128|0);break d}f=P()|0;O()|0}ac(e+32|0);T(f|0);L()}f=0;break a}f=1}jb=e+192|0;return f|0}function Dy(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,z=0,A=0,C=0,D=0,E=0;f=jb-16|0;jb=f;k=B(b,872)+a|0;m=k+1075800|0;i=w[m|0];l=a+1074312|0;Cb(f+8|0,l,23);h=c&15;a:{b:{c:{if(Bb(v[v[f+8>>2]>>2],v[f+12>>2])){if(!(v[a+1074392>>2]|!w[(B(b,872)+a|0)+1075780|0])){t[m|0]=h;break c}e=w[m|0];if(e){g=e-1|0;t[m|0]=g;e=0;if(g&255){break c}}t[m|0]=h;e=1;break c}Cb(f+8|0,l,52);d:{e:{g=c&256;if(!(!g|!Bb(v[v[f+8>>2]>>2],v[f+12>>2]))){g=v[a+480208>>2]&4096;if(!g){break e}e=B(b,872)+a|0;if(w[e+1075781|0]){i=CT(w[e+1075780|0])?1:i}if(w[(B(b,872)+a|0)+1075784|0]?w[e+1075782|0]==1:0){break b}e=0;if(h>>>0>i>>>0){break c}if(!g){break d}if(_c(w[(B(b,872)+a|0)+1075780|0])){break c}break d}j=v[a+480180>>2];if(j&16777250){e=!(i?(i>>>0)%((h?h:1)>>>0)|0:1);i=i+1|0;break c}f:{if((j|0)!=16){if((j|0)!=1){break f}g=y[a+1074392>>2]%y[a+1074416>>2]|0;if(!g){if(_c(w[(B(b,872)+a|0)+1075780|0])){break a}}e=h?!((g>>>0)%(h>>>0)|0):e;break c}e=v[a+1074392>>2]==(h|0)&(h|0)!=0;break c}g:{if(!g){break g}e=B(b,872)+a|0;if(w[e+1075782|0]!=1){break g}h=(w[e+1075785|0]>15)+h|0}h:{if(v[a+480208>>2]&4096?g:1){h=h?h:1;e=0;e=!v[a+1074416>>2]|g?e:!(y[a+1074392>>2]%(h>>>0)|0);i=i+1|0;break h}e=0;i=j&1048580?0:i}if(!(!(w[(B(b,872)+a|0)+1075780|0]|!g?v[a+1074392>>2]:1)|(i&255)>>>0<h>>>0)){e=1}Cb(f+8|0,l,52);if(!Bb(v[v[f+8>>2]>>2],v[f+12>>2])|c){break c}e=!v[a+1074392>>2];break c}if(h>>>0>i>>>0){break c}}i=0;e=1}h=k+1074992|0;n=(B(b,872)+a|0)+1075068|0;i:{if(v[n>>2]){break i}Cb(f+8|0,l,38);if(!Bb(v[v[f+8>>2]>>2],v[f+12>>2])){break i}if(!pj(v[h+656>>2])){break a}}Cb(f+8|0,l,106);if(C=0,D=Bb(v[v[f+8>>2]>>2],v[f+12>>2]),E=v[(B(b,872)+a|0)+1075688>>2],E?C:D){break a}if(e){j=B(b,872)+a|0;q=j+1075680|0;g=v[q>>2];v[f+4>>2]=g;e=c>>>4&15;j:{if(!e){e=v[j+1075080>>2];break j}Cb(f+8|0,l,52);k:{if(C=Bb(v[v[f+8>>2]>>2],v[f+12>>2]),D=0,E=w[(B(b,872)+a|0)+1075782|0]==1,E?C:D){break k}if(!(16191>>>e&1)){v[f+4>>2]=(B(g,t[e+33696|0])|0)/16;break k}v[f+4>>2]=g+(t[e+33712|0]<<2)}oe(f+4|0,0,256);g=(B(b,872)+a|0)+1075080|0;e=v[g>>2]|2097152;v[g>>2]=e}k=B(b,872)+a|0;r=k+1075692|0;s=v[r>>2];g=w[k+1075794|0];j=0;if(e&512){Cb(f+8|0,l,108);j=Bb(v[v[f+8>>2]>>2],v[f+12>>2])}if(!((j^-1)&v[a+480180>>2]==2|(!v[n>>2]|(g-1&255)>>>0>119))){iN(a,b,0,g,1)}k=k+1075080|0;l:{if(!(v[a+480180>>2]&1048580)){break l}u=(c|0)<256;if((c|0)>255){break l}e=w[(B(b,872)+a|0)+1075781|0];if(!e){break l}u=1;Tp(a,h,e,0,0,1)}o=B(b,872)+a|0;p=o+1075652|0;z=v[p>>2];A=v[k>>2];v[p>>2]=0;Cb(f+8|0,l,23);e=1;m:{if(Bb(v[v[f+8>>2]>>2],v[f+12>>2])){break m}e=0;if(v[a+480180>>2]!=2){break m}e=(j^1)&v[n>>2]!=0}nt(a,h,g,e,u,0,b);if(!w[o+1075781|0]){v[p>>2]=z}if(!(!(A&4096)|v[a+480180>>2]!=4)){v[k>>2]=v[k>>2]|4096}j=o+1075780|0;v[q>>2]=v[f+4>>2];if(x[a+480192>>1]){t[j|0]=g;gN(a,b)}g=v[a+480180>>2];if(!(!(g&16777248)|(w[j|0]|!s))){v[r>>2]=s}if(e){v[h>>2]=0;v[h+4>>2]=0}e=g&16777250;n:{if(d-11>>>0<4294967286){break n}g=v[(B(b,872)+a|0)+1075096>>2];if(!g){break n}o:{if((d|0)==1){b=v[(B(b,872)+a|0)+1075656>>2];break o}j=(B(b,872)+a|0)+1075656|0;b=v[Db(g+68|0,d-2|0)>>2];v[j>>2]=b}Zn(a,h,b)}i=e?i:0}a=f+8|0;Cb(a,l,52);b=v[v[f+8>>2]>>2];d=v[f+12>>2];Cb(a,l,23);if(Bb(v[v[f+8>>2]>>2],v[f+12>>2])){break a}i=(Bb(b,d)&c>>>8)+i|0}t[m|0]=i}jb=f+16|0}function Mba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=jb-112|0;jb=e;g=a+140|0;Bj(e+88|0,g,1296125513);v[23588]=0;f=S(178,v[e+88>>2])|0;h=v[23588];v[23588]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((h|0)!=1){if(f){f=Lb(e+32|0);v[23588]=0;h=S(160,v[e+88>>2])|0;i=v[23588];v[23588]=0;if((i|0)==1){break p}v[23588]=0;U(776,e+88|0,f|0,h|0);h=v[23588];v[23588]=0;if((h|0)==1){break p}h=x[a+174>>1];v[23588]=0;U(777,e+72|0,h|0,f|0);h=v[23588];v[23588]=0;if((h|0)==1){break o}v[23588]=0;U(8,e+8|0,c|0,e+72|0);c=v[23588];v[23588]=0;if((c|0)==1){break n}c=e+8|0;Cc(d,c);yb(c);zb(e+72|0);yb(f)}if(w[a+176|0]){v[23588]=0;R(778,e+32|0,d|0);c=v[23588];v[23588]=0;if((c|0)==1){break e}c=e+32|0;Be(b+43|0,c);yb(c)}v[23588]=0;U(771,e+32|0,g|0,1413894985);c=v[23588];v[23588]=0;if((c|0)==1){break l}v[23588]=0;f=S(779,e+32|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break k}g=e+32|0;Ab(g);c=a+40|0;yc(c);v[23588]=0;g=Q(780,c|0,g|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break j}if(g){q:{if(y[e+60>>2]<2){break q}v[23588]=0;g=Q(781,c|0,e+8|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break i}if(!g){break q}eM(e+8|0,b+12|0,b+16|0,v[b>>2],b+34|0,8,16,f)}v[23588]=0;c=Q(781,c|0,e+8|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break i}if(c){eM(e+8|0,b+4|0,b+8|0,v[b>>2],b+34|0,2,4,f)}c=v[e+44>>2];t[b+42|0]=c&128?0:c+1|0;Ck(b)}r:{if(w[b+42|0]){break r}c=v[a+60>>2];v[23588]=0;c=Q(651,c|0,7)|0;f=v[23588];v[23588]=0;if((f|0)==1){break j}if(!c){break r}c=a+60|0;yc(c);v[23588]=0;c=Q(782,c|0,e+8|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break d}if(!c){break r}c=t[e+8|0];t[b+42|0]=(c|0)<0?0:c+1|0}c=v[a+120>>2];v[23588]=0;c=S(178,c|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break j}if(!c){break f}v[23588]=0;h=a+120|0;c=S(157,h|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break c}v[e+72>>2]=c;wc(e+72|0,9);f=b+68|0;g=v[e+72>>2];c=0;while(1){if((c|0)==(g|0)){break g}v[23588]=0;R(783,h|0,e+8|0);i=v[23588];v[23588]=0;if((i|0)==1){break h}j=Db(f,c),k=v[e+12>>2],v[j>>2]=k;c=c+1|0;continue}}a=P()|0;O()|0;break a}a=P()|0;O()|0;break m}a=P()|0;O()|0;break m}a=P()|0;O()|0;zb(e+72|0)}yb(f);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ab(e+32|0);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}Zz(f+(g<<2)|0,wT(f),42680)}c=a+80|0;yc(c);v[23588]=0;f=Q(784,c|0,e+8|0)|0;g=v[23588];v[23588]=0;s:{if((g|0)==1){break s}if(!f){break b}if(w[e+8|0]&32){u[b+34>>1]=x[b+34>>1]|32}u[e+72>>1]=x[e+12>>1];u[e+6>>1]=256;j=b,k=x[Vc(e+72|0,e+6|0)>>1],u[j+28>>1]=k;u[e+72>>1]=x[e+14>>1];u[e+6>>1]=256;j=b,k=x[Vc(e+72|0,e+6|0)>>1],u[j+30>>1]=k;u[e+72>>1]=x[e+16>>1];u[e+6>>1]=64;j=b,k=x[Vc(e+72|0,e+6|0)>>1],u[j+32>>1]=k;t[b+38|0]=w[e+20|0];t[b+39|0]=w[e+21|0];t[b+40|0]=w[e+22|0];t[b+41|0]=w[e+23|0];f=v[a+88>>2];a=v[a+80>>2];v[23588]=0;a=W(156,a|0,f|0,32)|0;f=v[23588];v[23588]=0;if((f|0)==1){break s}if(!a){break b}v[23588]=0;R(785,c|0,d|0);a=v[23588];v[23588]=0;if((a|0)==1){break s}v[23588]=0;a=S(202,c|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break s}v[23588]=0;U(786,c|0,b+43|0,a|0);a=v[23588];v[23588]=0;if((a|0)!=1){break b}}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}Ab(e+88|0);jb=e+112|0;return}Ab(e+88|0);T(a|0);L()}function kK(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=jb-256|0;jb=e;t[e+255|0]=c;f=v[b+4>>2];a:{if(!f){break a}g=v[b>>2];h=w[cl(g,f)|0];if((h|0)==33){d=1}else{if((h|0)!=63){break a}d=0}jl(e+80|0,g,f,f-1|0);f=v[e+84>>2];v[b>>2]=v[e+80>>2];v[b+4>>2]=f}f=e+80|0;Wd(f);g=v[e+80>>2];Wd(e+224|0);h=bl(g,v[e+228>>2],b);Wd(f);f=v[b+4>>2];g=v[b>>2];b:{c:{d:{e:{f:{g:{h:{if((h|0)==v[e+84>>2]){a=qc(e+240|0,21619);c=v[a+4>>2];v[e>>2]=v[a>>2];v[e+4>>2]=c;if(Pc(g,f,e)){d=ba(8)|0;v[23588]=0;R(960,e+224|0,e+255|0);a=v[23588];v[23588]=0;if((a|0)==1){break g}v[23588]=0;U(967,e+80|0,17598,e+224|0);a=v[23588];v[23588]=0;if((a|0)==1){break f}a=0;b=rc(d,e+80|0);v[23588]=0;U(119,b|0,62688,956);b=v[23588];v[23588]=0;if((b|0)!=1){break b}b=P()|0;O()|0;yb(e+80|0);break e}if(!d){break h}d=ba(8)|0;a=v[b+4>>2];b=v[b>>2];v[23588]=0;a=Kh(e+192|0,b,a);b=v[23588];v[23588]=0;i:{j:{k:{l:{m:{n:{o:{p:{if((b|0)!=1){v[23588]=0;U(967,e+208|0,17634,a|0);b=v[23588];v[23588]=0;if((b|0)==1){break p}v[23588]=0;R(969,e+224|0,e+208|0);b=v[23588];v[23588]=0;c=1;if((b|0)==1){break o}v[23588]=0;R(960,e+176|0,e+255|0);b=v[23588];v[23588]=0;if((b|0)==1){break n}v[23588]=0;U(971,e+80|0,e+224|0,e+176|0);b=v[23588];v[23588]=0;if((b|0)==1){break m}b=rc(d,e+80|0);v[23588]=0;U(119,b|0,62688,956);b=v[23588];v[23588]=0;if((b|0)!=1){break b}b=P()|0;O()|0;yb(e+80|0);c=0;break l}b=P()|0;O()|0;break d}b=P()|0;c=1;O()|0;break i}b=P()|0;O()|0;break j}b=P()|0;O()|0;break k}b=P()|0;O()|0}yb(e+176|0)}yb(e+224|0)}yb(e+208|0)}yb(a);if(c){break d}break c}b=qc(e+168|0,21619);d=v[b+4>>2];v[e+72>>2]=v[b>>2];v[e+76>>2]=d;if(Pc(g,f,e+72|0)){d=ba(8)|0;v[23588]=0;R(960,e+224|0,e+255|0);a=v[23588];v[23588]=0;q:{r:{if((a|0)!=1){v[23588]=0;U(967,e+80|0,17598,e+224|0);a=v[23588];v[23588]=0;if((a|0)==1){break r}a=0;b=rc(d,e+80|0);v[23588]=0;U(119,b|0,62688,956);b=v[23588];v[23588]=0;if((b|0)!=1){break b}b=P()|0;O()|0;yb(e+80|0);break q}b=P()|0;O()|0;break d}b=P()|0;a=1;O()|0}yb(e+224|0);if(a){break d}break c}b=qc(e+160|0,7422);d=v[b+4>>2];v[e+64>>2]=v[b>>2];v[e+68>>2]=d;s:{if(!Pc(g,f,e- -64|0)){b=qc(e+152|0,7404);d=v[b+4>>2];v[e+56>>2]=v[b>>2];v[e+60>>2]=d;if(!Pc(g,f,e+56|0)){break s}}t[a+60|0]=c;break h}b=qc(e+144|0,6937);d=v[b+4>>2];v[e+48>>2]=v[b>>2];v[e+52>>2]=d;t:{if(!Pc(g,f,e+48|0)){b=qc(e+136|0,6918);d=v[b+4>>2];v[e+40>>2]=v[b>>2];v[e+44>>2]=d;if(!Pc(g,f,e+40|0)){break t}}t[a+61|0]=c;break h}b=qc(e+128|0,7021);d=v[b+4>>2];v[e+32>>2]=v[b>>2];v[e+36>>2]=d;if(Pc(g,f,e+32|0)){t[a+62|0]=c;break h}b=qc(e+120|0,6067);d=v[b+4>>2];v[e+24>>2]=v[b>>2];v[e+28>>2]=d;if(Pc(g,f,e+24|0)){t[a+63|0]=c;break h}b=qc(e+112|0,7471);d=v[b+4>>2];v[e+16>>2]=v[b>>2];v[e+20>>2]=d;if(Pc(g,f,e+16|0)){t[a+64|0]=c;break h}b=qc(e+104|0,13296);d=v[b+4>>2];v[e+8>>2]=v[b>>2];v[e+12>>2]=d;if(!Pc(g,f,e+8|0)){break h}b=v[a+24>>2];d=b+24664|0;f=v[d+4>>2];v[e+96>>2]=v[d>>2];v[e+100>>2]=f;d=b+24656|0;f=v[d+4>>2];v[e+88>>2]=v[d>>2];v[e+92>>2]=f;d=v[b+24652>>2];v[e+80>>2]=v[b+24648>>2];v[e+84>>2]=d;if(c){a=MJ(v[a+56>>2])}else{a=0}v[e+100>>2]=a;if(!xx(e+80|0,b+24648|0)){break h}py(b,e+80|0)}jb=e+256|0;return}b=P()|0;O()|0;break d}b=P()|0;a=1;O()|0}yb(e+224|0);if(!a){break c}}ca(d|0)}T(b|0)}L()}function Yv(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=jb-96|0;jb=c;i=a+32|0;Rc(c+56|0,i,11);a:{if(k=1,l=Bb(v[v[c+56>>2]>>2],v[c+60>>2]),m=v[a+8>>2],m?k:l){d=v[a+36>>2];b=v[a+76>>2]+v[a+20>>2]|0;f=v[a+16>>2];e=f+v[a+72>>2]|0;b=Xg(c+80|0,e,e>>>0<f>>>0?b+1|0:b);e=v[b+12>>2];v[c+24>>2]=v[b+8>>2];v[c+28>>2]=e;e=v[b+4>>2];v[c+16>>2]=v[b>>2];v[c+20>>2]=e;Xj(d,c+16|0);b=v[a+36>>2];if(Zk(v[(v[v[b>>2]-12>>2]+b|0)+16>>2])){th(a,2,256);break a}b=v[a+104>>2];e=a+52|0;f=v[e>>2];d=Qi(f,v[e+4>>2]);b:{if(b>>>0>d>>>0){h=jb-32|0;jb=h;f=b-d|0;d=v[Fb(e)>>2];g=v[e+4>>2];c:{if(f>>>0<=(d-g|0)/24>>>0){d=jb-16|0;jb=d;b=kE(d,e,f);e=v[b+4>>2];f=v[b+8>>2];while(1){if((e|0)==(f|0)){kc(b);jb=d+16|0}else{jE(e);e=e+24|0;v[b+4>>2]=e;continue}break}break c}b=Fb(e);d=nE(h+8|0,pE(e,Qi(v[e>>2],g)+f|0),Qi(v[e>>2],v[e+4>>2]),b);b=jb-16|0;jb=b;v[b>>2]=v[d+8>>2];g=v[d+8>>2];v[b+8>>2]=d+8;v[b+4>>2]=g+B(f,24);f=v[b>>2];while(1){if(v[b+4>>2]!=(f|0)){jE(f);f=v[b>>2]+24|0;v[b>>2]=f;continue}break}Td(b);jb=b+16|0;mE(e,d);lE(d)}jb=h+32|0;break b}if(b>>>0<d>>>0){Nd(e,f+B(b,24)|0)}}h=a+40|0;qn(h,v[a+104>>2]<<2);e=0;while(1){if(y[a+104>>2]>e>>>0){d=v[a+36>>2];if(Zk(v[(v[v[d>>2]-12>>2]+d|0)+16>>2])){th(a,2,1024);break a}b=x[a+24>>1];u[c+32>>1]=b;if((b|0)==65535){_v(d,c+32|0);b=x[c+32>>1]}d=ed(v[a+40>>2],v[a+44>>2]);f=b&65535;d:{if(!f){b=0;break d}if(f>>>0>(d^-1)>>>0){break d}Ri(h,d+f|0);Uk(v[a+36>>2],Kb(v[a+40>>2],d),f)}f=lf(v[a+52>>2],e);v[f>>2]=d;u[f+20>>1]=b;Rc(c+56|0,i,6);if(Bb(v[v[c+56>>2]>>2],v[c+60>>2])){Jk(v[a+36>>2],c+56|0);d=v[c+56>>2];b=v[c+60>>2];if(!Zv(d,b)){th(a,2,2048);break a}f=lf(v[a+52>>2],e);v[f+8>>2]=d;v[f+12>>2]=b}d=v[a+8>>2];e:{if(d){b=lf(v[a+52>>2],e);v[b+16>>2]=d;break e}Rc(c+56|0,i,7);if(!Bb(v[v[c+56>>2]>>2],v[c+60>>2])){b=lf(v[a+52>>2],e);break e}Jk(v[a+36>>2],c+56|0);d=v[c+56>>2];if(!Zv(d,v[c+60>>2])){th(a,2,2048);break a}b=lf(v[a+52>>2],e);v[b+16>>2]=d}f:{if(v[b+16>>2]==-1){break f}Rc(c+56|0,i,6);if(Bb(v[v[c+56>>2]>>2],v[c+60>>2])){break f}g:{if(!e){f=0;b=0;d=lf(v[a+52>>2],0);break g}g=v[a+52>>2];b=lf(g,e-1|0);f=v[b+16>>2];d=v[b+8>>2]+f|0;b=v[b+12>>2];b=d>>>0<f>>>0?b+1|0:b;f=d;d=lf(g,e)}v[d+8>>2]=f;v[d+12>>2]=b}Rc(c+56|0,i,8);if(Bb(v[v[c+56>>2]>>2],v[c+60>>2])){u[c+78>>1]=0;_v(v[a+36>>2],c+78|0);Rc(c+56|0,i,9);am(v[a+36>>2],x[c+78>>1]<<Bb(v[v[c+56>>2]>>2],v[c+60>>2]))}e=e+1|0;continue}break}me(c+56|0,v[a+36>>2]);b=v[c+68>>2];v[a+80>>2]=v[c+64>>2];v[a+84>>2]=b}e=c+56|0;Rc(e,i,4);Ye(e,1);f=v[a+84>>2];h=v[a+96>>2];g=v[a+16>>2];d=h+g|0;j=v[a+100>>2];b=j+v[a+20>>2]|0;b=d>>>0<g>>>0?b+1|0:b;g=d;d=(h|0)==v[a+72>>2]&(j|0)==v[a+76>>2];h=d?v[a+80>>2]:g;v[a+88>>2]=h;b=d?f:b;v[a+92>>2]=b;d=v[a+36>>2];b=Xg(c+40|0,h,b);f=v[b+12>>2];v[c+8>>2]=v[b+8>>2];v[c+12>>2]=f;f=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=f;Xj(d,c);Rc(e,i,6);if(Bb(v[v[c+56>>2]>>2],v[c+60>>2])){break a}Rc(c+32|0,i,7);if(!(k=1,l=Bb(v[v[c+32>>2]>>2],v[c+36>>2]),m=v[a+8>>2],m?k:l)){break a}b=v[a+88>>2];e=v[a+16>>2];i=b-e|0;d=v[a+92>>2]-(v[a+20>>2]+(b>>>0<e>>>0)|0)|0;f=v[a+52>>2];h=v[a+104>>2];a=0;while(1){if((a|0)==(h|0)){break a}b=lf(f,a);g=b;j=v[b+8>>2];e=j+i|0;b=v[b+12>>2]+d|0;v[g+8>>2]=e;v[g+12>>2]=e>>>0<j>>>0?b+1|0:b;a=a+1|0;continue}}jb=c+96|0}function HK(a){var b=0,c=C(0),d=C(0),e=C(0),f=C(0),g=C(0),h=0,i=0,j=0,k=0,l=C(0),m=C(0),n=0,o=C(0),p=0,q=C(0),r=C(0),s=C(0),u=0,w=C(0);j=jb-16|0;jb=j;b=a+4208|0;i=jk(C(z[Db(b,12)>>2]*C(3)));v[a+4264>>2]=i;d=C(v[v[a+16>>2]+24620>>2]>>>((i>>>1^-1)&1)>>>0);z[a+4268>>2]=d;u=a,w=C(C(z[Db(b,9)>>2]*C(100))*C(.0061803399585187435)),z[u+4272>>2]=w;u=j,w=te(C(10),C(C(GK(a)+C(C(z[Db(b,5)>>2]*C(11e3))+C(-1e4)))/C(2e3))),z[u+12>>2]=w;v[j+8>>2]=1065353216;u=a,w=C(z[nm(j+12|0,j+8|0)>>2]*C(.7609999775886536)),z[u+4280>>2]=w;c=te(C(10),C(C(C(C(z[Db(b,1)>>2]*C(1e4))+C(-1e4))/C(100))/C(10)));if(c!=C(1)){d=Bp(C(C(FK(a)*C(6.2831854820251465))/d));f=C(c+c);e=C(c*c);c=az(C(C(C(C(d*f)+C(-2))+C(K(C(C(C(C(d*C(C(d*e)*C(4)))+C(c*C(8)))-C(e*C(4)))-C(C(d*c)*C(8))))))/C(f+C(-2))),C(0),C(1))}else{c=C(0)}z[a+4276>>2]=c;i=jb-16|0;jb=i;c=z[a+4268>>2];b=a+4208|0;d=C(z[Db(b,6)>>2]*C(.30000001192092896));u=i,w=C(z[Db(b,8)>>2]*C(.10000000149011612)),z[u+12>>2]=w;v[i+8>>2]=1000593162;f=z[Jx(i+12|0,i+8|0)>>2];e=C(c*C(C(d+f)+C(.007000000216066837)));a:{if(C(D(e))<C(2147483648)){b=~~e;break a}b=-2147483648}v[a+4352>>2]=b;b=1;while(1){if((b|0)==12){u=i,w=C(C(C(C(z[Db(a+4208|0,10)>>2]*C(100))/C(100))+C(.10000000149011612))*C(.9090999960899353)),z[u+12>>2]=w;v[i+8>>2]=1065353216;d=z[nm(i+12|0,i+8|0)>>2];f=C(c*C(C(d*C(75))/C(1e3)));d=C(c*C(C(d*C(67))/C(1e3)));b=0;while(1){if((b|0)==6){h=a+4348|0;d=C(c*C(.0035299998708069324));b:{if(C(D(d))<C(2147483648)){b=~~d;break b}b=-2147483648}v[h>>2]=b;h=a+4344|0;d=C(c*C(.0032500000670552254));c:{if(C(D(d))<C(2147483648)){b=~~d;break c}b=-2147483648}v[h>>2]=b;h=a+4340|0;c=C(c*C(.009999999776482582));d:{if(C(D(c))<C(2147483648)){b=~~c;break d}b=-2147483648}v[h>>2]=b}else{h=(b<<2)+a|0;p=h+4316|0;n=b+n|0;e=te(C(.9300000071525574),C(n|0));g=C(f*e);e:{if(C(D(g))<C(2147483648)){k=~~g;break e}k=-2147483648}v[p>>2]=k;k=h+4292|0;e=C(d*e);f:{if(C(D(e))<C(2147483648)){h=~~e;break f}h=-2147483648}v[k>>2]=h;b=b+1|0;continue}break}b=0;while(1){if((b|0)!=15){KK((B(b,24)+a|0)+4504|0,v[((b<<2)+a|0)+4292>>2]);b=b+1|0;continue}break}jb=i+16|0}else{k=((B(b&1,24)+a|0)+(b<<1&-4)|0)+4352|0;e=C(c*C(C(f*z[(b<<2)+46944>>2])+d));g:{if(C(D(e))<C(2147483648)){h=~~e;break g}h=-2147483648}v[k>>2]=h;b=b+1|0;continue}break}b=jb-16|0;jb=b;d=wh(a,5);e=wh(a,11);c=C(d*wh(a,4));d=C(C(c*C(.03999999910593033))+C(C(d*C(.02250000089406967))+C(0)));f=C(e*wh(a,10));e=C(C(f*C(.03999999910593033))+C(C(e*C(.02250000089406967))+C(0)));if(t[a+4264|0]&1){g=wh(a,3);l=wh(a,9);g=C(c*g);c=C(g*wh(a,2));d=C(C(c*C(.1444000005722046))+C(C(g*C(.12250000238418579))+d));g=C(f*l);f=C(g*wh(a,8));e=C(C(f*C(.1444000005722046))+C(C(g*C(.12250000238418579))+e))}wh(a,12);g=z[a+4496>>2];l=wh(a,1);m=wh(a,7);q=wh(a,0);r=wh(a,6);u=b,w=te(C(10),C(C(GK(a)+C(C(z[Db(a+4208|0,7)>>2]*C(12e3))+C(-1e4)))/C(2e3))),z[u+12>>2]=w;v[b+8>>2]=1065353216;o=z[nm(b+12|0,b+8|0)>>2];s=c;c=C(g*g);g=C(l*C(s*c));l=C(q*g);c=C(m*C(f*c));f=C(r*c);m=C(C(C(l+f)*C(-.5))+C(1));z[a+4284>>2]=o*C(K(C(m/C(C(l*C(.1444000005722046))+C(C(c*C(.1444000005722046))+d)))));z[a+4288>>2]=o*C(K(C(m/C(C(f*C(.1444000005722046))+C(C(g*C(.1444000005722046))+e)))));jb=b+16|0;t[a+5046|0]=0;jb=j+16|0}function WM(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,x=0,y=0;if(b){h=a+327720|0;c=jb-400|0;jb=c;PO(c+384|0,8);v[23588]=0;oa(761,c+368|0,9);i=v[23588];v[23588]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if((i|0)!=1){v[23588]=0;i=Q(762,c+352|0,14)|0;e=v[23588];v[23588]=0;if((e|0)==1){break l}v[23588]=0;R(763,c+384|0,i|0);e=v[23588];v[23588]=0;if((e|0)==1){break k}v[23588]=0;R(763,c+368|0,i|0);e=v[23588];v[23588]=0;if((e|0)==1){break k}OO(c+280|0,4900);OO(c+208|0,32e3);HO(c+136|0,8377175819504598e-21,16754351639009197e-21,8377175819504598e-21,-1.991112714669597,.9911462233728751);v[23588]=0;e=Q(764,c+104|0,c+384|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break j}wt(c+120|0,c+280|0,e);qe(e);v[23588]=0;e=Q(764,c+72|0,c+368|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break i}wt(c+88|0,c+208|0,e);qe(e);v[23588]=0;e=Q(764,c+40|0,c+120|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break h}wt(c+56|0,c+136|0,e);qe(e);v[23588]=0;e=Q(764,c+8|0,c+88|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break g}g=c+24|0;wt(g,c+136|0,e);qe(e);e=c+120|0;Zp(e);l=c+56|0;Zp(l);m=c+88|0;Zp(m);Zp(g);p=c+368|0;Zp(p);Yp(v[c+120>>2],v[c+124>>2],ao(h,0));Yp(v[c+56>>2],v[c+60>>2],ao(h,1));Yp(v[c+88>>2],v[c+92>>2],ao(h,2));Yp(v[c+24>>2],v[c+28>>2],ao(h,3));Yp(v[c+368>>2],v[c+372>>2],ao(h,4));qe(g);qe(l);qe(m);qe(e);Bm(i);qe(p);qe(c+384|0);jb=c+400|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;break d}a=P()|0;O()|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;qe(c+56|0)}qe(c+88|0)}qe(c+120|0)}Bm(i)}qe(c+368|0)}qe(c+384|0);T(a|0);L()}ey(a+131112|0,9.6377,.97);ey(a+196648|0,8.5,.5);ey(a+262184|0,2.7625,.425)}c=a+368680|0;if(!(t=0,x=hM(c,a),y=b,y?t:x)){e=a+24|0;r=A[a+8>>3];g=w[a+16|0];h=jb+-64|0;jb=h;m:while(1){if((n|0)!=8193){s=+(n-4096|0)*.0001220703125;b=0;o=0;while(1)if((b|0)==8){j=1/o;l=n<<3;b=0;while(1)if((b|0)==8){n=n+1|0;continue m}else{m=e+(b+l<<1)|0;d=H(A[h+(b<<3)>>3]*32768*j+.5);d=d<-32768?-32768:F(d,32768);n:{if(D(d)<2147483648){i=~~d;break n}i=-2147483648}u[m>>1]=i;b=b+1|0;continue}}else{j=r;f=1;d=+(b|0)-s;q=d+-3.5;if(!(D(q)<1e-8)){o:{p:{switch(g|0){case 0:f=$e(d*.8975979010256552)*-.5+.5;break o;case 1:f=$e(d*.8975979010256552)*-.46+.54;break o;case 2:f=$e(d*1.7951958020513104)*.08+($e(d*.8975979010256552)*-.5+.42);break o;case 3:f=$e(d*1.7951958020513104)*.05677+($e(d*.8975979010256552)*-.49364+.44959);break o;case 4:f=$e(d*1.7951958020513104)*.07922+($e(d*.8975979010256552)*-.49755+.42323);break o;case 5:f=$e(d*1.7951958020513104);k=$e(d*.8975979010256552);f=$e(d*2.6927937030769655)*-.01168+(f*.14128+(k*-.48829+.35875));break o;case 6:f=$e(d*1.7951958020513104);k=$e(d*.8975979010256552);f=$e(d*2.6927937030769655)*-.00183+(f*.09392+(k*-.49703+.40217));break o;case 7:break p;default:break o}}f=$e(d*1.7951958020513104);k=$e(d*.8975979010256552);f=$e(d*2.6927937030769655)*-.00122+(f*.09831+(k*-.49804+.40243))}d=q*3.141592653589793;j=Ci(d*j)/d}j=f*j;A[h+(b<<3)>>3]=j;o=o+j;b=b+1|0;continue}}break}jb=h- -64|0;b=v[a+20>>2];v[c+16>>2]=v[a+16>>2];v[c+20>>2]=b;b=v[a+12>>2];v[c+8>>2]=v[a+8>>2];v[c+12>>2]=b;b=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=b}}function iK(a,b,c,d){a=a|0;b=b|0;c=+c;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=jb-176|0;jb=e;A[e+168>>3]=c;f=v[b+4>>2];a:{if(!f){break a}g=v[b>>2];h=w[cl(g,f)|0];if((h|0)==33){d=1}else{if((h|0)!=63){break a}d=0}jl(e+144|0,g,f,f-1|0);f=v[e+148>>2];v[b>>2]=v[e+144>>2];v[b+4>>2]=f}f=e+144|0;Wd(f);g=v[e+144>>2];Wd(e+128|0);h=bl(g,v[e+132>>2],b);Wd(f);f=v[b+4>>2];g=v[b>>2];b:{c:{d:{e:{if((h|0)==v[e+148>>2]){a=qc(e+160|0,21619);h=v[a+4>>2];v[e+8>>2]=v[a>>2];v[e+12>>2]=h;if(Pc(g,f,e+8|0)){d=ba(8)|0;v[23588]=0;R(964,e+128|0,e+168|0);a=v[23588];v[23588]=0;f:{g:{h:{if((a|0)!=1){v[23588]=0;U(967,e+144|0,17598,e+128|0);a=v[23588];v[23588]=0;if((a|0)==1){break h}a=0;b=rc(d,e+144|0);v[23588]=0;U(119,b|0,62688,956);b=v[23588];v[23588]=0;if((b|0)!=1){break b}b=P()|0;O()|0;yb(e+144|0);break g}b=P()|0;O()|0;break f}b=P()|0;a=1;O()|0}yb(e+128|0);if(!a){break c}}ca(d|0);break c}if(!d){break e}d=ba(8)|0;a=v[b+4>>2];b=v[b>>2];v[23588]=0;f=Kh(e+96|0,b,a);a=v[23588];v[23588]=0;i:{j:{k:{l:{m:{n:{o:{p:{q:{if((a|0)!=1){v[23588]=0;U(967,e+112|0,17634,f|0);a=v[23588];v[23588]=0;if((a|0)==1){break q}v[23588]=0;R(969,e+128|0,e+112|0);b=v[23588];v[23588]=0;a=1;if((b|0)==1){break p}v[23588]=0;R(964,e+80|0,e+168|0);a=v[23588];v[23588]=0;if((a|0)==1){break o}v[23588]=0;U(971,e+144|0,e+128|0,e+80|0);b=v[23588];v[23588]=0;a=1;if((b|0)==1){break n}a=rc(d,e+144|0);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(e+144|0);a=0;break m}b=P()|0;O()|0;break i}b=P()|0;a=1;O()|0;break j}b=P()|0;O()|0;break k}b=P()|0;a=1;O()|0;break l}b=P()|0;O()|0}yb(e+80|0)}yb(e+128|0)}yb(e+112|0)}yb(f);if(!a){break c}}ca(d|0);break c}b=qc(e+72|0,21619);d=v[b+4>>2];v[e+40>>2]=v[b>>2];v[e+44>>2]=d;if(Pc(g,f,e+40|0)){d=ba(8)|0;v[23588]=0;R(964,e+128|0,e+168|0);a=v[23588];v[23588]=0;r:{s:{t:{if((a|0)!=1){v[23588]=0;U(967,e+144|0,17598,e+128|0);a=v[23588];v[23588]=0;if((a|0)==1){break t}a=0;b=rc(d,e+144|0);v[23588]=0;U(119,b|0,62688,956);b=v[23588];v[23588]=0;if((b|0)!=1){break b}b=P()|0;O()|0;yb(e+144|0);break s}b=P()|0;O()|0;break r}b=P()|0;a=1;O()|0}yb(e+128|0);if(!a){break c}}ca(d|0);break c}b=qc(e- -64|0,7719);d=v[b+4>>2];v[e+32>>2]=v[b>>2];v[e+36>>2]=d;if(Pc(g,f,e+32|0)){if(!Pd(w[a+28|0])){break e}if(c<=0|c>4){a=ba(8)|0;v[23588]=0;d=Q(55,e+144|0,7814)|0;b=v[23588];v[23588]=0;if((b|0)==1){break d}a=rc(a,d);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(d);break c}a=v[a+24>>2];i=a,j=Pe(65536/c),v[i+480244>>2]=j;Mp(a);break e}b=qc(e+56|0,7771);d=v[b+4>>2];v[e+24>>2]=v[b>>2];v[e+28>>2]=d;if(Pc(g,f,e+24|0)){if(!Pd(w[a+28|0])){break e}if(c<=0|c>4){a=ba(8)|0;v[23588]=0;d=Q(55,e+144|0,7835)|0;b=v[23588];v[23588]=0;if((b|0)!=1){a=rc(a,d);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(d);break c}b=P()|0;O()|0;ca(a|0);break c}a=v[a+24>>2];i=a,j=Pe(c*65536),v[i+480240>>2]=j;Mp(a);break e}b=qc(e+48|0,7789);d=v[b+4>>2];v[e+16>>2]=v[b>>2];v[e+20>>2]=d;if(!Pc(g,f,e+16|0)){break e}i=v[a+24>>2],j=yl(c*65536),v[i+480236>>2]=j}jb=e+176|0;return}b=P()|0;O()|0;ca(a|0)}T(b|0)}L()}function _ha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;f=jb-240|0;jb=f;me(f+224|0,b);g=jb-48|0;jb=g;v[g+44>>2]=0;ok(b,g+44|0);a:{b:{c:{if(v[g+44>>2]!=(Tm(14058)|0)){break c}v[g+40>>2]=0;e=jb-32|0;jb=e;v[e+24>>2]=0;Vv(e+8|0,e+24|0);vn(e+16|0,b,v[e+8>>2],v[e+12>>2]);_l(g+40|0,v[e+24>>2]);jb=e+32|0;e=-1;i=v[g+40>>2];if(i-3>>>0<4294967294){break c}d:{e:{f:{if(i>>>0<=1){i=Lb(g+24|0);v[23588]=0;h=W(483,b|0,i|0,256)|0;j=v[23588];v[23588]=0;if((j|0)==1){break b}if(!h){break e}v[23588]=0;U(11,g+8|0,d|0,i|0);h=v[23588];v[23588]=0;if((h|0)!=1){break f}break b}i=Lb(g+24|0);v[23588]=0;h=Q(485,b|0,i|0)|0;j=v[23588];v[23588]=0;if((j|0)==1){break b}if(!h){break d}v[23588]=0;U(11,g+8|0,d|0,i|0);h=v[23588];v[23588]=0;if((h|0)==1){break b}}h=g+8|0;Ib(c,h);zb(h);yb(i);Vf(b,h);i=0;v[g+24>>2]=0;ok(b,g+24|0);h=v[g+24>>2];if(h>>>0>50){break c}g:{while(1){if((h|0)==(i|0)){break g}i=i+1|0;if(BL(a,b,d)){continue}break}break c}v[g+24>>2]=0;ok(b,g+24|0);e=v[g+24>>2]==(Tm(14104)|0)?1:-1;break c}yb(i);break c}yb(i)}jb=g+48|0;break a}a=P()|0;O()|0;yb(i);T(a|0);L()}h:{if(e){break h}Sl(v[v[b>>2]-12>>2]+b|0,0);e=v[f+236>>2];v[f+16>>2]=v[f+232>>2];v[f+20>>2]=e;e=v[f+228>>2];v[f+8>>2]=v[f+224>>2];v[f+12>>2]=e;b=Zl(f+112|0,Xj(b,f+8|0));v[23588]=0;e=Q(449,f+96|0,14243)|0;g=v[23588];v[23588]=0;i:{if((g|0)!=1){v[23588]=0;v[f+80>>2]=3;v[f+84>>2]=0;U(450,b|0,e|0,f+80|0);g=v[23588];v[23588]=0;if((g|0)!=1){_b(e);t[f+95|0]=0;v[23588]=0;e=Q(449,f+80|0,14706)|0;g=v[23588];v[23588]=0;if((g|0)!=1){v[23588]=0;U(451,b|0,f+95|0,e|0);g=v[23588];v[23588]=0;if((g|0)!=1){_b(e);v[23588]=0;g=w[f+95|0];e=S(464,b|0)|0;i=v[23588];v[23588]=0;if((i|0)!=1){v[23588]=0;i=S(465,b|0)|0;h=v[23588];v[23588]=0;if((h|0)!=1){g=g?0:d;v[f+72>>2]=e;j:{k:{l:{m:{while(1){if(!Ob(e,i)){a=Kk(w[b|0]);kh(b);e=a?-1:1;break h}v[23588]=0;d=Q(449,f+56|0,15771)|0;e=v[23588];v[23588]=0;if((e|0)==1){break l}e=v[b+44>>2];h=v[b+40>>2];v[23588]=0;e=fa(466,h|0,e|0,v[f+72>>2],d|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break k}_b(d);n:{o:{if(e){v[23588]=0;X(467,b|0,f+72|0,c|0,g|0);d=v[23588];v[23588]=0;if((d|0)!=1){break o}break j}v[23588]=0;d=Q(449,f+40|0,15441)|0;e=v[23588];v[23588]=0;p:{q:{if((e|0)!=1){e=v[b+44>>2];h=v[b+40>>2];v[23588]=0;e=fa(466,h|0,e|0,v[f+72>>2],d|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break q}_b(d);if(!e){break p}v[23588]=0;U(468,b|0,f+72|0,f+70|0);d=v[23588];v[23588]=0;if((d|0)==1){break j}break o}a=P()|0;O()|0;break i}a=P()|0;O()|0;_b(d);break i}v[23588]=0;d=Q(449,f+24|0,15334)|0;e=v[23588];v[23588]=0;if((e|0)==1){break n}e=v[b+44>>2];h=v[b+40>>2];v[23588]=0;e=fa(466,h|0,e|0,v[f+72>>2],d|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break m}_b(d);if(!e){break o}v[23588]=0;X(469,b|0,f+72|0,a|0,g|0);d=v[23588];v[23588]=0;if((d|0)==1){break j}}Ux(f+72|0);e=v[f+72>>2];continue}break}a=P()|0;O()|0;break i}a=P()|0;O()|0;_b(d);break i}a=P()|0;O()|0;break i}a=P()|0;O()|0;_b(d);break i}a=P()|0;O()|0;break i}a=P()|0;O()|0;break i}a=P()|0;O()|0;break i}a=P()|0;O()|0;_b(e);break i}a=P()|0;O()|0;break i}a=P()|0;O()|0;_b(e);break i}a=P()|0;O()|0}kh(b);T(a|0);L()}jb=f+240|0;return e|0}function mia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=jb-400|0;jb=e;g=jb-32|0;jb=g;d=g+8|0;MA(d,b);Tu(g,d);v[23588]=0;U(463,e+240|0,v[g>>2],v[g+4>>2]);b=v[23588];v[23588]=0;a:{if((b|0)!=1){Tc(g+8|0);jb=g+32|0;break a}a=P()|0;O()|0;Tc(g+8|0);T(a|0);L()}v[23588]=0;U(446,e+128|0,v[e+240>>2],v[e+244>>2]);b=v[23588];v[23588]=0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{if((b|0)!=1){v[23588]=0;g=Q(89,e+256|0,e+128|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break z}yb(e+128|0);hc(e+240|0);if(c>>>0<2189){break g}b=Zl(e+128|0,g);v[23588]=0;c=Q(449,e+112|0,10074)|0;d=v[23588];v[23588]=0;if((d|0)==1){break x}v[23588]=0;v[e+96>>2]=19988498;v[e+100>>2]=0;U(450,b|0,c|0,e+96|0);d=v[23588];v[23588]=0;if((d|0)==1){break w}_b(c);t[e+111|0]=0;v[23588]=0;c=Q(449,e+96|0,10968)|0;d=v[23588];v[23588]=0;if((d|0)==1){break i}v[23588]=0;U(451,b|0,e+111|0,c|0);d=v[23588];v[23588]=0;if((d|0)==1){break v}_b(c);c=0;c=w[e+111|0]?c:v[a+1298404>>2];f=v[a+4>>2];v[23588]=0;d=Q(449,e+80|0,15771)|0;h=v[23588];v[23588]=0;if((h|0)==1){break u}v[23588]=0;X(452,b|0,f|0,d|0,c|0);f=v[23588];v[23588]=0;if((f|0)==1){break t}_b(d);v[23588]=0;d=Q(449,e- -64|0,15441)|0;f=v[23588];v[23588]=0;if((f|0)==1){break s}v[23588]=0;X(453,b|0,a|0,d|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break r}_b(d);v[23588]=0;c=Q(449,e+48|0,15334)|0;d=v[23588];v[23588]=0;if((d|0)==1){break q}v[23588]=0;d=a+484360|0;U(454,b|0,d|0,c|0);f=v[23588];v[23588]=0;if((f|0)==1){break p}_b(c);v[23588]=0;c=Q(449,e+32|0,26646)|0;f=v[23588];v[23588]=0;if((f|0)==1){break o}v[23588]=0;U(455,b|0,a+484344|0,c|0);f=v[23588];v[23588]=0;if((f|0)==1){break n}_b(c);f=v[a+1298404>>2];v[23588]=0;c=Q(449,e+16|0,26652)|0;h=v[23588];v[23588]=0;if((h|0)==1){break m}v[23588]=0;X(456,b|0,d|0,c|0,f|0);d=v[23588];v[23588]=0;if((d|0)==1){break l}_b(c);if(Kk(w[b|0])){v[23588]=0;c=Q(1,e|0,16250)|0;d=v[23588];v[23588]=0;if((d|0)==1){break k}a=v[a+1298464>>2];v[23588]=0;U(376,a|0,1,c|0);a=v[23588];v[23588]=0;if((a|0)==1){break j}zb(c)}kh(b);break f}a=P()|0;O()|0;break y}a=P()|0;O()|0;yb(e+128|0)}hc(e+240|0);break b}a=P()|0;O()|0;break h}a=P()|0;O()|0;_b(c);break h}a=P()|0;O()|0;_b(c);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;_b(d);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;_b(d);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;_b(c);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;_b(c);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;_b(c);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;zb(c);break h}a=P()|0;O()|0}kh(b);break c}b=Lb(e+128|0);d=v[a+1298404>>2];f=v[a+4>>2];v[23588]=0;d=fa(457,f|0,g|0,b|0,d|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break e}A:{if((d|0)!=1){v[23588]=0;c=Q(1,e+112|0,16556)|0;d=v[23588];v[23588]=0;B:{if((d|0)!=1){a=v[a+1298464>>2];v[23588]=0;U(376,a|0,1,c|0);a=v[23588];v[23588]=0;if((a|0)==1){break B}zb(c);break A}a=P()|0;O()|0;break d}a=P()|0;O()|0;zb(c);break d}d=v[a+1298404>>2];v[23588]=0;X(458,g|0,a|0,d|0,c>>>0<2188|0);a=v[23588];v[23588]=0;if((a|0)==1){break e}}zb(b)}rf(g);jb=e+400|0;return}a=P()|0;O()|0}zb(b)}rf(g)}T(a|0);L()}function Mb(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{if(!a){break a}d=a-8|0;b=v[a-4>>2];a=b&-8;f=d+a|0;b:{if(b&1){break b}if(!(b&3)){break a}b=v[d>>2];d=d-b|0;if(d>>>0<y[116100]){break a}a=a+b|0;if(v[116101]!=(d|0)){if(b>>>0<=255){e=v[d+8>>2];b=b>>>3|0;c=v[d+12>>2];if((c|0)==(e|0)){i=464384,j=v[116096]&Pka(-2,b),v[i>>2]=j;break b}v[e+12>>2]=c;v[c+8>>2]=e;break b}h=v[d+24>>2];b=v[d+12>>2];c:{if((d|0)!=(b|0)){c=v[d+8>>2];v[c+12>>2]=b;v[b+8>>2]=c;break c}d:{e=d+20|0;c=v[e>>2];if(c){break d}e=d+16|0;c=v[e>>2];if(c){break d}b=0;break c}while(1){g=e;b=c;e=b+20|0;c=v[e>>2];if(c){continue}e=b+16|0;c=v[b+16>>2];if(c){continue}break}v[g>>2]=0}if(!h){break b}e=v[d+28>>2];c=(e<<2)+464688|0;e:{if(v[c>>2]==(d|0)){v[c>>2]=b;if(b){break e}i=464388,j=v[116097]&Pka(-2,e),v[i>>2]=j;break b}v[h+(v[h+16>>2]==(d|0)?16:20)>>2]=b;if(!b){break b}}v[b+24>>2]=h;c=v[d+16>>2];if(c){v[b+16>>2]=c;v[c+24>>2]=b}c=v[d+20>>2];if(!c){break b}v[b+20>>2]=c;v[c+24>>2]=b;break b}b=v[f+4>>2];if((b&3)!=3){break b}v[116098]=a;v[f+4>>2]=b&-2;v[d+4>>2]=a|1;v[a+d>>2]=a;return}if(d>>>0>=f>>>0){break a}b=v[f+4>>2];if(!(b&1)){break a}f:{if(!(b&2)){if(v[116102]==(f|0)){v[116102]=d;a=v[116099]+a|0;v[116099]=a;v[d+4>>2]=a|1;if(v[116101]!=(d|0)){break a}v[116098]=0;v[116101]=0;return}if(v[116101]==(f|0)){v[116101]=d;a=v[116098]+a|0;v[116098]=a;v[d+4>>2]=a|1;v[a+d>>2]=a;return}a=(b&-8)+a|0;g:{if(b>>>0<=255){e=v[f+8>>2];b=b>>>3|0;c=v[f+12>>2];if((c|0)==(e|0)){i=464384,j=v[116096]&Pka(-2,b),v[i>>2]=j;break g}v[e+12>>2]=c;v[c+8>>2]=e;break g}h=v[f+24>>2];b=v[f+12>>2];h:{if((f|0)!=(b|0)){c=v[f+8>>2];v[c+12>>2]=b;v[b+8>>2]=c;break h}i:{e=f+20|0;c=v[e>>2];if(c){break i}e=f+16|0;c=v[e>>2];if(c){break i}b=0;break h}while(1){g=e;b=c;e=b+20|0;c=v[e>>2];if(c){continue}e=b+16|0;c=v[b+16>>2];if(c){continue}break}v[g>>2]=0}if(!h){break g}e=v[f+28>>2];c=(e<<2)+464688|0;j:{if(v[c>>2]==(f|0)){v[c>>2]=b;if(b){break j}i=464388,j=v[116097]&Pka(-2,e),v[i>>2]=j;break g}v[h+(v[h+16>>2]==(f|0)?16:20)>>2]=b;if(!b){break g}}v[b+24>>2]=h;c=v[f+16>>2];if(c){v[b+16>>2]=c;v[c+24>>2]=b}c=v[f+20>>2];if(!c){break g}v[b+20>>2]=c;v[c+24>>2]=b}v[d+4>>2]=a|1;v[a+d>>2]=a;if(v[116101]!=(d|0)){break f}v[116098]=a;return}v[f+4>>2]=b&-2;v[d+4>>2]=a|1;v[a+d>>2]=a}if(a>>>0<=255){b=(a&-8)+464424|0;c=v[116096];a=1<<(a>>>3);k:{if(!(c&a)){v[116096]=a|c;a=b;break k}a=v[b+8>>2]}v[b+8>>2]=d;v[a+12>>2]=d;v[d+12>>2]=b;v[d+8>>2]=a;return}e=31;if(a>>>0<=16777215){b=a>>>8|0;g=b+1048320>>>16&8;b=b<<g;e=b+520192>>>16&4;b=b<<e;c=b+245760>>>16&2;b=(b<<c>>>15|0)-(c|(e|g))|0;e=(b<<1|a>>>b+21&1)+28|0}v[d+28>>2]=e;v[d+16>>2]=0;v[d+20>>2]=0;g=(e<<2)+464688|0;l:{m:{c=v[116097];b=1<<e;n:{if(!(c&b)){v[116097]=b|c;v[g>>2]=d;v[d+24>>2]=g;break n}e=a<<((e|0)==31?0:25-(e>>>1|0)|0);b=v[g>>2];while(1){c=b;if((v[b+4>>2]&-8)==(a|0)){break m}b=e>>>29|0;e=e<<1;g=c+(b&4)|0;b=v[g+16>>2];if(b){continue}break}v[g+16>>2]=d;v[d+24>>2]=c}v[d+12>>2]=d;v[d+8>>2]=d;break l}a=v[c+8>>2];v[a+12>>2]=d;v[c+8>>2]=d;v[d+24>>2]=0;v[d+12>>2]=c;v[d+8>>2]=a}a=v[116104]-1|0;v[116104]=a?a:-1}}function ZI(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;g=jb-48|0;jb=g;a:{b:{if(ss(c)){h=v[b+484344>>2];if(xe(h,v[b+484348>>2],c&65535)){break b}}c=a;a=Lb(g+32|0);b=Lb(g+16|0);ni(c,a,b);yb(b);yb(a);break a}c=Yb(h,c);if(!(v[c+12>>2]>(d|0)&(d|0)>=0)){c=a;a=Lb(g+32|0);b=Lb(g+16|0);ni(c,a,b);yb(b);yb(a);break a}if(!(x[b+480188>>1]>e>>>0&(e|0)>=0)){c=a;a=Lb(g+32|0);b=Lb(g+16|0);ni(c,a,b);yb(b);yb(a);break a}if(f>>>0>=6){c=a;a=Lb(g+32|0);b=Lb(g+16|0);ni(c,a,b);yb(b);yb(a);break a}c=id(v[c>>2],v[v[c+48>>2]+12>>2],d,e&65535);c:{d:{e:{f:{switch(f|0){case 0:g:{h:{i:{j:{k:{d=w[c|0];if(!_c(d)){if(!Kp(d)){break k}}e=g+16|0;xM(e,b,d,w[c+1|0]);v[23588]=0;R(1015,g+32|0,e|0);b=v[23588];v[23588]=0;d=1;if((b|0)!=1){break j}c=P()|0;O()|0;break g}d=0;v[23588]=0;Q(55,g+32|0,16730)|0;b=v[23588];v[23588]=0;if((b|0)==1){break i}}b=9918;c=w[c|0];if(!_c(c)){b=Kp(c)?10228:16730}v[23588]=0;b=Q(55,g|0,b|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break h}c=a;a=g+32|0;ni(c,a,b);yb(b);yb(a);if(!d){break a}zb(g+16|0);break a}c=P()|0;O()|0;break d}c=P()|0;O()|0;yb(g+32|0);if(!d){break d}}zb(g+16|0);break d;case 1:b=c+1|0;l:{if(w[c+1|0]){_t(g+32|0,b);break l}Mc(g+32|0,16735)}b=w[b|0];v[23588]=0;b=Q(55,g+16|0,(b?10722:16735)|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break e}c=a;a=g+32|0;ni(c,a,b);yb(b);yb(a);break a;case 2:m:{if(fh(w[c|0])){Mc(g+32|0,17790);break m}d=w[c+2|0];if(d){of(g+32|0,1,ZL(v[v[b+8>>2]+88>>2],d));break m}Mc(g+32|0,17790)}b=17790;if(!fh(w[c|0])){b=w[c+2|0]?5508:17790}v[23588]=0;b=Q(55,g+16|0,b|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){c=a;a=g+32|0;ni(c,a,b);yb(b);yb(a);break a}c=P()|0;O()|0;yb(g+32|0);break d;case 4:n:{if(fh(w[c|0])){i=g,j=gk(w[c+2|0],w[c+4|0])&255,v[i>>2]=j;sA(g+32|0,g);break n}if(w[c+2|0]){_t(g+32|0,c+4|0);break n}Mc(g+32|0,16735)}b=5492;if(!fh(w[c|0])){b=w[c+2|0]?5492:16735}v[23588]=0;b=Q(55,g+16|0,b|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){c=a;a=g+32|0;ni(c,a,b);yb(b);yb(a);break a}c=P()|0;O()|0;yb(g+32|0);break d;case 3:o:{if(fh(w[c|0])){i=g,j=(gk(w[c+3|0],w[c+5|0])&3840)!=0,t[i|0]=j;b=jb-32|0;jb=b;v[b+8>>2]=-1;v[b+12>>2]=0;v[b>>2]=0;Lb(b+16|0);v[23588]=0;v[b>>2]=v[b>>2]&-1332|1058;v[b+4>>2]=1;U(1084,g+32|0,g|0,b|0);d=v[23588];v[23588]=0;p:{if((d|0)!=1){jm(b);jb=b+32|0;break p}a=P()|0;O()|0;jm(b);T(a|0);L()}break o}d=w[c+3|0];if(d){of(g+32|0,1,YL(v[v[b+8>>2]+84>>2],d));break o}Mc(g+32|0,16736)}b=12227;if(!fh(w[c|0])){b=w[c+3|0]?12227:16736}v[23588]=0;b=Q(55,g+16|0,b|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){c=a;a=g+32|0;ni(c,a,b);yb(b);yb(a);break a}c=P()|0;O()|0;yb(g+32|0);break d;case 5:break f;default:break c}}q:{if(fh(w[c|0])){i=g,j=gk(w[c+3|0],w[c+5|0])&255,v[i>>2]=j;sA(g+32|0,g);break q}if(w[c+3|0]){_t(g+32|0,c+5|0);break q}Mc(g+32|0,16735)}b=11087;if(!fh(w[c|0])){b=w[c+3|0]?11087:16735}v[23588]=0;b=Q(55,g+16|0,b|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){c=a;a=g+32|0;ni(c,a,b);yb(b);yb(a);break a}c=P()|0;O()|0;yb(g+32|0);break d}c=P()|0;O()|0;yb(g+32|0)}T(c|0);L()}c=a;a=Lb(g+32|0);b=Lb(g+16|0);ni(c,a,b);yb(b);yb(a)}jb=g+48|0}function Fg(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;j=jb-112|0;jb=j;k=i&2147483647;l=e&2147483647;m=l;a:{b:{p=!(b|c);if(!(d|l?l-2147418112>>>0<2147549184:p)){n=k-2147418112|0;if(!h&(n|0)==-2147418112?f|g:(n|0)==-2147418112&(h|0)!=0|n>>>0>2147549184){break b}}if(!(!d&(m|0)==2147418112?p:m>>>0<2147418112)){h=d;i=e|32768;f=b;g=c;break a}if(!(!h&(k|0)==2147418112?!(f|g):k>>>0<2147418112)){i=i|32768;break a}if(!(b|d|(m^2147418112|c))){m=d;d=!(b^f|d^h|(c^g|e^i^-2147483648));h=d?0:m;i=d?2147450880:e;f=d?0:b;g=d?0:c;break a}if(!(f|h|(k^2147418112|g))){break a}if(!(b|d|(c|m))){if(f|h|(g|k)){break a}f=b&f;g=c&g;h=d&h;i=e&i;break a}if(f|h|(g|k)){break b}f=b;g=c;h=d;i=e;break a}l=(k|0)==(m|0);k=l&(d|0)==(h|0)?(c|0)==(g|0)&b>>>0<f>>>0|c>>>0<g>>>0:l&d>>>0<h>>>0|k>>>0>m>>>0;o=k?f:b;l=k?g:c;m=k?i:e;r=m;q=k?h:d;n=m&65535;e=k?e:i;s=e;h=k?d:h;m=e>>>16&32767;p=r>>>16&32767;if(!p){d=!(n|q);e=d<<6;i=E(d?o:q)+32|0;d=E(d?l:n);d=e+((d|0)==32?i:d)|0;Kf(j+96|0,o,l,q,n,d-15|0);q=v[j+104>>2];n=v[j+108>>2];o=v[j+96>>2];p=16-d|0;l=v[j+100>>2]}f=k?b:f;g=k?c:g;i=s&65535;if(!m){b=!(h|i);c=b<<6;d=E(b?f:h)+32|0;b=E(b?g:i);b=c+((b|0)==32?d:b)|0;Kf(j+80|0,f,g,h,i,b-15|0);m=16-b|0;h=v[j+88>>2];i=v[j+92>>2];g=v[j+84>>2];f=v[j+80>>2]}b=h;k=i<<3|b>>>29;d=b<<3|g>>>29;e=k|524288;b=q;c=n<<3|b>>>29;h=b<<3|l>>>29;i=c;b=f;c=g<<3|b>>>29;b=b<<3;g=r^s;c:{if((m|0)==(p|0)){break c}f=p-m|0;if(f>>>0>127){d=0;e=0;b=1;c=0;break c}Kf(j- -64|0,b,c,d,e,128-f|0);Em(j+48|0,b,c,d,e,f);b=v[j+48>>2]|(v[j+64>>2]|v[j+72>>2]|(v[j+68>>2]|v[j+76>>2]))!=0;c=v[j+52>>2];d=v[j+56>>2];e=v[j+60>>2]}m=h;q=i|524288;f=o;k=l<<3|f>>>29;n=f<<3;d:{if((g|0)<0){f=0;g=0;h=0;i=0;if(!(b^n|d^m|(c^k|e^q))){break a}o=n-b|0;l=k-((b>>>0>n>>>0)+c|0)|0;f=m-d|0;b=(c|0)==(k|0)&b>>>0>n>>>0|c>>>0>k>>>0;i=(q-((d>>>0>m>>>0)+e|0)|0)-(f>>>0<b>>>0)|0;h=f-b|0;if(i>>>0>524287){break d}b=!(h|i);c=b<<6;d=E(b?o:h)+32|0;b=E(b?l:i);b=c+((b|0)==32?d:b)|0;b=b-12|0;Kf(j+32|0,o,l,h,i,b);p=p-b|0;h=v[j+40>>2];i=v[j+44>>2];o=v[j+32>>2];l=v[j+36>>2];break d}k=c+k|0;f=b+n|0;k=f>>>0<n>>>0?k+1|0:k;o=f;l=k;f=(c|0)==(k|0)&b>>>0>f>>>0|c>>>0>k>>>0;c=e+q|0;b=d+m|0;c=b>>>0<m>>>0?c+1|0:c;d=b;b=f+b|0;h=b;i=b>>>0<d>>>0?c+1|0:c;if(!(i&1048576)){break d}o=o&1|((l&1)<<31|o>>>1);c=h;l=c<<31|l>>>1;p=p+1|0;h=(i&1)<<31|c>>>1;i=i>>>1|0}d=0;e=r&-2147483648;if((p|0)>=32767){h=d;i=e|2147418112;f=0;g=0;break a}m=0;e:{if((p|0)>0){m=p;break e}Kf(j+16|0,o,l,h,i,p+127|0);Em(j,o,l,h,i,1-p|0);o=v[j>>2]|(v[j+16>>2]|v[j+24>>2]|(v[j+20>>2]|v[j+28>>2]))!=0;l=v[j+4>>2];h=v[j+8>>2];i=v[j+12>>2]}c=h<<29;b=l>>>3|0;n=(l&7)<<29|o>>>3;l=o&7;g=l>>>0>4;f=n+g|0;b=b|c;k=f>>>0<g>>>0?b+1|0:b;c=f;g=k;b=(b|0)==(k|0)&c>>>0<n>>>0|b>>>0>k>>>0;c=d|((i&7)<<29|h>>>3);b=b+c|0;i=e|(i>>>3&65535|m<<16);i=b>>>0<c>>>0?i+1|0:i;h=b;f:{if((l|0)==4){c=g+0|0;e=f&1;b=f+e|0;c=b>>>0<f>>>0?c+1|0:c;f=b;g=c;c=(d|0)==(c|0)&b>>>0<e>>>0|c>>>0<d>>>0;b=c+h|0;i=b>>>0<c>>>0?i+1|0:i;h=b;break f}if(!l){break a}}}v[a>>2]=f;v[a+4>>2]=g;v[a+8>>2]=h;v[a+12>>2]=i;jb=j+112|0}function Wea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0;h=jb-4144|0;jb=h;g=Hb(w[a+14|0]|w[a+15|0]<<8);a:{if(!g|g>>>0>20){break a}j=b+480190|0;if(x[j>>1]<=w[a+23|0]){break a}md(d,32);u[d+34>>1]=1;f=h+24|0;g=a+20|0;v[f>>2]=g;v[f+4>>2]=(g+80|0)-g>>2;uQ(h+4136|0,v[h+24>>2],v[h+28>>2],Hb(w[a+14|0]|w[a+15|0]<<8));g=v[h+4136>>2];k=w[Db(g,0)+3|0];v[h+24>>2]=1;k=v[Yc(Gi(b,k+1|0)+24|0,f)>>2];i=f;f=v[h+4140>>2];uQ(i,g,f,c?f:1);q=1/+(k>>>0);f=v[h+24>>2];g=Db(f,v[h+28>>2]);k=v[h+4136>>2];j=x[j>>1];while(1){if((f|0)==(g|0)){b:{r=Ng(d);if(!r){break b}g=v[h+4140>>2];k=h+4120|0;v[k>>2]=0;v[k+4>>2]=0;Gc(k+8|0);if(g){f=jb-16|0;jb=f;v[f+12>>2]=4925421;v[f+8>>2]=2147483647;j=v[Jb(f+12|0,f+8|0)>>2];jb=f+16|0;if(g>>>0>j>>>0){bd();L()}if(g>>>0>=4925422){Lg();L()}g=B(g,872);f=sc(g);v[k>>2]=f;v[k+4>>2]=f;C=Fb(k),D=f+g|0,v[C>>2]=D;f=jb-16|0;jb=f;v[f>>2]=k;j=v[k+4>>2];v[f+4>>2]=j;v[f+8>>2]=g+j;i=v[f+4>>2];g=v[f+8>>2];while(1){if((g|0)==(i|0)){kc(f);jb=f+16|0}else{iQ(Tb(i,0,872));i=i+872|0;v[f+4>>2]=i;continue}break}}j=(e<<12>>>0)/1e4|0;s=v[k>>2];n=v[h+4136>>2];z=v[h+4140>>2];A=b+480190|0;f=0;i=0;while(1){if((f|0)==(z|0)){g=b+24648|0}else{g=Db(n,f);e=tQ(s,f);l=w[g+3|0];c:{if(l>>>0>=x[A>>1]){break c}o=t[g+1|0];if((o|0)<0){break c}m=0;g=w[g+2|0];if((g+14&255)>>>0<=5){m=t[g+26798|0]}g=Gi(b,l+1|0);l=v[g+24>>2];p=q*(mi(+(m<<24>>24)/96+ +(o-t[Db(n,0)+1|0]|0)/12)*+(l>>>0));if(p<=0){break c}m=sQ(p);v[e+8>>2]=m;l=mb;v[e+12>>2]=l;v[e+16>>2]=v[g+20>>2];o=v[g>>2];v[e+76>>2]=o;v[e+88>>2]=x[g+34>>1]&1023;d:{if(c){v[e+664>>2]=i;i=Pe(+(o>>>0)/Rz(m,l))+i|0;g=j;break d}g=(j>>>0)/(Hb(w[a+14|0]|w[a+15|0]<<8)>>>0)|0}v[e+20>>2]=g;v[e+24>>2]=g}f=f+1|0;continue}break}b=0;while(1){e:{a=v[d>>2];if(a>>>0>b>>>0){Tb(h+24|0,0,4096);v[h+16>>2]=512;v[h+12>>2]=a-b;c=v[Jb(h+16|0,h+12|0)>>2];C=h,D=Eb(v[k>>2]),v[C+16>>2]=D;j=Eb(v[k+4>>2]);while(1){a=v[h+16>>2];if(!Ob(a,j)){break e}f:{g:{if(!v[a+16>>2]){break g}e=v[a+664>>2];if(e>>>0>=c>>>0){v[a+664>>2]=e-c;break g}f=v[a+88>>2];v[h+12>>2]=c-e;C=h,D=Pe((+y[a+76>>2]-Rz(v[a>>2],v[a+4>>2]))/Rz(v[a+8>>2],v[a+12>>2])),v[C+8>>2]=D;i=v[Jb(h+12|0,h+8|0)>>2];v[23588]=0;X(v[((f&1|(f&64?18:16))<<2)+27392>>2],a|0,g|0,(h+24|0)+(e<<3)|0,i|0);e=v[23588];v[23588]=0;if((e|0)==1){break f}v[a+664>>2]=0;if(y[a+76>>2]>y[a+4>>2]){break g}v[a+16>>2]=0}v[h+16>>2]=v[h+16>>2]+872;continue}break}a=P()|0;O()|0;Qt(k);T(a|0);L()}Qt(k);break b}e=v[d+20>>2]+(b<<1)|0;f=h+24|0;a=jb-16|0;jb=a;v[a+12>>2]=c;wc(a+12|0,512);i=v[a+12>>2];while(1){if(i){j=kd(v[f>>2]+2048|0,12);j=(j|0)<32767?j:32767;u[e>>1]=(j|0)>-32768?j:-32768;f=f+8|0;e=e+2|0;i=i-1|0;continue}break}jb=a+16|0;b=b+c|0;continue}}f=(r|0)!=0}else{i=w[f+3|0];h:{if(i>>>0>=j>>>0){break h}n=t[f+1|0];if((n|0)<0){break h}i=Gi(b,i+1|0);m=v[i>>2];p=mi(+(n-t[Db(k,0)+1|0]|0)/-12);C=d,D=v[d>>2]+Pe(q*(p*+(m>>>0)*+y[i+24>>2]))|0,v[C>>2]=D}f=f+4|0;continue}break}}jb=h+4144|0;return f|0}function u6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=jb-128|0;jb=e;a:{if(Qe(b)){break a}f=w[PJ(b)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}f=e+112|0;Qv(f,b,0,Gb(b)-1|0);Ac(b,f);yb(f)}g=e+112|0;Wd(g);f=v[e+112>>2];Wd(e+96|0);f=OJ(f,v[e+100>>2],b);Wd(g);b:{c:{d:{e:{if((f|0)==v[e+116>>2]){if(ue(b,21619)){a=ba(8)|0;v[23588]=0;U(958,e+112|0,17598,c|0);b=v[23588];v[23588]=0;if((b|0)==1){break d}a=rc(a,e+112|0);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(e+112|0);break c}if(!d){break e}a=ba(8)|0;v[23588]=0;U(958,e+80|0,17634,b|0);b=v[23588];v[23588]=0;f:{g:{h:{i:{j:{if((b|0)!=1){v[23588]=0;R(969,e+96|0,e+80|0);b=v[23588];v[23588]=0;if((b|0)==1){break j}v[23588]=0;U(529,e+112|0,e+96|0,c|0);b=v[23588];v[23588]=0;d=1;if((b|0)==1){break i}b=rc(a,e+112|0);v[23588]=0;U(119,b|0,62688,956);b=v[23588];v[23588]=0;if((b|0)!=1){break b}b=P()|0;O()|0;yb(e+112|0);d=0;break h}b=P()|0;O()|0;break f}b=P()|0;d=1;O()|0;break g}b=P()|0;O()|0}yb(e+96|0)}yb(e+80|0);if(!d){break c}}ca(a|0);break c}k:{switch(v[f+4>>2]){case 0:Fe(e+72|0,b);b=jb-192|0;jb=b;f=b+16|0;oi(f,c);v[23588]=0;R(88,b+32|0,f|0);c=v[23588];v[23588]=0;l:{m:{n:{o:{p:{if((c|0)!=1){v[23588]=0;c=Q(89,b+48|0,b+32|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break p}yb(b+32|0);yb(b+16|0);f=v[v[c>>2]-12>>2];v[23588]=0;g=ga(62)|0;h=v[23588];v[23588]=0;if((h|0)==1){break n}v[23588]=0;U(63,b+8|0,c+f|0,g|0);f=v[23588];v[23588]=0;if((f|0)==1){break n}$b(b+8|0);v[23588]=0;f=Q(1066,c|0,b+32|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break n}c=Zk(v[(f+v[v[f>>2]-12>>2]|0)+16>>2]);g=w[b+32|0];rf(f);jb=b+192|0;b=(c^-1)&(g|0)!=0;break l}a=P()|0;O()|0;break o}a=P()|0;O()|0;yb(b+32|0)}yb(b+16|0);break m}a=P()|0;O()|0;rf(c)}T(a|0);L()}c=v[e+76>>2];v[e+8>>2]=v[e+72>>2];v[e+12>>2]=c;kK(a,e+8|0,b,d);break e;case 1:Fe(e- -64|0,b);b=jb-192|0;jb=b;f=b+16|0;oi(f,c);v[23588]=0;R(88,b+32|0,f|0);c=v[23588];v[23588]=0;q:{r:{s:{t:{u:{if((c|0)!=1){v[23588]=0;c=Q(89,b+48|0,b+32|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break u}yb(b+32|0);yb(b+16|0);f=v[v[c>>2]-12>>2];v[23588]=0;g=ga(62)|0;h=v[23588];v[23588]=0;if((h|0)==1){break s}v[23588]=0;U(63,b+8|0,c+f|0,g|0);f=v[23588];v[23588]=0;if((f|0)==1){break s}$b(b+8|0);v[23588]=0;f=Q(96,c|0,b+32|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break s}c=Zk(v[(f+v[v[f>>2]-12>>2]|0)+16>>2]);g=v[b+32>>2];h=v[b+36>>2];rf(f);jb=b+192|0;b=c?0:g;c=c?0:h;break q}a=P()|0;O()|0;break t}a=P()|0;O()|0;yb(b+32|0)}yb(b+16|0);break r}a=P()|0;O()|0;rf(c)}T(a|0);L()}f=v[e+68>>2];v[e+16>>2]=v[e+64>>2];v[e+20>>2]=f;hK(a,e+16|0,b,c,d);break e;case 2:Fe(e+56|0,b);i=uH(c);b=v[e+60>>2];v[e+24>>2]=v[e+56>>2];v[e+28>>2]=b;iK(a,e+24|0,i,d);break e;case 3:break k;default:break e}}Fe(e+48|0,b);Fe(e+40|0,c);b=v[e+52>>2];v[e+32>>2]=v[e+48>>2];v[e+36>>2]=b;gK(a,e+32|0,v[e+40>>2],v[e+44>>2],d)}jb=e+128|0;return}b=P()|0;O()|0;ca(a|0)}T(b|0)}L()}function LH(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=a+b|0;c=v[a+4>>2];a:{b:{if(c&1){break b}if(!(c&3)){break a}c=v[a>>2];b=c+b|0;c:{a=a-c|0;if((a|0)!=v[116101]){if(c>>>0<=255){e=v[a+8>>2];c=c>>>3|0;d=v[a+12>>2];if((d|0)!=(e|0)){break c}i=464384,j=v[116096]&Pka(-2,c),v[i>>2]=j;break b}h=v[a+24>>2];c=v[a+12>>2];d:{if((c|0)!=(a|0)){d=v[a+8>>2];v[d+12>>2]=c;v[c+8>>2]=d;break d}e:{e=a+20|0;d=v[e>>2];if(d){break e}e=a+16|0;d=v[e>>2];if(d){break e}c=0;break d}while(1){g=e;c=d;e=c+20|0;d=v[e>>2];if(d){continue}e=c+16|0;d=v[c+16>>2];if(d){continue}break}v[g>>2]=0}if(!h){break b}e=v[a+28>>2];d=(e<<2)+464688|0;f:{if(v[d>>2]==(a|0)){v[d>>2]=c;if(c){break f}i=464388,j=v[116097]&Pka(-2,e),v[i>>2]=j;break b}v[h+(v[h+16>>2]==(a|0)?16:20)>>2]=c;if(!c){break b}}v[c+24>>2]=h;d=v[a+16>>2];if(d){v[c+16>>2]=d;v[d+24>>2]=c}d=v[a+20>>2];if(!d){break b}v[c+20>>2]=d;v[d+24>>2]=c;break b}c=v[f+4>>2];if((c&3)!=3){break b}v[116098]=b;v[f+4>>2]=c&-2;v[a+4>>2]=b|1;v[f>>2]=b;return}v[e+12>>2]=d;v[d+8>>2]=e}c=v[f+4>>2];g:{if(!(c&2)){if(v[116102]==(f|0)){v[116102]=a;b=v[116099]+b|0;v[116099]=b;v[a+4>>2]=b|1;if(v[116101]!=(a|0)){break a}v[116098]=0;v[116101]=0;return}if(v[116101]==(f|0)){v[116101]=a;b=v[116098]+b|0;v[116098]=b;v[a+4>>2]=b|1;v[a+b>>2]=b;return}b=(c&-8)+b|0;h:{if(c>>>0<=255){e=v[f+8>>2];c=c>>>3|0;d=v[f+12>>2];if((d|0)==(e|0)){i=464384,j=v[116096]&Pka(-2,c),v[i>>2]=j;break h}v[e+12>>2]=d;v[d+8>>2]=e;break h}h=v[f+24>>2];c=v[f+12>>2];i:{if((f|0)!=(c|0)){d=v[f+8>>2];v[d+12>>2]=c;v[c+8>>2]=d;break i}j:{d=f+20|0;e=v[d>>2];if(e){break j}d=f+16|0;e=v[d>>2];if(e){break j}c=0;break i}while(1){g=d;c=e;d=c+20|0;e=v[d>>2];if(e){continue}d=c+16|0;e=v[c+16>>2];if(e){continue}break}v[g>>2]=0}if(!h){break h}e=v[f+28>>2];d=(e<<2)+464688|0;k:{if(v[d>>2]==(f|0)){v[d>>2]=c;if(c){break k}i=464388,j=v[116097]&Pka(-2,e),v[i>>2]=j;break h}v[h+(v[h+16>>2]==(f|0)?16:20)>>2]=c;if(!c){break h}}v[c+24>>2]=h;d=v[f+16>>2];if(d){v[c+16>>2]=d;v[d+24>>2]=c}d=v[f+20>>2];if(!d){break h}v[c+20>>2]=d;v[d+24>>2]=c}v[a+4>>2]=b|1;v[a+b>>2]=b;if(v[116101]!=(a|0)){break g}v[116098]=b;return}v[f+4>>2]=c&-2;v[a+4>>2]=b|1;v[a+b>>2]=b}if(b>>>0<=255){c=(b&-8)+464424|0;d=v[116096];b=1<<(b>>>3);l:{if(!(d&b)){v[116096]=b|d;b=c;break l}b=v[c+8>>2]}v[c+8>>2]=a;v[b+12>>2]=a;v[a+12>>2]=c;v[a+8>>2]=b;return}e=31;if(b>>>0<=16777215){c=b>>>8|0;g=c+1048320>>>16&8;c=c<<g;e=c+520192>>>16&4;c=c<<e;d=c+245760>>>16&2;c=(c<<d>>>15|0)-(d|(e|g))|0;e=(c<<1|b>>>c+21&1)+28|0}v[a+28>>2]=e;v[a+16>>2]=0;v[a+20>>2]=0;g=(e<<2)+464688|0;m:{d=v[116097];c=1<<e;n:{if(!(d&c)){v[116097]=c|d;v[g>>2]=a;v[a+24>>2]=g;break n}e=b<<((e|0)==31?0:25-(e>>>1|0)|0);c=v[g>>2];while(1){d=c;if((v[c+4>>2]&-8)==(b|0)){break m}c=e>>>29|0;e=e<<1;g=d+(c&4)|0;c=v[g+16>>2];if(c){continue}break}v[g+16>>2]=a;v[a+24>>2]=d}v[a+12>>2]=a;v[a+8>>2]=a;return}b=v[d+8>>2];v[b+12>>2]=a;v[d+8>>2]=a;v[a+24>>2]=0;v[a+12>>2]=d;v[a+8>>2]=b}}function oka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=jb-736|0;jb=e;yc(b);f=jb-16|0;jb=f;h=e+120|0;iV(f+8|0,h);g=v[f+12>>2];j=b;mc(f,v[b>>2],v[b+8>>2],v[f+8>>2],v[f+12>>2]);b=v[f+4>>2];if((b|0)==(g|0)){Zb(j,v[f+12>>2])}jb=f+16|0;b=(b|0)==(g|0);if(!b){hV(h)}a:{if(!b){break a}if(!jV(e+120|0)){break a}b:{if(!c){break b}Ad(a,67108864);$f(a);b=w[e+145|0];u[a+480190>>1]=31;u[a+480188>>1]=b;v[a+480228>>2]=256/(b>>>0);b=xc(e,8139);Ib(a+1298344|0,b);zb(b);b=xc(e,10725);Ib(a+1298356|0,b);zb(b);d=e+96|0;Rf(d,4177);f=w[e+144|0];v[e+72>>2]=f>>>4;b=0;v[23588]=0;v[e+116>>2]=f&15;X(302,e|0,d|0,e+72|0,e+116|0);d=v[23588];v[23588]=0;c:{d:{if((d|0)!=1){Ib(a+1298368|0,e);zb(e);ac(e+96|0);v[a+1298404>>2]=14;Hq(Vb(v[a+484360>>2],w[a+484376|0]),e+168|0,w[e+167|0]+1|0);while(1){e:{if((b|0)==31){MB(j,a+1298308|0,32);d=1;break e}d=b+1|0;g=B(d,104)+a|0;h=g+484380|0;md(h,1);f=(e+120|0)+(b<<2)|0;p=h,q=bc(w[f+176|0]|w[f+177|0]<<8|(w[f+178|0]<<16|w[f+179|0]<<24)),v[p>>2]=q;k=bc(w[f+300|0]|w[f+301|0]<<8|(w[f+302|0]<<16|w[f+303|0]<<24));v[g+484384>>2]=k;f=bc(w[f+424|0]|w[f+425|0]<<8|(w[f+426|0]<<16|w[f+427|0]<<24));v[g+484388>>2]=f+k;if(f){f=g+484414|0;u[f>>1]=x[f>>1]|2}Ck(h);b=(e+120|0)+b|0;t[e|0]=w[b+548|0];t[e+96|0]=64;p=g+484410|0,q=w[Wb(e,e+96|0)|0]<<2,u[p>>1]=q;t[g+484417|0]=w[b+579|0]<<4;b=d;continue}break}while(1){if((d|0)!=32){gV(j,((d<<5)+a|0)+946304|0,30);d=d+1|0;continue}break}n=c&1;if(n){wg(a+484344|0,w[e+166|0]+1|0)}k=a+484344|0;m=a+480188|0;f=0;while(1){if(w[e+166|0]<f>>>0){d=1;if(!(c&2)){break a}b=Zc(e,8,1,1,0);while(1){if((d|0)==32){break b}vg(b,(B(d,104)+a|0)+484380|0,j);d=d+1|0;continue}}g=Ih(e+96|0);f:{g:{if(w[e+146|0]){v[23588]=0;b=S(271,j|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break f}v[23588]=0;U(190,e+72|0,j|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break f}break g}b=x[m>>1];v[23588]=0;U(190,e+72|0,j|0,b<<8);b=v[23588];v[23588]=0;if((b|0)==1){break d}}b=e+72|0;d=jc(e,b);gd(g,d);Ab(d);Ab(b);h:{if(!n){break h}v[23588]=0;b=W(226,k|0,f&65535,64)|0;d=v[23588];v[23588]=0;if((d|0)==1){break d}if(!b){break h}b=0;if(w[e+146|0]){h=0;v[23588]=0;R(303,g|0,e|0);b=v[23588];v[23588]=0;if((b|0)==1){break d}i:while(1){if((h|0)==64){break h}i=e+h|0;b=128;d=0;l=Yb(v[k>>2],f);l=Cf(v[l>>2],v[v[l+48>>2]+12>>2],h);while(1){if(x[m>>1]<=d>>>0){h=h+1|0;continue i}j:{if(!(w[i|0]&b)){break j}v[23588]=0;R(304,g|0,l+B(d,6)|0);o=v[23588];v[23588]=0;if((o|0)!=1){break j}break d}b=b>>>1|0;d=d+1|0;continue}}}k:while(1){d=0;h=b&65535;if(h>>>0>=x[m>>1]){break h}while(1){if((d|0)==64){b=b+1|0;continue k}i=Yb(v[k>>2],f);i=id(v[i>>2],v[v[i+48>>2]+12>>2],d,h);v[23588]=0;R(304,g|0,i|0);i=v[23588];v[23588]=0;if((i|0)!=1){d=d+1|0;continue}break}break}break d}Ab(g);f=f+1|0;continue}break}break d}d=P()|0;O()|0;ac(e+96|0);break c}d=P()|0;O()|0;Ab(g)}T(d|0);L()}d=1}jb=e+736|0;return d|0}function sT(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=jb-176|0;jb=g;i=Xf(g+160|0);a:{b:{c:{if(d){v[23588]=0;U(470,a|0,i|0,c|0);c=v[23588];v[23588]=0;if((c|0)!=1){break c}break b}v[23588]=0;U(471,a|0,i|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break b}}k=Sb(g+144|0);m=b+480192|0;n=b+1298464|0;c=1;while(1){d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{h=c&65535;if(h>>>0<=x[m>>1]){v[23588]=0;u[g+142>>1]=0;R(472,a|0,g+142|0);d=v[23588];v[23588]=0;t:{u:{v:{w:{if((d|0)!=1){j=jb-16|0;jb=j;o=x[g+142>>1];d=Sd(i);e=ic(i);f=jb-16|0;jb=f;while(1){if(d){l=mo(x[d+16>>1],o);e=l?e:d;d=v[(l?d+4|0:d)>>2];continue}break}d=v[ec(f+8|0,e)>>2];jb=f+16|0;x:{if(Ob(d,Yf(i))){if(!mo(x[g+142>>1],x[vd(d)>>1])){break x}}d=Yf(i)}d=ec(j+8|0,d);jb=j+16|0;j=((h<<2)+b|0)+900380|0;if(!v[j>>2]){break d}d=v[d>>2];if(!Hg(d,wf(i))){break u}v[23588]=0;d=Q(3,g+128|0,vd(d)+4|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break t}v[23588]=0;e=Q(1,g+112|0,16746)|0;f=v[23588];v[23588]=0;if((f|0)==1){break v}f=mq(d,e);zb(e);if(f){break p}e=v[b+4>>2];v[23588]=0;e=Q(473,e|0,d|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break r}v[v[j>>2]+44>>2]=e;if(!v[v[j>>2]+44>>2]){break w}break e}c=P()|0;O()|0;break f}v[23588]=0;e=Q(1,g+96|0,13327)|0;f=v[23588];v[23588]=0;y:{z:{A:{if((f|0)!=1){B:{if(!mq(d,e)){v[23588]=0;f=Q(1,g+80|0,13577)|0;h=v[23588];v[23588]=0;if((h|0)==1){break A}h=mq(d,f);zb(f);zb(e);if(h){break B}break s}zb(e)}v[23588]=0;e=S(474,d|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break z}v[g+56>>2]=e;e=v[b+4>>2];f=v[dg(g+72|0,g+56|0)>>2];v[23588]=0;e=Q(475,e|0,f|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break y}rg(g+56|0);if(e){break e}break s}c=P()|0;O()|0;break g}c=P()|0;O()|0;zb(e);break g}c=P()|0;O()|0;break g}c=P()|0;O()|0;rg(g+56|0);break g}c=P()|0;O()|0;break g}d=v[j>>2];if(!d){break d}v[d+44>>2]=0;break d}c=P()|0;O()|0;break f}Rl(k);rT(i);jb=g+176|0;return}e=Eb(v[k>>2]);h=Eb(v[k+4>>2]);f=jb-16|0;jb=f;v[f+8>>2]=e;while(1){C:{if(!Ob(e,h)){break C}if(mq(e,d)){break C}e=v[lq(f+8|0)>>2];continue}break}jb=f+16|0;if(Ob(e,Eb(v[k+4>>2]))){break p}v[23588]=0;R(476,k|0,d|0);e=v[23588];v[23588]=0;if((e|0)!=1){break q}}c=P()|0;O()|0;break g}v[23588]=0;e=Q(1,g+24|0,17447)|0;f=v[23588];v[23588]=0;if((f|0)==1){break o}v[23588]=0;U(477,g+40|0,e|0,d|0);f=v[23588];v[23588]=0;if((f|0)==1){break n}v[23588]=0;f=Q(1,g+8|0,16299)|0;h=v[23588];v[23588]=0;if((h|0)==1){break m}v[23588]=0;U(2,g+56|0,g+40|0,f|0);h=v[23588];v[23588]=0;if((h|0)==1){break l}h=v[n>>2];v[23588]=0;U(376,h|0,2,g+56|0);h=v[23588];v[23588]=0;if((h|0)==1){break k}zb(g+56|0);zb(f);zb(g+40|0);zb(e)}v[v[j>>2]+44>>2]=0;break e}c=P()|0;O()|0;break g}c=P()|0;O()|0;break h}c=P()|0;O()|0;break i}c=P()|0;O()|0;break j}c=P()|0;O()|0;zb(g+56|0)}zb(f)}zb(g+40|0)}zb(e)}zb(d)}Rl(k);break a}zb(d)}c=c+1|0;continue}}c=P()|0;O()|0}rT(i);T(c|0);L()}function gY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=jb-352|0;jb=d;e=jb-16|0;jb=e;v[a+4>>2]=0;t[a|0]=0;f=a+40|0;qn(f,32);t[e+15|0]=0;pn(f,e+15|0);jb=e+16|0;e=v[a+36>>2];a:{if(!Yg(v[v[e>>2]-12>>2]+e|0)){th(a,2,16777216);break a}f=d+88|0;me(f,e);e=v[f+12>>2];v[a+16>>2]=v[f+8>>2];v[a+20>>2]=e;v[f>>2]=3;h=v[a+36>>2];g=d+24|0;e=0;while(1){if(y[f>>2]>e>>>0){hi(h,e+g|0);e=e+1|0;continue}break}if(Rb(g,25952,3)){th(a,2,512);break a}t[d+351|0]=0;hi(v[a+36>>2],d+351|0);Tb(d+88|0,0,256);e=w[d+351|0];if(e){Uk(v[a+36>>2],d+88|0,e)}g=b;b=Lk(d+24|0,d+88|0,e);e=cw(g,b);_b(b);if(!e){th(a,2,4096)}if(Kk(w[a|0])){break a}hi(v[a+36>>2],d+87|0);g=w[d+87|0];b=g&3;u[a+24>>1]=(b|0)==3?4:b;if(Si(g,6)){b=d+24|0;Rc(b,a+32|0,9);Ye(b,1)}v[d+80>>2]=0;uE(v[a+36>>2],d+80|0);b=v[d+80>>2];t[d+79|0]=0;if(b>>>0>=2){hi(v[a+36>>2],d+87|0);e=-1;if(!w[d+87|0]){hi(v[a+36>>2],d+79|0);e=-2}am(v[a+36>>2],b+e|0)}v[d+64>>2]=0;v[d+68>>2]=0;b:{if(!Si(g,4)){break b}Jk(v[a+36>>2],d- -64|0);b=v[d+68>>2];e=v[d+64>>2];v[a+64>>2]=e;v[a+68>>2]=b;f=v[c+4>>2];if((f|0)==(b|0)&y[c>>2]>=e>>>0|b>>>0<f>>>0){break b}th(a,1,4)}if(Si(g,5)){hi(v[a+36>>2],d+87|0);am(v[a+36>>2],w[d+87|0])}c=w[d+79|0];c:{if(!Si(c,0)){break c}hi(v[a+36>>2],d+87|0);b=w[d+87|0];b=b&1?-1:b>>>1|0;u[a+24>>1]=b;if(b){break c}th(a,1,2)}v[a+8>>2]=0;e=1;if(Si(c,1)){uE(v[a+36>>2],a+8|0)}h=Si(g,2);b=d+24|0;f=a+32|0;Rc(b,f,6);Ye(b,h);h=Si(g,3);Rc(b,f,7);Ye(b,h);h=x[a+24>>1];Rc(b,f,5);Ye(b,(h|0)!=0);g=Si(g,7);Rc(b,f,8);Ye(b,g);Rc(b,f,5);d:{if(Bb(v[v[d+24>>2]>>2],v[d+28>>2])){break d}Rc(d+8|0,f,6);if(Bb(v[v[d+8>>2]>>2],v[d+12>>2])){break d}Rc(d+56|0,f,7);if(Bb(v[v[d+56>>2]>>2],v[d+60>>2])){break d}Rc(d+48|0,f,8);e=Bb(v[v[d+48>>2]>>2],v[d+52>>2])}b=d+40|0;Rc(b,f,11);Ye(b,e);Rc(d+24|0,f,11);if(Si(c,2)){u[d+8>>1]=0;_v(v[a+36>>2],d+8|0);b=v[a+36>>2];e=x[d+8>>1];Rc(d+24|0,f,9);am(b,B(e,Bb(v[v[d+24>>2]>>2],v[d+28>>2])?2:1))}if(Si(c,3)){am(v[a+36>>2],5)}Jk(v[a+36>>2],d- -64|0);c=v[d+68>>2];g=c;b=v[d+64>>2];if(!c&b>>>0>=16001|c){th(a,2,8192);break a}v[a+104>>2]=b;if(!b){th(a,1,1)}Rc(d+24|0,f,11);e:{if(!Bb(v[v[d+24>>2]>>2],v[d+28>>2])){break e}Jk(v[a+36>>2],d- -64|0);c=v[d+68>>2];g=c;b=v[d+64>>2];if(Zv(b,c)){break e}th(a,2,2048);break a}c=d+8|0;me(c,v[a+36>>2]);e=v[a+16>>2];h=v[a+20>>2];i=v[c+4>>2];v[d+24>>2]=v[c>>2];v[d+28>>2]=i;i=v[c+12>>2];v[d+32>>2]=v[c+8>>2];v[d+36>>2]=i;c=v[d+32>>2];h=v[d+36>>2]-(h+(e>>>0>c>>>0)|0)|0;v[d+32>>2]=c-e;v[d+36>>2]=h;e=v[d+32>>2];c=v[d+36>>2];if((c|0)<0){th(a,2,16384);break a}v[a+96>>2]=e;v[a+100>>2]=c;c=d+24|0;Rc(c,f,11);e=v[a+100>>2];h=b;i=v[a+96>>2];b=Bb(v[v[d+24>>2]>>2],v[d+28>>2]);v[a+72>>2]=b?h:i;v[a+76>>2]=b?g:e;Rc(c,f,11);if(!Bb(v[v[d+24>>2]>>2],v[d+28>>2])){b=v[a+100>>2]+v[a+20>>2]|0;e=v[a+16>>2];c=e+v[a+96>>2]|0;v[a+80>>2]=c;v[a+84>>2]=c>>>0<e>>>0?b+1|0:b}a=d+24|0;Rc(a,f,10);Ye(a,1)}jb=d+352|0}function uM(a,b){var c=0,d=0,e=0,f=0,g=C(0),h=0,i=0,j=0,k=0,l=C(0),m=C(0),n=0,o=0,p=0,q=0,r=0,s=C(0),t=0;if(b){qy(a);c=a+24596|0;v[c>>2]=0;v[c+4>>2]=0;v[a+24588>>2]=0;v[a+24592>>2]=0;zM(a)}tM(a+24648|0);o=v[a+24620>>2];f=jb-144|0;jb=f;e=a+397456|0;c=v[e+4>>2];if(c>>>0>=29){v[e+4>>2]=0;c=0}h=B(c,44)+47520|0;if(!(b?0:(h|0)==v[e+8>>2])){v[e+8>>2]=h;m=C(o>>>0);c=f+8|0;d=v[h+24>>2];v[c>>2]=d;j=v[h+16>>2];v[c+4>>2]=j;v[c+8>>2]=v[h+4>>2];k=(d|0)>(j|0)?d:j;if((k|0)<=-601){i=j;j=k+600|0;v[c+4>>2]=i-j;v[c>>2]=d-j}g=C(z[h+36>>2]*C(79.30999755859375));a:{if(C(D(g))<C(2147483648)){d=~~g;break a}d=-2147483648}v[c+16>>2]=d- -8192;g=C(C(C(z[h+32>>2]*C(.0036000001709908247))+C(.15000000596046448))*C(32767));b:{if(C(D(g))<C(2147483648)){d=~~g;break b}d=-2147483648}v[c+20>>2]=(d|0)<32512?d:32512;j=0;g=z[h+8>>2];l=C(C(F(z[h+20>>2],C(.10000000149011612)))*m);c:{if(C(D(l))<C(2147483648)){d=~~l;break c}d=-2147483648}k=(d|0)>96?d:96;i=k-7500|0;n=k>>>0<i>>>0?0:i;l=C(z[h+28>>2]*m);d:{if(C(D(l))<C(2147483648)){i=~~l;break d}i=-2147483648}d=n+(i+((d|0)<96?d-96|0:0)|0)|0;i=(d|0)>128?d:128;p=i>>>0<3800?i:3800;v[c+24>>2]=p;n=(d|0)<128?d-128|0:0;g=C(g*m);e:{if(C(D(g))<C(2147483648)){q=~~g;break e}q=-2147483648}d=i-3800|0;i=(q+n|0)+(d>>>0>i>>>0?0:d)|0;v[c+32>>2]=i;n=k>>>0<7500?k:7500;while(1){if((j|0)==8){g=C(i|0);l=C(te(C(.0010000000474974513),(i|0)<4721?C(1):C(C(4720)/g))*C(32768));f:{if(C(D(l))<C(2147483648)){d=~~l;break f}d=-2147483648}v[c+12>>2]=d;g=C(z[h+12>>2]*g);r=c,s=te(C(.0010000000474974513),g<=C(4720)?C(1):C(C(4720)/g)),z[r+28>>2]=s}else{d=B(j,12);k=d+c|0;u[k+42>>1]=x[d+48810>>1];u[k+36>>1]=x[d+48804>>1];u[k+40>>1]=x[d+48808>>1];u[k+38>>1]=x[d+48806>>1];v[k+44>>2]=n+((B(v[d+48800>>2],p)+50|0)/100|0);j=j+1|0;continue}break}v[e+20>>2]=v[f+40>>2];c=wK(xK(v[f+16>>2]),m);u[e+86>>1]=c;u[e+84>>1]=c;c=x[f+24>>1]<<1;u[e+94>>1]=c;u[e+92>>1]=c;c=0;while(1){if((c|0)==8){v[e+49892>>2]=v[f+32>>2];c=v[f+12>>2];if((c|0)>-9e3){c=vK(c)}else{c=0}v[e+80>>2]=c;d=e+49948|0;c=v[f+8>>2];if((c|0)>=-8999){c=vK(c)}else{c=0}v[d>>2]=c;c=v[f+28>>2];d=e+49932|0;v[d>>2]=268464128;v[d+4>>2]=1879052288;c=c>>>0<32512?c:32512;u[e+49906>>1]=c;u[e+49904>>1]=c;u[e+49902>>1]=c;u[e+49900>>1]=c;v[f+4>>2]=v[f+20>>2];oe(f+4|0,0,32752);c=x[f+4>>1];u[e+49914>>1]=c;u[e+49910>>1]=0;u[e+49912>>1]=0;u[e+49908>>1]=c;g=z[f+36>>2];r=f,t=wK(C(g*g),m),v[r>>2]=t;oe(f,256,32512);c=x[f>>1];u[e+49922>>1]=c;u[e+49918>>1]=0;u[e+49920>>1]=0;u[e+49916>>1]=c}else{d=(c<<4)+e|0;h=(f+8|0)+B(c,12)|0;j=v[h+44>>2];v[d+100>>2]=j;v[d+104>>2]=j;u[d+108>>1]=x[h+36>>1];u[d+110>>1]=x[h+42>>1];u[d+112>>1]=x[h+40>>1];u[d+114>>1]=x[h+38>>1];c=c+1|0;continue}break}}c=a+397448|0;d=a+397452|0;if(b){v[e+16>>2]=0;zK(e,c,d)}b=B(o,5);if(b>>>0>y[e+20>>2]){v[e+20>>2]=b}jb=f+144|0;b=v[a+1298300>>2];if(Ed(b)){XO(b,v[a+24620>>2])}}function KW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0;e=jb-32|0;jb=e;v[e+28>>2]=b;a:{if((d|0)<=0){break a}v[e+8>>2]=d;v[e+16>>2]=214748364;u=e,x=B(v[Jb(e+28|0,e+16|0)>>2],20),v[u+20>>2]=x;qn(c,v[Jb(e+8|0,e+20|0)>>2]);v[e+12>>2]=b;v[e+8>>2]=a;while(1){b:{c:{d:{e:{if((d|0)<=0){break e}g=qh(a,b,i);h=qh(a,b,i+4|0);f=qh(a,b,i+5|0);u=e,x=qh(a,b,i+6|0)<<8|qh(a,b,i+7|0),v[u+24>>2]=x;n=f|h<<8;s=i+8|0;f:{g:{switch(g|0){case 0:i=0;if(d>>>0<n>>>0){i=ba(8)|0;v[23588]=0;a=S(193,i|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break f}break d}while(1){if((i|0)!=(n|0)){u=e,x=qh(a,b,i+s|0),t[u+20|0]=x;pn(c,e+20|0);i=i+1|0;continue}break};r=n;break b;case 1:break g;default:break e}}ai(e+24|0,d);r=v[e+24>>2];o=qh(a,b,i+10|0);t[e+20|0]=o;pn(c,e+20|0);j=i+11|0;n=n+3&65532;i=r-1|0;h=0;l=0;p=0;m=0;while(1){if((i|0)<=0){break c}f=Ag(j,h,1,e+8|0);h:{i:{j:{k:{l:{if((l|0)<=7){if(f){g=h;break i}g=h+1|0;m=8;break l}g=h+1|0;m:{if(!f){if(!Ag(j,g,1,e+8|0)){break i}k=2;n:{o:{f=h+2|0;if(!Ag(j,f,1,e+8|0)){break o}k=3;f=h+3|0;if(!Ag(j,f,1,e+8|0)){break o}k=Ag(j,f,3,e+8|0);g=h+6|0;break n}g=f+1|0}f=4;p:{q:{r:{h=((m<<3)+k|0)-17|0;s:{if((h|0)<0){a=ba(8)|0;v[23588]=0;b=S(193,a|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break r}break s}if(h>>>0<56){break p}a=ba(8)|0;v[23588]=0;b=S(193,a|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break q}}b=P()|0;O()|0;ca(a|0);T(b|0);L()}ha(b|0,26056,168);L()}ha(b|0,26056,168);L()}m=w[h+26096|0];if((m|0)!=8){break k}break m}f=4;if((m|0)!=8){break k}}m=8;f=1;if((p|0)>19){break k}}f=0;break j}p=p+8|0}while(1){if(!((f|0)<0|(i|0)<=0)){k=(g|0)/8|0;h=k+j|0;q=qh(v[e+8>>2],v[e+12>>2],h);o=o-kd((qh(v[e+8>>2],v[e+12>>2],h+1|0)<<8|q<<16|qh(v[e+8>>2],v[e+12>>2],h+2|0))<<(g-(k<<3)|0)+8,32-m|0)|0;t[e+20|0]=o;pn(c,e+20|0);f=f-1|0;i=i-1|0;g=g+m|0;continue}break}l=(l|0)==31?31:l+1|0;h=g;break h}t:{u:{v:{f=g+1|0;if(!Ag(j,f,1,e+8|0)){h=2;break v}f=g+2|0;if(!Ag(j,f,1,e+8|0)){h=4;break v}f=g+3|0;if(!Ag(j,f,1,e+8|0)){h=6;break v}f=g+5|0;if(!Ag(j,g+4|0,1,e+8|0)){g=g+8|0;f=Ag(j,f,3,e+8|0)+8|0;break t}g=g+10|0;h=16;f=Ag(j,f,5,e+8|0);break u}g=f+2|0;f=Ag(j,f+1|0,1,e+8|0)}f=f+h|0}w:{if(Ag(j,g,1,e+8|0)){k=-256;h=12;break w}g=g+1|0;h=Ag(j,g,1,e+8|0);k=h?-4352:0;h=h?14:8}q=g+1|0;g=Ag(j,q,h,e+8|0);if(f>>>0>=3){l=l-((f|0)!=3)|0;l=((l|0)>1?l:1)-1|0}k=(g^-1)+k|0;g=ed(v[c>>2],v[c+4>>2])+k|0;if(g>>>0<k>>>0){h=h+q|0;while(1){if((f|0)<=0|(i|0)<=0){break h}o=w[Kb(v[c>>2],g)|0];t[e+20|0]=o;pn(c,e+20|0);i=i-1|0;g=g+1|0;f=f-1|0;continue}}i=ba(8)|0;v[23588]=0;a=S(193,i|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break d}ha(a|0,26056,168);L()}p=p-(p>>3)|0;continue}}ha(a|0,26056,168);L()}i=oc(v[c>>2],v[c+4>>2])^1;break a}a=P()|0;O()|0;ca(i|0);T(a|0);L()}v[e+24>>2]=i}d=d-r|0;i=n+s|0;continue}}jb=e+32|0;return i|0}function wea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=jb-32|0;jb=j;a:{b:{if(Ct(a)>>>0<b>>>0){if((b|0)<0){break b}n=go(j+16|0);v[23588]=0;R(730,n|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break a}ul(j+8|0,v[a>>2]);Cm(j,v[a>>2],v[a+4>>2]);m=jb-48|0;jb=m;c=v[n+4>>2];e=gc(m+40|0,v[j+8>>2],v[j+12>>2]);f=gc(m+32|0,v[j>>2],v[j+4>>2]);b=jb-16|0;jb=b;e=gc(b+8|0,v[e>>2],v[e+4>>2]);f=gc(b,v[f>>2],v[f+4>>2]);e=mR(v[e>>2],v[e+4>>2],v[f>>2],v[f+4>>2]);jb=b+16|0;e=c+e|0;v[n+4>>2]=e;c:{d:{if(!c){b=e-1|0;break d}b=e-1|0;if((b^c-1)>>>0<32){break c}}v[v[n>>2]+((e>>>0<33?0:b>>>5|0)<<2)>>2]=0}f=gc(m+24|0,v[j+8>>2],v[j+12>>2]);e=gc(m+16|0,v[j>>2],v[j+4>>2]);b=m+8|0;Lo(b,v[n>>2],c);c=v[f>>2];o=jb-48|0;jb=o;f=v[f+4>>2];e:{if((f|0)==v[b+4>>2]){f=gc(o+40|0,c,f);c=gc(o+32|0,v[e>>2],v[e+4>>2]);b=gc(o+24|0,v[b>>2],v[b+4>>2]);e=jb-16|0;jb=e;g=v[f>>2];d=v[f+4>>2];c=tl(v[c>>2],v[c+4>>2],g,d);v[e+12>>2]=c;f:{if((c|0)<=0){c=v[b>>2];break f}if(d){i=32-d|0;v[e+8>>2]=i;k=c;c=v[sd(e+8|0,e+12|0)>>2];v[e+12>>2]=k-c;h=v[b>>2];d=-1<<d&-1>>>i-c;v[h>>2]=v[h>>2]&(d^-1)|d&v[g>>2];c=c+v[b+4>>2]|0;v[b+4>>2]=c&31;v[b>>2]=h+(c>>>3&536870908);g=v[f>>2]+4|0;v[f>>2]=g;c=v[e+12>>2]}k=g;d=(c|0)/32|0;g=d<<2;gj(v[b>>2],k,g);d=c-(d<<5)|0;v[e+12>>2]=d;c=g+v[b>>2]|0;v[b>>2]=c;if((d|0)<=0){break f}c=f;f=g+v[f>>2]|0;v[c>>2]=f;c=v[b>>2];g=-1>>>32-d|0;v[c>>2]=v[c>>2]&(g^-1)|g&v[f>>2];v[b+4>>2]=v[e+12>>2]}gc(m,c,v[b+4>>2]);break e}g=gc(o+16|0,c,f);c=gc(o+8|0,v[e>>2],v[e+4>>2]);f=gc(o,v[b>>2],v[b+4>>2]);e=jb-16|0;jb=e;k=v[c>>2];d=v[c+4>>2];b=v[g>>2];c=v[g+4>>2];d=tl(k,d,b,c);v[e+12>>2]=d;g:{if((d|0)<=0){c=v[f+4>>2];break g}h:{if(!c){c=v[f+4>>2];break h}l=32-c|0;v[e+8>>2]=l;i=e+8|0;h=v[sd(i,e+12|0)>>2];v[e+12>>2]=d-h;d=v[f+4>>2];p=v[b>>2];v[e+8>>2]=h;k=32-d|0;v[e+4>>2]=k;b=v[f>>2];q=v[b>>2];i=v[Jb(i,e+4|0)>>2];l=p&(-1<<c&-1>>>l-h);v[b>>2]=(-1<<d&-1>>>k-i^-1)&q|(c>>>0<d>>>0?l<<d-c:l>>>c-d|0);d=d+i|0;c=d&31;v[f+4>>2]=c;d=b+(d>>>3&536870908)|0;v[f>>2]=d;b=h-i|0;if((b|0)>0){v[d>>2]=v[d>>2]&(-1>>>32-b^-1)|l>>>i+v[g+4>>2];v[f+4>>2]=b;c=b}b=v[g>>2]+4|0;v[g>>2]=b;d=v[e+12>>2]}h=32-c|0;i=-1<<c;l=i^-1;while(1){if((d|0)>=32){d=v[f>>2];b=v[b>>2];v[d>>2]=l&v[d>>2]|b<<c;v[f>>2]=d+4;v[d+4>>2]=i&v[d+4>>2]|b>>>h;d=v[e+12>>2]-32|0;v[e+12>>2]=d;b=v[g>>2]+4|0;v[g>>2]=b;continue}break}if((d|0)<=0){break g}l=v[b>>2];v[e+8>>2]=h;g=v[f>>2];b=v[g>>2];k=b;b=v[sd(e+12|0,e+8|0)>>2];k=k&(i&-1>>>h-b^-1);h=l&-1>>>32-d;v[g>>2]=k|h<<c;d=b+c|0;c=d&31;v[f+4>>2]=c;g=g+(d>>>3&536870908)|0;v[f>>2]=g;d=v[e+12>>2]-b|0;v[e+12>>2]=d;if((d|0)<=0){break g}v[g>>2]=v[g>>2]&(-1>>>32-d^-1)|h>>>b;c=v[e+12>>2];v[f+4>>2]=c}gc(m,v[f>>2],c)}jb=e+16|0;jb=o+48|0;jb=m+48|0;Lt(a,n);Ve(n)}jb=j+32|0;return}bd();L()}a=P()|0;O()|0;Ve(n);T(a|0);L()}function oE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-176|0;jb=d;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{if((b|0)<=5){Wv(d+128|0,b);v[23588]=0;b=Q(1,d+112|0,17734)|0;e=v[23588];v[23588]=0;if((e|0)==1){break E}v[23588]=0;U(2,d+144|0,d+128|0,b|0);e=v[23588];v[23588]=0;if((e|0)==1){break D}v[23588]=0;c=Q(3,d+80|0,c|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break C}v[23588]=0;e=Q(1,d- -64|0,19562)|0;f=v[23588];v[23588]=0;if((f|0)==1){break B}v[23588]=0;U(4,d+96|0,c|0,e|0);f=v[23588];v[23588]=0;if((f|0)==1){break A}v[23588]=0;U(2,d+160|0,d+144|0,d+96|0);f=v[23588];v[23588]=0;if((f|0)==1){break z}zb(d+96|0);zb(e);zb(c);c=d+144|0;zb(c);zb(b);zb(d+128|0);b=v[a>>2];v[23588]=0;U(5,c|0,1,(b?b:21619)|0);b=v[23588];v[23588]=0;if((b|0)==1){break t}b=v[a+4>>2];v[23588]=0;U(5,d+128|0,1,(b?b:21619)|0);b=v[23588];v[23588]=0;if((b|0)==1){break s}a=v[a+8>>2];v[23588]=0;v[d+48>>2]=a;R(6,d+96|0,d+48|0);a=v[23588];v[23588]=0;if((a|0)==1){break r}v[23588]=0;Y(7,17613);a=v[23588];v[23588]=0;if((a|0)==1){break q}v[23588]=0;U(8,d+48|0,0,d+144|0);a=v[23588];v[23588]=0;if((a|0)==1){break p}v[23588]=0;Y(9,d+48|0);a=v[23588];v[23588]=0;if((a|0)==1){break o}v[23588]=0;Y(7,17407);a=v[23588];v[23588]=0;if((a|0)==1){break o}v[23588]=0;U(8,d+32|0,0,d+96|0);a=v[23588];v[23588]=0;if((a|0)==1){break n}v[23588]=0;Y(9,d+32|0);a=v[23588];v[23588]=0;if((a|0)==1){break m}v[23588]=0;Y(7,17405);a=v[23588];v[23588]=0;if((a|0)==1){break m}v[23588]=0;Y(7,17734);a=v[23588];v[23588]=0;if((a|0)==1){break m}v[23588]=0;U(8,d+16|0,0,d+160|0);a=v[23588];v[23588]=0;if((a|0)==1){break l}v[23588]=0;Y(9,d+16|0);a=v[23588];v[23588]=0;if((a|0)==1){break k}v[23588]=0;Y(7,13353);a=v[23588];v[23588]=0;if((a|0)==1){break k}v[23588]=0;U(8,d|0,0,d+128|0);a=v[23588];v[23588]=0;if((a|0)==1){break j}v[23588]=0;Y(9,d|0);a=v[23588];v[23588]=0;if((a|0)==1){break i}v[23588]=0;Y(7,13351);a=v[23588];v[23588]=0;if((a|0)==1){break i}v[23588]=0;Z(10);a=v[23588];v[23588]=0;if((a|0)==1){break i}yb(d);yb(d+16|0);yb(d+32|0);yb(d+48|0);zb(d+96|0);zb(d+128|0);zb(d+144|0);zb(d+160|0)}jb=d+176|0;return}a=P()|0;O()|0;break u}a=P()|0;O()|0;break v}a=P()|0;O()|0;break w}a=P()|0;O()|0;break x}a=P()|0;O()|0;break y}a=P()|0;O()|0;zb(d+96|0)}zb(e)}zb(c)}zb(d+144|0)}zb(b)}zb(d+128|0);break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;yb(d)}yb(d+16|0)}yb(d+32|0)}yb(d+48|0)}zb(d+96|0)}zb(d+128|0)}zb(d+144|0)}zb(d+160|0)}T(a|0);L()}function hK(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=jb-160|0;jb=f;v[f+152>>2]=c;v[f+156>>2]=d;g=v[b+4>>2];a:{if(!g){break a}h=v[b>>2];i=w[cl(h,g)|0];if((i|0)==33){e=1}else{if((i|0)!=63){break a}e=0}jl(f+128|0,h,g,g-1|0);g=v[f+132>>2];v[b>>2]=v[f+128>>2];v[b+4>>2]=g}g=f+128|0;Wd(g);h=v[f+128>>2];Wd(f+112|0);i=bl(h,v[f+116>>2],b);Wd(g);g=v[b+4>>2];h=v[b>>2];b:{c:{d:{e:{f:{g:{h:{if((i|0)==v[f+132>>2]){a=qc(f+144|0,21619);c=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=c;if(Pc(h,g,f+8|0)){a=ba(8)|0;v[23588]=0;R(962,f+112|0,f+152|0);b=v[23588];v[23588]=0;if((b|0)==1){break g}v[23588]=0;U(967,f+128|0,17598,f+112|0);b=v[23588];v[23588]=0;if((b|0)==1){break f}e=0;b=rc(a,f+128|0);v[23588]=0;U(119,b|0,62688,956);b=v[23588];v[23588]=0;if((b|0)!=1){break b}b=P()|0;O()|0;yb(f+128|0);break e}if(!e){break h}a=ba(8)|0;c=v[b>>2];b=v[b+4>>2];v[23588]=0;c=Kh(f+80|0,c,b);b=v[23588];v[23588]=0;i:{j:{k:{l:{m:{n:{o:{p:{if((b|0)!=1){v[23588]=0;U(967,f+96|0,17634,c|0);b=v[23588];v[23588]=0;if((b|0)==1){break p}v[23588]=0;R(969,f+112|0,f+96|0);b=v[23588];v[23588]=0;e=1;if((b|0)==1){break o}v[23588]=0;R(962,f- -64|0,f+152|0);b=v[23588];v[23588]=0;if((b|0)==1){break n}v[23588]=0;U(971,f+128|0,f+112|0,f- -64|0);b=v[23588];v[23588]=0;if((b|0)==1){break m}b=rc(a,f+128|0);v[23588]=0;U(119,b|0,62688,956);b=v[23588];v[23588]=0;if((b|0)!=1){break b}b=P()|0;O()|0;yb(f+128|0);e=0;break l}b=P()|0;O()|0;break d}b=P()|0;e=1;O()|0;break i}b=P()|0;O()|0;break j}b=P()|0;O()|0;break k}b=P()|0;O()|0}yb(f- -64|0)}yb(f+112|0)}yb(f+96|0)}yb(c);if(e){break d}break c}b=qc(f+56|0,21619);e=v[b+4>>2];v[f+32>>2]=v[b>>2];v[f+36>>2]=e;if(Pc(h,g,f+32|0)){a=ba(8)|0;v[23588]=0;R(962,f+112|0,f+152|0);b=v[23588];v[23588]=0;q:{r:{if((b|0)!=1){v[23588]=0;U(967,f+128|0,17598,f+112|0);b=v[23588];v[23588]=0;if((b|0)==1){break r}e=0;b=rc(a,f+128|0);v[23588]=0;U(119,b|0,62688,956);b=v[23588];v[23588]=0;if((b|0)!=1){break b}b=P()|0;O()|0;yb(f+128|0);break q}b=P()|0;O()|0;break d}b=P()|0;e=1;O()|0}yb(f+112|0);if(e){break d}break c}b=qc(f+48|0,10895);e=v[b+4>>2];v[f+24>>2]=v[b>>2];v[f+28>>2]=e;if(Pc(h,g,f+24|0)){aK(a,Hc(c,d));break h}b=qc(f+40|0,8587);e=v[b+4>>2];v[f+16>>2]=v[b>>2];v[f+20>>2]=e;if(!Pc(h,g,f+16|0)){break h}a=v[a+32>>2];b=bz(c,d);b=b>>>0<4?b:1;c=jb-16|0;jb=c;s:{if((bk(w[a+140|0])|0)==(b|0)){d=a+120|0;zs(w[d+20|0]);b=jb-16|0;jb=b;v[b+8>>2]=c+8;a=jb-16|0;jb=a;e=v[15595];v[a+8>>2]=v[15594];v[a+12>>2]=e;e=v[15593];v[a>>2]=v[15592];v[a+4>>2]=e;nb[v[vp(a,bk(w[d+20|0]))>>2]](b+8|0,d);jb=a+16|0;jb=b+16|0;break s}JJ(a,b,KJ(a))}jb=c+16|0}jb=f+160|0;return}b=P()|0;O()|0;break d}b=P()|0;e=1;O()|0}yb(f+112|0);if(!e){break c}}ca(a|0)}T(b|0)}L()}function QW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=jb-160|0;jb=d;yc(b);Wo(a);a:{if(!wv(b,d+120|0)){break a}if(!qD(d+120|0)){break a}j=v[b+8>>2];b:{if(!cd(b,w[d+136|0]|w[d+137|0]<<8|(w[d+138|0]<<16|w[d+139|0]<<24))){break b}while(1){c:{if((w[d+132|0]|w[d+133|0]<<8|(w[d+134|0]<<16|w[d+135|0]<<24))>>>0>h>>>0){if(Pb(v[b>>2],v[b+8>>2],5)){break c}}f=i&1;break b}f=0;g=1;d:{if((w[d+124|0]|w[d+125|0]<<8)>>>0>=64){if((ti(b)|0)<=0){break d}}while(1){l=Le(b);if(l){m=f>>>0>4;e=m&g;if(!((g^1)&1|m)){e=(Pp(l<<24>>24)&255)==w[f+13017|0]}g=e;f=f+1|0;continue}break}Zb(b,4);i=(f|0)==5?g&1?1:i:i}h=h+1|0;continue}}cd(b,j);if(!f){break a}if(!Pb(v[b>>2],v[b+8>>2],pD(d+120|0))){break a}if(!c){k=1;break a}g=jb-16|0;jb=g;e=d+120|0;cd(b,w[e+16|0]|w[e+17|0]<<8|(w[e+18|0]<<16|w[e+19|0]<<24));i=d+104|0;f=Sb(i);c=w[e+12|0]|w[e+13|0]<<8|(w[e+14|0]<<16|w[e+15|0]<<24);v[23588]=0;R(181,f|0,c|0);c=v[23588];v[23588]=0;e:{f:{g:{if((c|0)!=1){c=0;h:{i:{while(1){if((w[e+12|0]|w[e+13|0]<<8|(w[e+14|0]<<16|w[e+15|0]<<24))>>>0<=c>>>0){break h}h=v[b+8>>2];j=v[b>>2];v[23588]=0;h=W(156,j|0,h|0,5)|0;j=v[23588];v[23588]=0;if((j|0)==1){break g}if(!h){break h}h=w[e+4|0]|w[e+5|0]<<8;v[23588]=0;U(182,g|0,b|0,h|0);h=v[23588];v[23588]=0;if((h|0)!=1){v[23588]=0;R(183,f|0,g|0);h=v[23588];v[23588]=0;if((h|0)==1){break i}c=c+1|0;yb(g);continue}break}c=P()|0;O()|0;break f}c=P()|0;O()|0;yb(g);break f}jb=g+16|0;break e}c=P()|0;O()|0;break f}c=P()|0;O()|0}We(f);T(c|0);L()}v[23588]=0;X(176,d+88|0,b|0,e|0,i|0);c=v[23588];v[23588]=0;j:{if((c|0)!=1){v[23588]=0;Q(155,b|0,v[d+144>>2])|0;c=v[23588];v[23588]=0;k:{if((c|0)!=1){g=d+36|0;l:{m:{n:{o:{while(1){p:{q:{if(y[d+140>>2]>k>>>0){c=v[b+8>>2];e=v[b>>2];v[23588]=0;c=W(156,e|0,c|0,8)|0;e=v[23588];v[23588]=0;if((e|0)==1){break q}if(c){break p}}k=oc(v[a>>2],v[a+4>>2])^1;vc(d+88|0);We(d+104|0);break a}b=P()|0;O()|0;break k}v[23588]=0;ea(177,d- -64|0,b|0,d+120|0,d+88|0,d+104|0);c=v[23588];v[23588]=0;if((c|0)!=1){e=Xo(d- -64|0);v[23588]=0;c=S(178,v[d+64>>2])|0;f=v[23588];v[23588]=0;if((f|0)==1){break o}if(c){v[23588]=0;c=S(179,d+24|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break n}e=v[e>>2];r:{if((e|0)<0){break r}f=v[d+104>>2];if(xd(f,v[d+108>>2])>>>0<=e>>>0){break r}v[23588]=0;U(11,d+8|0,8,Md(f,e)|0);e=v[23588];v[23588]=0;if((e|0)==1){break m}e=d+8|0;Ib(c,e);zb(e)}uv(g,d- -64|0);v[23588]=0;R(180,a|0,c|0);e=v[23588];v[23588]=0;if((e|0)==1){break m}ir(c)}k=k+1|0;Ab(d- -64|0);continue}break}b=P()|0;O()|0;break k}b=P()|0;O()|0;break l}b=P()|0;O()|0;break l}b=P()|0;O()|0;ir(c)}Ab(d- -64|0);break k}b=P()|0;O()|0}vc(d+88|0);break j}b=P()|0;O()|0}We(d+104|0);T(b|0);L()}jb=d+160|0;return k|0}function EK(a){var b=C(0),c=C(0),d=0,e=C(0),f=C(0),g=0,h=0,i=C(0),k=0,m=C(0),r=C(0),s=0,t=C(0),u=0,w=C(0),x=C(0);d=a+4208|0;dO(Db(d,0),z[a+4272>>2]);b=C(C(z[Db(d,0)>>2]*C(15920))+C(80));t=te(C(10),C(C(C(z[Db(d,2)>>2]+C(-.5))*C(30))/C(40)));c=C(C(b/C(y[v[a+16>>2]+24620>>2]))*C(6.2831854820251465));b=VK(c);w=Bp(c);x=b;f=C(C(c*C(C(C(z[Db(d,1)>>2]*C(35))+C(1))*C(.02888113260269165)))/b);m=(l(2,(p(f),j(2))&-2147483648|1056964608),q());g=(p(f),j(2))&2147483647;c=(l(2,g),q());a:{if(g>>>0<=1118925334){b:{c:{d:{e:{f:{g:{h=(p(c),j(2));d=h&2147483647;if(d>>>0>=1100331076){if(d>>>0>2139095040){break c}b=C(-1);if((h|0)<0){break b}if(!(c>C(88.7216796875))){break g}b=C(c*C(17014118346046923e22));break b}if(d>>>0<1051816473){break e}if(d>>>0>1065686417){break g}if((h|0)>=0){d=1;e=C(905800061445916e-20);b=C(c+C(-.6931381225585938));break f}d=-1;e=C(-905800061445916e-20);b=C(c+C(.6931381225585938));break f}b=C(C(c*C(1.4426950216293335))+(l(2,(p(c),j(2))&-2147483648|1056964608),q()));h:{if(C(D(b))<C(2147483648)){d=~~b;break h}d=-2147483648}b=C(d|0);e=C(b*C(905800061445916e-20));b=C(c+C(b*C(-.6931381225585938)))}c=C(b-e);e=C(C(b-c)-e);break d}if(d>>>0<855638016){break c}d=0}b=C(c*C(.5));i=C(c*b);r=C(C(i*C(C(i*C(.0015807170420885086))+C(-.03333321213722229)))+C(1));b=C(C(3)-C(r*b));r=C(i*C(C(r-b)/C(C(6)-C(c*b))));b=C(c-C(C(c*r)-i));if(!d){break b}e=C(C(C(c*C(r-e))-e)-i);i:{switch(d+1|0){case 0:b=C(C(C(c-e)*C(.5))+C(-.5));break b;case 2:b=C(C(e-C(c+C(.5)))*C(-2));if(c<C(-.25)){break b}b=C(c-e);b=C(C(b+b)+C(1));break b;default:break i}}h=d<<23;b=(l(2,h+1065353216|0),q());if(d>>>0>=57){c=C(C(c-e)+C(1));b=C(((d|0)==128?C(C(c+c)*C(17014118346046923e22)):C(c*b))+C(-1));break b}i=(l(2,1065353216-h|0),q());c=C((d>>>0<=22?C(C(C(1)-i)+C(c-e)):C(C(c-C(e+i))+C(1)))*b)}b=c}if(g>>>0<=1065353215){if(g>>>0<964689920){break a}f=C(m*C(C(b+b)-C(C(b*b)/C(b+C(1)))));break a}f=C(m*C(b+C(b/C(b+C(1)))));break a}m=C(C(m+m)*C(1661534994731145e20));b=C(c+C(-162.88958740234375));d=cx(b)&2047;j:{k:{if(cx(C(88))>>>0>d>>>0){break k}c=C(0);if(((p(b),j(2))|0)==-8388608){break j}c=C(b+b);if(cx(C(N))>>>0<=d>>>0){break j}if(b>C(88.72283172607422)){c=GD(0);break j}if(!(b<C(-103.97207641601562))){break k}c=fD(0);break j}k=A[165]*+b;s=A[164];u=k+s;k=k-(u-s);s=(A[166]*k+A[167])*(k*k)+(A[168]*k+1);o(+u);j(1)|0;d=j(0)|0;h=d<<15;d=((d&31)<<3)+1024|0;g=v[d>>2];d=v[d+4>>2]+h|0;l(0,g|0);l(1,(g>>>0<g>>>0?d+1|0:d)|0);c=C(s*+n())}f=C(C(m*c)*C(1661534994731145e20))}c=C(x*f);f=C(c/t);b=C(f+C(1));z[a+4236>>2]=C(C(1)-f)/b;f=C(C(w*C(-2))/b);z[a+4232>>2]=f;c=C(c*t);z[a+4228>>2]=C(C(1)-c)/b;z[a+4224>>2]=f;z[a+4220>>2]=C(c+C(1))/b}function B6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-192|0;jb=d;e=v[b+4>>2];a:{if(!e){break a}f=v[b>>2];g=w[cl(f,e)|0];if((g|0)==33){c=1}else{if((g|0)!=63){break a}c=0}jl(d+168|0,f,e,e-1|0);e=v[d+172>>2];v[b>>2]=v[d+168>>2];v[b+4>>2]=e}f=d+168|0;Wd(f);e=v[d+168>>2];Wd(d+152|0);e=bl(e,v[d+156>>2],b);Wd(f);b:{c:{d:{e:{if((e|0)==v[d+172>>2]){a=v[b+4>>2];e=v[b>>2];f=qc(d+184|0,21619);g=v[f+4>>2];v[d>>2]=v[f>>2];v[d+4>>2]=g;if(Pc(e,a,d)){a=ba(8)|0;v[23588]=0;c=Q(55,d+168|0,10432)|0;b=v[23588];v[23588]=0;if((b|0)==1){break d}a=rc(a,c);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(c);break c}e=0;if(!c){break e}a=ba(8)|0;c=v[b+4>>2];b=v[b>>2];v[23588]=0;e=Kh(d+152|0,b,c);b=v[23588];v[23588]=0;f:{g:{h:{if((b|0)!=1){v[23588]=0;U(967,d+168|0,17634,e|0);b=v[23588];v[23588]=0;if((b|0)==1){break h}c=0;b=rc(a,d+168|0);v[23588]=0;U(119,b|0,62688,956);b=v[23588];v[23588]=0;if((b|0)!=1){break b}b=P()|0;O()|0;yb(d+168|0);break g}b=P()|0;O()|0;break f}b=P()|0;c=1;O()|0}yb(e);if(!c){break c}}ca(a|0);break c}if(v[e+4>>2]){a=ba(8)|0;v[23588]=0;c=Q(55,d+168|0,11504)|0;b=v[23588];v[23588]=0;if((b|0)!=1){a=rc(a,c);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(c);break c}b=P()|0;O()|0;ca(a|0);break c}c=v[b+4>>2];b=v[b>>2];e=qc(d+144|0,21619);f=v[e+4>>2];v[d+72>>2]=v[e>>2];v[d+76>>2]=f;if(Pc(b,c,d+72|0)){a=ba(8)|0;v[23588]=0;c=Q(55,d+168|0,10432)|0;b=v[23588];v[23588]=0;if((b|0)!=1){a=rc(a,c);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(c);break c}b=P()|0;O()|0;ca(a|0);break c}e=qc(d+136|0,7422);f=v[e+4>>2];v[d+64>>2]=v[e>>2];v[d+68>>2]=f;i:{if(!Pc(b,c,d- -64|0)){e=qc(d+128|0,7404);f=v[e+4>>2];v[d+56>>2]=v[e>>2];v[d+60>>2]=f;if(!Pc(b,c,d+56|0)){break i}}e=w[a+60|0]!=0;break e}e=qc(d+120|0,6937);f=v[e+4>>2];v[d+48>>2]=v[e>>2];v[d+52>>2]=f;j:{if(!Pc(b,c,d+48|0)){e=qc(d+112|0,6918);f=v[e+4>>2];v[d+40>>2]=v[e>>2];v[d+44>>2]=f;if(!Pc(b,c,d+40|0)){break j}}e=w[a+61|0]!=0;break e}e=qc(d+104|0,7021);f=v[e+4>>2];v[d+32>>2]=v[e>>2];v[d+36>>2]=f;if(Pc(b,c,d+32|0)){e=w[a+62|0]!=0;break e}e=qc(d+96|0,6067);f=v[e+4>>2];v[d+24>>2]=v[e>>2];v[d+28>>2]=f;if(Pc(b,c,d+24|0)){e=w[a+63|0]!=0;break e}e=qc(d+88|0,7471);f=v[e+4>>2];v[d+16>>2]=v[e>>2];v[d+20>>2]=f;if(Pc(b,c,d+16|0)){e=w[a+64|0]!=0;break e}e=qc(d+80|0,13296);f=v[e+4>>2];v[d+8>>2]=v[e>>2];v[d+12>>2]=f;e=0;if(!Pc(b,c,d+8|0)){break e}e=v[v[a+24>>2]+24668>>2]!=0}jb=d+192|0;return e|0}b=P()|0;O()|0;ca(a|0)}T(b|0)}L()}function rF(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0;i=jb-48|0;jb=i;o(+a);e=j(1)|0;d=j(0)|0;a:{b:{h=e;k=e&2147483647;c:{if(k>>>0<=1074752122){if((h&1048575)==598523){break c}if(k>>>0<=1073928572){if((e|0)>0|(e|0)>=0){a=a+-1.5707963267341256;c=a+-6077100506506192e-26;A[b>>3]=c;A[b+8>>3]=a-c+-6077100506506192e-26;d=1;break a}a=a+1.5707963267341256;c=a+6077100506506192e-26;A[b>>3]=c;A[b+8>>3]=a-c+6077100506506192e-26;d=-1;break a}if((e|0)>0|(e|0)>=0){a=a+-3.1415926534682512;c=a+-1.2154201013012384e-10;A[b>>3]=c;A[b+8>>3]=a-c+-1.2154201013012384e-10;d=2;break a}a=a+3.1415926534682512;c=a+1.2154201013012384e-10;A[b>>3]=c;A[b+8>>3]=a-c+1.2154201013012384e-10;d=-2;break a}if(k>>>0<=1075594811){if(k>>>0<=1075183036){if((k|0)==1074977148){break c}if((e|0)>0|(e|0)>=0){a=a+-4.712388980202377;c=a+-1.8231301519518578e-10;A[b>>3]=c;A[b+8>>3]=a-c+-1.8231301519518578e-10;d=3;break a}a=a+4.712388980202377;c=a+1.8231301519518578e-10;A[b>>3]=c;A[b+8>>3]=a-c+1.8231301519518578e-10;d=-3;break a}if((k|0)==1075388923){break c}if((e|0)>0|(e|0)>=0){a=a+-6.2831853069365025;c=a+-2.430840202602477e-10;A[b>>3]=c;A[b+8>>3]=a-c+-2.430840202602477e-10;d=4;break a}a=a+6.2831853069365025;c=a+2.430840202602477e-10;A[b>>3]=c;A[b+8>>3]=a-c+2.430840202602477e-10;d=-4;break a}if(k>>>0>1094263290){break b}}f=a*.6366197723675814+6755399441055744+-6755399441055744;c=a+f*-1.5707963267341256;g=f*6077100506506192e-26;p=c-g;e=p<-.7853981633974483;if(D(f)<2147483648){d=~~f}else{d=-2147483648}d:{if(e){d=d-1|0;f=f+-1;g=f*6077100506506192e-26;c=a+f*-1.5707963267341256;break d}if(!(p>.7853981633974483)){break d}d=d+1|0;f=f+1;g=f*6077100506506192e-26;c=a+f*-1.5707963267341256}a=c-g;A[b>>3]=a;o(+a);h=j(1)|0;j(0)|0;e=k>>>20|0;e:{if((e-(h>>>20&2047)|0)<17){break e}g=c;a=f*6077100506303966e-26;c=c-a;g=f*20222662487959506e-37-(g-c-a);a=c-g;A[b>>3]=a;h=e;o(+a);e=j(1)|0;j(0)|0;if((h-(e>>>20&2047)|0)<50){break e}g=c;a=f*20222662487111665e-37;c=c-a;g=f*84784276603689e-45-(g-c-a);a=c-g;A[b>>3]=a}A[b+8>>3]=c-a-g;break a}if(k>>>0>=2146435072){a=a-a;A[b>>3]=a;A[b+8>>3]=a;d=0;break a}l(0,d|0);l(1,e&1048575|1096810496);a=+n();d=0;h=1;while(1){m=(i+16|0)+(d<<3)|0;if(D(a)<2147483648){d=~~a}else{d=-2147483648}c=+(d|0);A[m>>3]=c;a=(a-c)*16777216;d=1;m=h;h=0;if(m){continue}break}A[i+32>>3]=a;d=2;while(1){h=d;d=d-1|0;if(A[(i+16|0)+(h<<3)>>3]==0){continue}break}d=SH(i+16|0,i,(k>>>20|0)-1046|0,h+1|0,1);a=A[i>>3];if((e|0)<0){A[b>>3]=-a;A[b+8>>3]=-A[i+8>>3];d=0-d|0;break a}A[b>>3]=a;A[b+8>>3]=A[i+8>>3]}jb=i+48|0;return d}function Am(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=jb-80|0;jb=e;h=Sb(a);v[23588]=0;a=S(279,b|0)|0;c=v[23588];v[23588]=0;a:{b:{c:{d:{e:{if((c|0)==1){break e}c=v[b+8>>2];d=v[b>>2];v[23588]=0;c=W(156,d|0,c|0,a|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break e}if(c){break d}v[23588]=0;a=S(202,b|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break e}v[23588]=0;Q(188,b|0,a|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){break c}}a=P()|0;O()|0;break a}v[23588]=0;U(190,e+32|0,b|0,a|0);b=v[23588];v[23588]=0;f:{g:{h:{if((b|0)!=1){b=e+32|0;c=jc(e+56|0,b);Ab(b);if(a>>>0<10){break g}v[23588]=0;b=S(707,c|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break b}if(!b){break g}v[23588]=0;b=S(279,c|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break b}v[e+28>>2]=b;a=a-10|0;wc(e+28|0,a>>>0>25264513?-1:B(a,170));v[23588]=0;d=v[e+28>>2];R(285,h|0,d|0);a=v[23588];v[23588]=0;if((a|0)!=1){break h}break b}a=P()|0;O()|0;break a}b=0;i:while(1){f=0;j:{k:{while(1){if(f){break j}a=v[c+8>>2];f=v[c>>2];v[23588]=0;a=Q(708,f|0,a|0)|0;f=v[23588];v[23588]=0;l:{m:{n:{o:{if((f|0)!=1){if(a){break j}v[23588]=0;a=S(519,c|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break b}f=1;switch(a|0){case 3:break l;case 2:break m;case 1:break n;case 0:break o;default:continue}}break b}v[23588]=0;a=S(206,c|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break b}if(a>>>0>d>>>0){continue}g=v[c+8>>2];i=v[c>>2];v[23588]=0;g=W(156,i|0,g|0,a|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break b}if(!g){continue}re(e+32|0,v[h>>2],v[h+4>>2]);Bq(e+16|0,v[e+32>>2],v[e+36>>2],b,a);v[23588]=0;Nk(459,e+8|0,c,v[e+16>>2],v[e+20>>2]);f=v[23588];v[23588]=0;if((f|0)!=1){d=d-a|0;b=a+b|0;continue i}break b}v[23588]=0;a=S(206,c|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break b}g=a<<2;if(g>>>0>d>>>0){continue}v[23588]=0;i=Q(709,c|0,e+24|0)|0;j=v[23588];v[23588]=0;if((j|0)==1){break b}if(!i){continue}while(1){if(!(a&255)){break k}f=e+24|0;i=ic(f);ph(f,i,Qf(Eb(v[h>>2]),b));b=b+4|0;a=a-1|0;continue}}if(d>>>0<8){continue}v[23588]=0;a=Q(709,c|0,e+24|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break b}if(!a){continue}a=e+24|0;f=ic(a);ph(a,f,Qf(Eb(v[h>>2]),b));ph(a,f,Qf(Qf(Eb(v[h>>2]),b),4));d=d-8|0;b=b+8|0;continue i}v[23588]=0;a=S(206,c|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break b}if(a>>>0>d>>>0){continue}break}d=d-a|0;b=a+b|0;continue}d=d-g|0;continue}break}if(!d){break f}a=Sb(e+32|0);Lt(a,h);hc(a);break f}v[23588]=0;U(327,c|0,h|0,a|0);a=v[23588];v[23588]=0;if((a|0)==1){break b}}Ab(c)}jb=e+80|0;return}a=P()|0;O()|0;Ab(c)}hc(h);T(a|0);L()}function dba(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;v[a+24588>>2]=0;v[a+24592>>2]=0;v[a+8>>2]=43568;v[a+4>>2]=0;v[a>>2]=32176;b=a+24596|0;v[b>>2]=0;v[b+4>>2]=0;bq(a+24604|0);$M(a+24648|0,0);v[a+397448>>2]=0;v[a+397452>>2]=0;b=a+397456|0;v[b>>2]=8;v[b+4>>2]=0;v[b+16>>2]=0;v[b+20>>2]=0;t[b+12|0]=0;v[b+8>>2]=0;u[b+24>>1]=0;Tb(b+28|0,0,40);Tb(b+68|0,0,49824);Tb(b+49892|0,0,32832);t[a+480224|0]=0;u[a+480212>>1]=0;v[a+480204>>2]=0;v[a+480208>>2]=0;v[a+480180>>2]=0;v[a+480184>>2]=0;b=a+480186|0;u[b>>1]=0;u[b+2>>1]=0;u[b+4>>1]=0;u[b+6>>1]=0;v[a+480240>>2]=65536;v[a+480244>>2]=65536;h=Sb(a+480248|0);v[a+480272>>2]=0;c=a+484344|0;b=a+480280|0;while(1){t[b+8|0]=0;v[b>>2]=0;v[b+4>>2]=4194432;LC(b+9|0);b=b+32|0;if((c|0)!=(b|0)){continue}break}f=Sb(c);v[f+12>>2]=a;v[23588]=0;i=Q(808,a+484360|0,a|0)|0;b=v[23588];v[23588]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((b|0)!=1){c=a+900380|0;b=a+484380|0;while(1){v[23588]=0;b=S(681,b|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break i}b=b+104|0;if((c|0)!=(b|0)){continue}break}v[23588]=0;S(809,a+901404|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break h}d=a+906300|0;b=0;while(1){VM(d+B(b,160)|0);b=b+1|0;if((b|0)!=250){continue}break}v[a+946300>>2]=0;e=a+1074304|0;g=a+946304|0;b=g;while(1){b=zt(b)+32|0;if((e|0)!=(b|0)){continue}break}v[a+1074304>>2]=0;v[a+1074308>>2]=0;hr(a+1074312|0);v[23588]=0;Z(810);b=v[23588];v[23588]=0;if((b|0)==1){break g}r=a,s=UM(),v[r+1074328>>2]=s;b=a+1074332|0;v[b+12>>2]=1065353216;KM(b,4);v[23588]=0;e=S(811,a+1074376|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break g}v[23588]=0;j=W(581,a+1298264|0,a|0,255)|0;b=v[23588];v[23588]=0;if((b|0)==1){break f}k=Gc(a+1298300|0);l=Gc(a+1298304|0);m=Lb(a+1298308|0);n=Lb(a+1298320|0);o=Lb(a+1298332|0);p=_M(a+1298344|0);q=Sb(a+1298408|0);t[a+1298420|0]=0;b=a+1298424|0;v[b>>2]=0;v[b+4>>2]=0;v[b+32>>2]=0;v[b+36>>2]=1072693248;v[b+24>>2]=0;v[b+28>>2]=0;v[b+16>>2]=0;v[b+20>>2]=0;v[b+8>>2]=0;v[b+12>>2]=0;v[a+1298464>>2]=0;Np(a+12|0);zy(a+8204|0);zy(a+12300|0);b=a+1074408|0;v[b>>2]=4;v[b+4>>2]=16;v[a+480216>>2]=4;v[a+480220>>2]=16;Tb(c,0,1024);TM(g);v[23588]=0;b=S(812,12)|0;c=v[23588];v[23588]=0;if((c|0)==1){break e}v[b>>2]=0;v[b+4>>2]=0;v[b+8>>2]=0;r=a,s=Sb(b),v[r+4>>2]=s;return a|0}b=P()|0;O()|0;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;ZM(q);Cy(p);yb(o);zb(n);yb(m);By(l);Ay(k);mt(j)}Ny(e)}YM(d)}zz(i)}QM(f);vc(h);T(b|0);L()}function zga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0;f=jb-560|0;jb=f;a:{if(!cd(b,1464)){break a}if(!no(b,f+556|0)){break a}Ad(a,1);Nb(Nb(Zf(a+1074312|0,83),84,1),85,1);b:{if(ne(f+556|0,26889)){d=f+32|0;e=xc(d,8390);Ib(a+1298344|0,e);zb(e);e=xc(d,14781);Ib(a+1298356|0,e);zb(e);d=xc(d,14846);Ib(a+1298368|0,d);break b}if(!ne(f+556|0,15497)){break a}d=f+32|0;e=xc(d,8564);Ib(a+1298344|0,e);zb(e);e=xc(d,12192);Ib(a+1298356|0,e);zb(e);d=xc(d,15404);Ib(a+1298368|0,d)}zb(d);v[a+1298404>>2]=14;cd(b,0);OA(b,a+1298308|0,20);u[a+480190>>1]=31;d=1;while(1)if((d|0)==32){if(g>>>0>40){break a}d=f+552|0;dv(d,b);m=Nc(d);if(w[f+552|0]>128){break a}e=f+32|0;d=jb-16|0;jb=d;c:{if(!Pb(v[b>>2],v[b+8>>2],512)){UR(e);break c}Lu(d+8|0,e);td(d,b,v[d+8>>2],v[d+12>>2])}jb=d+16|0;d=0;e=w[m|0];while(1){n=(d|0)==512;if(!n){g=(f+32|0)+d|0;d=d+1|0;if(e>>>0>=w[g|0]){continue}break a}break}if(!c){break a}v[a+480260>>2]=56;v[a+480264>>2]=13696;v[a+480204>>2]=125e4;v[a+480196>>2]=6;u[a+480192>>1]=0;u[a+480188>>1]=4;v[a+480228>>2]=64;v[a+480208>>2]=v[a+480208>>2]|18874368;nh(a,0);o=a+484376|0;ug(Vb(v[a+484360>>2],w[o|0]),w[f+552|0]);l=a+484344|0;wg(l,w[f+552|0]);while(1){if(w[f+552|0]<=i>>>0){if(!(c&2)){break a}cd(b,(w[m|0]<<8)+1468|0);d=1;while(1){if((d|0)==32){break a}c=(B(d,104)+a|0)+484380|0;if(v[c>>2]){vg(Zc(f+8|0,8,1,0,0),c,b)}d=d+1|0;continue}}s=cc(v[Vb(v[a+484360>>2],w[o|0])>>2],i),x=i,u[s>>1]=x;d:{if(!oh(l,i&65535,64)){break d}r=i<<2;e=0;e:while(1){if((e|0)==4){s=f,x=Eb(v[Yb(v[l>>2],i)>>2]),v[s+24>>2]=x;e=0;while(1){if((e|0)==64){break d}d=0;f:{while(1){if((d&65535)>>>0>=4){g:{t[f+31|0]=p;t[f+30|0]=q;d=h&255;if(d){break g}h=0;break f}}else{g=v[f+24>>2];h:{if((w[g+3|0]&254)!=16){break h}t[g+3|0]=16;h=0;k=w[g+5|0];if(k>>>0<16){break h}h=k>>>4|0;t[g+5|0]=h;j=h;h=k&15;g=(j|0)==(h|0)|!h;q=g?q:j;p=g?p:h;h=!g}d=d+1|0;bA(f+24|0);continue}break}ze(Yb(v[l>>2],i),Te(Ne(f+8|0,16,w[(d+f|0)+29|0]),e));h=h+1|0;h=(h&255)==3?1:h}e=e+1|0;continue}}cd(b,(w[f+32+(e+r)|0]<<8)+1468|0);g=0;d=Yb(v[l>>2],i);d=id(v[d>>2],v[v[d+48>>2]+12>>2],0,e&65535);while(1)if((g|0)==64){e=e+1|0;continue e}else{j=f+8|0;Hu(j,b,d);k=w[f+8|0];j=w[Nc(j)|0];i:{if(!(!(k|j)|(k-5&255)>>>0<5|(k|0)==14&j>>>0>15)){Of(d,k,j);break i}t[d+3|0]=0}d=d+24|0;g=g+1|0;continue}}}i=i+1|0;continue}}else{g=jA(b,f+32|0,(B(d,104)+a|0)+484380|0,((d<<5)+a|0)+946304|0,1)+g|0;d=d+1|0;continue}}jb=f+560|0;return n|0}function $2(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0,g=0;d=jb-192|0;jb=d;v[d+184>>2]=c;a:{b:{c:{if(b>=.8){v[23588]=0;e=ga(1076)|0;f=v[23588];v[23588]=0;d:{e:{f:{if((f|0)!=1){v[d+80>>2]=e;v[23588]=0;c=S(1077,c|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break e}v[d+176>>2]=c;Hn(e,c);a=je(d+152|0,a);v[23588]=0;f=v[a+12>>2];c=d- -64|0;v[c>>2]=v[a+8>>2];v[c+4>>2]=f;v[d+72>>2]=v[a+16>>2];c=v[a+4>>2];v[d+56>>2]=v[a>>2];v[d+60>>2]=c;a=W(1069,e|0,d+56|0,15)|0;c=v[23588];v[23588]=0;if((c|0)==1){break f}if(a){v[23588]=0;Y(813,e|0);a=v[23588];v[23588]=0;g=1;if((a|0)==1){break f}}ij(d+176|0);jj(d+80|0);break b}c=V(0)|0;O()|0;break c}c=V(0)|0;O()|0;ij(d+176|0);break d}c=V(0)|0;O()|0}jj(d+80|0);break c}if(b>=.6){v[23588]=0;e=ga(1076)|0;f=v[23588];v[23588]=0;g:{h:{i:{if((f|0)!=1){v[d+80>>2]=e;v[23588]=0;c=S(1077,c|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break h}v[d+176>>2]=c;Hn(e,c);a=je(d+128|0,a);v[23588]=0;c=v[a+12>>2];v[d+40>>2]=v[a+8>>2];v[d+44>>2]=c;v[d+48>>2]=v[a+16>>2];c=v[a+4>>2];v[d+32>>2]=v[a>>2];v[d+36>>2]=c;a=W(1069,e|0,d+32|0,2)|0;c=v[23588];v[23588]=0;if((c|0)==1){break i}if(a){v[23588]=0;Y(813,e|0);a=v[23588];v[23588]=0;g=.8;if((a|0)==1){break i}}ij(d+176|0);jj(d+80|0);break b}c=V(0)|0;O()|0;break c}c=V(0)|0;O()|0;ij(d+176|0);break g}c=V(0)|0;O()|0}jj(d+80|0);break c}g=.2;if(b>=.2){v[23588]=0;e=ga(1076)|0;f=v[23588];v[23588]=0;j:{k:{l:{if((f|0)!=1){v[d+80>>2]=e;v[23588]=0;c=S(1077,c|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break k}v[d+176>>2]=c;Hn(e,c);a=je(d+104|0,a);v[23588]=0;c=v[a+12>>2];v[d+16>>2]=v[a+8>>2];v[d+20>>2]=c;v[d+24>>2]=v[a+16>>2];c=v[a+4>>2];v[d+8>>2]=v[a>>2];v[d+12>>2]=c;a=W(1069,e|0,d+8|0,0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break l}g=0;if(a){v[23588]=0;Y(813,e|0);a=v[23588];v[23588]=0;g=.6;if((a|0)==1){break l}}ij(d+176|0);jj(d+80|0);break b}c=V(0)|0;O()|0;break c}c=V(0)|0;O()|0;ij(d+176|0);break j}c=V(0)|0;O()|0}jj(d+80|0);break c}if(!(b>=.1)){break b}v[23588]=0;U(203,d+80|0,a|0,2048);c=v[23588];v[23588]=0;if((c|0)!=1){c=Ie(d+80|0);a=v[a>>2];v[23588]=0;e=v[d+80>>2];a=S(160,a|0)|0;f=v[23588];v[23588]=0;m:{if((f|0)==1){break m}v[23588]=0;a=kF(1078,c,e,a,0);c=v[23588];v[23588]=0;if((c|0)==1){break m}g=A[(a<<3)+62392>>3];Tc(d+80|0);break b}c=V(0)|0;O()|0;Tc(d+80|0);break c}c=V(0)|0;O()|0}_(c|0)|0;v[23588]=0;Z(18);a=v[23588];v[23588]=0;g=0;if((a|0)==1){break a}}De(d+184|0);jb=d+192|0;return+g}a=P()|0;O()|0;De(d+184|0);T(a|0);L()}function faa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=jb-48|0;jb=c;a:{b:{if(!Ob(v[b>>2],v[b+4>>2])){break b}l=v[b+12>>2];k=Pg(v[v[b+48>>2]+12>>2]);d=k;f=c+32|0;v[f>>2]=0;v[f+4>>2]=0;Gc(f+8|0);if(d){lu(f,d);g=jb-16|0;jb=g;e=Fq(g,f,d);d=v[e+4>>2];h=v[e+8>>2];while(1){if((d|0)==(h|0)){kc(e);jb=g+16|0}else{t[d|0]=0;t[d+1|0]=0;t[d+2|0]=0;t[d+3|0]=0;t[d+4|0]=0;t[d+5|0]=0;tg(d);d=d+6|0;v[e+4>>2]=d;continue}break}}while(1){c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{if(j>>>0>=l>>>0){break r}if(!Yg(v[v[a>>2]-12>>2]+a|0)){break r}v[23588]=0;t[c+31|0]=0;Q(875,a|0,c+31|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break a}d=t[c+31|0];if(!d){j=j+1|0;continue}t[c+30|0]=0;s:{if((d|0)>=0){break s}v[23588]=0;Q(875,a|0,c+30|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){break s}break a}t[c+29|0]=0;Ej(c+16|0);t:{d=d&127;g=(d?d-1|0:0)&65535;i=g>>>0>=k>>>0;u:{v:{if(!i){h=id(v[b>>2],v[v[b+48>>2]+12>>2],j,g);d=w[c+30|0];if(d&1){break v}e=Hd(v[f>>2],g);break u}h=c+16|0;d=w[c+30|0];if(!(d&1)){break t}}v[23588]=0;Q(875,a|0,c+29|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break a}if(i){break t}e=Hd(v[f>>2],g);t[e|0]=w[c+29|0]}t[h|0]=w[e|0];d=w[c+30|0];if(!(d&2)){break p}break q}if(d&2){break q}break o}uk(f);break b}v[23588]=0;Q(875,a|0,c+29|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break a}if(i){break o}e=Hd(v[f>>2],g);t[e+1|0]=w[c+29|0]}t[h+1|0]=w[e+1|0];if(d&4){break n}break m}if(!(d&4)){break l}}v[23588]=0;Q(875,a|0,c+29|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break a}if(i){break l}e=Hd(v[f>>2],g);t[e+2|0]=w[c+29|0]}t[h+2|0]=w[e+2|0];if(!(d&8)){break j}break k}if(!(d&8)){break i}}v[23588]=0;Q(875,a|0,c+29|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break a}if(i){break i}e=Hd(v[f>>2],g);t[e+4|0]=w[c+29|0]}t[h+4|0]=w[e+4|0];if(d&16){break h}break g}if(!(d&16)){break f}}v[23588]=0;Q(875,a|0,c+29|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break a}if(i){break f}e=Hd(v[f>>2],g);t[e+3|0]=w[c+29|0]}t[h+3|0]=w[e+3|0];if(!(d&32)){break d}break e}if(!(d&32)){break c}}v[23588]=0;Q(875,a|0,c+29|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break a}if(i){break c}e=Hd(v[f>>2],g);t[e+5|0]=w[c+29|0]}t[h+5|0]=w[e+5|0]}if(!(d&64)){continue}v[23588]=0;Q(875,a|0,c+15|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){v[23588]=0;Q(876,a|0,w[c+15|0])|0;d=v[23588];v[23588]=0;if((d|0)!=1){continue}}break}break a}jb=c+48|0;return}a=P()|0;O()|0;uk(f);T(a|0);L()}function Vfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;g=jb-32|0;jb=g;a:{if(!Pb(v[a>>2],v[a+8>>2],2)){oh(c+484344|0,b,64);break a}l=c+484344|0;m=Cd(Gj(a),1,1024);if(!oh(l,b,m)){break a}p=x[c+480188>>1];q=c+480190|0;b:while(1){if((k|0)==(m|0)){break a}i=0;e=Yb(v[l>>2],b);n=Cf(v[e>>2],v[v[e+48>>2]+12>>2],k);while(1)if((i|0)==(p|0)){k=k+1|0;continue b}else{f=g+24|0;Sm(f,a);e=B(i,6)+n|0;r=Se(f);f=Li(f);h=w[g+24|0];c:{if((h-1&255)>>>0>35){break c}t[e|0]=h+48;o=w[Nc(g+24|0)|0];h=o+1|0;t[e+1|0]=h;j=h;h=h&255;if((j|0)!=(h|0)|h>>>0>x[q>>1]){break c}h=Gi(c,h);j=Kb(d,i);if(!(!w[j|0]|x[h+30>>1]>255)){t[e+4|0]=64;t[e+2|0]=1}h=v[Db(h+68|0,0)>>2];if(!(w[j|0]|h?w[j|0]?(h|0)==1:0:1)){break c}t[e+1|0]=o+101}d:{e:{switch(w[r|0]){case 1:if(!w[f|0]){break d}t[e+3|0]=2;t[e+5|0]=w[f|0];break d;case 2:if(!w[f|0]){break d}t[e+3|0]=3;t[e+5|0]=w[f|0];break d;case 12:if(!w[f|0]){break d}t[e+3|0]=1;t[e+5|0]=w[f|0];break d;case 13:if(!w[f|0]){break d}t[e+3|0]=39;t[g+23|0]=15;s=e,u=w[Wb(g+23|0,f)|0]|16,t[s+5|0]=u;break d;case 30:if(!w[f|0]){break d}t[e+3|0]=38;t[g+22|0]=15;s=e,u=w[Wb(g+22|0,f)|0]|16,t[s+5|0]=u;break d;case 21:if(!w[f|0]){break d}t[e+3|0]=39;t[g+21|0]=15;s=e,u=w[Wb(g+21|0,f)|0]|80,t[s+5|0]=u;break d;case 17:if(!w[f|0]){break d}t[e+3|0]=38;t[g+20|0]=15;s=e,u=w[Wb(g+20|0,f)|0]|80,t[s+5|0]=u;break d;case 15:t[e+3|0]=19;t[e+5|0]=w[f|0]!=0;break d;case 25:t[e+3|0]=12;t[e+5|0]=w[f|0];break d;case 27:io(e);t[e|0]=255;break d;case 28:if(w[f|0]>31){break d}t[e+3|0]=16;t[e+5|0]=w[f|0];break d;case 31:h=w[f|0];if(h&15){s=e,u=w[Kb(d,i)|0]?22:11,t[s+3|0]=u;t[e+5|0]=w[f|0]&15;h=w[f|0]}f:{g:{switch(h>>>4|0){case 4:if((h|0)!=64){break f}case 0:case 1:case 2:case 3:if(w[Kb(d,i)|0]){t[e+3|0]=21;t[e+5|0]=w[f|0];break f}t[e+2|0]=1;f=w[f|0];t[e+3|0]=0;t[e+4|0]=f;break f;case 5:t[e+5|0]=w[e+5|0]<<4;break f;case 6:t[g+19|0]=w[e+5|0];t[g+18|0]=14;s=e,u=w[Wb(g+19|0,g+18|0)|0]|240,t[s+5|0]=u;break f;case 7:t[g+17|0]=w[e+5|0];t[g+16|0]=14;s=e,u=w[Wb(g+17|0,g+16|0)|0]<<4|15,t[s+5|0]=u;break f;default:break g}}t[e+3|0]=0}if((w[e+3|0]-21&255)>>>0>1){break d}f=B(t[Kb(d,i)|0]+i|0,6)+n|0;Oq(g+8|0,w[f+3|0],w[f+5|0],1);if(w[g+8|0]){h=x[g+8>>1];t[f+4|0]=h>>>8;t[f+2|0]=h}t[f+3|0]=w[e+3|0];t[f+5|0]=w[e+5|0];break d;case 0:break d;default:break e}}t[e+3|0]=0}i=i+1|0;continue}}}jb=g+32|0}function pea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=jb+-64|0;jb=d;u[d+62>>1]=c;Ef(d+62|0,32);j=Sb(a);v[23588]=0;o=x[d+62>>1];R(523,j|0,o|0);a=v[23588];v[23588]=0;a:{b:{if((a|0)!=1){k=b+480190|0;p=b+480192|0;c:{d:{while(1){if((q&65535)>>>0>=o>>>0){break d}e=1;c=x[k>>1];a=c+1|0;u[d+60>>1]=a;e:{f:{g:{if((a&65535)>>>0<4e3){break g}h:{while(1){f=e&65535;if(f>>>0>c>>>0){break h}i:{g=Gi(b,f);if(!Zd(v[g>>2],v[g+20>>2])){if(!Ob(cA(Eb(v[j>>2]),Eb(v[j+4>>2]),e),Eb(v[j+4>>2]))){break i}c=x[k>>1]}e=e+1|0;continue}break}u[d+60>>1]=e;a=1;while(1){if(x[p>>1]<a>>>0){a=e;break h}j:{c=v[((a<<2)+b|0)+900380>>2];if(!c){break j}c=c+236|0;g=yq(c);while(1){if((c|0)==(g|0)){break j}if((f|0)==x[c>>1]){u[c>>1]=0}c=c+2|0;continue}}a=a+1|0;continue}}if((a&65535)>>>0<4e3){break g}e=go(d+48|0);v[23588]=0;a=Q(746,b|0,e|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break b}if(!a){break e}v[23588]=0;R(747,b|0,e|0);c=v[23588];v[23588]=0;a=1;if((c|0)==1){break b}while(1){c=a&65535;if(c>>>0<=x[p>>1]){k:{c=v[((c<<2)+b|0)+900380>>2];if(!c){break k}c=c+236|0;f=yq(c);while(1){if((c|0)==(f|0)){break k}g=x[c>>1];l:{if(g>>>0>=y[d+52>>2]){break l}Cb(d+40|0,v[e>>2],g);if(Bb(v[v[d+40>>2]>>2],v[d+44>>2])){break l}u[c>>1]=0}c=c+2|0;continue}}a=a+1|0;continue}break}ul(d+24|0,v[e>>2]);QP(d+32|0,v[d+24>>2],v[d+28>>2],1);Cm(d+16|0,v[e>>2],v[d+52>>2]);m=jb-16|0;jb=m;g=d+40|0;c=gc(m,v[d+32>>2],v[d+36>>2]);a=tl(v[d+16>>2],v[d+20>>2],v[d+32>>2],v[d+36>>2]);f=jb-16|0;jb=f;v[f+12>>2]=a;h=v[c+4>>2];m:{if(h){i=32-h|0;v[f+8>>2]=i;n=v[Jb(f+8|0,f+12|0)>>2];l=-1<<h&-1>>>i-n;i=v[c>>2];l=l&(v[i>>2]^-1);if(l){gc(g,i,Kka(l));break m}if((a|0)==(n|0)){QP(g,i,h,a);break m}a=a-n|0;v[f+12>>2]=a;v[c>>2]=i+4}while(1){if(a>>>0>=32){h=v[c>>2];i=v[h>>2];if((i|0)!=-1){gc(g,h,Kka(i^-1));break m}else{v[c>>2]=h+4;a=a-32|0;v[f+12>>2]=a;continue}}break}if(!a){gc(g,v[c>>2],0);break m}c=v[c>>2];h=(v[c>>2]^-1)&-1>>>32-a;if(!h){gc(g,c,a);break m}gc(g,c,Kka(h))}jb=f+16|0;jb=m+16|0;ul(d+8|0,v[e>>2]);a=tl(v[d+40>>2],v[d+44>>2],v[d+8>>2],v[d+12>>2]);u[d+60>>1]=a;Ve(e);if((a&65535)>>>0>3999){break f}}v[23588]=0;R(257,j|0,d+60|0);c=v[23588];v[23588]=0;if((c|0)==1){break c}if(x[k>>1]>=(a&65535)>>>0){break f}u[k>>1]=a}q=q+1|0;continue}break}Ve(e)}jb=d- -64|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;break a}c=P()|0;O()|0;Ve(e)}nd(j);T(c|0);L()}function x3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=jb-192|0;jb=d;h=CJ(d+176|0);v[h>>2]=49332;Sb(h+4|0);Hn(v[a+24>>2],h);e=v[a+24>>2];i=w[a+62|0];f=w[a+61|0];g=w[a+60|0];b=je(d+152|0,b);v[23588]=0;j=v[b+12>>2];v[d+16>>2]=v[b+8>>2];v[d+20>>2]=j;v[d+24>>2]=v[b+16>>2];j=v[b+4>>2];v[d+8>>2]=v[b>>2];v[d+12>>2]=j;b=g?13:15;b=f?b&14:b;b=W(1069,e|0,d+8|0,(i?b&3:b)|0)|0;e=v[23588];v[23588]=0;a:{b:{c:{d:{e:{if((e|0)==1){break e}if(!b){b=ba(8)|0;v[23588]=0;c=Q(55,d+136|0,11930)|0;a=v[23588];v[23588]=0;if((a|0)!=1){a=rc(b,c);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}a=P()|0;O()|0;ca(b|0);break b}if(!w[a+63|0]){v[23588]=0;R(1070,a|0,a+36|0);b=v[23588];v[23588]=0;if((b|0)==1){break e}}t[a+28|0]=1;Hn(v[a+24>>2],v[a+4>>2]);v[23588]=0;R(1071,d+136|0,h|0);b=v[23588];v[23588]=0;if((b|0)==1){break c}k=d,l=Eb(v[d+136>>2]),v[k+128>>2]=l;e=a+68|0;i=Eb(v[d+140>>2]);f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{while(1){b=v[d+128>>2];if(!Ob(b,i)){k=d,l=Fi(v[c>>2]),v[k+112>>2]=l;c=wf(c);while(1){b=v[d+112>>2];if(!Hg(b,c)){break d}v[23588]=0;e=vd(b);b=Q(54,d+32|0,e|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break h}v[23588]=0;X(968,a|0,b|0,e+12|0,0);e=v[23588];v[23588]=0;if((e|0)==1){break g}yb(b);Kg(d+112|0);continue}}f=v[a+24>>2];g=v[b>>2];v[23588]=0;j=f;f=b+4|0;U(1072,j|0,g|0,f|0);g=v[23588];v[23588]=0;if((g|0)!=1){b=v[b>>2];v[23588]=0;R(1073,d- -64|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break r}v[23588]=0;R(1015,d+80|0,d- -64|0);b=v[23588];v[23588]=0;if((b|0)==1){break q}v[23588]=0;b=Q(55,d+48|0,17734)|0;g=v[23588];v[23588]=0;if((g|0)==1){break p}v[23588]=0;U(971,d+96|0,d+80|0,b|0);g=v[23588];v[23588]=0;if((g|0)==1){break o}v[23588]=0;U(529,d+112|0,d+96|0,f|0);f=v[23588];v[23588]=0;if((f|0)==1){break n}v[23588]=0;R(183,e|0,d+112|0);f=v[23588];v[23588]=0;if((f|0)==1){break m}yb(d+112|0);yb(d+96|0);yb(b);yb(d+80|0);zb(d- -64|0);eq(d+128|0);continue}break}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;break i}a=P()|0;O()|0;break j}a=P()|0;O()|0;break k}a=P()|0;O()|0;break l}a=P()|0;O()|0;yb(d+112|0)}yb(d+96|0)}yb(b)}yb(d+80|0)}zb(d- -64|0);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;yb(b)}vx(d+136|0);break b}a=P()|0;O()|0;break b}vx(d+136|0);xs(h);jb=d+192|0;return}a=P()|0;O()|0}xs(h);T(a|0)}L()}function eha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;e=jb-32|0;jb=e;a:{b:{if(!c){break b}s=e,u=Le(a),t[s+16|0]=u;pn(b,e+16|0);k=c-1|0;c=0;while(1){g=1;if(!k){break a}c:{d:{d=c<<1;c=d&254;if(!c){if(!nf(a,e+16|0)){break b}i=1;d=w[e+16|0]<<1|1;c=d&255;if(d>>>0<=255){break d}break c}if((d&65535)>>>0<=255){break d}i=1;break c}if(!nf(a,e+16|0)){break b}BU(b,e+16|0);k=k-1|0;continue}while(1){e:{f:{g:{d=c<<1&254;if(d){c=(c&65535)>>>0>127}else{if(!nf(a,e+16|0)){break g}c=w[e+16|0]<<1|1;d=c&255;c=c>>>0>255}i=jq(i,1)+c|0;c=d<<1&254;if(c){break f}if(!nf(a,e+16|0)){break g}d=w[e+16|0]<<1|1;c=d&255;if(d>>>0>255){continue}break e}c=0;break e}if(d>>>0>127){continue}}break}h:{if((i|0)<=2){j=0;h=i-2|0;break h}if(!nf(a,e+16|0)){break b}d=jq(i-3|0,8)|w[e+16|0];j=((d|0)>1279?2:1)+((d|0)>31999)|0;n=d^-1;h=0}d=c<<1&254;if(d){f=c>>>0>127}else{if(!nf(a,e+16|0)){break b}c=w[e+16|0]<<1|1;d=c&255;f=c>>>0>255}g=jq(h,1);c=d<<1&254;if(c){d=d>>>0>127}else{if(!nf(a,e+16|0)){break b}d=w[e+16|0]<<1|1;c=d&255;d=d>>>0>255}i=1;h=k;d=jq(f+g|0,1)+d|0;if(!d){while(1){i:{j:{k:{d=c<<1&254;if(d){c=(c&65535)>>>0>127}else{if(!nf(a,e+16|0)){break k}c=w[e+16|0]<<1|1;d=c&255;c=c>>>0>255}i=jq(i,1)+c|0;c=d<<1&254;if(c){break j}if(!nf(a,e+16|0)){break k}d=w[e+16|0]<<1|1;c=d&255;if(d>>>0>255){continue}break i}c=0;break i}if(d>>>0>127){continue}}break}d=i+2|0}f=h;h=d+j|0;g=0;if(f>>>0<h>>>0|(h|0)<=0|(n|0)>=0){break a}d=v[b+4>>2];g=0;if((0-ed(v[b>>2],d)|0)>(n|0)){break a}d=ec(e+24|0,Eb(d));t[e+16|0]=0;l=e+16|0;o=jb-32|0;jb=o;f=v[d>>2];d=v[b>>2];j=ro(f,Eb(d))+d|0;f=v[Fb(b)>>2];g=v[b+4>>2];l:{if(h>>>0<=f-g>>>0){d=h;f=g-j|0;if(d>>>0>f>>>0){Mo(b,h-f|0,l);d=f;if(!d){break l}}p=jb-16|0;jb=p;f=g;r=v[b+4>>2];g=(r-(h+j|0)|0)+j|0;q=Ok(p,b,f-g|0);m=v[q+4>>2];i=g;while(1){if(i>>>0>=f>>>0){kc(q);Aq(j,g,r);jb=p+16|0}else{wd(m,w[i|0]);m=m+1|0;v[q+4>>2]=m;i=i+1|0;continue}break}bi(j,d,(j>>>0<=l>>>0?y[b+4>>2]>l>>>0?h:0:0)+l|0);break l}d=Fb(b);d=Yl(o+8|0,Wl(b,ed(v[b>>2],g)+h|0),j-v[b>>2]|0,d);dT(d,h,l);j=CU(b,d,j);Xl(d)}Eb(j);jb=o+32|0;s=e,u=Qf(rS(Eb(v[b+4>>2]),h),n),v[s+16>>2]=u;s=e,u=rS(Eb(v[b+4>>2]),h),v[s+8>>2]=u;d=h;while(1){f=w[qS(e+16|0)|0];s=qS(e+8|0),u=f,t[s|0]=u;f=d>>>0>1;d=d-1|0;if(f){continue}break}k=k-h|0;continue}}g=0}f=g;jb=e+32|0;return f|0}function vaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=jb-16|0;jb=h;f=v[a+8>>2];e=v[a>>2];v[23588]=0;f=Q(600,e|0,f|0)|0;e=v[23588];v[23588]=0;a:{b:{if((e|0)!=1){if(f){break b}v[23588]=0;f=S(206,a|0)|0;e=v[23588];v[23588]=0;c:{if((e|0)==1){break c}v[23588]=0;j=d+484344|0;k=Cd(f+1|0,1,1024);f=W(226,j|0,b|0,k|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break c}if(!f){break b}d=x[d+480188>>1];if(!d){break b}l=d-1|0;d=0;d:while(1){if(d>>>0>=k>>>0){break b}while(1){f=v[a+8>>2];e=v[a>>2];v[23588]=0;f=W(156,e|0,f|0,1)|0;e=v[23588];v[23588]=0;e:{if((e|0)!=1){if(!f){break b}v[23588]=0;i=S(206,a|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break a}if(i){break e}d=d+1|0;continue d}break a}e=v[j>>2];u[h+14>>1]=i&31;u[h+12>>1]=l;e=Yb(e,b);e=id(v[e>>2],v[v[e+48>>2]+12>>2],d,x[Vc(h+14|0,h+12|0)>>1]);if(!(i&224)){continue}break}f:{if(!(i&128)){break f}v[23588]=0;g=S(206,a|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break a}t[e+5|0]=g;v[23588]=0;g=S(206,a|0)|0;f=v[23588];v[23588]=0;g:{h:{if((f|0)!=1){if(g>>>0<26){break h}break g}break a}f=w[g+42688|0];t[e+3|0]=f;i:{switch(f-1|0){case 0:if(!w[e+5|0]){break g}break f;case 12:if(w[e+2|0]){break f}t[e+2|0]=1;f=w[e+5|0];t[e+5|0]=0;t[e+3|0]=0;m=e,n=Cd(f,0,64),t[m+4|0]=n;break f;case 5:case 6:case 10:case 23:case 28:f=w[e+5|0]&240;if(!f){break f}t[e+5|0]=f;break f;case 8:f=w[e+5|0];if(f>>>0<=128){m=e,n=sg(f<<1),t[m+5|0]=n;break f}if((f|0)!=164){break f}t[e+5|0]=145;t[e+3|0]=20;break f;case 13:f=w[e+5|0];t[e+5|0]=B(f>>>4|0,10)+(f&15);break f;case 18:Vu(e);break f;case 16:if(w[e+5|0]>31){break f}t[e+3|0]=16;break f;case 27:break i;default:break f}}g=w[e+5|0];f=g&240;j:{if((f|0)==16){f=2}else{if((f|0)!=32){break j}f=3}t[e+3|0]=f}t[e+5|0]=g&15|224;break f}t[e+3|0]=0}k:{l:{if(!(i&64)){break l}v[23588]=0;R(260,h+8|0,a|0);f=v[23588];v[23588]=0;if((f|0)==1){break k}t[e+1|0]=w[h+8|0];g=w[Nc(h+8|0)|0];t[e|0]=g;f=255;if((g|0)!=128){f=253;if(g>>>0<129){break l}}t[e|0]=f}if(!(i&32)){continue}t[e+2|0]=1;v[23588]=0;g=S(206,a|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break a}t[e+4|0]=g;if(!c){continue}t[e+4|0]=(g<<6>>>0)/127;continue}break}break a}break a}break a}Ab(a);jb=h+16|0;return}b=P()|0;O()|0;Ab(a);T(b|0);L()}function Z3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a=Lb(a);v[23588]=0;Z(105);c=v[23588];v[23588]=0;a:{b:{if((c|0)==1){c=Wa(62688,92948,93532,0)|0;d=O()|0;c:{d:{e:{if((da(62688)|0)==(d|0)){c=_(c|0)|0;v[23588]=0;b=Q(941,a|0,b|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break e}v[23588]=0;b=Q(941,b|0,17734)|0;d=v[23588];v[23588]=0;if((d|0)==1){break e}v[23588]=0;d=Q(941,b|0,17710)|0;b=v[23588];v[23588]=0;if((b|0)==1){break e}b=nb[v[v[c>>2]+8>>2]](c)|0;v[23588]=0;Q(941,d|0,(b?b:21619)|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break e}v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}f:{if((da(92948)|0)==(d|0)){c=_(c|0)|0;v[23588]=0;b=Q(941,a|0,b|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break f}v[23588]=0;b=Q(941,b|0,17734)|0;d=v[23588];v[23588]=0;if((d|0)==1){break f}v[23588]=0;d=Q(941,b|0,17685)|0;b=v[23588];v[23588]=0;if((b|0)==1){break f}b=nb[v[v[c>>2]+8>>2]](c)|0;v[23588]=0;Q(941,d|0,(b?b:21619)|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break f}v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}e=da(93532)|0;c=_(c|0)|0;g:{if((d|0)==(e|0)){v[23588]=0;b=Q(941,a|0,b|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break g}v[23588]=0;b=Q(941,b|0,17734)|0;d=v[23588];v[23588]=0;if((d|0)==1){break g}v[23588]=0;d=Q(941,b|0,17701)|0;b=v[23588];v[23588]=0;if((b|0)==1){break g}b=nb[v[v[c>>2]+8>>2]](c)|0;v[23588]=0;Q(941,d|0,(b?b:21619)|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break g}v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}v[23588]=0;b=Q(941,a|0,b|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break d}v[23588]=0;b=Q(941,b|0,17734)|0;c=v[23588];v[23588]=0;if((c|0)==1){break d}v[23588]=0;Q(941,b|0,13664)|0;b=v[23588];v[23588]=0;if((b|0)==1){break d}v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}b=P()|0;O()|0;v[23588]=0;Z(18);c=v[23588];v[23588]=0;if((c|0)!=1){break a}break c}b=P()|0;O()|0;v[23588]=0;Z(18);c=v[23588];v[23588]=0;if((c|0)!=1){break a}break c}b=P()|0;O()|0;v[23588]=0;Z(18);c=v[23588];v[23588]=0;if((c|0)==1){break c}break a}b=P()|0;O()|0;v[23588]=0;Z(18);c=v[23588];v[23588]=0;if((c|0)!=1){break a}}V(0)|0;O()|0;Ub()}L()}return}yb(a);T(b|0);L()}function vW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=jb-384|0;jb=f;yc(b);d=jb-16|0;jb=d;h=f+344|0;HC(d+8|0,h);e=v[d+12>>2];mc(d,v[b>>2],v[b+8>>2],v[d+8>>2],v[d+12>>2]);i=v[d+4>>2];if((i|0)==(e|0)){Zb(b,v[d+12>>2])}jb=d+16|0;d=(e|0)==(i|0);if(!d){GC(h)}a:{if(!d){break a}if(!JC(f+344|0)){break a}if(!Pb(v[b>>2],v[b+8>>2],Dc(IC(w[f+379|0]),mb))){break a}b:{if(!c){break b}Ad(a,2097152);$f(a);nh(a,1);u[a+480188>>1]=8;v[a+480196>>2]=w[f+376|0];v[a+480204>>2]=B(w[f+377|0],1e4);j=a+480190|0;u[j>>1]=w[f+378|0];d=w[f+381|0];if(d>>>0<w[f+380|0]){Ue(Vb(v[a+484360>>2],w[a+484376|0]),d)}d=f+80|0;g=xc(d,6522);Ib(a+1298344|0,g);zb(g);g=xc(d,11070);Ib(a+1298356|0,g);zb(g);v[a+1298404>>2]=5;ev(b,d);Vq(Vb(v[a+484360>>2],w[a+484376|0]),d,w[f+380|0],65535,65535);g=1;while(1){i=g&65535;if(i>>>0>x[j>>1]){Zb(b,B(64-w[f+378|0]|0,37));h=a+484344|0;wg(h,w[f+379|0]);i=c&1;g=0;while(1){if(w[f+379|0]<=g>>>0){if(!(c&2)){break b}c=Zc(f+40|0,8,1,0,0);d=a+480190|0;g=1;while(1){e=g&65535;if(e>>>0>x[d>>1]){break b}vg(c,(B(e,104)+a|0)+484380|0,b);g=g+1|0;continue}}c:{d:{if(i){if(oh(h,g&65535,64)){break d}}Zb(b,2048);break c}d=Yb(v[h>>2],g);n=f,o=Eb(v[d>>2]),v[n+40>>2]=o;j=Eb(v[d+4>>2]);while(1){d=v[f+40>>2];if(!Ob(d,j)){break c}e=f+24|0;Sm(e,b);k=Nc(e);m=Se(e);e=Li(e);l=w[f+24|0];if((l-1&255)>>>0<=106){t[d|0]=l+13}t[d+1|0]=w[k|0];Of(d,w[m|0],w[e|0]);Bk(f+40|0);continue}}g=g+1|0;continue}}else{d=f+40|0;FC(b,d);h=jb-16|0;jb=h;e=(B(i,104)+a|0)+484380|0;md(e,0);t[e+37|0]=w[d+22|0]<<4;t[h+15|0]=w[d+23|0];t[h+14|0]=64;n=e,o=w[Wb(h+15|0,h+14|0)|0]<<2,u[n+30>>1]=o;t[e+36|0]=w[d+24|0];v[e>>2]=w[d+25|0]|w[d+26|0]<<8|(w[d+27|0]<<16|w[d+28|0]<<24);k=w[d+33|0]|w[d+34|0]<<8|(w[d+35|0]<<16|w[d+36|0]<<24);if(!(k>>>0<3|k+(w[d+29|0]|w[d+30|0]<<8|(w[d+31|0]<<16|w[d+32|0]<<24))>>>0>(w[d+25|0]|w[d+26|0]<<8|(w[d+27|0]<<16|w[d+28|0]<<24))>>>0)){u[e+34>>1]=x[e+34>>1]|2;v[e+4>>2]=w[d+29|0]|w[d+30|0]<<8|(w[d+31|0]<<16|w[d+32|0]<<24);v[e+8>>2]=(w[d+33|0]|w[d+34|0]<<8|(w[d+35|0]<<16|w[d+36|0]<<24))+(w[d+29|0]|w[d+30|0]<<8|(w[d+31|0]<<16|w[d+32|0]<<24))}jb=h+16|0;e=f+8|0;Hl(e,2,d);d=f+24|0;Ec(d,e);Cc(((i<<5)+a|0)+946304|0,d);g=g+1|0;yb(d);continue}}}g=1}jb=f+384|0;return g|0}function oca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;f=jb-48|0;jb=f;s=v[a+16>>2];u=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);b=0;o=v[a+128>>2];if(o){e=v[a+8>>2];k=v[a+12>>2];p=kg(e,k,o);q=mb;i=v[a+76>>2];Pf(v[a>>2],v[a+4>>2],kf(e,k,d),mb);k=i>>>0<mb>>>0?d:0}else{k=0}j=a+112|0;while(1){if((b|0)!=2){e=b<<3;h=e+(f+16|0)|0;e=a+e|0;v[h+4>>2]=v[e+44>>2];v[h+8>>2]=v[e+48>>2];b=b+1|0;continue}break}l=v[a+40>>2];m=v[a+36>>2];b=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=b;w=v[a+8>>2];x=v[a+12>>2];while(1){if(d){d=d-1|0;b=v[f+12>>2];e=v[f+8>>2];v[f+40>>2]=e;v[f+44>>2]=0;k=k-1|0;p=k?p:0;q=k?q:0;n=(((b&2147483647)<<1|e>>>31)&-2)+s|0;e=o;a:{b:while(1){c:{if((e|0)<=0){Qb(j,v[a+120>>2],v[a+124>>2]);h=v[a+116>>2];if(!h){break a}e=((v[f+44>>2]&2147483647)<<1|v[f+40>>2]>>>31)&-2;g=0;b=0;break c}h=((v[f+44>>2]&2147483647)<<1|v[f+40>>2]>>>31)&-2;b=0;g=0;while(1)if((b|0)==2){Rd(j,(g|0)/8<<16>>16);Qd(j,4);Qb(f+40|0,p,q);e=e-1|0;continue b}else{g=(t[n+(b+h|0)|0]<<8)+g|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){g=(t[n+(b+e|0)|0]<<8)+g|0;b=b+1|0;continue}break}Rd(j,(g|0)/8<<16>>16);Qd(j,h);v[j>>2]=v[j>>2];v[j+4>>2]=0}b=ig(j,u);v[f+4>>2]=b;v[f>>2]=b;y=v[a+72>>2];b=v[a+68>>2];z=b;A=b>>31;b=v[a+64>>2];C=b;D=b>>31;b=v[a+60>>2];E=b;F=b>>31;b=0;while(1){if((b|0)!=2){r=(b<<2)+f|0;e=v[r>>2];i=(f+16|0)+(b<<3)|0;G=v[i+8>>2];g=v[i+4>>2];v[i+8>>2]=g;n=e<<8;e=n;e=Lka(E,F,e,e>>31);h=mb;H=i;i=e;e=Xb(g,-16777216,16776704);e=Lka(C,D,e,e>>31);g=i+e|0;i=mb+h|0;i=e>>>0>g>>>0?i+1|0:i;e=Xb(G,-16777216,16776704);h=Lka(z,A,e,e>>31);g=h+g|0;e=mb+i|0;e=g>>>0<h>>>0?e+1|0:e;h=g+8388608|0;e=h>>>0<8388608?e+1|0:e;e=Xc(h,e,24);v[H+4>>2]=e-(n&y);v[r>>2]=(e|0)/256;b=b+1|0;continue}break}b=v[a+32>>2];m=v[a+28>>2]+m|0;v[c>>2]=v[c>>2]+B(v[f>>2],m>>12);l=b+l|0;v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],l>>12);Qb(f+8|0,w,x);c=c+8|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;v[a+40>>2]=l;v[a+20>>2]=m>>12;v[a+36>>2]=m;v[a+24>>2]=l>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+16|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}jb=f+48|0}function aW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,z=0,A=0,C=0,D=0,E=0,F=0;f=jb-32|0;jb=f;k=tg(f+24|0);p=k+3|0;q=k+5|0;r=k+4|0;s=k+2|0;x=k+1|0;d=f+16|0;z=d|5;A=d|3;while(1){a:{if(y[a+12>>2]>m>>>0){C=Cf(v[a>>2],v[v[a+48>>2]+12>>2],m);b:while(1){if(!Pb(v[c>>2],v[c+8>>2],1)){break a}l=Le(c);if((l|0)==255){break a}d=l&31;g=B(d,6)+C|0;i=Pg(v[v[a+48>>2]+12>>2])>>>0>d>>>0;j=i?g:k;e=1;if(!(l&64)){d=Le(c);h=d<<24>>24;e=255;d=d&127;c:{d:{if((d|0)==1){break d}e=d-1|0;if(b?e>>>0<=120:0){break d}if((d-109&255)>>>0<159|b){break c}e=d+13|0}t[j|0]=e}E=i?g+1|0:x,F=Le(c),t[E|0]=F;e=(h|0)<0}h=i?g+3|0:p;d=i?g+5|0:q;n=i?g+4|0:r;i=i?g+2|0:s;while(1){e:{f:{g:{if(e&1){v[f+16>>2]=w[j|0]|w[j+1|0]<<8|(w[j+2|0]<<16|w[j+3|0]<<24);u[f+20>>1]=w[j+4|0]|w[j+5|0]<<8;o=Le(c);g=o&63;if(o&64){t[i|0]=1;t[n|0]=g;break e}e=Le(c);t[d|0]=e;if(g>>>0<=15){Of(j,g,e);h:{i:{j:{e=w[h|0];switch(e-9|0){case 1:case 2:case 3:break f;case 4:break i;case 0:break j;default:break h}}t[h|0]=9;t[d|0]=B(w[d|0]&15,17);break f}t[h|0]=0;t[i|0]=1;v[f+12>>2]=w[d|0]+1>>>1;v[f+8>>2]=64;E=n,F=v[sd(f+12|0,f+8|0)>>2],t[E|0]=F;break f}if((e|0)!=19){break f}if(w[d|0]==128){break g}Vu(j);break f}if(g>>>0>44){break f}t[h|0]=w[g+26208|0];k:{switch(g-16|0){case 0:if(e>>>0>1){break g}t[d|0]=e|158;break f;case 1:case 2:t[f+12|0]=15;E=d,F=w[Wb(f+12|0,d)|0]|224,t[E|0]=F;break f;case 5:case 6:v[f+12>>2]=16;v[f+8>>2]=e+1;E=d,F=v[sd(f+12|0,f+8|0)>>2]/2|240,t[E|0]=F;break f;case 14:l:{m:{n:{o:{p:{g=e>>>4|0;switch(g-1|0){case 1:break n;case 0:break o;default:break p}}switch(g-10|0){case 1:break l;case 0:break m;default:break g}}t[h|0]=2;t[d|0]=e|240;break f}t[h|0]=3;t[d|0]=e|240;break f}t[h|0]=11;t[d|0]=(e<<3&120)+8|15;break f}t[h|0]=11;t[d|0]=(e&15)+1>>>1|240;break f;case 12:break k;default:break f}}v[f+12>>2]=e+1>>>1;v[f+8>>2]=64;E=d,F=v[sd(f+12|0,f+8|0)>>2],t[E|0]=F;break f}if(!(l&128)){continue b}break a}t[h|0]=0}Uu(h,d,A,z);e=w[f+19|0];D=Ji(e);g=w[h|0];if(D>>>0<=Ji(g)>>>0){break e}if(!w[i|0]){Oq(f,g,w[d|0],1);g=w[f+1|0];t[i|0]=w[f|0];t[n|0]=g}t[h|0]=e;t[d|0]=w[f+21|0]}e=o>>>7|0;continue}}}jb=f+32|0;return}m=m+1|0;continue}}function z6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-112|0;jb=d;e=v[b+4>>2];a:{if(!e){break a}f=v[b>>2];h=w[cl(f,e)|0];if((h|0)==33){c=1}else{if((h|0)!=63){break a}c=0}jl(d+88|0,f,e,e-1|0);e=v[d+92>>2];v[b>>2]=v[d+88>>2];v[b+4>>2]=e}f=d+88|0;Wd(f);e=v[d+88>>2];Wd(d+72|0);e=bl(e,v[d+76>>2],b);Wd(f);b:{c:{d:{e:{if((e|0)==v[d+92>>2]){a=v[b+4>>2];e=v[b>>2];f=qc(d+104|0,21619);h=v[f+4>>2];v[d>>2]=v[f>>2];v[d+4>>2]=h;if(Pc(e,a,d)){a=ba(8)|0;v[23588]=0;c=Q(55,d+88|0,10432)|0;b=v[23588];v[23588]=0;if((b|0)==1){break d}a=rc(a,c);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(c);break c}g=0;if(!c){break e}a=ba(8)|0;c=v[b+4>>2];b=v[b>>2];v[23588]=0;e=Kh(d+72|0,b,c);b=v[23588];v[23588]=0;f:{g:{h:{if((b|0)!=1){v[23588]=0;U(967,d+88|0,17634,e|0);b=v[23588];v[23588]=0;if((b|0)==1){break h}c=0;b=rc(a,d+88|0);v[23588]=0;U(119,b|0,62688,956);b=v[23588];v[23588]=0;if((b|0)!=1){break b}b=P()|0;O()|0;yb(d+88|0);break g}b=P()|0;O()|0;break f}b=P()|0;c=1;O()|0}yb(e);if(!c){break c}}ca(a|0);break c}if(v[e+4>>2]!=2){a=ba(8)|0;v[23588]=0;c=Q(55,d+88|0,11504)|0;b=v[23588];v[23588]=0;if((b|0)!=1){a=rc(a,c);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(c);break c}b=P()|0;O()|0;ca(a|0);break c}c=v[b+4>>2];b=v[b>>2];e=qc(d- -64|0,21619);f=v[e+4>>2];v[d+32>>2]=v[e>>2];v[d+36>>2]=f;if(Pc(b,c,d+32|0)){a=ba(8)|0;v[23588]=0;c=Q(55,d+88|0,10432)|0;b=v[23588];v[23588]=0;if((b|0)!=1){a=rc(a,c);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(c);break c}b=P()|0;O()|0;ca(a|0);break c}e=qc(d+56|0,7719);f=v[e+4>>2];v[d+24>>2]=v[e>>2];v[d+28>>2]=f;if(Pc(b,c,d+24|0)){g=1;if(!Pd(w[a+28|0])){break e}g=65536/+y[v[a+24>>2]+480244>>2];break e}e=qc(d+48|0,7771);f=v[e+4>>2];v[d+16>>2]=v[e>>2];v[d+20>>2]=f;if(Pc(b,c,d+16|0)){g=1;if(!Pd(w[a+28|0])){break e}g=+y[v[a+24>>2]+480240>>2]*152587890625e-16;break e}e=qc(d+40|0,7789);f=v[e+4>>2];v[d+8>>2]=v[e>>2];v[d+12>>2]=f;g=0;if(!Pc(b,c,d+8|0)){break e}g=+y[v[a+24>>2]+480236>>2]*152587890625e-16}jb=d+112|0;return+g}b=P()|0;O()|0;ca(a|0)}T(b|0)}L()}function st(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;i=jb-16|0;jb=i;f=v[a+24>>2];h=lz(f,w[a+32|0]);j=v[h>>2];a:{if(Qc(j,v[h+4>>2])>>>0<=b>>>0){break a}if(DO(f,x[cc(j,b)>>1])>>>0<=c>>>0){break a}h=v[a>>2];b:{if(xd(h,v[a+4>>2])>>>0>b>>>0){if(y[Md(h,b)+4>>2]>c>>>0){break b}}$n(a,0);if(xd(v[a>>2],v[a+4>>2])>>>0<=b>>>0){break a}f=v[a+24>>2]}fc(i,v[d>>2],x[f+480188>>1]);d=i+8|0;h=v[i>>2];f=e?-2046629010:-2078137563;e=e?-1352371636:-873292572;j=v[i+4>>2];while(1){if(!g&(k|0)==(j|0)){v[d>>2]=f;v[d+4>>2]=e}else{l=w[tQ(h,k)+841|0];m=l^Lka(f^k,e^g,435,256);l=!l;f=(q=f,r=Lka(m,mb,435,256),s=l,s?q:r);e=l?e:mb;k=k+1|0;g=k?g:g+1|0;continue}break}e=d;d=0;f=xm(i,b,c);h=jb-16|0;jb=h;k=a+12|0;g=tO(x[f>>1],v[f+4>>2],Sd(k),ic(k));c:{if(Ob(g,Yf(k))){j=x[f>>1];l=v[f+4>>2];f=vd(g);if(!ll(j,l,x[f>>1],v[f+4>>2])){break c}}g=Yf(k)}f=v[ec(h+8|0,g)>>2];jb=h+16|0;if(Hg(f,wf(k))){d=vd(f);d=oc(v[d+8>>2],v[d+12>>2])^1}h=v[e>>2]!=-2078137563|v[e+4>>2]!=-873292572;Cb(i,v[Md(v[a>>2],b)>>2],c);g=1;j=d|h;m=Bb(v[v[i>>2]>>2],v[i+4>>2])^1;if(!(m?1:j)){break a}d:{e:{f:{g:{if(d){l=vd(f);f=Eb(v[l+8>>2]);n=Eb(v[l+12>>2]);o=v[e>>2];p=v[e+4>>2];j=jb-16|0;jb=j;v[j+8>>2]=f;while(1){if(!(!Ob(f,n)|v[f>>2]==(o|0)&v[f+4>>2]==(p|0))){f=v[ut(j+8|0)>>2];continue}break}jb=j+16|0;if(Ob(f,Eb(v[l+12>>2]))){break a}if(!h){break e}break g}if(h){break g}if(!j){break d}break f}v[a+28>>2]=v[a+28>>2]+1}if(d|m){break e}d=rO(k,xm(i,b,c));h:{if(y[d+4>>2]<y[Fb(d)>>2]){g=jb-16|0;jb=g;d=qO(g,d);oO(v[d+4>>2]);v[d+4>>2]=v[d+4>>2]+8;kc(d);jb=g+16|0;break h}f=jb-32|0;jb=f;g=Fb(d);g=mr(f+8|0,nr(d,Ug(v[d>>2],v[d+4>>2])+1|0),Ug(v[d>>2],v[d+4>>2]),g);oO(v[g+8>>2]);v[g+8>>2]=v[g+8>>2]+8;Dd(d,g);lr(g);jb=f+32|0}}d=rO(k,xm(i,b,c));i:{if(y[d+4>>2]<y[Fb(d)>>2]){g=jb-16|0;jb=g;d=qO(g,d);pO(v[d+4>>2],v[e>>2],v[e+4>>2]);v[d+4>>2]=v[d+4>>2]+8;kc(d);jb=g+16|0;break i}f=jb-32|0;jb=f;g=Fb(d);g=mr(f+8|0,nr(d,Ug(v[d>>2],v[d+4>>2])+1|0),Ug(v[d>>2],v[d+4>>2]),g);pO(v[g+8>>2],v[e>>2],v[e+4>>2]);v[g+8>>2]=v[g+8>>2]+8;Dd(d,g);lr(g);jb=f+32|0}}Cb(i,v[Md(v[a>>2],b)>>2],c);Ye(i,1);g=0}jb=i+16|0;return g|0}function Ex(a){a=a|0;var b=0,c=0,d=C(0),e=0;Tb(a+4960|0,0,76);t[a+5044|0]=0;v[a+5036>>2]=0;v[a+5040>>2]=0;b=v[a+4292>>2];d=z[a+4268>>2];v[23588]=0;e=a+4504|0;if(d<C(4294967296)&d>=C(0)){c=~~d>>>0}else{c=0}ea(929,e|0,67,5,c|0,b|0);b=v[23588];v[23588]=0;a:{if((b|0)==1){break a}b=v[a+4296>>2];v[23588]=0;ea(929,a+4528|0,62,5,c|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break a}b=v[a+4300>>2];v[23588]=0;ea(929,a+4552|0,53,5,c|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break a}b=v[a+4304>>2];v[23588]=0;ea(929,a+4576|0,43,5,c|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break a}b=v[a+4308>>2];v[23588]=0;ea(929,a+4600|0,32,5,c|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break a}b=v[a+4312>>2];v[23588]=0;ea(929,a+4624|0,22,5,c|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break a}b=v[a+4316>>2];v[23588]=0;ea(929,a+4648|0,75,5,c|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break a}b=v[a+4320>>2];v[23588]=0;ea(929,a+4672|0,69,5,c|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break a}b=v[a+4324>>2];v[23588]=0;ea(929,a+4696|0,60,5,c|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break a}b=v[a+4328>>2];v[23588]=0;ea(929,a+4720|0,48,5,c|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break a}b=v[a+4332>>2];v[23588]=0;ea(929,a+4744|0,36,5,c|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break a}b=v[a+4336>>2];v[23588]=0;ea(929,a+4768|0,25,5,c|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break a}v[23588]=0;ea(929,a+4792|0,0,0,0,0);b=v[23588];v[23588]=0;if((b|0)==1){break a}b=v[a+4344>>2];v[23588]=0;ea(929,a+4816|0,3,0,c|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break a}b=v[a+4348>>2];v[23588]=0;ea(929,a+4840|0,3,0,c|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break a}v[23588]=0;ea(929,a+4864|0,407,1,c|0,0);b=v[23588];v[23588]=0;if((b|0)==1){break a}v[23588]=0;ea(929,a+4888|0,400,1,c|0,0);b=v[23588];v[23588]=0;if((b|0)==1){break a}v[23588]=0;ea(929,a+4912|0,10,0,c|0,-1);b=v[23588];v[23588]=0;if((b|0)==1){break a}v[23588]=0;ea(929,a+4936|0,10,0,c|0,-1);c=v[23588];v[23588]=0;if((c|0)==1){break a}t[a+5045|0]=1;return}c=V(92948)|0;if((O()|0)==(da(92948)|0)){_(c|0)|0;t[a+5045|0]=0;$();return}T(c|0);L()}function Qea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-128|0;jb=d;a:{b:{c:{d:{switch(w[a|0]-23|0){case 0:e=t[a+1|0];f=d,g=aB(c,+w[a+2|0]*1e4/240),t[f|0]=g;v[d+96>>2]=127;v[d+80>>2]=(B(w[a+3|0],127)>>>0)/185;f=d,g=v[sd(d+96|0,d+80|0)>>2],t[f+127|0]=g;e:{switch(((e>>>0)%5|0)-1|0){case 0:Ju(d+80|0,15572);v[23588]=0;R(544,d- -64|0,d|0);a=v[23588];v[23588]=0;f:{g:{h:{i:{if((a|0)!=1){v[23588]=0;R(544,d+48|0,d+127|0);a=v[23588];v[23588]=0;if((a|0)==1){break i}v[23588]=0;X(545,d+96|0,d+80|0,d- -64|0,d+48|0);a=v[23588];v[23588]=0;if((a|0)==1){break h}a=d+96|0;Fe(d+112|0,a);gf(b,v[d+112>>2],v[d+116>>2]);yb(a);yb(d+48|0);yb(d- -64|0);_b(d+80|0);break b}a=P()|0;O()|0;break f}a=P()|0;O()|0;break g}a=P()|0;O()|0;yb(d+48|0)}yb(d- -64|0)}break c;case 1:Ju(d+80|0,15512);v[23588]=0;R(544,d- -64|0,d|0);a=v[23588];v[23588]=0;j:{k:{l:{m:{if((a|0)!=1){v[23588]=0;R(544,d+48|0,d+127|0);a=v[23588];v[23588]=0;if((a|0)==1){break m}v[23588]=0;X(545,d+96|0,d+80|0,d- -64|0,d+48|0);a=v[23588];v[23588]=0;if((a|0)==1){break l}a=d+96|0;Fe(d+40|0,a);gf(b,v[d+40>>2],v[d+44>>2]);yb(a);yb(d+48|0);yb(d- -64|0);_b(d+80|0);break b}a=P()|0;O()|0;break j}a=P()|0;O()|0;break k}a=P()|0;O()|0;yb(d+48|0)}yb(d- -64|0)}break c;default:break e}}a=qc(d+32|0,15599);gf(b,v[a>>2],v[a+4>>2]);break b;case 1:break d;default:break a}}c=t[a+1|0];t[d+127|0]=(c|0)<5?c:0;c=t[a+2|0];t[d+31|0]=(c|0)>=0?c:127;a=t[a+3|0];t[d+30|0]=(a|0)>=0?a:127;a=jb-16|0;jb=a;c=Mc(a,4051);$c(d+80|0,c);yb(c);jb=a+16|0;v[23588]=0;R(544,d- -64|0,d+127|0);a=v[23588];v[23588]=0;n:{o:{p:{q:{r:{s:{if((a|0)!=1){v[23588]=0;R(544,d+48|0,d+31|0);a=v[23588];v[23588]=0;if((a|0)==1){break s}v[23588]=0;R(544,d|0,d+30|0);a=v[23588];v[23588]=0;if((a|0)==1){break r}v[23588]=0;ea(710,d+96|0,d+80|0,d- -64|0,d+48|0,d|0);a=v[23588];v[23588]=0;if((a|0)==1){break q}a=d+96|0;Fe(d+16|0,a);gf(b,v[d+16>>2],v[d+20>>2]);yb(a);yb(d);yb(d+48|0);yb(d- -64|0);_b(d+80|0);break b}a=P()|0;O()|0;break n}a=P()|0;O()|0;break o}a=P()|0;O()|0;break p}a=P()|0;O()|0;yb(d)}yb(d+48|0)}yb(d- -64|0)}}_b(d+80|0);T(a|0);L()}e=1}jb=d+128|0;return e|0}function nca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;f=jb-48|0;jb=f;s=v[a+16>>2];t=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);b=0;o=v[a+128>>2];if(o){e=v[a+8>>2];j=v[a+12>>2];p=kg(e,j,o);q=mb;g=v[a+76>>2];Pf(v[a>>2],v[a+4>>2],kf(e,j,d),mb);j=g>>>0<mb>>>0?d:0}else{j=0}i=a+112|0;while(1){if((b|0)!=2){e=b<<3;h=e+(f+16|0)|0;e=a+e|0;v[h+4>>2]=v[e+44>>2];v[h+8>>2]=v[e+48>>2];b=b+1|0;continue}break}m=v[a+40>>2];n=v[a+36>>2];b=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=b;w=v[a+8>>2];x=v[a+12>>2];a:while(1){if(d){d=d-1|0;b=v[f+12>>2];e=v[f+8>>2];v[f+40>>2]=e;v[f+44>>2]=0;j=j-1|0;p=j?p:0;q=j?q:0;l=((((b&2147483647)<<1|e>>>31)&2147483646)<<1)+s|0;b=o;while(1)if((b|0)<=0){Qb(i,v[a+120>>2],v[a+124>>2]);h=v[a+116>>2];if(h){b=(v[f+44>>2]&2147483647)<<1|v[f+40>>2]>>>31;Rd(i,(u[(b<<1|2)+l>>1]+u[l+((b&2147483646)<<1)>>1]|0)/8<<16>>16);Qd(i,h);v[i>>2]=v[i>>2];v[i+4>>2]=0}b=ig(i,t);v[f+4>>2]=b;v[f>>2]=b;y=v[a+72>>2];b=v[a+68>>2];z=b;A=b>>31;b=v[a+64>>2];C=b;D=b>>31;b=v[a+60>>2];E=b;F=b>>31;b=0;while(1){if((b|0)!=2){r=(b<<2)+f|0;e=v[r>>2];g=(f+16|0)+(b<<3)|0;G=v[g+8>>2];k=v[g+4>>2];v[g+8>>2]=k;l=e<<8;e=l;e=Lka(E,F,e,e>>31);h=mb;H=g;g=e;e=Xb(k,-16777216,16776704);e=Lka(C,D,e,e>>31);k=g+e|0;g=mb+h|0;g=e>>>0>k>>>0?g+1|0:g;e=Xb(G,-16777216,16776704);h=Lka(z,A,e,e>>31);k=h+k|0;e=mb+g|0;e=h>>>0>k>>>0?e+1|0:e;h=k+8388608|0;e=h>>>0<8388608?e+1|0:e;e=Xc(h,e,24);v[H+4>>2]=e-(l&y);v[r>>2]=(e|0)/256;b=b+1|0;continue}break}b=v[a+32>>2];n=v[a+28>>2]+n|0;v[c>>2]=v[c>>2]+B(v[f>>2],n>>12);m=b+m|0;v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],m>>12);Qb(f+8|0,w,x);c=c+8|0;continue a}else{e=(v[f+44>>2]&2147483647)<<1|v[f+40>>2]>>>31;Rd(i,(u[(e<<1|2)+l>>1]+u[l+((e&2147483646)<<1)>>1]|0)/8<<16>>16);Qd(i,4);Qb(f+40|0,p,q);b=b-1|0;continue}}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;v[a+40>>2]=m;v[a+20>>2]=n>>12;v[a+36>>2]=n;v[a+24>>2]=m>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+16|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}jb=f+48|0}function t8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=C(0),h=C(0),i=0,j=0,k=0,l=C(0),m=0,n=C(0),o=0,p=0,q=0,r=0,s=0,t=0,u=0,x=0,y=C(0),A=0,B=0,E=0,F=0,G=0,H=0,I=C(0),J=0,K=0,L=0,M=0,N=0,O=C(0),P=0,Q=C(0);a:{if(!v[a+4316>>2]){break a}if(!$h(a+44|0)){break a}G=a+4300|0;H=a+4288|0;J=a+4264|0;K=a+4276|0;e=v[a+44>>2];s=Jc(e,0);t=Jc(e,1);e=v[a+56>>2];u=Jc(e,0);x=Jc(e,1);L=nb[v[v[a>>2]+196>>2]](a)|0;y=C(C(nb[v[v[a>>2]+204>>2]](a))/C(100));I=C(nb[v[v[a>>2]+192>>2]](a));A=nb[v[v[a>>2]+216>>2]](a)|0;M=A&1;o=v[a+4324>>2];i=v[a+4320>>2];m=v[a+4328>>2];k=v[a+4312>>2];N=v[a+4276>>2];p=v[a+4264>>2];B=v[a+4256>>2];E=w[a+4260|0];r=a+4316|0;F=d;while(1){if(F){h=z[t>>2];l=z[s>>2];j=v[r>>2];e=Ln(j,k+B|0);j=Ln(j,k);b:{if(E){P=Db(H,m),Q=l,z[P>>2]=Q;P=Db(G,m),Q=h,z[P>>2]=Q;q=Db(p,e);P=Db(p,j),Q=C(C(z[q>>2]*y)+l),z[P>>2]=Q;g=C(C(z[Db(N,e)>>2]*y)+h);e=K;break b}g=C(C(z[Db(p,e)>>2]*y)+C(C(l+h)*C(.5)));e=J}P=Db(v[e>>2],j),Q=g,z[P>>2]=Q;c:{if(L){f=z[a+4244>>2];g=C(f+z[a+4236>>2]);z[a+4236>>2]=g;f=C(f+z[a+4240>>2]);z[a+4240>>2]=f;if(g>C(1)){g=C(g+C(-2));z[a+4236>>2]=g}if(f>C(1)){f=C(f+C(-2));z[a+4240>>2]=f}g=C(D(g));g=C(C(g+g)+C(-1));f=C(D(f));f=C(C(f+f)+C(-1));break c}f=z[a+4240>>2];n=z[a+4244>>2];g=C(C(f*n)+z[a+4236>>2]);z[a+4236>>2]=g;f=C(f-C(g*n));z[a+4240>>2]=f}if(E){e=(m+2|0)%3|0;l=z[Db(H,e)>>2];h=z[Db(G,e)>>2]}e=v[r>>2];j=Db(p,Ln(e,i+k|0));q=e;e=k+4096|0;O=z[Db(p,Ln(q,e+i|0))>>2];n=z[j>>2];z[u>>2]=C(C(C(C(C(O-n)*C(C(i&4095)*C(.000244140625)))+n)-l)*I)+l;i=v[(E?4276:4264)+a>>2];j=v[r>>2];q=Db(i,Ln(j,k+o|0));n=z[Db(i,Ln(j,e+o|0))>>2];l=z[q>>2];z[x>>2]=C(C(C(C(C(n-l)*C(C(o&4095)*C(.000244140625)))+l)-h)*I)+h;m=((m|0)<=0?m+3|0:m)-1|0;v[a+4328>>2]=m;k=(((k|0)>0?0:v[r>>2]<<12)+k|0)-4096|0;v[a+4312>>2]=k;h=M?f:g;f=z[a+4248>>2];h=C(h*f);d:{if(C(D(h))<C(2147483648)){e=~~h;break d}e=-2147483648}o=(A>>>0>1?e:0-e|0)+B|0;v[a+4324>>2]=o;i=A>>>0<4;t=t+4|0;s=s+4|0;g=C(g*f);e:{if(C(D(g))<C(2147483648)){e=~~g;break e}e=-2147483648}i=(i?e:0-e|0)+B|0;v[a+4320>>2]=i;F=F-1|0;x=x+4|0;u=u+4|0;continue}else{e=a;a=v[a+56>>2];ri(e,b,c,Jc(a,0),Jc(a,1),d)}break}}}function b7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=0,g=0,h=0,i=0,j=0,k=C(0),l=0,m=C(0),n=0,o=C(0),p=C(0),q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,A=C(0),B=0,D=0,E=0,F=0,G=C(0),H=0,I=0,J=0,K=0,L=C(0),M=C(0),N=C(0),O=C(0),P=C(0),Q=0,R=C(0);if($h(a+44|0)){f=v[a+44>>2];B=Jc(f,0);D=Jc(f,1);f=v[a+56>>2];E=Jc(f,0);F=Jc(f,1);s=v[a+4296>>2];g=s+1|0;l=a+4304|0;f=a+4272|0;u=g+v[Db(f,0)>>2]&4095;q=l+(u<<4)|0;w=g+v[Db(f,1)>>2]&4095;n=((w<<4)+l|0)+4|0;x=g+v[Db(f,2)>>2]&4095;j=((x<<4)+l|0)+8|0;h=Db(f,3);i=v[Db(f,4)>>2];r=v[a+4300>>2];i=i+r|0;y=g+v[h>>2]&4095;h=((y<<4)+l|0)+12|0;t=v[Db(f,5)>>2]+r|0;g=a+4232|0;H=a+69840|0;I=a+78032|0;f=d;while(1){if(f){L=z[h>>2];M=z[j>>2];N=z[n>>2];O=z[q>>2];A=z[D>>2];P=z[B>>2];J=i&1023;j=(J<<3)+H|0;k=z[j+4>>2];u=u-1&4095;q=(u<<4)+l|0;e=z[q>>2];h=r<<3;i=h+H|0;w=w-1&4095;n=(w<<4)+l|0;m=z[n+4>>2];o=m;p=C(m*C(.6180340051651001));G=z[j>>2];m=z[Db(g,0)>>2];p=C(p+C(G*m));z[i+4>>2]=o+C(p*C(-.6180340051651001));o=e;e=C(C(k*m)+C(e*C(-.6180340051651001)));z[i>>2]=o+C(e*C(.6180340051651001));z[q>>2]=p;z[n+4>>2]=e;t=t&1023;K=(t<<3)+I|0;m=z[K+4>>2];x=x-1&4095;i=(x<<4)+l|0;e=z[i+8>>2];h=h+I|0;y=y-1&4095;j=(y<<4)+l|0;k=z[j+12>>2];o=k;G=z[K>>2];p=z[Db(g,1)>>2];k=C(C(k*C(.6180340051651001))+C(G*p));z[h+4>>2]=o+C(k*C(-.6180340051651001));o=e;e=C(C(m*p)+C(e*C(-.6180340051651001)));z[h>>2]=o+C(e*C(.6180340051651001));z[i+8>>2]=k;z[j+12>>2]=e;e=C(P+C(1.0000000031710769e-30));z[E>>2]=k+C(C(e*z[a+4224>>2])+z[q>>2]);k=C(A+C(1.0000000031710769e-30));z[F>>2]=C(C(k*z[a+4224>>2])+z[n+4>>2])+z[j+12>>2];h=(s<<4)+l|0;m=e;e=z[a+4228>>2];A=C(m*e);Q=h,R=C(A+C(C(z[q>>2]*z[Db(g,2)>>2])+C(O*z[Db(g,3)>>2]))),z[Q>>2]=R;e=C(k*e);Q=h,R=C(e+C(C(z[n+4>>2]*z[Db(g,4)>>2])+C(N*z[Db(g,5)>>2]))),z[Q+4>>2]=R;Q=h,R=C(C(C(z[i+8>>2]*z[Db(g,6)>>2])+C(M*z[Db(g,7)>>2]))-e),z[Q+8>>2]=R;Q=h,R=C(A+C(C(z[j+12>>2]*z[Db(g,8)>>2])+C(L*z[Db(g,9)>>2]))),z[Q+12>>2]=R;h=j+12|0;j=i+8|0;n=n+4|0;f=f-1|0;F=F+4|0;E=E+4|0;D=D+4|0;B=B+4|0;t=t-1|0;i=J-1|0;r=r-1&1023;s=s-1&4095;continue}else{v[a+4300>>2]=r;v[a+4296>>2]=s;f=a;a=v[a+56>>2];ri(f,b,c,Jc(a,0),Jc(a,1),d)}break}}}function tca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;f=jb-48|0;jb=f;q=v[a+16>>2];r=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);b=0;m=v[a+128>>2];if(m){e=v[a+8>>2];k=v[a+12>>2];n=kg(e,k,m);o=mb;i=v[a+76>>2];Pf(v[a>>2],v[a+4>>2],kf(e,k,d),mb);k=i>>>0<mb>>>0?d:0}else{k=0}j=a+112|0;while(1){if((b|0)!=2){e=b<<3;h=e+(f+16|0)|0;e=a+e|0;v[h+4>>2]=v[e+44>>2];v[h+8>>2]=v[e+48>>2];b=b+1|0;continue}break}s=v[a+24>>2];u=v[a+20>>2];b=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=b;w=v[a+8>>2];x=v[a+12>>2];while(1){if(d){d=d-1|0;b=v[f+12>>2];e=v[f+8>>2];v[f+40>>2]=e;v[f+44>>2]=0;k=k-1|0;n=k?n:0;o=k?o:0;l=(((b&2147483647)<<1|e>>>31)&-2)+q|0;e=m;a:{b:while(1){c:{if((e|0)<=0){Qb(j,v[a+120>>2],v[a+124>>2]);h=v[a+116>>2];if(!h){break a}e=((v[f+44>>2]&2147483647)<<1|v[f+40>>2]>>>31)&-2;g=0;b=0;break c}h=((v[f+44>>2]&2147483647)<<1|v[f+40>>2]>>>31)&-2;b=0;g=0;while(1)if((b|0)==2){Rd(j,(g|0)/8<<16>>16);Qd(j,4);Qb(f+40|0,n,o);e=e-1|0;continue b}else{g=(t[l+(b+h|0)|0]<<8)+g|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){g=(t[l+(b+e|0)|0]<<8)+g|0;b=b+1|0;continue}break}Rd(j,(g|0)/8<<16>>16);Qd(j,h);v[j>>2]=v[j>>2];v[j+4>>2]=0}b=ig(j,r);v[f+4>>2]=b;v[f>>2]=b;y=v[a+72>>2];b=v[a+68>>2];z=b;A=b>>31;b=v[a+64>>2];C=b;D=b>>31;b=v[a+60>>2];E=b;F=b>>31;b=0;while(1){if((b|0)!=2){p=(b<<2)+f|0;e=v[p>>2];i=(f+16|0)+(b<<3)|0;G=v[i+8>>2];g=v[i+4>>2];v[i+8>>2]=g;l=e<<8;e=l;e=Lka(E,F,e,e>>31);h=mb;H=i;i=e;e=Xb(g,-16777216,16776704);e=Lka(C,D,e,e>>31);g=i+e|0;i=mb+h|0;i=e>>>0>g>>>0?i+1|0:i;e=Xb(G,-16777216,16776704);h=Lka(z,A,e,e>>31);g=h+g|0;e=mb+i|0;e=g>>>0<h>>>0?e+1|0:e;h=g+8388608|0;e=h>>>0<8388608?e+1|0:e;e=Xc(h,e,24);v[H+4>>2]=e-(l&y);v[p>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[f>>2],u);v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],s);Qb(f+8|0,w,x);c=c+8|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+16|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}jb=f+48|0}function uP(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=jb-128|0;jb=j;a:{b:{c:{if(!Gm(f,g,h,i,0,0,0,0)){break c}m=i&65535;n=i>>>16&32767;d:{e:{if((n|0)!=32767){l=4;if(n){break e}l=f|h|(g|m)?3:2;break d}l=!(f|h|(g|m))}}r=e>>>16|0;o=r&32767;if((o|0)==32767){break c}if(l){break b}}Id(j+16|0,b,c,d,e,f,g,h,i);e=v[j+16>>2];d=v[j+20>>2];c=v[j+24>>2];b=v[j+28>>2];GP(j,e,d,c,b,e,d,c,b);d=v[j+8>>2];e=v[j+12>>2];h=v[j>>2];i=v[j+4>>2];break a}m=e&65535|o<<16;p=m;l=d;m=h;q=i>>>16&32767;k=i&65535|q<<16;if((Gm(b,c,l,p,f,g,h,k)|0)<=0){if(Gm(b,c,l,p,f,g,m,k)){h=b;i=c;break a}Id(j+112|0,b,c,d,e,0,0,0,0);d=v[j+120>>2];e=v[j+124>>2];h=v[j+112>>2];i=v[j+116>>2];break a}if(o){i=c;h=b}else{Id(j+96|0,b,c,l,p,0,0,0,1081540608);h=v[j+108>>2];p=h;l=v[j+104>>2];o=(h>>>16|0)-120|0;i=v[j+100>>2];h=v[j+96>>2]}if(!q){Id(j+80|0,f,g,m,k,0,0,0,1081540608);f=v[j+92>>2];k=f;m=v[j+88>>2];q=(k>>>16|0)-120|0;g=v[j+84>>2];f=v[j+80>>2]}s=k&65535|65536;p=p&65535|65536;if((o|0)>(q|0)){while(1){t=l-m|0;k=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;n=(p-((l>>>0<m>>>0)+s|0)|0)-(t>>>0<k>>>0)|0;k=t-k|0;f:{if((n|0)>0|(n|0)>=0){l=h;h=h-f|0;i=i-((f>>>0>l>>>0)+g|0)|0;if(!(h|k|(i|n))){Id(j+32|0,b,c,d,e,0,0,0,0);d=v[j+40>>2];e=v[j+44>>2];h=v[j+32>>2];i=v[j+36>>2];break a}n=n<<1|k>>>31;l=k<<1|i>>>31;p=n;break f}n=p<<1|l>>>31;l=l<<1|i>>>31;p=n}n=i<<1|h>>>31;h=h<<1;i=n;o=o-1|0;if((q|0)<(o|0)){continue}break}o=q}q=l-m|0;n=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;k=(p-((l>>>0<m>>>0)+s|0)|0)-(q>>>0<n>>>0)|0;m=q-n|0;g:{if((k|0)<0){m=l;k=p;break g}l=h;h=h-f|0;i=i-((f>>>0>l>>>0)+g|0)|0;if(h|m|(i|k)){break g}Id(j+48|0,b,c,d,e,0,0,0,0);d=v[j+56>>2];e=v[j+60>>2];h=v[j+48>>2];i=v[j+52>>2];break a}if((k|0)==65535|k>>>0<65535){while(1){b=i>>>31|0;o=o-1|0;p=i<<1|h>>>31;h=h<<1;i=p;c=b;b=m;k=k<<1|b>>>31;m=c|b<<1;if(k>>>0<65536){continue}break}}b=r&32768;if((o|0)<=0){Id(j- -64|0,h,i,m,k&65535|(b|o+120)<<16,0,0,0,1065811968);d=v[j+72>>2];e=v[j+76>>2];h=v[j+64>>2];i=v[j+68>>2];break a}d=m;e=k&65535|(b|o)<<16}v[a>>2]=h;v[a+4>>2]=i;v[a+8>>2]=d;v[a+12>>2]=e;jb=j+128|0}function $ba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=jb-16|0;jb=h;c=qf(a,c);me(h,v[a+36>>2]);j=a;a:{if(!c){Rc(h,a+32|0,5);e=0;if(Bb(v[v[h>>2]>>2],v[h+4>>2])){break a}}e=jb-240|0;jb=e;g=Zl(e+128|0,v[a+36>>2]);v[23588]=0;f=Q(449,e+112|0,27800)|0;a=v[23588];v[23588]=0;b:{c:{d:{e:{if((a|0)!=1){v[23588]=0;v[e+96>>2]=19988498;v[e+100>>2]=0;U(450,g|0,f|0,e+96|0);a=v[23588];v[23588]=0;if((a|0)==1){break e}_b(f);if(!Kk(w[g|0])){break d}break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;_b(f);break c}t[e+111|0]=0;v[23588]=0;f=Q(449,e+96|0,5508)|0;a=v[23588];v[23588]=0;f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if((a|0)!=1){v[23588]=0;U(451,g|0,e+111|0,f|0);a=v[23588];v[23588]=0;if((a|0)==1){break q}_b(f);f=Lb(e+80|0);v[23588]=0;a=Q(449,e- -64|0,10044)|0;i=v[23588];v[23588]=0;if((i|0)==1){break p}v[23588]=0;U(755,g|0,f|0,a|0);i=v[23588];v[23588]=0;if((i|0)==1){break o}_b(a);v[23588]=0;U(11,e+48|0,(w[e+111|0]?0:d)|0,f|0);d=v[23588];v[23588]=0;if((d|0)==1){break n}v[23588]=0;R(273,b|0,e+48|0);d=v[23588];v[23588]=0;if((d|0)==1){break m}d=e+48|0;zb(d);u[e+46>>1]=0;v[23588]=0;d=Q(449,d|0,10704)|0;a=v[23588];v[23588]=0;if((a|0)==1){break g}v[23588]=0;W(479,g|0,e+46|0,d|0)|0;a=v[23588];v[23588]=0;if((a|0)==1){break l}_b(d);Ef(e+46|0,4e3);v[23588]=0;d=Q(449,e+32|0,13325)|0;a=v[23588];v[23588]=0;if((a|0)==1){break k}i=x[e+46>>1];a=v[ec(e+24|0,i)>>2];v[23588]=0;X(756,g|0,b|0,d|0,a|0);a=v[23588];v[23588]=0;if((a|0)==1){break j}_b(d);u[e+22>>1]=65535;v[23588]=0;d=Q(449,e+8|0,8924)|0;a=v[23588];v[23588]=0;if((a|0)==1){break i}v[23588]=0;k=W(479,g|0,e+22|0,d|0)|0;a=v[23588];v[23588]=0;if((a|0)==1){break h}a=x[e+22>>1];_b(d);if(a>>>0<i>>>0&k){Ue(b,a)}yb(f);break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;_b(f);break c}b=P()|0;O()|0;break f}b=P()|0;O()|0;_b(a);break f}b=P()|0;O()|0;break f}b=P()|0;O()|0;zb(e+48|0);break f}b=P()|0;O()|0;_b(d);break f}b=P()|0;O()|0;break f}b=P()|0;O()|0;_b(d);break f}b=P()|0;O()|0;break f}b=P()|0;O()|0;_b(d);break f}b=P()|0;O()|0}yb(f)}kh(g);T(b|0);L()}kh(g);jb=e+240|0;e=c}Xe(j,e);jb=h+16|0}function Uca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;e=jb-48|0;jb=e;a:{b:{c:{j=v[a+12>>2];l=v[a+8>>2];d:{if((j|0)<=1&l>>>0<=805306368|(j|0)<=0){if((j|0)>=-2&l>>>0>=3489660928|(j|0)>-2){break c}if((j|0)==-2&l>>>0>2147483647|j>>>0>4294967294){break d}break b}if((j|0)==1&l>>>0>2147483648|j>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}s=b;t=v[a+16>>2];b=0;while(1){if((b|0)!=2){f=b<<3;k=f+(e+24|0)|0;f=a+f|0;v[k+4>>2]=v[f+44>>2];v[k+8>>2]=v[f+48>>2];b=b+1|0;continue}break}m=v[a+40>>2];n=v[a+36>>2];b=v[a+4>>2];v[e+16>>2]=v[a>>2];v[e+20>>2]=b;w=v[a+32>>2];x=v[a+28>>2];y=v[a+72>>2];b=v[a+68>>2];z=b;A=b>>31;b=v[a+64>>2];C=b;D=b>>31;b=v[a+60>>2];E=b;F=b>>31;while(1){if(d){b=v[e+16>>2];G=((((v[e+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+t|0;b=(b>>>16&65520)+s|0;H=u[b+14>>1];g=u[b+12>>1];q=u[b+10>>1];r=u[b+8>>1];h=u[b+6>>1];k=u[b+4>>1];f=u[b+2>>1];b=u[b>>1];o=0;p=0;while(1){if((p|0)!=2){i=G+(p<<1)|0;v[(e+8|0)+(p<<2)>>2]=(((((((B(u[i-8>>1],f)+B(u[i-12>>1],b)|0)+B(u[i-4>>1],k)|0)+B(u[i>>1],h)|0)+B(u[i+4>>1],r)|0)+B(u[i+8>>1],q)|0)+B(g,u[i+12>>1])|0)+B(H,u[i+16>>1])|0)/32768;p=p+1|0;continue}break}while(1){if((o|0)!=2){q=(e+8|0)+(o<<2)|0;b=v[q>>2];g=(e+24|0)+(o<<3)|0;r=v[g+8>>2];h=v[g+4>>2];v[g+8>>2]=h;k=b<<8;b=k;b=Lka(E,F,b,b>>31);f=mb;i=g;g=b;b=Xb(h,-16777216,16776704);b=Lka(C,D,b,b>>31);h=g+b|0;g=mb+f|0;g=b>>>0>h>>>0?g+1|0:g;b=Xb(r,-16777216,16776704);f=Lka(z,A,b,b>>31);h=f+h|0;b=mb+g|0;b=f>>>0>h>>>0?b+1|0:b;f=h+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Xc(f,b,24);v[i+4>>2]=b-(k&y);v[q>>2]=(b|0)/256;o=o+1|0;continue}break}n=n+x|0;v[c>>2]=v[c>>2]+B(v[e+8>>2],n>>12);m=m+w|0;v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],m>>12);Qb(e+16|0,l,j);c=c+8|0;d=d-1|0;continue}break}b=v[e+20>>2];v[a>>2]=v[e+16>>2];v[a+4>>2]=b;v[a+40>>2]=m;v[a+20>>2]=n>>12;v[a+36>>2]=n;v[a+24>>2]=m>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(e+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}jb=e+48|0}function lia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=C(0),h=0,i=C(0);d=jb-112|0;jb=d;c=jb-16|0;jb=c;e=b+16|0;$S(c+8|0,e);f=v[c+12>>2];mc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);h=v[c+4>>2];if((h|0)==(f|0)){Zb(a,v[c+12>>2])}jb=c+16|0;if((f|0)!=(h|0)){Tb(e,0,128)}t[b+79|0]=0;t[b+143|0]=0;v[b+152>>2]=-2147483648;v[b+156>>2]=-2147483648;c=d- -64|0;$d(c,a,Bg(a));f=jc(d+88|0,c);Ab(c);v[23588]=0;c=S(202,f|0)|0;e=v[23588];v[23588]=0;a:{b:{if((e|0)==1){break b}v[23588]=0;R(285,b+4|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break b}re(d+56|0,v[b+4>>2],v[b+8>>2]);v[23588]=0;Nk(459,d- -64|0,f,v[d+56>>2],v[d+60>>2]);c=v[23588];v[23588]=0;if((c|0)!=1){v[23588]=0;c=S(157,a|0)|0;e=v[23588];v[23588]=0;c:{if((e|0)==1){break c}v[23588]=0;U(190,d+32|0,a|0,c|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}a=d+32|0;c=jc(d- -64|0,a);Ab(a);a=v[c>>2];v[23588]=0;a=S(178,a|0)|0;e=v[23588];v[23588]=0;d:{if((e|0)!=1){e:{f:{if(!a){break f}while(1){g:{a=v[c+8>>2];e=v[c>>2];v[23588]=0;a=W(156,e|0,a|0,5)|0;e=v[23588];v[23588]=0;if((e|0)==1){break e}if(!a){break f}v[23588]=0;Q(460,c|0,d+28|0)|0;a=v[23588];v[23588]=0;h:{if((a|0)!=1){a=4;if(!Rb(d+28|0,13510,4)){break h}if(!Rb(d+28|0,14071,4)){break h}v[23588]=0;a=S(157,c|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){break h}a=P()|0;O()|0;break d}a=P()|0;O()|0;break d}v[23588]=0;U(190,d+8|0,c|0,a|0);a=v[23588];v[23588]=0;i:{j:{k:{if((a|0)!=1){a=d+8|0;e=jc(d+32|0,a);Ab(a);if(Rb(d+28|0,13510,4)){break k}v[23588]=0;g=C(Ba(461,e|0));a=v[23588];v[23588]=0;if((a|0)==1){break g}z[d+8>>2]=g;v[d+4>>2]=0;v[d>>2]=1065353216;g=z[kq(d+8|0,d+4|0,d)>>2];z[b+144>>2]=g;i=C(D(g));if((i<C(11754943508222875e-54)^-1)&(!(i>=C(N))&g==g)){break j}v[b+144>>2]=0;break j}a=P()|0;O()|0;break d}if(Rb(d+28|0,14071,4)){break j}v[23588]=0;a=S(157,e|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break i}v[b+148>>2]=a}Ab(e);continue}}break}a=P()|0;O()|0;Ab(e);break d}Ab(c);Ab(f);jb=d+112|0;return}a=P()|0;O()|0;break d}a=P()|0;O()|0}Ab(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}Ab(f);T(a|0);L()}function Vca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;e=jb-48|0;jb=e;a:{b:{c:{j=v[a+12>>2];l=v[a+8>>2];d:{if((j|0)<=1&l>>>0<=805306368|(j|0)<=0){if((j|0)>=-2&l>>>0>=3489660928|(j|0)>-2){break c}if((j|0)==-2&l>>>0>2147483647|j>>>0>4294967294){break d}break b}if((j|0)==1&l>>>0>2147483648|j>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}s=b;w=v[a+16>>2];b=0;while(1){if((b|0)!=2){f=b<<3;k=f+(e+24|0)|0;f=a+f|0;v[k+4>>2]=v[f+44>>2];v[k+8>>2]=v[f+48>>2];b=b+1|0;continue}break}m=v[a+40>>2];n=v[a+36>>2];b=v[a+4>>2];v[e+16>>2]=v[a>>2];v[e+20>>2]=b;x=v[a+32>>2];y=v[a+28>>2];z=v[a+72>>2];b=v[a+68>>2];A=b;C=b>>31;b=v[a+64>>2];D=b;E=b>>31;b=v[a+60>>2];F=b;G=b>>31;while(1){if(d){b=v[e+16>>2];H=(((v[e+20>>2]&2147483647)<<1|b>>>31)&-2)+w|0;b=(b>>>16&65520)+s|0;I=u[b+14>>1];g=u[b+12>>1];q=u[b+10>>1];r=u[b+8>>1];h=u[b+6>>1];k=u[b+4>>1];f=u[b+2>>1];b=u[b>>1];o=0;p=0;while(1){if((p|0)!=2){i=p+H|0;v[(e+8|0)+(p<<2)>>2]=(((((((B(t[i-4|0],f)+B(t[i-6|0],b)|0)+B(t[i-2|0],k)|0)+B(t[i|0],h)|0)+B(t[i+2|0],r)|0)+B(t[i+4|0],q)|0)+B(g,t[i+6|0])|0)+B(I,t[i+8|0])<<8)/32768;p=p+1|0;continue}break}while(1){if((o|0)!=2){q=(e+8|0)+(o<<2)|0;b=v[q>>2];g=(e+24|0)+(o<<3)|0;r=v[g+8>>2];h=v[g+4>>2];v[g+8>>2]=h;k=b<<8;b=k;b=Lka(F,G,b,b>>31);f=mb;i=g;g=b;b=Xb(h,-16777216,16776704);b=Lka(D,E,b,b>>31);h=g+b|0;g=mb+f|0;g=b>>>0>h>>>0?g+1|0:g;b=Xb(r,-16777216,16776704);f=Lka(A,C,b,b>>31);h=f+h|0;b=mb+g|0;b=f>>>0>h>>>0?b+1|0:b;f=h+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Xc(f,b,24);v[i+4>>2]=b-(k&z);v[q>>2]=(b|0)/256;o=o+1|0;continue}break}n=n+y|0;v[c>>2]=v[c>>2]+B(v[e+8>>2],n>>12);m=m+x|0;v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],m>>12);Qb(e+16|0,l,j);c=c+8|0;d=d-1|0;continue}break}b=v[e+20>>2];v[a>>2]=v[e+16>>2];v[a+4>>2]=b;v[a+40>>2]=m;v[a+20>>2]=n>>12;v[a+36>>2]=n;v[a+24>>2]=m>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(e+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}jb=e+48|0}function l6(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=jb-96|0;jb=j;a:{b:{c:{k=xp(1,32);d:{e:{if(!k){a=mm(ba(4)|0);v[23588]=0;U(119,a|0,92948,26);a=v[23588];v[23588]=0;if((a|0)!=1){break a}i=V(0)|0;O()|0;break e}v[k+12>>2]=f;v[k+8>>2]=e;v[k+4>>2]=d;v[k>>2]=c?c:933;c=Xf(j+80|0);f:{g:{h:{if(!i){break h}while(1){d=v[i>>2];if(!d){break h}e=v[i+4>>2];i:{if(e){v[23588]=0;d=Q(55,j- -64|0,d|0)|0;f=v[23588];v[23588]=0;j:{if((f|0)!=1){v[23588]=0;f=Q(944,c|0,d|0)|0;l=v[23588];v[23588]=0;if((l|0)==1){break j}v[23588]=0;R(270,f|0,e|0);e=v[23588];v[23588]=0;if((e|0)==1){break j}break i}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;yb(d);break f}v[23588]=0;d=Q(55,j+48|0,d|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break g}Ks(c,d)}yb(d);i=i+8|0;continue}}d=v[a+8>>2];e=v[a+4>>2];f=v[a>>2];v[23588]=0;a=S(812,104)|0;i=v[23588];v[23588]=0;k:{l:{m:{if((i|0)!=1){v[j+44>>2]=d;v[j+40>>2]=e;v[j+36>>2]=f;v[j+32>>2]=b;b=v[k+4>>2];d=v[k>>2];v[23588]=0;b=Q(945,d|0,b|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break m}v[j+16>>2]=b;b=v[dg(j+24|0,j+16|0)>>2];d=v[j+44>>2];v[j+8>>2]=v[j+40>>2];v[j+12>>2]=d;v[23588]=0;d=v[j+36>>2];v[j>>2]=v[j+32>>2];v[j+4>>2]=d;b=fa(975,a|0,j|0,b|0,c|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){break k}i=V(0)|0;O()|0;De(j+16|0);break l}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0}Mb(a);break f}v[k+28>>2]=b;De(j+16|0);a=v[k+28>>2];v[k+24>>2]=a?a+8|0:0;kl(c);break d}i=V(0)|0;O()|0}kl(c);_(i|0)|0;v[23588]=0;X(939,11260,k|0,g|0,h|0);a=v[23588];v[23588]=0;if((a|0)!=1){v[23588]=0;Z(18);a=v[23588];v[23588]=0;if((a|0)!=1){a=v[k+28>>2];if(a){nb[v[v[a>>2]+4>>2]](a)}v[k+24>>2]=0;v[k+28>>2]=0;a=v[k+20>>2];if(a){Mb(a);v[k+20>>2]=0}Mb(k);k=0;break d}i=V(0)|0;O()|0;break e}i=V(0)|0;O()|0;v[23588]=0;Z(18);a=v[23588];v[23588]=0;if((a|0)==1){break b}}_(i|0)|0;k=0;v[23588]=0;X(939,11260,0,g|0,h|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}$()}jb=j+96|0;return k|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)==1){break b}T(a|0);L()}V(0)|0;O()|0;Ub()}L()}function KO(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0;c=jb-176|0;jb=c;i=1;p=2;d=v[a+12>>2];q=1<<d;m=q;a:while(1){if(d>>>0>=p>>>0){m=m>>>2|0;w=B(i,3);x=i<<1;h=0;b:while(1){if((h|0)==(m|0)){p=p+2|0;i=i<<2;d=v[a+12>>2];continue a}d=v[a>>2];e=Jd(d,h<<1);gM(c+160|0,A[e>>3],A[e+8>>3]);d=Jd(d,h);gM(c+144|0,A[d>>3],A[d+8>>3]);ui(c+128|0,A[c+144>>3],A[c+152>>3],A[c+160>>3],A[c+168>>3]);d=h<<p;e=i+d|0;y=d>>>0>e>>>0?d:e;while(1)if((d|0)==(y|0)){h=h+1|0;continue b}else{f=v[b>>2];e=Jd(f,d);g=e+8|0;j=v[g+4>>2];v[c+120>>2]=v[g>>2];v[c+124>>2]=j;g=v[e+4>>2];v[c+112>>2]=v[e>>2];v[c+116>>2]=g;k=d+i|0;g=Jd(f,k);n=A[g+8>>3];o=A[g>>3];r=d+x|0;g=Jd(f,r);j=v[g+12>>2];v[c+104>>2]=v[g+8>>2];v[c+108>>2]=j;j=v[g+4>>2];v[c+96>>2]=v[g>>2];v[c+100>>2]=j;s=d+w|0;f=Jd(f,s);t=A[f+8>>3];u=A[f>>3];g=c+80|0;f=c+112|0;fl(g,f,o,n);j=c- -64|0;mj(j,f,o,n);l=c+96|0;fl(c+48|0,l,u,t);f=c+16|0;mj(f,l,u,t);ui(c+32|0,0,1,A[c+16>>3],A[c+24>>3]);fl(f,g,A[c+48>>3],A[c+56>>3]);l=v[c+28>>2];v[e+8>>2]=v[c+24>>2];v[e+12>>2]=l;l=v[c+20>>2];v[e>>2]=v[c+16>>2];v[e+4>>2]=l;fl(c,j,A[c+32>>3],A[c+40>>3]);ui(f,A[c+160>>3],A[c+168>>3],A[c>>3],A[c+8>>3]);e=Jd(v[b>>2],k);k=v[c+28>>2];v[e+8>>2]=v[c+24>>2];v[e+12>>2]=k;k=v[c+20>>2];v[e>>2]=v[c+16>>2];v[e+4>>2]=k;mj(c,g,A[c+48>>3],A[c+56>>3]);ui(f,A[c+144>>3],A[c+152>>3],A[c>>3],A[c+8>>3]);e=Jd(v[b>>2],r);g=v[c+28>>2];v[e+8>>2]=v[c+24>>2];v[e+12>>2]=g;g=v[c+20>>2];v[e>>2]=v[c+16>>2];v[e+4>>2]=g;mj(c,j,A[c+32>>3],A[c+40>>3]);ui(f,A[c+128>>3],A[c+136>>3],A[c>>3],A[c+8>>3]);e=Jd(v[b>>2],s);f=v[c+28>>2];v[e+8>>2]=v[c+24>>2];v[e+12>>2]=f;f=v[c+20>>2];v[e>>2]=v[c+16>>2];v[e+4>>2]=f;d=d+1|0;continue}}}break}c:{if(!(d&1)){break c}i=q>>>1|0;d=0;while(1){if((d|0)==(i|0)){break c}h=v[b>>2];a=Jd(h,d+i|0);m=Jd(h,d);n=A[a>>3];o=A[a+8>>3];mj(c+160|0,m,n,o);h=v[c+172>>2];v[a+8>>2]=v[c+168>>2];v[a+12>>2]=h;h=v[c+164>>2];v[a>>2]=v[c+160>>2];v[a+4>>2]=h;cy(Jd(v[b>>2],d),n,o);d=d+1|0;continue}}jb=c+176|0}function kt(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=jb-16|0;jb=f;e=B(c,872)+b|0;h=e+704|0;v[h>>2]=v[h>>2]|524288;a:{b:{if(!(v[a+480208>>2]&8)){Cb(f+8|0,a+1074312|0,15);if(Bb(v[v[f+8>>2]>>2],v[f+12>>2])){break b}}if(v[a+480180>>2]!=268435456){break a}}g=B(c,872)+b|0;d=d?d:w[(B(c,872)+b|0)+1427|0];t[g+1427|0]=d;t[g+1428|0]=d}if(d){u[(B(c,872)+b|0)+1384>>1]=d}c:{d:{g=e+616|0;j=v[g+656>>2];if(vj(j)){a=x[(B(c,872)+b|0)+1384>>1];if(!a){break d}e=0;d=v[b+16>>2];e=d?v[(B(c,872)+b|0)+1472>>2]:e;k=0-a|0;l=a;i=B(c,872)+b|0;g=i+1324|0;a=v[g>>2];m=(+(d>>>0)+1)*+(((a|0)<0?k:l)|0)/+y[b+40>>2];e:{if(D(m)<2147483648){d=~~m;break e}d=-2147483648}i=i+1472|0;v[i>>2]=d;if(w[h+2|0]&16){d=B(v[v[j+44>>2]+36>>2]+1|0,d);v[i>>2]=d}d=d-e|0;h=d>>31;e=a>>31;if((e^a)-e>>>0<=(d^h)-h>>>0){if(!a){break d}b=B(c,872)+b|0;c=b+1468|0;v[c>>2]=a+v[c>>2];v[g>>2]=0;a=b+1467|0;t[a|0]=w[a|0]|64;a=0;break c}b=B(c,872)+b|0;c=b+1468|0;v[c>>2]=d+v[c>>2];v[g>>2]=a-d;a=b+1467|0;t[a|0]=w[a|0]|64;break d}h=1;j=B(c,872)+b|0;e=j+1467|0;f:{if(!(t[e|0]&1)){break f}d=v[a+480180>>2];if(d&524352){break f}if(v[b+40>>2]==1){Cb(f+8|0,a+1074312|0,6);if(Bb(v[v[f+8>>2]>>2],v[f+12>>2])){break f}d=v[a+480180>>2]}h=0;if((d|0)!=8){break f}h=(w[a+480208|0]&2)>>>1|0}i=v[a+480180>>2];d=x[j+1384>>1];if(!((i|0)!=268435456|d>>>0<240)){h=t[e|0]&1;d=d-240|0}d=B((i|0)==64?2:4,d);j=B(c,872)+b|0;b=j+1316|0;g:{if(!v[b>>2]){break g}c=j+1324|0;if(!v[c>>2]|!h){break g}i=nj(a)?d:0-d|0;l=v[b>>2];k=v[c>>2];if(!(w[e|0]&16?0:(l|0)>=(k|0))){fk(a,g,b,i,1);c=v[c>>2];if((c|0)>=v[b>>2]){break g}v[b>>2]=c;break g}if((l|0)<=(k|0)){break g}fk(a,g,b,0-i|0,1);g=v[b>>2];c=v[c>>2];h:{if((g|0)<(c|0)){v[b>>2]=c;break h}if((c|0)!=(g|0)){break g}}Cb(f+8|0,a+1074312|0,112);if(!Bb(v[v[f+8>>2]>>2],v[f+12>>2])){break g}t[e|0]=w[e|0]|16}c=v[b>>2];b=j+1324|0;i:{if((c|0)!=v[b>>2]){break i}Cb(f+8|0,a+1074312|0,25);if(!Bb(v[v[f+8>>2]>>2],v[f+12>>2])&v[a+480180>>2]!=1){break i}v[b>>2]=0}a=h?d:0;break c}a=0}jb=f+16|0;return a}function ze(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=jb-16|0;jb=h;e=v[a>>2];a:{if(oc(e,v[a+4>>2])){break a}g=v[b+4>>2];if(g>>>0>=y[a+12>>2]){break a}c=x[b+8>>1];i=v[v[a+48>>2]+12>>2];f=Pg(i);if(c>>>0>=f>>>0&(c|0)!=65535){break a}d=(c|0)==65535;l=d?f-1|0:c;f=g;g=d?0:c;c=id(e,i,f,g);f=w[b+12|0];j=f&4;b:{c:{if(f&2){break c}k=w[b+10|0];e=c;d=g;while(1){if((d&65535)>>>0>(l&65535)>>>0){break c}d:{if(!j){if((k|0)!=w[e+3|0]){break d}break b}if((k|0)==w[e+2|0]){break b}}e=e+6|0;d=d+1|0;continue}}k=l&65535;d=c;e=g;while(1){if(k>>>0>=(e&65535)>>>0){e:{if(!j){if(w[d+3|0]){break e}t[d+3|0]=w[b+10|0];t[d+5|0]=w[b+11|0];break b}if(w[d+2|0]){break e}t[d+2|0]=w[b+10|0];t[d+4|0]=w[b+11|0];break b}d=d+6|0;e=e+1|0;continue}break}f:{if(!(f&1)){break f}d=v[i+480180>>2]&2;g:{h:{i:{if(!j){while(1){if((g&65535)>>>0<=(l&65535)>>>0){j:{k:{switch(w[c+3|0]-9|0){case 4:if(!gU(v[v[i+8>>2]+88>>2])){break j}d=1;t[c+2|0]=1;t[c+4|0]=w[c+5|0];t[c+3|0]=w[b+10|0];t[c+5|0]=w[b+11|0];break a;case 0:break k;default:break j}}l:{if(d){e=w[c+5|0];if(e>>>0>128){break j}t[c+2|0]=2;t[c+3|0]=w[b+10|0];a=1;break l}t[c+2|0]=2;t[c+3|0]=w[b+10|0];e=w[c+5|0];a=2}t[c+4|0]=a+e>>>a;t[c+5|0]=w[b+11|0];break b}c=c+6|0;g=g+1|0;continue}break}if(!j){break i}}e=w[b+11|0];g=13;m:{switch(w[b+10|0]-1|0){case 1:g=9;e=Ll(B(d?2:4,e));break;case 0:break m;default:break g}}t[b+11|0]=e;t[b+10|0]=g;f=f&254;break h}t[h+15|0]=0;t[h+14|0]=0;g=b;c=!d;d=w[b+10|0];n:{if(!(c|(d|0)!=9)){e=w[b+11|0];if(e>>>0>128){break g}d=2;c=e>>>1|0;break n}e=h+8|0;Oq(e,d,w[b+11|0],1);qB(h,h+15|0,h+14|0);pB(h,e);d=w[h+15|0];if(!d){f=w[b+12|0];break g}f=w[b+12|0];c=w[h+14|0]}t[g+11|0]=c;t[b+10|0]=d;f=f&254}t[b+12|0]=f}d=1;if(f&1){break f}t[b+12|0]=f^4;if(ze(a,b)){break a}}d=0;o:{p:{switch(v[b>>2]-1|0){case 0:c=v[b+4>>2]+1|0;if(c>>>0>=y[a+12>>2]){break a}v[b+4>>2]=c;break o;case 1:break p;default:break a}}c=v[b+4>>2];if(!c){break a}v[b+4>>2]=c-1}t[b+12|0]=w[b+12|0]|1;d=ze(a,b);break a}d=1}jb=h+16|0;return d}function sca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;f=jb-48|0;jb=f;q=v[a+16>>2];r=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);b=0;m=v[a+128>>2];if(m){e=v[a+8>>2];j=v[a+12>>2];n=kg(e,j,m);o=mb;g=v[a+76>>2];Pf(v[a>>2],v[a+4>>2],kf(e,j,d),mb);j=g>>>0<mb>>>0?d:0}else{j=0}i=a+112|0;while(1){if((b|0)!=2){e=b<<3;h=e+(f+16|0)|0;e=a+e|0;v[h+4>>2]=v[e+44>>2];v[h+8>>2]=v[e+48>>2];b=b+1|0;continue}break}s=v[a+24>>2];t=v[a+20>>2];b=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=b;w=v[a+8>>2];x=v[a+12>>2];a:while(1){if(d){d=d-1|0;b=v[f+12>>2];e=v[f+8>>2];v[f+40>>2]=e;v[f+44>>2]=0;j=j-1|0;n=j?n:0;o=j?o:0;l=((((b&2147483647)<<1|e>>>31)&2147483646)<<1)+q|0;b=m;while(1)if((b|0)<=0){Qb(i,v[a+120>>2],v[a+124>>2]);h=v[a+116>>2];if(h){b=(v[f+44>>2]&2147483647)<<1|v[f+40>>2]>>>31;Rd(i,(u[(b<<1|2)+l>>1]+u[l+((b&2147483646)<<1)>>1]|0)/8<<16>>16);Qd(i,h);v[i>>2]=v[i>>2];v[i+4>>2]=0}b=ig(i,r);v[f+4>>2]=b;v[f>>2]=b;y=v[a+72>>2];b=v[a+68>>2];z=b;A=b>>31;b=v[a+64>>2];C=b;D=b>>31;b=v[a+60>>2];E=b;F=b>>31;b=0;while(1){if((b|0)!=2){p=(b<<2)+f|0;e=v[p>>2];g=(f+16|0)+(b<<3)|0;G=v[g+8>>2];k=v[g+4>>2];v[g+8>>2]=k;l=e<<8;e=l;e=Lka(E,F,e,e>>31);h=mb;H=g;g=e;e=Xb(k,-16777216,16776704);e=Lka(C,D,e,e>>31);k=g+e|0;g=mb+h|0;g=e>>>0>k>>>0?g+1|0:g;e=Xb(G,-16777216,16776704);h=Lka(z,A,e,e>>31);k=h+k|0;e=mb+g|0;e=h>>>0>k>>>0?e+1|0:e;h=k+8388608|0;e=h>>>0<8388608?e+1|0:e;e=Xc(h,e,24);v[H+4>>2]=e-(l&y);v[p>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[f>>2],t);v[c+4>>2]=v[c+4>>2]+B(s,v[f+4>>2]);Qb(f+8|0,w,x);c=c+8|0;continue a}else{e=(v[f+44>>2]&2147483647)<<1|v[f+40>>2]>>>31;Rd(i,(u[(e<<1|2)+l>>1]+u[l+((e&2147483646)<<1)>>1]|0)/8<<16>>16);Qd(i,4);Qb(f+40|0,n,o);b=b-1|0;continue}}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+16|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}jb=f+48|0}function oK(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=jb-96|0;jb=j;a:{b:{c:{d:{e:{f:{k=xp(1,28);if(!k){a=mm(ba(4)|0);v[23588]=0;U(119,a|0,92948,26);a=v[23588];v[23588]=0;if((a|0)!=1){break a}break f}v[k+12>>2]=f;v[k+8>>2]=e;v[k+4>>2]=d;v[k>>2]=c?c:933;c=Xf(j+80|0);g:{h:{i:{if(!i){break i}while(1){d=v[i>>2];if(!d){break i}e=v[i+4>>2];j:{if(e){v[23588]=0;d=Q(55,j- -64|0,d|0)|0;f=v[23588];v[23588]=0;k:{if((f|0)!=1){v[23588]=0;f=Q(944,c|0,d|0)|0;l=v[23588];v[23588]=0;if((l|0)==1){break k}v[23588]=0;R(270,f|0,e|0);e=v[23588];v[23588]=0;if((e|0)==1){break k}break j}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;yb(d);break g}v[23588]=0;d=Q(55,j+48|0,d|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break h}Ks(c,d)}yb(d);i=i+8|0;continue}}d=v[a+8>>2];e=v[a+4>>2];f=v[a>>2];v[23588]=0;a=S(812,80)|0;i=v[23588];v[23588]=0;l:{m:{n:{if((i|0)!=1){v[j+44>>2]=d;v[j+40>>2]=e;v[j+36>>2]=f;v[j+32>>2]=b;b=v[k+4>>2];d=v[k>>2];v[23588]=0;b=Q(945,d|0,b|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break n}v[j+16>>2]=b;b=v[dg(j+24|0,j+16|0)>>2];d=v[j+44>>2];v[j+8>>2]=v[j+40>>2];v[j+12>>2]=d;v[23588]=0;d=v[j+36>>2];v[j>>2]=v[j+32>>2];v[j+4>>2]=d;b=fa(946,a|0,j|0,b|0,c|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){break l}i=V(0)|0;O()|0;De(j+16|0);break m}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0}Mb(a);break g}v[k+24>>2]=b;De(j+16|0);kl(c);i=k;break d}i=V(0)|0;O()|0}kl(c);_(i|0)|0;v[23588]=0;X(939,15164,k|0,g|0,h|0);a=v[23588];v[23588]=0;if((a|0)!=1){v[23588]=0;Z(18);a=v[23588];v[23588]=0;if((a|0)==1){break f}a=v[k+24>>2];if(a){Mb(Js(a))}i=0;v[k+24>>2]=0;a=v[k+20>>2];if(a){Mb(a);v[k+20>>2]=0}Mb(k);break d}i=V(0)|0;O()|0;v[23588]=0;Z(18);a=v[23588];v[23588]=0;if((a|0)!=1){break e}break b}i=V(0)|0;O()|0}_(i|0)|0;i=0;v[23588]=0;X(939,15164,0,g|0,h|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}$()}jb=j+96|0;return i|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)==1){break b}T(a|0);L()}V(0)|0;O()|0;Ub()}L()}function IG(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;e=v[b>>2];a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(!d){break k}h=v[d>>2];if(!h){break k}if(!a){g=c;break j}v[d>>2]=0;g=c;break i}l:{if(!v[v[116090]>>2]){if(!a){break l}if(!c){break a}d=c;while(1){g=t[e|0];if(g){v[a>>2]=g&57343;a=a+4|0;e=e+1|0;d=d-1|0;if(d){continue}break a}break}v[a>>2]=0;v[b>>2]=0;return c-d|0}if(!a){g=c;d=0;break g}g=c;d=0;break h}return xg(e)}d=1;break g}d=1}while(1){if(!d){if(!g){break a}while(1){m:{f=w[e|0];h=f-1|0;n:{o:{if(h>>>0>126){d=f;break o}if(e&3|g>>>0<5){break n}p:{while(1){d=v[e>>2];if((d|d-16843009)&-2139062144){break p}v[a>>2]=d&255;v[a+4>>2]=w[e+1|0];v[a+8>>2]=w[e+2|0];v[a+12>>2]=w[e+3|0];a=a+16|0;e=e+4|0;g=g-4|0;if(g>>>0>4){continue}break}d=w[e|0]}f=d&255;h=f-1|0}if(h>>>0>126){break m}}v[a>>2]=f;a=a+4|0;e=e+1|0;g=g-1|0;if(g){continue}break a}break}f=f-194|0;if(f>>>0>50){break e}e=e+1|0;h=v[(f<<2)+82768>>2];d=1;continue}d=w[e|0];f=d>>>3|0;if((f-16|f+(h>>26))>>>0>7){break f}q:{r:{f=e+1|0;d=d-128|h<<6;s:{if((d|0)>=0){break s}i=w[f|0]-128|0;if(i>>>0>63){break r}f=e+2|0;d=i|d<<6;if((d|0)>=0){break s}f=w[f|0]-128|0;if(f>>>0>63){break r}d=f|d<<6;f=e+3|0}e=f;v[a>>2]=d;g=g-1|0;a=a+4|0;break q}v[116064]=25;e=e-1|0;break c}d=0;continue}}while(1){t:{if(!d){u:{v:{d=w[e|0];if(!(e&3|d-1>>>0>126)){d=v[e>>2];if(!((d|d-16843009)&-2139062144)){break v}}f=e;break u}while(1){g=g-4|0;d=v[e+4>>2];f=e+4|0;e=f;if(!((d-16843009|d)&-2139062144)){continue}break}}e=d&255;if(e-1>>>0<=126){e=f+1|0;g=g-1|0;break t}h=e-194|0;if(h>>>0>50){e=f;break e}e=f+1|0;h=v[(h<<2)+82768>>2];d=1;continue}d=w[e|0]>>>3|0;if((d-16|d+(h>>26))>>>0>7){break f}d=e+1|0;w:{if(!(h&33554432)){break w}if((w[d|0]&192)!=128){e=e-1|0;break d}d=e+2|0;if(!(h&524288)){break w}if((w[d|0]&192)!=128){e=e-1|0;break d}d=e+3|0}e=d;g=g-1|0}d=0;continue}}e=e-1|0;if(h){break d}d=w[e|0]}if(d&255){break d}if(a){v[a>>2]=0;v[b>>2]=0}return c-g|0}v[116064]=25;if(!a){break b}}v[b>>2]=e}return-1}v[b>>2]=e;return c}function ri(a,b,c,d,e,f){var g=0,h=0,i=0,j=C(0),k=C(0),l=0,m=0,n=C(0),o=C(0),p=C(0),q=0,r=C(0);m=nb[v[v[a>>2]+140>>2]](a)|0;g=v[a+20>>2];h=m?h:w[g+25|0];j=z[g+144>>2];k=C(1);if(!(nb[v[v[a>>2]+140>>2]](a)|0)){k=z[v[a+20>>2]+144>>2]}j=C(C(1)-j);a:{if((nb[v[v[a>>2]+156>>2]](a)|0)<=0){break a}if(!iL(w[v[a+20>>2]+24|0])){break a}j=C(C(j+j)+C(-1));k=C(-j)}n=z[a+4196>>2];k=C(k*n);j=C(j*n);g=0;l=v[a+44>>2];m=Jc(l,0);l=Jc(l,1);b:{c:{d:{e:{f:{g:{h:{h=h&255;switch(h|0){case 0:break h;case 5:break c;case 4:break d;case 3:break e;case 2:break f;case 1:break g;default:break b}}while(1){if((f|0)==(h|0)){break b}g=h<<2;i=g+b|0;z[i>>2]=z[i>>2]+C(C(z[d+g>>2]*j)+C(k*z[g+m>>2]));i=c+g|0;z[i>>2]=z[i>>2]+C(C(z[e+g>>2]*j)+C(k*z[g+l>>2]));h=h+1|0;continue}}while(1){if((f|0)==(g|0)){break b}h=g<<2;i=h+b|0;z[i>>2]=z[i>>2]+C(z[h+m>>2]-C(z[d+h>>2]*j));i=c+h|0;z[i>>2]=z[i>>2]+C(z[h+l>>2]-C(z[e+h>>2]*j));g=g+1|0;continue}}while(1){if((f|0)==(g|0)){break b}h=g<<2;i=h+b|0;z[i>>2]=z[i>>2]+C(z[d+h>>2]-C(z[h+m>>2]*k));i=c+h|0;z[i>>2]=z[i>>2]+C(z[e+h>>2]-C(z[h+l>>2]*k));g=g+1|0;continue}}while(1){if((f|0)==(g|0)){break b}h=g<<2;i=h+b|0;z[i>>2]=z[i>>2]-C(z[d+h>>2]-C(z[h+m>>2]*j));i=c+h|0;z[i>>2]=z[i>>2]-C(z[e+h>>2]-C(z[h+l>>2]*j));g=g+1|0;continue}}while(1){if((f|0)==(g|0)){break b}h=g<<2;i=h+b|0;k=z[i>>2];q=i;r=k;n=z[h+m>>2];i=c+h|0;o=z[i>>2];p=z[h+l>>2];k=C(C(C(C(k+n)+o)+p)*C(.5));z[q>>2]=r-C(C(k+C(k-C(z[d+h>>2]*j)))-n);z[i>>2]=o-C(C(k+C(k-C(z[e+h>>2]*j)))-p);g=g+1|0;continue}}g=iL(w[v[a+20>>2]+24|0]);j=g?C(j*C(.5)):j;k=g?C(k*C(.5)):k;h=0;while(1){if((f|0)==(h|0)){break b}g=h<<2;i=g+b|0;n=C(z[d+g>>2]-z[g+m>>2]);o=C(z[g+l>>2]-z[e+g>>2]);z[i>>2]=z[i>>2]+C(C(j*n)+C(k*o));g=c+g|0;z[g>>2]=z[g>>2]+C(C(k*n)+C(j*o));h=h+1|0;continue}}i:{if(!((w[v[a+20>>2]+24|0]&4)>>>2|0)){break i}if(nb[v[v[a>>2]+140>>2]](a)|0){break i}g=0;while(1){if((f|0)==(g|0)){break i}a=g<<2;d=a+b|0;z[d>>2]=z[a+m>>2]+z[d>>2];d=a+c|0;z[d>>2]=z[a+l>>2]+z[d>>2];g=g+1|0;continue}}}function hh(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{b:{c:{switch(b|0){case 1:b=0;a=Lb(a);d=Gb(c);v[23588]=0;R(46,a|0,d|0);d=v[23588];v[23588]=0;d:{if((d|0)!=1){e:{while(1){if(Gb(c)>>>0>b>>>0){d=v[zi(c,b)>>2];v[23588]=0;R(47,a|0,(d>>>0<128?d:63)<<24>>24);d=v[23588];v[23588]=0;if((d|0)==1){break e}b=b+1|0;continue}break}break d}}break a}return;case 2:b=0;a=Lb(a);d=Gb(c);v[23588]=0;R(46,a|0,d|0);d=v[23588];v[23588]=0;f:{if((d|0)!=1){g:{while(1){if(Gb(c)>>>0>b>>>0){d=v[zi(c,b)>>2];v[23588]=0;R(47,a|0,(d>>>0<256?d:63)<<24>>24);d=v[23588];v[23588]=0;if((d|0)==1){break g}b=b+1|0;continue}break}break f}}break a}return;case 3:pl(a,c,49552);return;case 5:pl(a,c,50576);return;case 4:pl(a,c,51600);return;case 6:pl(a,c,52624);return;case 7:pl(a,c,53648);return;case 8:pl(a,c,54672);return;case 9:pl(a,c,55696);return;case 10:uz(a,c,56720);return;case 11:uz(a,c,49552);return;case 12:uz(a,c,53648);return;default:a=ba(8)|0;v[23588]=0;b=Q(45,a|0,11027)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break b}b=P()|0;O()|0;ca(a|0);T(b|0);L();case 0:break c}}e=jb-16|0;jb=e;f=Lb(a);h:{while(1){i:{j:{k:{if(Gb(c)>>>0>g>>>0){b=v[zi(c,g)>>2];if(b>>>0>=2097152){v[23588]=0;R(47,f|0,63);a=v[23588];v[23588]=0;if((a|0)!=1){break j}break i}a=0;while(1){if((a|0)==6){b=7;a=6;break k}d=b&63;t[(e+10|0)+a|0]=d;if(b>>>0>=64){a=a+1|0;b=b>>>6|0;continue}break}if(a){b=a+1|0;if((b|0)!=2){break k}a=1;b=2;if((d|0)!=1){break k}a=w[e+10|0]|64}else{a=w[e+10|0]}v[23588]=0;R(47,f|0,a<<24>>24);a=v[23588];v[23588]=0;if((a|0)!=1){break j}break i}jb=e+16|0;break h}i=(-1<<b^-1)<<7-a;d=b-1|0;j=d+(e+10|0)|0;a=b;while(1){if(!a){break j}l:{if((a|0)==(b|0)){a=w[j|0];v[23588]=0;R(47,f|0,(a|i)<<24>>24);h=v[23588];v[23588]=0;a=d;break l}v[23588]=0;a=a-1|0;R(47,f|0,t[a+(e+10|0)|0]|-128);h=v[23588];v[23588]=0}if((h|0)!=1){continue}break}break i}g=g+1|0;continue}break}a=P()|0;O()|0;yb(f);T(a|0);L()}return}ha(b|0,93080,25);L()}b=P()|0;O()|0;yb(a);T(b|0);L()}function Yca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0;e=jb-48|0;jb=e;a:{b:{c:{j=v[a+12>>2];l=v[a+8>>2];d:{if((j|0)<=1&l>>>0<=805306368|(j|0)<=0){if((j|0)>=-2&l>>>0>=3489660928|(j|0)>-2){break c}if((j|0)==-2&l>>>0>2147483647|j>>>0>4294967294){break d}break b}if((j|0)==1&l>>>0>2147483648|j>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}q=b;r=v[a+16>>2];b=0;while(1){if((b|0)!=2){f=b<<3;k=f+(e+24|0)|0;f=a+f|0;v[k+4>>2]=v[f+44>>2];v[k+8>>2]=v[f+48>>2];b=b+1|0;continue}break}s=v[a+24>>2];t=v[a+20>>2];b=v[a+4>>2];v[e+16>>2]=v[a>>2];v[e+20>>2]=b;w=v[a+72>>2];b=v[a+68>>2];x=b;y=b>>31;b=v[a+64>>2];z=b;A=b>>31;b=v[a+60>>2];C=b;D=b>>31;while(1){if(d){b=v[e+16>>2];E=((((v[e+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+r|0;b=(b>>>16&65520)+q|0;F=u[b+14>>1];g=u[b+12>>1];o=u[b+10>>1];p=u[b+8>>1];h=u[b+6>>1];k=u[b+4>>1];f=u[b+2>>1];b=u[b>>1];m=0;n=0;while(1){if((n|0)!=2){i=E+(n<<1)|0;v[(e+8|0)+(n<<2)>>2]=(((((((B(u[i-8>>1],f)+B(u[i-12>>1],b)|0)+B(u[i-4>>1],k)|0)+B(u[i>>1],h)|0)+B(u[i+4>>1],p)|0)+B(u[i+8>>1],o)|0)+B(g,u[i+12>>1])|0)+B(F,u[i+16>>1])|0)/32768;n=n+1|0;continue}break}while(1){if((m|0)!=2){o=(e+8|0)+(m<<2)|0;b=v[o>>2];g=(e+24|0)+(m<<3)|0;p=v[g+8>>2];h=v[g+4>>2];v[g+8>>2]=h;k=b<<8;b=k;b=Lka(C,D,b,b>>31);f=mb;i=g;g=b;b=Xb(h,-16777216,16776704);b=Lka(z,A,b,b>>31);h=g+b|0;g=mb+f|0;g=b>>>0>h>>>0?g+1|0:g;b=Xb(p,-16777216,16776704);f=Lka(x,y,b,b>>31);h=f+h|0;b=mb+g|0;b=f>>>0>h>>>0?b+1|0:b;f=h+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Xc(f,b,24);v[i+4>>2]=b-(k&w);v[o>>2]=(b|0)/256;m=m+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],t);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],s);Qb(e+16|0,l,j);c=c+8|0;d=d-1|0;continue}break}b=v[e+20>>2];v[a>>2]=v[e+16>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(e+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}jb=e+48|0}function y6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-96|0;jb=d;e=v[b+4>>2];a:{if(!e){break a}f=v[b>>2];g=w[cl(f,e)|0];if((g|0)==33){c=1}else{if((g|0)!=63){break a}c=0}jl(d+72|0,f,e,e-1|0);e=v[d+76>>2];v[b>>2]=v[d+72>>2];v[b+4>>2]=e}f=d+72|0;Wd(f);e=v[d+72>>2];Wd(d+56|0);e=bl(e,v[d+60>>2],b);Wd(f);b:{c:{d:{e:{if((e|0)==v[d+76>>2]){a=v[b+4>>2];e=v[b>>2];f=qc(d+88|0,21619);g=v[f+4>>2];v[d>>2]=v[f>>2];v[d+4>>2]=g;if(Pc(e,a,d)){a=ba(8)|0;v[23588]=0;c=Q(55,d+72|0,10432)|0;b=v[23588];v[23588]=0;if((b|0)==1){break d}a=rc(a,c);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(c);break c}e=0;f=0;if(!c){break e}c=ba(8)|0;a=v[b+4>>2];b=v[b>>2];v[23588]=0;e=Kh(d+56|0,b,a);a=v[23588];v[23588]=0;f:{g:{h:{if((a|0)!=1){v[23588]=0;U(967,d+72|0,17634,e|0);a=v[23588];v[23588]=0;if((a|0)==1){break h}a=0;b=rc(c,d+72|0);v[23588]=0;U(119,b|0,62688,956);b=v[23588];v[23588]=0;if((b|0)!=1){break b}b=P()|0;O()|0;yb(d+72|0);break g}b=P()|0;O()|0;break f}b=P()|0;a=1;O()|0}yb(e);if(!a){break c}}ca(c|0);break c}if(v[e+4>>2]!=1){a=ba(8)|0;v[23588]=0;c=Q(55,d+72|0,11504)|0;b=v[23588];v[23588]=0;if((b|0)!=1){a=rc(a,c);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(c);break c}b=P()|0;O()|0;ca(a|0);break c}c=v[b+4>>2];b=v[b>>2];e=qc(d+48|0,21619);f=v[e+4>>2];v[d+24>>2]=v[e>>2];v[d+28>>2]=f;if(Pc(b,c,d+24|0)){a=ba(8)|0;v[23588]=0;c=Q(55,d+72|0,10432)|0;b=v[23588];v[23588]=0;if((b|0)!=1){a=rc(a,c);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(c);break c}b=P()|0;O()|0;ca(a|0);break c}e=qc(d+40|0,10895);f=v[e+4>>2];v[d+16>>2]=v[e>>2];v[d+20>>2]=f;if(Pc(b,c,d+16|0)){a=v[a+8>>2];e=a;f=a>>31;break e}e=qc(d+32|0,8587);f=v[e+4>>2];v[d+8>>2]=v[e>>2];v[d+12>>2]=f;e=0;f=0;if(!Pc(b,c,d+8|0)){break e}e=bk(w[v[a+32>>2]+140|0]);f=0}jb=d+96|0;mb=f;return e|0}b=P()|0;O()|0;ca(a|0)}T(b|0)}L()}function Zca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;e=jb-48|0;jb=e;a:{b:{c:{j=v[a+12>>2];l=v[a+8>>2];d:{if((j|0)<=1&l>>>0<=805306368|(j|0)<=0){if((j|0)>=-2&l>>>0>=3489660928|(j|0)>-2){break c}if((j|0)==-2&l>>>0>2147483647|j>>>0>4294967294){break d}break b}if((j|0)==1&l>>>0>2147483648|j>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}q=b;r=v[a+16>>2];b=0;while(1){if((b|0)!=2){f=b<<3;k=f+(e+24|0)|0;f=a+f|0;v[k+4>>2]=v[f+44>>2];v[k+8>>2]=v[f+48>>2];b=b+1|0;continue}break}s=v[a+24>>2];w=v[a+20>>2];b=v[a+4>>2];v[e+16>>2]=v[a>>2];v[e+20>>2]=b;x=v[a+72>>2];b=v[a+68>>2];y=b;z=b>>31;b=v[a+64>>2];A=b;C=b>>31;b=v[a+60>>2];D=b;E=b>>31;while(1){if(d){b=v[e+16>>2];F=(((v[e+20>>2]&2147483647)<<1|b>>>31)&-2)+r|0;b=(b>>>16&65520)+q|0;G=u[b+14>>1];g=u[b+12>>1];o=u[b+10>>1];p=u[b+8>>1];h=u[b+6>>1];k=u[b+4>>1];f=u[b+2>>1];b=u[b>>1];m=0;n=0;while(1){if((n|0)!=2){i=n+F|0;v[(e+8|0)+(n<<2)>>2]=(((((((B(t[i-4|0],f)+B(t[i-6|0],b)|0)+B(t[i-2|0],k)|0)+B(t[i|0],h)|0)+B(t[i+2|0],p)|0)+B(t[i+4|0],o)|0)+B(g,t[i+6|0])|0)+B(G,t[i+8|0])<<8)/32768;n=n+1|0;continue}break}while(1){if((m|0)!=2){o=(e+8|0)+(m<<2)|0;b=v[o>>2];g=(e+24|0)+(m<<3)|0;p=v[g+8>>2];h=v[g+4>>2];v[g+8>>2]=h;k=b<<8;b=k;b=Lka(D,E,b,b>>31);f=mb;i=g;g=b;b=Xb(h,-16777216,16776704);b=Lka(A,C,b,b>>31);h=g+b|0;g=mb+f|0;g=b>>>0>h>>>0?g+1|0:g;b=Xb(p,-16777216,16776704);f=Lka(y,z,b,b>>31);h=f+h|0;b=mb+g|0;b=f>>>0>h>>>0?b+1|0:b;f=h+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Xc(f,b,24);v[i+4>>2]=b-(k&x);v[o>>2]=(b|0)/256;m=m+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],w);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],s);Qb(e+16|0,l,j);c=c+8|0;d=d-1|0;continue}break}b=v[e+20>>2];v[a>>2]=v[e+16>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(e+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}jb=e+48|0}function A$(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=jb-16|0;jb=j;k=Qw(g);o=xw(g);bh(j,o);v[f>>2]=d;a:{b:{c:{i=a;g=w[i|0];switch(g-43|0){case 0:case 2:break c;default:break b}}v[23588]=0;g=Q(1154,k|0,g<<24>>24)|0;i=v[23588];v[23588]=0;if((i|0)==1){break a}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=g;i=a+1|0}d:{g=i;if(!((c-g|0)<2|w[g|0]!=48|(w[g+1|0]|32)!=120)){v[23588]=0;g=Q(1154,k|0,48)|0;h=v[23588];v[23588]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=g;g=t[i+1|0];v[23588]=0;g=Q(1154,k|0,g|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=g;i=i+2|0;g=i;while(1){if(c>>>0<=g>>>0){break d}h=t[g|0];Gd();if(!WG(h)){break d}g=g+1|0;continue}}while(1){if(c>>>0<=g>>>0){break d}h=t[g|0];Gd();if(!$j(h)){break d}g=g+1|0;continue}}e:{if(Qe(j)){h=v[f>>2];v[23588]=0;X(1148,k|0,i|0,g|0,h|0);h=v[23588];v[23588]=0;if((h|0)==1){break a}v[f>>2]=v[f>>2]+(g-i<<2);break e}$l(i,g);v[23588]=0;q=S(1146,o|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break a}h=i;while(1){if(g>>>0<=h>>>0){Sr((i-a<<2)+d|0,v[f>>2]);break e}f:{if(t[Sc(j,l)|0]<=0){break f}if(t[Sc(j,l)|0]!=(m|0)){break f}m=v[f>>2];v[f>>2]=m+4;v[m>>2]=q;l=(Gb(j)-1>>>0>l>>>0)+l|0;m=0}p=t[h|0];v[23588]=0;p=Q(1154,k|0,p|0)|0;n=v[23588];v[23588]=0;if((n|0)!=1){n=v[f>>2];v[f>>2]=n+4;v[n>>2]=p;h=h+1|0;m=m+1|0;continue}break}break a}g:{while(1){if(c>>>0>g>>>0){i=w[g|0];if((i|0)==46){v[23588]=0;i=S(1149,o|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break a}l=v[f>>2];h=l+4|0;v[f>>2]=h;v[l>>2]=i;g=g+1|0;break g}v[23588]=0;i=Q(1154,k|0,i<<24>>24)|0;h=v[23588];v[23588]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=i;g=g+1|0;continue}break}h=v[f>>2]}v[23588]=0;X(1148,k|0,g|0,c|0,h|0);i=v[23588];v[23588]=0;if((i|0)==1){break a}i=f;f=v[f>>2]+(c-g<<2)|0;v[i>>2]=f;v[e>>2]=(b|0)==(c|0)?f:(b-a<<2)+d|0;yb(j);jb=j+16|0;return}a=P()|0;O()|0;yb(j);T(a|0);L()}function ks(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if(!a){return Od(b)}if(b>>>0>=4294967232){v[116064]=48;return 0}e=b>>>0<11?16:b+11&-8;h=a-4|0;i=v[h>>2];c=i&-8;a:{b:{if(!(i&3)){if(e>>>0<256|c>>>0<(e|4)>>>0){break b}if(c-e>>>0<=v[116216]<<1>>>0){break a}break b}g=a-8|0;f=c+g|0;if(c>>>0>=e>>>0){b=c-e|0;if(b>>>0<16){break a}v[h>>2]=i&1|e|2;c=e+g|0;v[c+4>>2]=b|3;v[f+4>>2]=v[f+4>>2]|1;LH(c,b);return a}if(v[116102]==(f|0)){c=c+v[116099]|0;if(c>>>0<=e>>>0){break b}v[h>>2]=i&1|e|2;b=e+g|0;c=c-e|0;v[b+4>>2]=c|1;v[116099]=c;v[116102]=b;return a}if(v[116101]==(f|0)){c=c+v[116098]|0;if(c>>>0<e>>>0){break b}b=c-e|0;c:{if(b>>>0>=16){v[h>>2]=i&1|e|2;d=e+g|0;v[d+4>>2]=b|1;c=c+g|0;v[c>>2]=b;v[c+4>>2]=v[c+4>>2]&-2;break c}v[h>>2]=c|i&1|2;b=c+g|0;v[b+4>>2]=v[b+4>>2]|1;b=0}v[116101]=d;v[116098]=b;return a}d=v[f+4>>2];if(d&2){break b}j=c+(d&-8)|0;if(j>>>0<e>>>0){break b}l=j-e|0;d:{if(d>>>0<=255){b=v[f+8>>2];d=d>>>3|0;c=v[f+12>>2];if((c|0)==(b|0)){n=464384,o=v[116096]&Pka(-2,d),v[n>>2]=o;break d}v[b+12>>2]=c;v[c+8>>2]=b;break d}k=v[f+24>>2];c=v[f+12>>2];e:{if((f|0)!=(c|0)){b=v[f+8>>2];v[b+12>>2]=c;v[c+8>>2]=b;break e}f:{b=f+20|0;d=v[b>>2];if(d){break f}b=f+16|0;d=v[b>>2];if(d){break f}c=0;break e}while(1){m=b;c=d;b=c+20|0;d=v[b>>2];if(d){continue}b=c+16|0;d=v[c+16>>2];if(d){continue}break}v[m>>2]=0}if(!k){break d}b=v[f+28>>2];d=(b<<2)+464688|0;g:{if(v[d>>2]==(f|0)){v[d>>2]=c;if(c){break g}n=464388,o=v[116097]&Pka(-2,b),v[n>>2]=o;break d}v[(v[k+16>>2]==(f|0)?16:20)+k>>2]=c;if(!c){break d}}v[c+24>>2]=k;b=v[f+16>>2];if(b){v[c+16>>2]=b;v[b+24>>2]=c}b=v[f+20>>2];if(!b){break d}v[c+20>>2]=b;v[b+24>>2]=c}if(l>>>0<=15){v[h>>2]=i&1|j|2;b=g+j|0;v[b+4>>2]=v[b+4>>2]|1;return a}v[h>>2]=i&1|e|2;b=e+g|0;v[b+4>>2]=l|3;c=g+j|0;v[c+4>>2]=v[c+4>>2]|1;LH(b,l);return a}c=Od(b);if(!c){return 0}d=v[h>>2];d=(d&3?-4:-8)+(d&-8)|0;tc(c,a,b>>>0>d>>>0?d:b);Mb(a);a=c}return a}function Uja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0;d=jb-1104|0;jb=d;v[d+1100>>2]=c;i=wB(d+40|0,b);q=Dq(i);e=Sb(a);v[23588]=0;a=S(202,b|0)|0;c=v[23588];v[23588]=0;a:{if((c|0)!=1){v[d+8>>2]=a;v[d+36>>2]=85899345;s=d,z=B(v[Jb(d+8|0,d+36|0)>>2],50),v[s+24>>2]=z;a=v[Jb(d+1100|0,d+24|0)>>2];v[23588]=0;R(322,e|0,a|0);a=v[23588];v[23588]=0;if((a|0)!=1){v[23588]=0;h=S(334,d+24|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){v[23588]=0;f=Q(335,d+8|0,8192)|0;a=v[23588];v[23588]=0;b:{if((a|0)!=1){a=v[h>>2];c=0;while(1){if((c|0)!=256){g=Db(a,c);t[g+2|0]=c;u[g>>1]=8192;c=c+1|0;continue}break}m=9;c:{d:while(1){g=0;n=257;while(1){r=m&255;e:{while(1){j=n&65535;while(1){v[23588]=0;o=Q(164,i|0,r|0)|0;a=v[23588];v[23588]=0;if((a|0)==1){break c}k=o&65535;if((k|0)==257|j>>>0<k>>>0){break e}if(ed(v[e>>2],v[e+4>>2])>>>0>=y[d+1100>>2]){break e}if((k|0)==256){m=9;continue d}c=j>>>0>k>>>0?o:g;a=v[h>>2];l=8192;while(1){c=c&65535;a=Db(a,c);l=l-1|0;p=l&65535;s=Kb(v[f>>2],p),z=w[a+2|0],t[s|0]=z;a=v[h>>2];c=x[Db(a,c)>>1];if(c>>>0<8192){continue}break}a=ec(d,Eb(v[e+4>>2]));c=Qf(Eb(v[f>>2]),p);l=Eb(v[f+4>>2]);a=v[a>>2];v[23588]=0;X(323,e|0,a|0,c|0,l|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}f:{if((j|0)!=(k|0)){break f}a=v[f>>2];v[23588]=0;R(336,e|0,Kb(a,p)|0);a=v[23588];v[23588]=0;if((a|0)!=1){break f}break c}if(j>>>0>=8192){g=o;continue}if(ed(v[e>>2],v[e+4>>2])>>>0>=y[d+1100>>2]){continue}break}a=w[Kb(v[f>>2],p)|0];c=Db(v[h>>2],j);u[c>>1]=g;t[c+2|0]=a;a=n+1|0;n=8192;g=o;c=a&65535;if((c|0)==8192){continue}break}m=((c|0)==1<<r)+m|0;n=a;continue}break}break}a=Dq(i);v[23588]=0;Q(155,b|0,((a-q|0)+3&-4)+q|0)|0;a=v[23588];v[23588]=0;if((a|0)==1){break c}hc(f);vc(h);Ab(i);jb=d+1104|0;return}c=P()|0;O()|0;hc(f);break b}c=P()|0;O()|0}vc(h);break a}c=P()|0;O()|0;break a}c=P()|0;O()|0;break a}c=P()|0;O()|0}hc(e);Ab(i);T(c|0);L()}function w6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=jb-96|0;jb=e;f=v[c+4>>2];a:{if(!f){break a}g=v[c>>2];h=w[cl(g,f)|0];if((h|0)==33){d=1}else{if((h|0)!=63){break a}d=0}jl(e+72|0,g,f,f-1|0);f=v[e+76>>2];v[c>>2]=v[e+72>>2];v[c+4>>2]=f}f=e+72|0;Wd(f);g=v[e+72>>2];Wd(e+56|0);h=bl(g,v[e+60>>2],c);Wd(f);f=v[c+4>>2];g=v[c>>2];b:{c:{d:{e:{if((h|0)==v[e+76>>2]){b=qc(e+88|0,21619);h=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=h;if(Pc(g,f,e)){a=ba(8)|0;v[23588]=0;b=Q(55,e+72|0,10432)|0;c=v[23588];v[23588]=0;if((c|0)==1){break d}a=rc(a,b);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break b}c=P()|0;O()|0;yb(b);break c}if(d){a=ba(8)|0;b=v[c+4>>2];c=v[c>>2];v[23588]=0;b=Kh(e+56|0,c,b);c=v[23588];v[23588]=0;f:{g:{h:{if((c|0)!=1){v[23588]=0;U(967,e+72|0,17634,b|0);c=v[23588];v[23588]=0;if((c|0)==1){break h}d=0;c=rc(a,e+72|0);v[23588]=0;U(119,c|0,62688,956);c=v[23588];v[23588]=0;if((c|0)!=1){break b}c=P()|0;O()|0;yb(e+72|0);break g}c=P()|0;O()|0;break f}c=P()|0;d=1;O()|0}yb(b);if(!d){break c}}ca(a|0);break c}Lb(a);break e}c=qc(e+48|0,21619);d=v[c+4>>2];v[e+24>>2]=v[c>>2];v[e+28>>2]=d;if(Pc(g,f,e+24|0)){a=ba(8)|0;v[23588]=0;b=Q(55,e+72|0,10432)|0;c=v[23588];v[23588]=0;if((c|0)!=1){a=rc(a,b);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break b}c=P()|0;O()|0;yb(b);break c}c=P()|0;O()|0;ca(a|0);break c}c=qc(e+40|0,12273);d=v[c+4>>2];v[e+16>>2]=v[c>>2];v[e+20>>2]=d;if(Pc(g,f,e+16|0)){i:{switch(v[b+52>>2]){case 0:Mc(a,5604);break e;case 1:Mc(a,11205);break e;case 2:Mc(a,9166);break e;default:break i}}Lb(a);break e}c=qc(e+32|0,11442);d=v[c+4>>2];v[e+8>>2]=v[c>>2];v[e+12>>2]=d;if(Pc(g,f,e+8|0)){j:{switch(v[b+56>>2]){case 0:Mc(a,15561);break e;case 1:Mc(a,15566);break e;case 2:Mc(a,12547);break e;case 3:Mc(a,9230);break e;default:break j}}Lb(a);break e}Lb(a)}jb=e+96|0;return}c=P()|0;O()|0;ca(a|0)}T(c|0)}L()}function Nha(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=jb-48|0;jb=c;a:{b:{c:{d:{e:{f:{g:{if(Ed(v[a+24>>2])){break g}h=a+4|0;k=Gb(h);e=jb-32|0;jb=e;d=e+24|0;b=d;v[b>>2]=-1;v[b+4>>2]=-1;v[23588]=0;f=jF(39);b=v[23588];v[23588]=0;if((b|0)==1){break a}v[e+8>>2]=f;v[e+12>>2]=mb;g=jb-16|0;jb=g;i=e+8|0;b=i;l=g,m=Lka(v[b>>2],v[b+4>>2],1e3,0),v[l>>2]=m;v[g+4>>2]=mb;f=rl(g+8|0,g);b=v[f+4>>2];jb=g+16|0;v[e+16>>2]=v[f>>2];v[e+20>>2]=b;b=e+16|0;l=e,m=pA(v[b>>2],v[b+4>>2]),v[l+16>>2]=m;v[e+20>>2]=mb;g=hS(d,b,Fb(b));v[23588]=0;d=jF(40);f=v[23588];v[23588]=0;if((f|0)==1){break a}j=a+24|0;v[e+8>>2]=d;v[e+12>>2]=mb;d=jb-16|0;jb=d;a=v[i+4>>2];v[d>>2]=v[i>>2];v[d+4>>2]=a;f=rl(d+8|0,d);a=v[f+4>>2];jb=d+16|0;v[e+16>>2]=v[f>>2];v[e+20>>2]=a;l=e,m=pA(v[b>>2],v[b+4>>2]),v[l+16>>2]=m;v[e+20>>2]=mb;a=hS(g,b,Fb(b));b=v[a>>2];a=v[a+4>>2];jb=e+32|0;if(k){d=Sb(c+32|0);v[23588]=0;v[c+16>>2]=a;R(33,d|0,c+16|0);a=v[23588];v[23588]=0;if((a|0)==1){break d}v[23588]=0;v[c+16>>2]=b;R(33,d|0,c+16|0);a=v[23588];v[23588]=0;if((a|0)==1){break e}a=0;h:{while(1){if(Gb(h)>>>0<=a>>>0){b=Eb(v[d>>2]);a=Eb(v[d+4>>2]);v[23588]=0;f=W(34,c+16|0,b|0,a|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){break h}a=P()|0;O()|0;break c}b=w[Sc(h,a)|0];v[23588]=0;v[c+16>>2]=b;R(33,d|0,c+16|0);b=v[23588];v[23588]=0;if((b|0)!=1){a=a+1|0;continue}break}a=P()|0;O()|0;break c}v[23588]=0;b=S(35,f|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){v[c+8>>2]=b;a=c+8|0;rA(j,a);yj(a);Fm(f);vc(d);break g}a=P()|0;O()|0;Fm(f);break c}mb=b;v[c+16>>2]=a;v[c+20>>2]=mb;b=Sb(c+32|0);v[23588]=0;U(38,b|0,c+16|0,c+24|0);a=v[23588];v[23588]=0;if((a|0)==1){a=P()|0;O()|0;vc(b);T(a|0);L()}v[23588]=0;f=S(35,b|0)|0;a=v[23588];v[23588]=0;if((a|0)==1){break f}v[c+8>>2]=f;a=c+8|0;rA(j,a);yj(a);Fm(b)}jb=c+48|0;return}a=P()|0;O()|0;Fm(b);break b}a=P()|0;O()|0;break c}a=P()|0;O()|0}vc(d)}T(a|0);L()}V(0)|0;O()|0;Ub();L()}function Q4(a,b,c){a=a|0;b=C(b);c=c|0;var d=0,e=C(0),f=C(0),g=C(0),h=C(0),i=C(0),k=C(0),m=0,n=0,o=0;d=jb-16|0;jb=d;a:{b:{c:{d:{switch(c-1|0){case 0:a=(p(b),j(2));e:{f:{g:{if((a|0)<=8388607){e=C(C(-1)/C(b*b));if(!(a&2147483647)){break e}e=C(C(b-b)/C(0));if((a|0)<0){break e}a=(p(C(b*C(33554432))),j(2));c=-152;break g}if(a>>>0>2139095039){break f}c=-127;b=C(0);if((a|0)==1065353216){break f}}a=a+4913933|0;k=C((a>>>23|0)+c|0);b=C((l(2,(a&8388607)+1060439283|0),q())+C(-1));f=C(b*C(b*C(.5)));g=C(b/C(b+C(2)));h=C(g*g);i=C(h*h);e=b;b=(l(2,(p(C(b-f)),j(2))&-4096),q());f=C(C(g*C(f+C(C(h*C(C(i*C(.2849878668785095))+C(.6666666269302368)))+C(i*C(C(i*C(.24279078841209412))+C(.40000972151756287))))))+C(C(e-b)-f));b=C(C(k*C(.3010292053222656))+C(C(b*C(.434326171875))+C(C(f*C(.434326171875))+C(C(k*C(7.903415166765626e-7))+C(C(f+b)*C(-3168997136526741e-20))))))}e=b}b=C(e*C(2e3));if(!(C(D(b))<C(2147483648))){break c}a=~~b;break b;case 1:a=(B(v[a+24604>>2],100)|0)/128|0;break b;case 2:c=jb-16|0;jb=c;h:{i:{j:{k:{a=w[a+24648|0];if(a>>>0>=6){a=ba(8)|0;v[23588]=0;c=Q(55,c|0,5126)|0;d=v[23588];v[23588]=0;if((d|0)==1){break k}a=rc(a,c);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break i}d=P()|0;O()|0;yb(c);break j}jb=c+16|0;a=v[(a<<2)+62408>>2];break h}d=P()|0;O()|0;ca(a|0)}T(d|0)}L()}break b;case 3:v[d>>2]=0;m=v[a+24640>>2];c=jb-80|0;jb=c;a=v[a+24636>>2];v[c+40>>2]=a;v[c>>2]=m;n=c+40|0;o=v[Oe(n,c)>>2];l:{if((a|0)==v[bq(n)+32>>2]){a=-1;if(v[bq(c)+36>>2]==(m|0)){break l}}a=0;if((o|0)<=0){break l}a=(o+500>>>0)/1e3|0}v[d>>2]=a;jb=c+80|0;a=v[d>>2];break b;default:break d}}c=ba(8)|0;v[23588]=0;d=Q(55,d|0,10335)|0;a=v[23588];v[23588]=0;m:{if((a|0)!=1){a=rc(c,d);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(d);break m}a=P()|0;O()|0;ca(c|0)}T(a|0);L()}a=-2147483648}jb=d+16|0;return a|0}L()}function K$(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=jb-16|0;jb=j;k=hv(g);o=Dw(g);bh(j,o);v[f>>2]=d;a:{b:{c:{i=a;g=w[i|0];switch(g-43|0){case 0:case 2:break c;default:break b}}v[23588]=0;g=Q(20,k|0,g<<24>>24)|0;i=v[23588];v[23588]=0;if((i|0)==1){break a}i=v[f>>2];v[f>>2]=i+1;t[i|0]=g;i=a+1|0}d:{g=i;if(!((c-g|0)<2|w[g|0]!=48|(w[g+1|0]|32)!=120)){v[23588]=0;g=Q(20,k|0,48)|0;h=v[23588];v[23588]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=g;g=t[i+1|0];v[23588]=0;g=Q(20,k|0,g|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=g;i=i+2|0;g=i;while(1){if(c>>>0<=g>>>0){break d}h=t[g|0];Gd();if(!WG(h)){break d}g=g+1|0;continue}}while(1){if(c>>>0<=g>>>0){break d}h=t[g|0];Gd();if(!$j(h)){break d}g=g+1|0;continue}}e:{if(Qe(j)){h=v[f>>2];v[23588]=0;X(1134,k|0,i|0,g|0,h|0);h=v[23588];v[23588]=0;if((h|0)==1){break a}v[f>>2]=v[f>>2]+(g-i|0);break e}$l(i,g);v[23588]=0;q=S(1132,o|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break a}h=i;while(1){if(g>>>0<=h>>>0){$l((i-a|0)+d|0,v[f>>2]);break e}f:{if(t[Sc(j,m)|0]<=0){break f}if(t[Sc(j,m)|0]!=(l|0)){break f}l=v[f>>2];v[f>>2]=l+1;t[l|0]=q;m=(Gb(j)-1>>>0>m>>>0)+m|0;l=0}p=t[h|0];v[23588]=0;p=Q(20,k|0,p|0)|0;n=v[23588];v[23588]=0;if((n|0)!=1){n=v[f>>2];v[f>>2]=n+1;t[n|0]=p;h=h+1|0;l=l+1|0;continue}break}break a}while(1){g:{if(c>>>0>g>>>0){i=w[g|0];if((i|0)!=46){break g}v[23588]=0;i=S(1135,o|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=i;g=g+1|0}i=v[f>>2];v[23588]=0;X(1134,k|0,g|0,c|0,i|0);i=v[23588];v[23588]=0;if((i|0)==1){break a}i=f;f=v[f>>2]+(c-g|0)|0;v[i>>2]=f;v[e>>2]=(b|0)==(c|0)?f:(b-a|0)+d|0;yb(j);jb=j+16|0;return}v[23588]=0;i=Q(20,k|0,i<<24>>24)|0;h=v[23588];v[23588]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=i;g=g+1|0;continue}}a=P()|0;O()|0;yb(j);T(a|0);L()}function LO(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0;c=jb-176|0;jb=c;e=v[a+12>>2];j=1<<e;a:{if(!(e&1)){h=j>>>2|0;l=1;break a}l=j>>>1|0;e=0;while(1){if((e|0)==(l|0)){h=j>>>3|0;l=2;e=v[a+12>>2]}else{i=v[b>>2];h=Jd(i,e+l|0);d=Jd(i,e);o=A[h>>3];p=A[h+8>>3];mj(c+160|0,d,o,p);i=v[c+172>>2];v[h+8>>2]=v[c+168>>2];v[h+12>>2]=i;i=v[c+164>>2];v[h>>2]=v[c+160>>2];v[h+4>>2]=i;cy(Jd(v[b>>2],e),o,p);e=e+1|0;continue}break}}i=e&-2;b:while(1){if(i){x=B(h,3);y=h<<1;j=0;c:while(1){if((j|0)==(l|0)){i=i-2|0;h=h>>>2|0;l=l<<2;continue b}d=v[a>>2];e=Jd(d,j<<1);d=Jd(d,j);o=A[d>>3];p=A[d+8>>3];r=A[e>>3];s=A[e+8>>3];ui(c+160|0,o,p,r,s);e=j<<i;d=h+e|0;z=d>>>0<e>>>0?e:d;while(1)if((e|0)==(z|0)){j=j+1|0;continue c}else{f=v[b>>2];d=Jd(f,e);g=v[d+12>>2];v[c+152>>2]=v[d+8>>2];v[c+156>>2]=g;g=v[d+4>>2];v[c+144>>2]=v[d>>2];v[c+148>>2]=g;g=c+128|0;t=e+h|0;k=Jd(f,t);ui(g,r,s,A[k>>3],A[k+8>>3]);u=e+y|0;k=Jd(f,u);ui(c+112|0,o,p,A[k>>3],A[k+8>>3]);m=A[c+160>>3];n=A[c+168>>3];w=e+x|0;f=Jd(f,w);ui(c+96|0,m,n,A[f>>3],A[f+8>>3]);k=c+80|0;f=c+144|0;m=A[c+112>>3];n=A[c+120>>3];fl(k,f,m,n);q=c- -64|0;mj(q,f,m,n);m=A[c+96>>3];n=A[c+104>>3];fl(c+48|0,g,m,n);f=c+16|0;nl(f,-0,-1);mj(c,g,m,n);ui(c+32|0,A[c+16>>3],A[c+24>>3],A[c>>3],A[c+8>>3]);fl(f,k,A[c+48>>3],A[c+56>>3]);g=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=g;g=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=g;mj(f,k,A[c+48>>3],A[c+56>>3]);d=Jd(v[b>>2],t);g=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=g;g=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=g;fl(f,q,A[c+32>>3],A[c+40>>3]);d=Jd(v[b>>2],u);g=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=g;g=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=g;mj(f,q,A[c+32>>3],A[c+40>>3]);d=Jd(v[b>>2],w);f=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=f;f=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=f;e=e+1|0;continue}}}break}jb=c+176|0}function j6(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;k=jb+-64|0;jb=k;a:{b:{c:{j=xp(1,32);d:{e:{if(!j){a=mm(ba(4)|0);v[23588]=0;U(119,a|0,92948,26);a=v[23588];v[23588]=0;if((a|0)!=1){break a}i=V(0)|0;O()|0;break e}v[j+12>>2]=f;v[j+8>>2]=e;v[j+4>>2]=d;v[j>>2]=c?c:933;c=Xf(k+48|0);f:{g:{h:{if(!i){break h}while(1){d=v[i>>2];if(!d){break h}e=v[i+4>>2];i:{if(e){v[23588]=0;d=Q(55,k+32|0,d|0)|0;f=v[23588];v[23588]=0;j:{if((f|0)!=1){v[23588]=0;f=Q(944,c|0,d|0)|0;l=v[23588];v[23588]=0;if((l|0)==1){break j}v[23588]=0;R(270,f|0,e|0);e=v[23588];v[23588]=0;if((e|0)==1){break j}break i}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;yb(d);break f}v[23588]=0;d=Q(55,k+16|0,d|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break g}Ks(c,d)}yb(d);i=i+8|0;continue}}v[23588]=0;d=S(812,104)|0;e=v[23588];v[23588]=0;k:{l:{m:{if((e|0)!=1){e=v[j+4>>2];f=v[j>>2];v[23588]=0;e=Q(945,f|0,e|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break m}v[k>>2]=e;e=v[dg(k+8|0,k)>>2];v[23588]=0;a=ja(976,d|0,a|0,b|0,e|0,c|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break k}i=V(0)|0;O()|0;De(k);break l}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0}Mb(d);break f}v[j+28>>2]=a;De(k);a=v[j+28>>2];v[j+24>>2]=a?a+8|0:0;kl(c);break d}i=V(0)|0;O()|0}kl(c);_(i|0)|0;v[23588]=0;X(939,4976,j|0,g|0,h|0);a=v[23588];v[23588]=0;if((a|0)!=1){v[23588]=0;Z(18);a=v[23588];v[23588]=0;if((a|0)!=1){a=v[j+28>>2];if(a){nb[v[v[a>>2]+4>>2]](a)}v[j+24>>2]=0;v[j+28>>2]=0;a=v[j+20>>2];if(a){Mb(a);v[j+20>>2]=0}Mb(j);j=0;break d}i=V(0)|0;O()|0;break e}i=V(0)|0;O()|0;v[23588]=0;Z(18);a=v[23588];v[23588]=0;if((a|0)==1){break b}}_(i|0)|0;j=0;v[23588]=0;X(939,4976,0,g|0,h|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}$()}jb=k- -64|0;return j|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)==1){break b}T(a|0);L()}V(0)|0;O()|0;Ub()}L()}function ih(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;a:{b:{c:{switch(b|0){case 1:b=0;a=Lb(a);d=Gb(c);v[23588]=0;R(48,a|0,d|0);d=v[23588];v[23588]=0;d:{if((d|0)!=1){e:{while(1){if(Gb(c)>>>0>b>>>0){d=t[gg(c,b)|0];v[23588]=0;R(49,a|0,((d|0)<0?65533:d&255)|0);d=v[23588];v[23588]=0;if((d|0)==1){break e}b=b+1|0;continue}break}break d}}break a}return;case 2:b=0;a=Lb(a);d=Gb(c);v[23588]=0;R(48,a|0,d|0);d=v[23588];v[23588]=0;f:{if((d|0)!=1){while(1){if(Gb(c)>>>0<=b>>>0){break f}d=w[gg(c,b)|0];v[23588]=0;R(49,a|0,d|0);d=v[23588];v[23588]=0;if((d|0)!=1){b=b+1|0;continue}break}}break a}return;case 3:ml(a,c,49552);return;case 5:ml(a,c,50576);return;case 4:ml(a,c,51600);return;case 6:ml(a,c,52624);return;case 7:ml(a,c,53648);return;case 8:ml(a,c,54672);return;case 9:ml(a,c,55696);return;case 10:kz(a,c,56720);return;case 11:kz(a,c,49552);return;case 12:kz(a,c,53648);return;default:a=ba(8)|0;v[23588]=0;b=Q(45,a|0,11027)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break b}b=P()|0;O()|0;ca(a|0);T(b|0);L();case 0:break c}}e=jb-16|0;jb=e;f=Lb(a);g=e,h=qt(c),v[g+8>>2]=h;g=e,h=pt(c),v[g>>2]=h;a=0;g:{h:{while(1){i:{if(!yi(e+8|0,e)){if(!a){break i}v[23588]=0;R(49,f|0,65533);a=v[23588];v[23588]=0;if((a|0)!=1){break i}break h}b=w[v[e+8>>2]];j:{k:{if(!a){if(!(b&128)){a=0;v[23588]=0;R(49,f|0,b|0);b=v[23588];v[23588]=0;if((b|0)!=1){break j}break h}if((b&224)==192){d=b&31;a=1;break j}if((b&240)==224){d=b&15;a=2;break j}d=65533;if((b&248)!=240){break k}d=b&7;a=3;break j}if((b&192)!=128){d=0;v[23588]=0;R(49,f|0,65533);c=v[23588];v[23588]=0;a=0;if((c|0)==1){break h}}d=b&63|d<<6;a=a-1|0;if(a){break j}}a=0;v[23588]=0;R(49,f|0,d|0);b=v[23588];v[23588]=0;d=0;if((b|0)==1){break h}}Ge(e+8|0);continue}break}jb=e+16|0;break g}a=P()|0;O()|0;Fc(f);T(a|0);L()}return}ha(b|0,93080,25);L()}b=P()|0;O()|0;Fc(a);T(b|0);L()}function D6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-96|0;jb=d;f=1;a:{if(Qe(c)){break a}e=w[PJ(c)|0];if((e|0)!=33){if((e|0)!=63){break a}f=0}e=d+80|0;Qv(e,c,0,Gb(c)-1|0);Ac(c,e);yb(e)}e=d+80|0;Wd(e);g=v[d+80>>2];Wd(d+72|0);g=OJ(g,v[d+76>>2],c);Wd(e);b:{c:{d:{e:{f:{if((g|0)==v[d+84>>2]){if(ue(c,21619)){a=ba(8)|0;v[23588]=0;b=Q(55,d+80|0,10432)|0;c=v[23588];v[23588]=0;if((c|0)==1){break d}a=rc(a,b);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break b}c=P()|0;O()|0;yb(b);break c}if(!f){break f}a=ba(8)|0;v[23588]=0;U(958,d+80|0,17634,c|0);b=v[23588];v[23588]=0;if((b|0)!=1){a=rc(a,d+80|0);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break b}c=P()|0;O()|0;yb(d+80|0);break c}c=P()|0;O()|0;ca(a|0);break c}e=Lb(d+80|0);g:{h:{i:{j:{switch(v[g+4>>2]){case 0:Fe(d- -64|0,c);v[23588]=0;c=v[d+68>>2];v[d+8>>2]=v[d+64>>2];v[d+12>>2]=c;b=W(959,b|0,d+8|0,f|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){v[23588]=0;t[d+72|0]=b;R(960,a|0,d+72|0);a=v[23588];v[23588]=0;if((a|0)!=1){break g}}break i;case 1:Fe(d+56|0,c);v[23588]=0;c=v[d+60>>2];v[d+16>>2]=v[d+56>>2];v[d+20>>2]=c;b=mF(b,d+16|0,f);c=mb;f=v[23588];v[23588]=0;if((f|0)!=1){v[23588]=0;v[d+72>>2]=b;v[d+76>>2]=c;R(962,a|0,d+72|0);a=v[23588];v[23588]=0;if((a|0)!=1){break g}}break i;case 2:Fe(d+48|0,c);v[23588]=0;c=v[d+52>>2];v[d+24>>2]=v[d+48>>2];v[d+28>>2]=c;h=+ra(963,b|0,d+24|0,f|0);b=v[23588];v[23588]=0;if((b|0)!=1){v[23588]=0;A[d+72>>3]=h;R(964,a|0,d+72|0);a=v[23588];v[23588]=0;if((a|0)!=1){break g}}break i;case 3:break j;default:break h}}Fe(d+40|0,c);v[23588]=0;c=v[d+44>>2];v[d+32>>2]=v[d+40>>2];v[d+36>>2]=c;X(965,a|0,b|0,d+32|0,f|0);a=v[23588];v[23588]=0;if((a|0)!=1){break g}}c=P()|0;O()|0;yb(e);break c}$c(a,e)}yb(e);break e}Lb(a)}jb=d+96|0;return}c=P()|0;O()|0;ca(a|0)}T(c|0)}L()}function Eca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;g=jb-48|0;jb=g;p=v[a+16>>2];while(1){if((f|0)!=2){e=f<<3;i=e+(g+24|0)|0;e=a+e|0;v[i+4>>2]=v[e+44>>2];v[i+8>>2]=v[e+48>>2];f=f+1|0;continue}break}i=v[a+40>>2];k=v[a+36>>2];f=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=f;q=b+24|0;r=v[a+32>>2];s=v[a+28>>2];t=v[a+72>>2];b=v[a+68>>2];w=b;x=b>>31;b=v[a+64>>2];y=b;z=b>>31;b=v[a+60>>2];A=b;C=b>>31;D=v[a+8>>2];E=v[a+12>>2];while(1){if(d){f=v[g+16>>2];l=((((v[g+20>>2]&2147483647)<<1|f>>>31)&2147483646)<<1)+p|0;b=(((f>>>16|0)+4&131064)<<1)+q|0;j=u[b+14>>1];h=u[b+12>>1];m=u[b+10>>1];n=u[b+8>>1];o=u[b+6>>1];F=u[b+4>>1];G=u[b+2>>1];H=u[b>>1];f=0;e=0;while(1){if((e|0)!=2){b=l+(e<<1)|0;v[(g+8|0)+(e<<2)>>2]=(((((B(u[b+8>>1],m)+B(u[b+4>>1],n)|0)+B(h,u[b+12>>1])|0)+B(j,u[b+16>>1])|0)/2|0)+((((B(u[b-8>>1],G)+B(u[b-12>>1],H)|0)+B(u[b-4>>1],F)|0)+B(u[b>>1],o)|0)/2|0)|0)/16384;e=e+1|0;continue}break}while(1){if((f|0)!=2){l=(g+8|0)+(f<<2)|0;e=v[l>>2];b=(g+24|0)+(f<<3)|0;j=v[b+8>>2];h=v[b+4>>2];v[b+8>>2]=h;m=e<<8;e=m;e=Lka(A,C,e,e>>31);n=mb;o=b;b=Xb(h,-16777216,16776704);h=Lka(y,z,b,b>>31);e=h+e|0;b=mb+n|0;b=e>>>0<h>>>0?b+1|0:b;h=e;e=Xb(j,-16777216,16776704);j=Lka(w,x,e,e>>31);e=h+j|0;b=mb+b|0;b=e>>>0<j>>>0?b+1|0:b;e=e+8388608|0;b=e>>>0<8388608?b+1|0:b;b=Xc(e,b,24);v[o+4>>2]=b-(m&t);v[l>>2]=(b|0)/256;f=f+1|0;continue}break}k=k+s|0;v[c>>2]=v[c>>2]+B(v[g+8>>2],k>>12);i=i+r|0;v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],i>>12);Qb(g+16|0,D,E);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;v[a+40>>2]=i;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+24>>2]=i>>12;f=0;while(1){if((f|0)!=2){b=f<<3;c=b+a|0;b=b+(g+24|0)|0;v[c+44>>2]=v[b+4>>2];v[c+48>>2]=v[b+8>>2];f=f+1|0;continue}break}jb=g+48|0}function fk(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;i=jb-16|0;jb=i;a:{if(!d){break a}g=v[c>>2];if(!g){break a}b:{c:{d:{e:{f=v[a+480180>>2];if((f|0)!=512){if((f|0)!=64){break e}f=B(d,20)+g|0;break d}f=((B(d,36318)|0)/1024|0)+g|0;break d}f:{g:{h:{if(w[a+480208|0]&16){if((f|0)==4){break h}f=d>>31;v[i+12>>2]=(f^d)-f;wc(i+12|0,1020);h=v[i+12>>2];i:{if((d|0)>0){if(h>>>0<=15){f=jb-16|0;jb=f;Cb(f+8|0,a+1074312|0,7);j=Bb(v[v[f+8>>2]>>2],v[f+12>>2]);jb=f+16|0;h=v[(h<<2)+(j?37008:37072)>>2];break i}f=jb-16|0;jb=f;Cb(f+8|0,a+1074312|0,7);j=Bb(v[v[f+8>>2]>>2],v[f+12>>2]);jb=f+16|0;h=v[(h>>>2<<2)+(j?37136:38160)>>2];break i}if(h>>>0<=15){f=jb-16|0;jb=f;Cb(f+8|0,a+1074312|0,7);j=Bb(v[v[f+8>>2]>>2],v[f+12>>2]);jb=f+16|0;h=v[(h<<2)+(j?37072:37008)>>2];break i}f=jb-16|0;jb=f;Cb(f+8|0,a+1074312|0,7);j=Bb(v[v[f+8>>2]>>2],v[f+12>>2]);jb=f+16|0;h=v[(h>>>2<<2)+(j?38160:37136)>>2]}h=Lka(h,h>>31,g,g>>31)+32768|0;f=mb;f=Hc(Mka(h,h>>>0<32768?f+1|0:f,65536,0),mb);v[c>>2]=f;if((f|0)!=(g|0)){break c}Cb(i,a+1074312|0,7);g=v[c>>2];if(!(Bb(v[v[i>>2]>>2],v[i+4>>2])^(d|0)>0)){f=2147483647;d=1;if((g|0)==2147483647){break c}break f}d=-1;if((g|0)>=2){break f}f=g;break c}Cb(i,a+1074312|0,7);if(Bb(v[v[i>>2]>>2],v[i+4>>2])){break g}g=v[c>>2]}f=g-d|0;break d}f=v[c>>2];if((d|0)<0){g=Lka(f,0,14317456,0);h=mb;f=Lka(f,0,0-d|0,0)+14317456|0;d=mb;f=qN(Oka(g,h,f,f>>>0<14317456?d+1|0:d),mb);break d}d=Lka(f,f>>31,d,0);g=mb;if((g|0)>=0&d>>>0>=14317456|(g|0)>0){if(e){v[c>>2]=2147483647;break a}v[c>>2]=0;v[b+696>>2]=0;v[b+88>>2]=v[b+88>>2]|2101248;break a}d=qN(Oka(Lka(f,0,14317456,0),mb,14317456-d|0,0-(g+(d>>>0>14317456)|0)|0),mb);v[c>>2]=d;if((d|0)>0){break a}break b}f=d+g|0}v[c>>2]=f}if((f|0)>0){break a}}v[c>>2]=1;if(v[a+480180>>2]!=2|e){break a}v[b+696>>2]=0;v[b+88>>2]=v[b+88>>2]|2101248}jb=i+16|0}function Fca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;g=jb-48|0;jb=g;p=v[a+16>>2];while(1){if((f|0)!=2){e=f<<3;i=e+(g+24|0)|0;e=a+e|0;v[i+4>>2]=v[e+44>>2];v[i+8>>2]=v[e+48>>2];f=f+1|0;continue}break}i=v[a+40>>2];k=v[a+36>>2];f=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=f;q=b+24|0;r=v[a+32>>2];s=v[a+28>>2];w=v[a+72>>2];b=v[a+68>>2];x=b;y=b>>31;b=v[a+64>>2];z=b;A=b>>31;b=v[a+60>>2];C=b;D=b>>31;E=v[a+8>>2];F=v[a+12>>2];while(1){if(d){f=v[g+16>>2];l=(((v[g+20>>2]&2147483647)<<1|f>>>31)&-2)+p|0;b=(((f>>>16|0)+4&131064)<<1)+q|0;j=u[b+14>>1];h=u[b+12>>1];m=u[b+10>>1];n=u[b+8>>1];o=u[b+6>>1];G=u[b+4>>1];H=u[b+2>>1];I=u[b>>1];f=0;e=0;while(1){if((e|0)!=2){b=e+l|0;v[(g+8|0)+(e<<2)>>2]=(((((B(t[b+4|0],m)+B(t[b+2|0],n)|0)+B(h,t[b+6|0])|0)+B(j,t[b+8|0])<<8)/2|0)+((((B(t[b-4|0],H)+B(t[b-6|0],I)|0)+B(t[b-2|0],G)|0)+B(t[b|0],o)<<8)/2|0)|0)/16384;e=e+1|0;continue}break}while(1){if((f|0)!=2){l=(g+8|0)+(f<<2)|0;e=v[l>>2];b=(g+24|0)+(f<<3)|0;j=v[b+8>>2];h=v[b+4>>2];v[b+8>>2]=h;m=e<<8;e=m;e=Lka(C,D,e,e>>31);n=mb;o=b;b=Xb(h,-16777216,16776704);h=Lka(z,A,b,b>>31);e=h+e|0;b=mb+n|0;b=e>>>0<h>>>0?b+1|0:b;h=e;e=Xb(j,-16777216,16776704);j=Lka(x,y,e,e>>31);e=h+j|0;b=mb+b|0;b=e>>>0<j>>>0?b+1|0:b;e=e+8388608|0;b=e>>>0<8388608?b+1|0:b;b=Xc(e,b,24);v[o+4>>2]=b-(m&w);v[l>>2]=(b|0)/256;f=f+1|0;continue}break}k=k+s|0;v[c>>2]=v[c>>2]+B(v[g+8>>2],k>>12);i=i+r|0;v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],i>>12);Qb(g+16|0,E,F);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;v[a+40>>2]=i;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+24>>2]=i>>12;f=0;while(1){if((f|0)!=2){b=f<<3;c=b+a|0;b=b+(g+24|0)|0;v[c+44>>2]=v[b+4>>2];v[c+48>>2]=v[b+8>>2];f=f+1|0;continue}break}jb=g+48|0}function nK(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;k=jb+-64|0;jb=k;a:{b:{c:{d:{e:{f:{j=xp(1,28);if(!j){a=mm(ba(4)|0);v[23588]=0;U(119,a|0,92948,26);a=v[23588];v[23588]=0;if((a|0)!=1){break a}break f}v[j+12>>2]=f;v[j+8>>2]=e;v[j+4>>2]=d;v[j>>2]=c?c:933;c=Xf(k+48|0);g:{h:{i:{if(!i){break i}while(1){d=v[i>>2];if(!d){break i}e=v[i+4>>2];j:{if(e){v[23588]=0;d=Q(55,k+32|0,d|0)|0;f=v[23588];v[23588]=0;k:{if((f|0)!=1){v[23588]=0;f=Q(944,c|0,d|0)|0;l=v[23588];v[23588]=0;if((l|0)==1){break k}v[23588]=0;R(270,f|0,e|0);e=v[23588];v[23588]=0;if((e|0)==1){break k}break j}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;yb(d);break g}v[23588]=0;d=Q(55,k+16|0,d|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break h}Ks(c,d)}yb(d);i=i+8|0;continue}}v[23588]=0;d=S(812,80)|0;e=v[23588];v[23588]=0;l:{m:{n:{if((e|0)!=1){e=v[j+4>>2];f=v[j>>2];v[23588]=0;e=Q(945,f|0,e|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break n}v[k>>2]=e;e=v[dg(k+8|0,k)>>2];v[23588]=0;a=ja(950,d|0,a|0,b|0,e|0,c|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break l}i=V(0)|0;O()|0;De(k);break m}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0}Mb(d);break g}v[j+24>>2]=a;De(k);kl(c);i=j;break d}i=V(0)|0;O()|0}kl(c);_(i|0)|0;v[23588]=0;X(939,15050,j|0,g|0,h|0);a=v[23588];v[23588]=0;if((a|0)!=1){v[23588]=0;Z(18);a=v[23588];v[23588]=0;if((a|0)==1){break f}a=v[j+24>>2];if(a){Mb(Js(a))}i=0;v[j+24>>2]=0;a=v[j+20>>2];if(a){Mb(a);v[j+20>>2]=0}Mb(j);break d}i=V(0)|0;O()|0;v[23588]=0;Z(18);a=v[23588];v[23588]=0;if((a|0)!=1){break e}break b}i=V(0)|0;O()|0}_(i|0)|0;i=0;v[23588]=0;X(939,15050,0,g|0,h|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}$()}jb=k- -64|0;return i|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)==1){break b}T(a|0);L()}V(0)|0;O()|0;Ub()}L()}function T_(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a=jb-1072|0;jb=a;v[a+16>>2]=f;v[a+20>>2]=g;v[a+24>>2]=h;v[a+28>>2]=i;j=a+960|0;v[a+956>>2]=j;j=Gw(j,100,11090,a+16|0);v[a+48>>2]=1123;k=a+48|0;o=se(a+536|0,0,k);v[a+48>>2]=1123;k=se(a+528|0,0,k);a:{b:{c:{d:{if(j>>>0<100){h=a+544|0;f=a+960|0;break d}j=Gd();v[a>>2]=f;v[a+4>>2]=g;v[a+8>>2]=h;v[a+12>>2]=i;j=Zi(a+956|0,j,11090,a);if((j|0)!=-1){f=v[a+956>>2];Ze(o,f);Ze(k,Od(j<<2));h=v[k>>2];if(!ik(h)){break d}}v[23588]=0;Z(1124);a=v[23588];v[23588]=0;if((a|0)!=1){break a}j=P()|0;O()|0;break c}g=a+520|0;fd(g,d);v[23588]=0;q=S(1136,g|0)|0;g=v[23588];v[23588]=0;e:{f:{g:{h:{i:{j:{if((g|0)==1){break j}v[23588]=0;X(1148,q|0,f|0,f+j|0,h|0);g=v[23588];v[23588]=0;if((g|0)==1){break j}p=(j|0)>0?w[f|0]==45:p;i=Lb(a+488|0);f=Lb(a+472|0);g=Lb(a+456|0);v[23588]=0;na(1175,c|0,p|0,a+520|0,a+512|0,a+508|0,a+504|0,i|0,f|0,g|0,a+452|0);c=v[23588];v[23588]=0;if((c|0)==1){break i}v[a+36>>2]=1123;c=se(a+40|0,0,a+36|0);m=a+48|0;n=v[a+452>>2];k:{if((n|0)<(j|0)){l=((Gb(g)+(j-n<<1)|0)+Gb(f)|0)+1|0;break k}l=(Gb(g)+Gb(f)|0)+2|0}l=l+n|0;if(l>>>0<101){break h}Ze(c,Od(l<<2));m=v[c>>2];if(m){break h}v[23588]=0;Z(1124);b=v[23588];v[23588]=0;if((b|0)!=1){break a}break g}j=P()|0;O()|0;break e}j=P()|0;O()|0;break f}l=v[d+4>>2];v[23588]=0;pa(1176,m|0,a+36|0,a+32|0,l|0,h|0,(j<<2)+h|0,q|0,p|0,a+512|0,v[a+508>>2],v[a+504>>2],i|0,f|0,g|0,n|0);h=v[23588];v[23588]=0;if((h|0)!=1){v[23588]=0;b=ka(1157,b|0,m|0,v[a+36>>2],v[a+32>>2],d|0,e|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){break b}}}j=P()|0;O()|0;Wc(c)}Fc(g);Fc(f);yb(i)}$b(a+520|0)}Wc(k);Wc(o);T(j|0);L()}Wc(c);Fc(g);Fc(f);yb(i);$b(a+520|0);Wc(k);Wc(o);jb=a+1072|0;return b|0}L()}function hg(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;j=v[a+8>>2]+(B(x[a+14>>1],(w[a+80|0]?c:0)+b|0)>>>1|0)|0;v[a+8>>2]=j;i=w[a+79|0]?x[v[a>>2]+3836>>1]:i;c=x[a+20>>1];l=x[a+22>>1];m=x[a+70>>1];a:{b:{c:{d:{switch(v[a+16>>2]){case 1:b=x[v[a>>2]+3832>>1];f=x[a+26>>1]?x[a+48>>1]>>>x[v[a+52>>2]+((b>>>x[a+44>>1]&7)<<1)>>1]|0:0;g=b;b=x[a+46>>1];f=c+(b?g&b?0:f:f)|0;u[a+20>>1]=f;b=2;h=x[a+28>>1];if((h|0)<=f<<16>>16){break c}break b;case 2:if(w[a+78|0]){break b}case 3:b=0;f=x[v[a>>2]+3832>>1];h=x[a+30>>1]?x[a+60>>1]>>>x[v[a+64>>2]+((f>>>x[a+56>>1]&7)<<1)>>1]|0:0;g=f;f=x[a+58>>1];f=c+(f?g&f?0:h:h)|0;u[a+20>>1]=f;if(f<<16>>16<511){break b}v[a+16>>2]=-1;u[a+20>>1]=511;v[a+72>>2]=0;break a;default:b=0;v[a+72>>2]=0;break a;case 0:break d}}b=1;f=x[v[a>>2]+3832>>1];k=x[a+24>>1]?B((c^-1)<<16>>16,x[a+36>>1]>>>x[v[a+40>>2]+((f>>>x[a+32>>1]&7)<<1)>>1]|0)>>>3|0:0;g=f;f=x[a+34>>1];f=c+(f?g&f?0:k:k)|0;u[a+20>>1]=f;if(f<<16>>16>0){break b}}v[a+16>>2]=b;u[a+20>>1]=h}i=((c+l|0)+m|0)+i<<3;if(e){d=(u[a+74>>1]+u[a+72>>1]>>e)+d|0}d=(j>>>10|0)+d|0;c=d&255;b=d&65535;e:{f:{switch(x[a+12>>1]){case 0:d=(b&512)>>>9|0;b=x[((b&256?c^255:c)<<1)+28400>>1];break e;case 1:d=0;b=x[((b&512?0:b&256?c^255:c)<<1)+28400>>1];break e;case 2:d=0;b=x[((b&256?c^255:c)<<1)+28400>>1];break e;case 3:d=0;b=x[((b&256?0:c)<<1)+28400>>1];break e;case 4:e=0;d=0;if(!(b&512)){e=(c<<1^b<<24>>31)&254;d=(b&256)>>>8|0}b=x[(e<<1)+28400>>1];break e;case 5:d=0;if(b&512){b=0}else{c=c<<1&254;b=b&128?c^255:c}b=x[(b<<1)+28400>>1];break e;case 6:d=(d&512)>>>9|0;b=0;break e;default:break f}}c=d<<3&4088;d=(b&512)>>>9|0;b=d?c^4088:c}u[a+74>>1]=x[a+72>>1];c=a;a=b+i&65535;a=a>>>0<8191?a:8191;b=0-(d&1)^x[((a&255)<<1)+27888>>1]+1024>>>(a>>>8)<<1;u[c+72>>1]=b}return b<<16>>16}function PR(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=jb-16|0;jb=f;t[a|0]=0;c=w[b|0];if(c){t[a|0]=c>>>0>96?-1:c+12|0}t[a+1|0]=w[b+1|0];c=w[b+2|0];d=c-16|0;a:{b:{if((d&255)>>>0<=128){t[a+2|0]=1;c=(d&254)>>>1|0;break b}c:{switch((c+96&240)>>>4|0){case 0:t[a+2|0]=4;c=c&15;break b;case 1:t[a+2|0]=3;c=c&15;break b;case 2:t[a+2|0]=6;c=c&15;break b;case 3:break c;default:break a}}t[a+2|0]=5;c=c&15}t[a+4|0]=c}e=w[b+4|0];d=w[b+5|0];c=w[b+6|0];d:{if(!(c?1:e|d)){break d}e:{f:{g:{h:{i:{j:{switch(e|0){default:k:{switch(e-29|0){case 7:break f;case 5:break g;case 3:break h;case 0:break i;case 1:case 2:case 4:case 6:break d;default:break k}}if((e|0)==128){break e}if((e|0)!=157){break d}t[a+2|0]=15;t[a+3|0]=20;t[a+4|0]=c>>>3;t[f+15|0]=15;h=a,i=w[Wb(b+5|0,f+15|0)|0]|208,t[h+5|0]=i;break d;case 0:Of(a,c,d);g=w[b+6|0]==15;break d;case 1:t[a+3|0]=2;h=a,i=sg(c<<4|(d&240)>>>4),t[h+5|0]=i;break d;case 2:t[a+3|0]=3;h=a,i=sg(c<<4|(d&240)>>>4),t[h+5|0]=i;break d;case 3:t[a+3|0]=4;h=a,i=sg(c<<4|(d&240)>>>4),t[h+5|0]=i;break d;case 4:t[a+3|0]=5;t[a+5|0]=c&240|(d&240)>>>4;break d;case 8:if(d){t[a+5|0]=d;t[a+3|0]=9;break d}if((c-1&255)>>>0>1){break d}t[a+5|0]=145;t[a+3|0]=20;break d;case 12:t[a+3|0]=13;t[a+5|0]=c>>>1;break d;case 15:if(c){t[a+5|0]=c;t[a+3|0]=17;break d}t[a+3|0]=16;t[a+5|0]=d&15;break d;case 16:break j;case 5:case 6:case 7:case 9:case 10:case 11:case 13:case 14:break d}}RA(a,c,d,1);g=(w[a+3|0]&254)==16;break d}t[a+5|0]=d;t[a+3|0]=18;break d}t[a+3|0]=31;t[a+5|0]=c>>>1;break d}t[a+3|0]=31;t[a+5|0]=c>>>1&120;break d}t[a+5|0]=159;t[a+3|0]=20;break d}t[a+3|0]=21;t[a+5|0]=c>>>2}b=w[b+3|0];l:{if(!b){break l}if(!w[a+3|0]){t[a+5|0]=b;t[a+3|0]=9;break l}if(w[a+2|0]){break l}t[a+2|0]=2;t[a+4|0]=b>>>2}jb=f+16|0;return g}function Vp(a,b,c,d){var e=0,f=C(0),g=C(0),h=C(0),i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=jb-16|0;jb=e;v[e+12>>2]=u[b+780>>1]+w[b+837|0];v[e+8>>2]=u[b+782>>1]+(w[b+838|0]&127);oe(e+12|0,0,127);oe(e+8|0,0,127);k=a+1074312|0;Cb(e,k,1);j=v[e+12>>2];a:{if(Bb(v[v[e>>2]>>2],v[e+4>>2])){i=v[e+8>>2];break a}u[b+780>>1]=0;t[b+837|0]=j;i=v[e+8>>2];u[b+782>>1]=0;t[b+838|0]=i}Cb(e,k,36);l=B(j,d+256|0);m=(l|0)/256|0;b:{if(!(!Bb(v[v[e>>2]>>2],v[e+4>>2])|i|(l|0)<65024)){m=-1;if(!_c(w[b+788|0])){break b}if(vm(w[b+790|0],w[b+791|0])|x[b+786>>1]|!(w[b+851|0]&2)){break b}v[b+88>>2]=v[b+88>>2]&-32769;break b}v[b+88>>2]=v[b+88>>2]|32768;f=te(C(10),C(C(0-i|0)*C(.00937500037252903)));i=jb-16|0;jb=i;g=C(B(j,d+256|0)>>>0);c:{if(v[a+480180>>2]!=33554432){h=C(110);g=C(C(g/(w[a+480209|0]&128?C(10240):C(12288)))+C(.25));break c}h=C(125);g=C(C(g*C(6))/C(65024))}n=i,o=Sh(C(te(C(2),g)*h)),v[n+12>>2]=o;oe(i+12|0,120,2e4);d=v[i+12>>2];j=v[a+24620>>2];jb=i+16|0;Cb(e,k,36);g=C(C(((j|0)<d<<1?j>>>1|0:d)>>>0)*C(6.2831854820251465));d:{if(!(!Bb(v[v[e>>2]>>2],v[e+4>>2])|v[a+480208>>2]&32768)){h=C(C(y[a+24620>>2])/g);g=C(C(C(f*h)+f)+C(-1));z[e>>2]=g;f=C(h*h);break d}h=C(f+f);f=C(g/C(y[a+24620>>2]));z[e>>2]=C(C(1)-h)*f;dO(e,C(2));g=C(C(h-z[e>>2])/f);z[e>>2]=g;f=C(C(1)/C(f*f))}h=C(f+C(g+C(1)));g=C(C(f+C(f+g))/h);f=C(C(-f)/h);h=C(C(1)/h);e:{if(w[b+845|0]==1){n=b,o=Sh(C(C(C(1)-h)*C(16777216))),v[n+60>>2]=o;n=b,o=Sh(C(g*C(16777216))),v[n+64>>2]=o;n=b,o=Sh(C(f*C(16777216))),v[n+68>>2]=o;a=-1;break e}d=Sh(C(h*C(16777216)));v[b+60>>2]=d;n=b,o=Sh(C(g*C(16777216))),v[n+64>>2]=o;n=b,o=Sh(C(f*C(16777216))),v[n+68>>2]=o;a=0;if(d){break e}v[b+60>>2]=1}v[b+72>>2]=a;if(!c){break b}v[b+44>>2]=0;v[b+48>>2]=0;v[b+52>>2]=0;v[b+56>>2]=0}jb=e+16|0;return m}function X_(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a=jb-464|0;jb=a;v[a+16>>2]=f;v[a+20>>2]=g;v[a+24>>2]=h;v[a+28>>2]=i;j=a+352|0;v[a+348>>2]=j;j=Gw(j,100,11090,a+16|0);v[a+48>>2]=1123;k=a+48|0;o=se(a+232|0,0,k);v[a+48>>2]=1123;k=se(a+224|0,0,k);a:{b:{c:{d:{if(j>>>0<100){h=a+240|0;f=a+352|0;break d}j=Gd();v[a>>2]=f;v[a+4>>2]=g;v[a+8>>2]=h;v[a+12>>2]=i;j=Zi(a+348|0,j,11090,a);if((j|0)!=-1){f=v[a+348>>2];Ze(o,f);Ze(k,Od(j));h=v[k>>2];if(!ik(h)){break d}}v[23588]=0;Z(1124);a=v[23588];v[23588]=0;if((a|0)!=1){break a}j=P()|0;O()|0;break c}g=a+216|0;fd(g,d);v[23588]=0;q=S(19,g|0)|0;g=v[23588];v[23588]=0;e:{f:{g:{h:{i:{j:{if((g|0)==1){break j}v[23588]=0;X(1134,q|0,f|0,f+j|0,h|0);g=v[23588];v[23588]=0;if((g|0)==1){break j}p=(j|0)>0?w[f|0]==45:p;i=Lb(a+192|0);f=Lb(a+176|0);g=Lb(a+160|0);v[23588]=0;na(1173,c|0,p|0,a+216|0,a+208|0,a+207|0,a+206|0,i|0,f|0,g|0,a+156|0);c=v[23588];v[23588]=0;if((c|0)==1){break i}v[a+36>>2]=1123;c=se(a+40|0,0,a+36|0);m=a+48|0;n=v[a+156>>2];k:{if((n|0)<(j|0)){l=((Gb(g)+(j-n<<1)|0)+Gb(f)|0)+1|0;break k}l=(Gb(g)+Gb(f)|0)+2|0}l=l+n|0;if(l>>>0<101){break h}Ze(c,Od(l));m=v[c>>2];if(m){break h}v[23588]=0;Z(1124);b=v[23588];v[23588]=0;if((b|0)!=1){break a}break g}j=P()|0;O()|0;break e}j=P()|0;O()|0;break f}l=v[d+4>>2];v[23588]=0;pa(1174,m|0,a+36|0,a+32|0,l|0,h|0,h+j|0,q|0,p|0,a+208|0,t[a+207|0],t[a+206|0],i|0,f|0,g|0,n|0);h=v[23588];v[23588]=0;if((h|0)!=1){v[23588]=0;b=ka(15,b|0,m|0,v[a+36>>2],v[a+32>>2],d|0,e|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){break b}}}j=P()|0;O()|0;Wc(c)}yb(g);yb(f);yb(i)}$b(a+216|0)}Wc(k);Wc(o);T(j|0);L()}Wc(c);yb(g);yb(f);yb(i);$b(a+216|0);Wc(k);Wc(o);jb=a+464|0;return b|0}L()}function nR(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=jb-16|0;jb=l;g=v[b>>2];i=v[b+4>>2];a:{if((i|0)==(f|0)){b=gc(l+8|0,e,f);j=jb-16|0;jb=j;e=tl(c,d,g,f);v[j+12>>2]=e;b:{if((e|0)<=0){e=v[b>>2];break b}c:{if(!f){f=v[b>>2];break c}h=32-f|0;v[j+8>>2]=h;c=v[sd(j+8|0,j+12|0)>>2];v[j+12>>2]=e-c;d=v[b>>2];e=-1<<f&-1>>>h-c;v[d>>2]=v[d>>2]&(e^-1)|e&v[g>>2];c=c+v[b+4>>2]|0;v[b+4>>2]=c&31;f=d+(c>>>3&536870908)|0;v[b>>2]=f;g=g+4|0;e=v[j+12>>2]}d=(e|0)/32|0;c=d<<2;gj(f,g,c);d=e-(d<<5)|0;v[j+12>>2]=d;e=c+v[b>>2]|0;v[b>>2]=e;if((d|0)<=0){break b}d=-1>>>32-d|0;v[e>>2]=v[e>>2]&(d^-1)|d&v[c+g>>2];v[b+4>>2]=v[j+12>>2]}gc(a,e,v[b+4>>2]);jb=j+16|0;break a}j=a;h=gc(l,e,f);f=jb-16|0;jb=f;e=tl(c,d,g,i);v[f+12>>2]=e;d:{if((e|0)<=0){a=v[h+4>>2];break d}e:{if(!i){a=v[h+4>>2];break e}k=32-i|0;v[f+8>>2]=k;c=f+8|0;b=v[sd(c,f+12|0)>>2];v[f+12>>2]=e-b;a=v[h+4>>2];e=v[g>>2];v[f+8>>2]=b;m=32-a|0;v[f+4>>2]=m;d=v[h>>2];n=v[d>>2];c=v[Jb(c,f+4|0)>>2];e=e&(-1<<i&-1>>>k-b);v[d>>2]=(-1<<a&-1>>>m-c^-1)&n|(a>>>0>i>>>0?e<<a-i:e>>>i-a|0);k=a+c|0;a=k&31;v[h+4>>2]=a;d=d+(k>>>3&536870908)|0;v[h>>2]=d;b=b-c|0;if((b|0)>0){v[d>>2]=v[d>>2]&(-1>>>32-b^-1)|e>>>c+i;v[h+4>>2]=b;a=b}g=g+4|0;e=v[f+12>>2]}c=32-a|0;d=-1<<a;i=d^-1;while(1){if((e|0)>=32){b=v[h>>2];e=v[g>>2];v[b>>2]=i&v[b>>2]|e<<a;v[h>>2]=b+4;v[b+4>>2]=d&v[b+4>>2]|e>>>c;e=v[f+12>>2]-32|0;v[f+12>>2]=e;g=g+4|0;continue}break}if((e|0)<=0){break d}i=v[g>>2];v[f+8>>2]=c;g=v[h>>2];b=v[g>>2];k=b;b=v[sd(f+12|0,f+8|0)>>2];e=i&-1>>>32-e;v[g>>2]=k&(d&-1>>>c-b^-1)|e<<a;c=a+b|0;a=c&31;v[h+4>>2]=a;c=g+(c>>>3&536870908)|0;v[h>>2]=c;d=v[f+12>>2]-b|0;v[f+12>>2]=d;if((d|0)<=0){break d}v[c>>2]=v[c>>2]&(-1>>>32-d^-1)|e>>>b;a=v[f+12>>2];v[h+4>>2]=a}gc(j,v[h>>2],a);jb=f+16|0}jb=l+16|0}function rM(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=jb-16|0;jb=g;e=B(b,872)+a|0;j=e+1074992|0;a:{b:{i=v[e+1075080>>2];if(i&131072){h=a+480180|0;e=v[h>>2];i=1;c:{d:{e:{f=v[a+480208>>2];if(f&4096){if(!(e&16777248)){break e}i=!(f&4)}if((e|0)!=64){break d}break b}if((e|0)==64){break b}h=a+480180|0;i=0;break c}if(!i){break c}Cb(g+8|0,a+1074312|0,21);if(!Bb(v[v[g+8>>2]>>2],v[g+12>>2])){break c}e=B(b,872)+a|0;f=e+1075811|0;t[f|0]=w[f|0]+(w[e+1075815|0]<<2)}f=B(b,872)+a|0;k=f+1075814|0;l=f+1075811|0;e=oy(a,w[k|0],w[l|0]);f:{if(vj(v[j+656>>2])){z[d>>2]=z[d>>2]+C(C(C(B(w[f+1075816|0],e)|0)*C(.05000000074505806))/C(7680));c=f+1075843|0;d=w[c|0];t[c|0]=d&159|64;if(v[a+1074416>>2]!=(v[a+1074392>>2]+1|0)){break f}t[c|0]=d|96;break f}d=v[a+480208>>2];if((d&2101248)==2101248){break a}f=v[h>>2];if(d&4096?f&67633152:0){break a}e=f&5?(w[k|0]&3)==1?0-e|0:e:e;k=a+1074312|0;Cb(g+8|0,k,21);f=v[a+480208>>2];g:{if(Bb(v[v[g+8>>2]>>2],v[g+12>>2])){d=f&4;e=d?e:0-e|0;d=d?5:6;break g}d=5;h:{if(f&131072){break h}h=v[h>>2];d=8;if((h|0)==1024){break h}d=7;if(h&524304){break h}d=h&16777248?f&4?6:7:6}Cb(g+8|0,k,80);if(!Bb(v[v[g+8>>2]>>2],v[g+12>>2])){break g}d=w[(B(b,872)+a|0)+1075783|0]==26?d+2|0:d}d=(0-B(w[(B(b,872)+a|0)+1075816|0],e)|0)/(1<<d)|0;fk(a,j,c,d,0);e=v[j+656>>2];c=Op(a,v[j+88>>2],e);if(!c){break f}nb[v[v[c>>2]+92>>2]](c,d,(e?t[e+33|0]:2)<<24>>24,b)}if(!i){break a}Cb(g+8|0,a+1074312|0,21);if(Bb(v[v[g+8>>2]>>2],v[g+12>>2])){break a}t[l|0]=w[l|0]+w[(B(b,872)+a|0)+1075815|0];break a}if(!(w[e+1075662|0]&2)){break a}a=Op(a,i,v[j+656>>2]);if(!a){break a}nb[v[v[a>>2]+92>>2]](a,0,0,b);break a}a=B(b,872)+a|0;b=a+1075811|0;d=w[b|0];if(d&1){v[c>>2]=v[c>>2]+B(w[a+1075816|0],167)}t[b|0]=d+1}jb=g+16|0}function tZ(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;r=jb-16|0;jb=r;j=c;while(1){a:{if((d|0)==(j|0)){j=d;break a}if(!w[j|0]){break a}j=j+1|0;continue}break}v[h>>2]=f;v[e>>2]=c;while(1){b:{c:{d:{if((c|0)==(d|0)|(f|0)==(g|0)){break d}i=v[b+4>>2];v[r+8>>2]=v[b>>2];v[r+12>>2]=i;s=jb-16|0;jb=s;u=ji(s+8|0,v[a+8>>2]);m=j-c|0;k=0;o=0;n=jb-1040|0;jb=n;i=v[e>>2];v[n+12>>2]=i;p=f?f:n+16|0;l=f?g-f>>2:256;e:{f:{if(!(!i|!l)){while(1){g:{q=m>>>2|0;if(q>>>0<l>>>0&m>>>0<=131){break f}q=IG(p,n+12|0,l>>>0>q>>>0?q:l,b);if((q|0)==-1){k=-1;l=0;i=v[n+12>>2];break g}t=(n+16|0)==(p|0)?0:q;l=l-t|0;p=(t<<2)+p|0;m=i+m|0;i=v[n+12>>2];m=i?m-i|0:0;k=k+q|0;if(!i){break g}if(l){continue}}break}}if(!i){break e}}if(!(!l|!m)){o=i;i=k;while(1){h:{k=Wr(p,o,m,b);i:{if(k+2>>>0<=2){j:{switch(k+1|0){case 1:o=0;break i;case 0:break e;default:break j}}v[b>>2]=0;break i}i=i+1|0;o=k+o|0;l=l-1|0;if(l){break h}}k=i;break e}p=p+4|0;m=m-k|0;k=i;if(m){continue}break}break e}o=i}if(f){v[e>>2]=o}jb=n+1040|0;ii(u);jb=s+16|0;k:{l:{m:{n:{if((k|0)==-1){while(1){o:{v[h>>2]=f;if(v[e>>2]==(c|0)){break o}g=1;p:{q:{r:{b=EF(f,c,j-c|0,r+8|0,v[a+8>>2]);switch(b+2|0){case 0:break l;case 2:break p;case 1:break r;default:break q}}v[e>>2]=c;break n}g=b}c=c+g|0;f=v[h>>2]+4|0;continue}break}v[e>>2]=c;break d}f=v[h>>2]+(k<<2)|0;v[h>>2]=f;if((f|0)==(g|0)){break k}c=v[e>>2];if((d|0)==(j|0)){j=d;continue}if(!EF(f,c,1,b,v[a+8>>2])){break m}}a=2;break c}v[h>>2]=v[h>>2]+4;c=v[e>>2]+1|0;v[e>>2]=c;j=c;while(1){if((d|0)==(j|0)){j=d;break b}if(!w[j|0]){break b}j=j+1|0;continue}}v[e>>2]=c;a=1;break c}c=v[e>>2]}a=(c|0)!=(d|0)}jb=r+16|0;return a|0}f=v[h>>2];continue}}function Tr(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;i=jb-128|0;jb=i;v[i+120>>2]=b;k=FG(c,d);v[i+4>>2]=1123;m=EG(i+8|0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=Od(k);if(!j){v[23588]=0;Z(1124);a=v[23588];v[23588]=0;if((a|0)!=1){break a}b=P()|0;O()|0;break b}Ze(m,j)}h=j;b=c;while(1){if((b|0)==(d|0)){c:{d:{e:while(1){f:{v[23588]=0;h=Q(1125,a|0,i+120|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break f}if(!(h&(k|0)!=0)){v[23588]=0;b=Q(1126,a|0,i+120|0)|0;a=v[23588];v[23588]=0;if((a|0)==1){break c}if(!b){break d}v[f>>2]=v[f>>2]|2;break d}b=v[a>>2];v[23588]=0;n=S(1127,b|0)|0;b=v[23588];v[23588]=0;g:{if((b|0)!=1){if(g){break g}v[23588]=0;n=Q(1128,e|0,n|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break g}}b=P()|0;O()|0;break b}q=o+1|0;r=0;h=j;b=c;while(1){if((b|0)==(d|0)){o=q;if(!r){continue e}v[23588]=0;S(1129,a|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){h=j;b=c;if(k+l>>>0<2){continue e}while(1){if((b|0)==(d|0)){continue e}h:{if(w[h|0]!=2){break h}if((Gb(b)|0)==(o|0)){break h}t[h|0]=0;l=l-1|0}h=h+1|0;b=b+12|0;continue}}b=P()|0;O()|0;break b}i:{if(w[h|0]!=1){break i}p=t[gg(b,o)|0];j:{if(g){break j}v[23588]=0;p=Q(1128,e|0,p<<24>>24)|0;s=v[23588];v[23588]=0;if((s|0)!=1){break j}b=P()|0;O()|0;break b}k:{if((n&255)==(p&255)){r=1;if((Gb(b)|0)!=(q|0)){break i}t[h|0]=2;l=l+1|0;break k}t[h|0]=0}k=k-1|0}h=h+1|0;b=b+12|0;continue}}break}b=P()|0;O()|0;break b}l:{m:{while(1){if((c|0)==(d|0)){break m}if(w[j|0]!=2){j=j+1|0;c=c+12|0;continue}break}d=c;break l}v[f>>2]=v[f>>2]|4}Wc(m);jb=i+128|0;return d|0}b=P()|0;O()|0}else{n:{if(!Qe(b)){t[h|0]=1;break n}t[h|0]=2;l=l+1|0;k=k-1|0}h=h+1|0;b=b+12|0;continue}break}}Wc(m);T(b|0)}L()}function ui(a,b,c,d,e){var f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;q=c*d;r=b*e;m=q+r;s=b*d;t=c*e;p=s-t;a:{if(!Ai(p)){break a}if(!Ai(m)){break a}h=mf(b);f=mf(c);k=h|f;if((k|0)==1){o(+(f?1:0));f=j(1)|0;i=j(0)|0;o(+c);g=j(1)|0;j(0)|0;l(0,i|0);l(1,f&2147483647|g&-2147483648);c=+n();o(0);f=j(1)|0;i=j(0)|0;o(+d);g=j(1)|0;j(0)|0;l(0,i|0);l(1,f&2147483647|g&-2147483648);d=(u=+n(),v=d,w=Ai(d),w?u:v);o(0);f=j(1)|0;i=j(0)|0;o(+e);g=j(1)|0;j(0)|0;l(0,i|0);l(1,f&2147483647|g&-2147483648);e=(u=+n(),v=e,w=Ai(e),w?u:v);o(+(h?1:0));h=j(1)|0;g=j(0)|0;o(+b);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);b=+n()}h=mf(d);f=mf(e);b:{if(f?1:h){o(+(f?1:0));f=j(1)|0;g=j(0)|0;o(+e);k=j(1)|0;j(0)|0;l(0,g|0);l(1,f&2147483647|k&-2147483648);e=+n();o(+(h?1:0));h=j(1)|0;g=j(0)|0;o(+d);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);d=+n();o(0);h=j(1)|0;g=j(0)|0;o(+b);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);b=(u=+n(),v=b,w=Ai(b),w?u:v);o(0);h=j(1)|0;g=j(0)|0;o(+c);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);c=(u=+n(),v=c,w=Ai(c),w?u:v);break b}if(k){break b}c:{if(mf(s)){break c}if(mf(t)){break c}if(mf(r)){break c}if(!mf(q)){break a}}o(0);h=j(1)|0;g=j(0)|0;o(+b);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);b=(u=+n(),v=b,w=Ai(b),w?u:v);o(0);h=j(1)|0;g=j(0)|0;o(+c);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);c=(u=+n(),v=c,w=Ai(c),w?u:v);o(0);h=j(1)|0;g=j(0)|0;o(+d);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);d=(u=+n(),v=d,w=Ai(d),w?u:v);o(0);h=j(1)|0;g=j(0)|0;o(+e);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);e=(u=+n(),v=e,w=Ai(e),w?u:v)}m=(b*e+d*c)*N;p=(b*d-e*c)*N}nl(a,p,m)}function haa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;c=jb-224|0;jb=c;e=Zl(c+112|0,a);v[23588]=0;d=Q(449,c+96|0,43806)|0;a=v[23588];v[23588]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((a|0)!=1){v[23588]=0;v[c+80>>2]=19988498;v[c+84>>2]=0;U(450,e|0,d|0,c+80|0);a=v[23588];v[23588]=0;if((a|0)==1){break n}_b(d);if(Kk(w[e|0])){break e}v[23588]=0;d=Q(449,c+80|0,13250)|0;a=v[23588];v[23588]=0;if((a|0)==1){break m}v[23588]=0;X(481,e|0,b|0,d|0,871);a=v[23588];v[23588]=0;if((a|0)==1){break l}_b(d);v[c+76>>2]=0;v[c+72>>2]=0;v[23588]=0;d=Q(449,c+56|0,16715)|0;a=v[23588];v[23588]=0;if((a|0)==1){break k}v[23588]=0;U(872,e|0,c+76|0,d|0);a=v[23588];v[23588]=0;if((a|0)==1){break j}_b(d);v[23588]=0;d=Q(449,c+40|0,16687)|0;a=v[23588];v[23588]=0;if((a|0)==1){break i}v[23588]=0;U(872,e|0,c+72|0,d|0);a=v[23588];v[23588]=0;if((a|0)==1){break h}_b(d);a=v[c+76>>2];d=v[c+72>>2];o:{if(!a|d>>>0<a>>>0){break o}f=v[v[v[v[b+48>>2]+12>>2]+8>>2]+40>>2];if(f>>>0<a>>>0|d>>>0>f>>>0){break o}v[b+20>>2]=d;v[b+16>>2]=a}d=Sb(c+24|0);v[23588]=0;f=Q(449,c+8|0,14076)|0;a=v[23588];v[23588]=0;if((a|0)==1){break d}v[23588]=0;U(873,e|0,d|0,f|0);a=v[23588];v[23588]=0;if((a|0)==1){break g}_b(f);if(oc(v[d>>2],v[d+4>>2])){break f}a=v[b+16>>2];v[23588]=0;R(826,d|0,a|0);a=v[23588];v[23588]=0;if((a|0)!=1){break f}break c}a=P()|0;O()|0;break a}a=P()|0;O()|0;_b(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;_b(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;_b(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;_b(d);break a}a=P()|0;O()|0;_b(f);break b}v[23588]=0;R(874,b|0,d|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}vc(d)}kh(e);jb=c+224|0;return}a=P()|0;O()|0;break b}a=P()|0;O()|0}vc(d)}kh(e);T(a|0);L()}function Rr(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;i=jb-128|0;jb=i;v[i+120>>2]=b;k=FG(c,d);v[i+4>>2]=1123;m=EG(i+8|0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=Od(k);if(!j){v[23588]=0;Z(1124);a=v[23588];v[23588]=0;if((a|0)!=1){break a}b=P()|0;O()|0;break b}Ze(m,j)}h=j;b=c;while(1){if((b|0)==(d|0)){c:{d:{e:while(1){f:{v[23588]=0;h=Q(1141,a|0,i+120|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break f}if(!(h&(k|0)!=0)){v[23588]=0;b=Q(1142,a|0,i+120|0)|0;a=v[23588];v[23588]=0;if((a|0)==1){break c}if(!b){break d}v[f>>2]=v[f>>2]|2;break d}b=v[a>>2];v[23588]=0;n=S(1143,b|0)|0;b=v[23588];v[23588]=0;g:{if((b|0)!=1){if(g){break g}v[23588]=0;n=Q(1144,e|0,n|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break g}}b=P()|0;O()|0;break b}q=o+1|0;r=0;h=j;b=c;while(1){if((b|0)==(d|0)){o=q;if(!r){continue e}v[23588]=0;S(1145,a|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){h=j;b=c;if(k+l>>>0<2){continue e}while(1){if((b|0)==(d|0)){continue e}h:{if(w[h|0]!=2){break h}if((Gb(b)|0)==(o|0)){break h}t[h|0]=0;l=l-1|0}h=h+1|0;b=b+12|0;continue}}b=P()|0;O()|0;break b}i:{if(w[h|0]!=1){break i}p=v[zi(b,o)>>2];j:{if(g){break j}v[23588]=0;p=Q(1144,e|0,p|0)|0;s=v[23588];v[23588]=0;if((s|0)!=1){break j}b=P()|0;O()|0;break b}k:{if((n|0)==(p|0)){r=1;if((Gb(b)|0)!=(q|0)){break i}t[h|0]=2;l=l+1|0;break k}t[h|0]=0}k=k-1|0}h=h+1|0;b=b+12|0;continue}}break}b=P()|0;O()|0;break b}l:{m:{while(1){if((c|0)==(d|0)){break m}if(w[j|0]!=2){j=j+1|0;c=c+12|0;continue}break}d=c;break l}v[f>>2]=v[f>>2]|4}Wc(m);jb=i+128|0;return d|0}b=P()|0;O()|0}else{n:{if(!Qe(b)){t[h|0]=1;break n}t[h|0]=2;l=l+1|0;k=k-1|0}h=h+1|0;b=b+12|0;continue}break}}Wc(m);T(b|0)}L()}function Ica(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0;g=jb-48|0;jb=g;o=v[a+16>>2];while(1){if((f|0)!=2){e=f<<3;j=e+(g+24|0)|0;e=a+e|0;v[j+4>>2]=v[e+44>>2];v[j+8>>2]=v[e+48>>2];f=f+1|0;continue}break}j=v[a+24>>2];p=v[a+20>>2];f=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=f;q=b+24|0;r=v[a+72>>2];b=v[a+68>>2];s=b;t=b>>31;b=v[a+64>>2];w=b;x=b>>31;b=v[a+60>>2];y=b;z=b>>31;A=v[a+8>>2];C=v[a+12>>2];while(1){if(d){f=v[g+16>>2];k=((((v[g+20>>2]&2147483647)<<1|f>>>31)&2147483646)<<1)+o|0;b=(((f>>>16|0)+4&131064)<<1)+q|0;i=u[b+14>>1];h=u[b+12>>1];l=u[b+10>>1];m=u[b+8>>1];n=u[b+6>>1];D=u[b+4>>1];E=u[b+2>>1];F=u[b>>1];f=0;e=0;while(1){if((e|0)!=2){b=k+(e<<1)|0;v[(g+8|0)+(e<<2)>>2]=(((((B(u[b+8>>1],l)+B(u[b+4>>1],m)|0)+B(h,u[b+12>>1])|0)+B(i,u[b+16>>1])|0)/2|0)+((((B(u[b-8>>1],E)+B(u[b-12>>1],F)|0)+B(u[b-4>>1],D)|0)+B(u[b>>1],n)|0)/2|0)|0)/16384;e=e+1|0;continue}break}while(1){if((f|0)!=2){k=(g+8|0)+(f<<2)|0;e=v[k>>2];b=(g+24|0)+(f<<3)|0;i=v[b+8>>2];h=v[b+4>>2];v[b+8>>2]=h;l=e<<8;e=l;e=Lka(y,z,e,e>>31);m=mb;n=b;b=Xb(h,-16777216,16776704);h=Lka(w,x,b,b>>31);e=h+e|0;b=mb+m|0;b=e>>>0<h>>>0?b+1|0:b;h=e;e=Xb(i,-16777216,16776704);i=Lka(s,t,e,e>>31);e=h+i|0;b=mb+b|0;b=e>>>0<i>>>0?b+1|0:b;e=e+8388608|0;b=e>>>0<8388608?b+1|0:b;b=Xc(e,b,24);v[n+4>>2]=b-(l&r);v[k>>2]=(b|0)/256;f=f+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[g+8>>2],p);v[c+4>>2]=v[c+4>>2]+B(j,v[g+12>>2]);Qb(g+16|0,A,C);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;f=0;while(1){if((f|0)!=2){b=f<<3;c=b+a|0;b=b+(g+24|0)|0;v[c+44>>2]=v[b+4>>2];v[c+48>>2]=v[b+8>>2];f=f+1|0;continue}break}jb=g+48|0}function SW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=jb+-64|0;jb=e;yc(b);Wo(a);a:{if(!ci(b,e+56|0)){break a}if(!tD(e+56|0)){break a}if(!c){l=1;break a}if(!Pb(v[b>>2],v[b+8>>2],4)){break a}Mv(a);p=e,q=Lv(),v[p+32>>2]=q;c=e+32|0;Kv(Tj(v[a+4>>2])+32|0,c);rr(c);k=v[Tj(v[a+4>>2])+32>>2];c=Vg(v[b>>2]);if(c&1){break a}d=c-4|0;cd(b,d);h=jb-16|0;jb=h;c=h+8|0;yv(c,b);f=w[Kb(c,0)|0];i=w[Kb(c,1)|0];c=w[Kb(c,2)|0];jb=h+16|0;h=c|(i<<8|f<<16);if(!h){break a}v[23588]=0;R(175,k|0,h|0);c=v[23588];v[23588]=0;l=1;if((c|0)==1){a=V(92948)|0;if((O()|0)==(da(92948)|0)){_(a|0)|0;$();l=0;break a}T(a|0);L()}cd(b,4);m=e+32|0;sD(m,b);i=v[k>>2];f=jb-32|0;jb=f;b=v[e+32>>2];t[f+24|0]=w[b|0];t[f+25|0]=w[b+1|0];t[f+26|0]=w[b+2|0];t[f+27|0]=w[b+3|0];c=hr(f+8|0);d=b+d|0;v[c+12>>2]=d-4;v[c+8>>2]=b;Rj(c,w[d-1|0]);b=h;b:while(1){c:{d:{e:{if(!b){break e}if(Rj(c,1)){break d}d=1;while(1){g=Rj(c,2);d=g+d|0;if((g|0)==3){continue}break}v[f+4>>2]=d;wc(f+4|0,b);d=0;g=v[f+4>>2];while(1)if((d|0)==(g|0)){if(!b){break e}break d}else{b=b-1|0;p=i+b|0,q=Rj(c,8),t[p|0]=q;d=d+1|0;continue}}jb=f+32|0;break c}g=Rj(c,2);d=g+2|0;v[f+4>>2]=d;f:{if((g|0)==3){if(Rj(c,1)){g=w[Kb(f+24|0,3)|0]}else{g=7}g=Rj(c,g);while(1){j=Rj(c,3);d=j+d|0;if((j|0)==7){continue}break}v[f+4>>2]=d;break f}g=Rj(c,w[Kb(f+24|0,g)|0])}wc(f+4|0,b);d=0;o=v[f+4>>2];while(1){if((d|0)==(o|0)){continue b}j=0;n=b+g|0;if(h>>>0>n>>>0){j=w[i+n|0]}b=b-1|0;t[i+b|0]=j;d=d+1|0;continue}}break}re(e+16|0,v[k>>2],v[k+4>>2]);_g(e+24|0,v[e+16>>2],v[e+20>>2]);b=ee(e+8|0);c=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=c;b=pr(m,v[e+24>>2],v[e+28>>2],e);gd(Tj(v[a+4>>2])+12|0,b);Ab(b)}jb=e- -64|0;return l|0}function Vba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0;h=jb-48|0;jb=h;f=NO(h+32|0,1<<v[b+12>>2]);g=v[f>>2];while(1){c=v[a>>2];if(Ug(c,v[a+4>>2])>>>0>d>>>0){c=af(c,d);MO(Jd(g,d),A[c>>3]);d=d+1|0;continue}break}LO(b,f);x=h,y=Eb(v[f>>2]),v[x+8>>2]=y;w=Eb(v[f+4>>2]);while(1){g=v[h+8>>2];if(Ob(g,w)){m=A[g+8>>3];k=jb-32|0;jb=k;o(+A[g>>3]);e=j(1)|0;r=j(0)|0;o(+m);c=j(1)|0;s=j(0)|0;q=e&2147483647;t=c&2147483647;d=t;c=(q|0)==(d|0)&r>>>0<s>>>0|d>>>0>q>>>0;e=c?r:s;c=c?q:d;d=c;l(0,e|0);l(1,c|0);p=+n();u=c>>>20|0;i=p;a:{if((u|0)==2047){break a}c=(q|0)==(t|0)&r>>>0>s>>>0|q>>>0>t>>>0;l(0,(c?r:s)|0);c=c?q:t;l(1,c|0);m=+n();b:{if(!(d|e)){break b}c=c>>>20|0;if((c|0)==2047){break b}i=m+p;if((c-u|0)>=65){break a}c:{if(c>>>0>=1534){p=p*190109156629516e-225;m=m*190109156629516e-225;i=5.260135901548374e210;break c}i=1;if(u>>>0>572){break c}p=p*5.260135901548374e210;m=m*5.260135901548374e210;i=190109156629516e-225}ZH(k+24|0,k+16|0,m);ZH(k+8|0,k,p);i=i*K(A[k>>3]+A[k+16>>3]+A[k+8>>3]+A[k+24>>3]);break a}i=m}p=i;jb=k+32|0;MO(g,zp(p));eq(h+8|0);continue}break}KO(b,f);JO(f);e=v[f>>2];g=lk(e,v[f+4>>2])>>>1|0;c=g>>>0>1?g:1;d=1;while(1){if((c|0)!=(d|0)){nz(Jd(e,d),2);nz(Jd(e,d+g|0),0);d=d+1|0;continue}break}LO(b,f);x=h,y=Eb(v[f>>2]),v[x+24>>2]=y;g=Eb(v[f+4>>2]);while(1){e=v[h+24>>2];if(Ob(e,g)){IO(h+8|0,A[e>>3],A[e+8>>3]);c=v[h+20>>2];v[e+8>>2]=v[h+16>>2];v[e+12>>2]=c;c=v[h+12>>2];v[e>>2]=v[h+8>>2];v[e+4>>2]=c;eq(h+24|0);continue}break}KO(b,f);JO(f);g=v[a>>2];c=Ug(g,v[a+4>>2]);b=v[f>>2];d=0;while(1){if((c|0)==(d|0)){Bm(f);jb=h+48|0}else{a=Jd(b,d);x=af(g,d),z=A[a>>3],A[x>>3]=z;d=d+1|0;continue}break}}function Jca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;g=jb-48|0;jb=g;o=v[a+16>>2];while(1){if((f|0)!=2){e=f<<3;j=e+(g+24|0)|0;e=a+e|0;v[j+4>>2]=v[e+44>>2];v[j+8>>2]=v[e+48>>2];f=f+1|0;continue}break}j=v[a+24>>2];p=v[a+20>>2];f=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=f;q=b+24|0;r=v[a+72>>2];b=v[a+68>>2];s=b;w=b>>31;b=v[a+64>>2];x=b;y=b>>31;b=v[a+60>>2];z=b;A=b>>31;C=v[a+8>>2];D=v[a+12>>2];while(1){if(d){f=v[g+16>>2];k=(((v[g+20>>2]&2147483647)<<1|f>>>31)&-2)+o|0;b=(((f>>>16|0)+4&131064)<<1)+q|0;i=u[b+14>>1];h=u[b+12>>1];l=u[b+10>>1];m=u[b+8>>1];n=u[b+6>>1];E=u[b+4>>1];F=u[b+2>>1];G=u[b>>1];f=0;e=0;while(1){if((e|0)!=2){b=e+k|0;v[(g+8|0)+(e<<2)>>2]=(((((B(t[b+4|0],l)+B(t[b+2|0],m)|0)+B(h,t[b+6|0])|0)+B(i,t[b+8|0])<<8)/2|0)+((((B(t[b-4|0],F)+B(t[b-6|0],G)|0)+B(t[b-2|0],E)|0)+B(t[b|0],n)<<8)/2|0)|0)/16384;e=e+1|0;continue}break}while(1){if((f|0)!=2){k=(g+8|0)+(f<<2)|0;e=v[k>>2];b=(g+24|0)+(f<<3)|0;i=v[b+8>>2];h=v[b+4>>2];v[b+8>>2]=h;l=e<<8;e=l;e=Lka(z,A,e,e>>31);m=mb;n=b;b=Xb(h,-16777216,16776704);h=Lka(x,y,b,b>>31);e=h+e|0;b=mb+m|0;b=e>>>0<h>>>0?b+1|0:b;h=e;e=Xb(i,-16777216,16776704);i=Lka(s,w,e,e>>31);e=h+i|0;b=mb+b|0;b=e>>>0<i>>>0?b+1|0:b;e=e+8388608|0;b=e>>>0<8388608?b+1|0:b;b=Xc(e,b,24);v[n+4>>2]=b-(l&r);v[k>>2]=(b|0)/256;f=f+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[g+8>>2],p);v[c+4>>2]=v[c+4>>2]+B(j,v[g+12>>2]);Qb(g+16|0,C,D);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;f=0;while(1){if((f|0)!=2){b=f<<3;c=b+a|0;b=b+(g+24|0)|0;v[c+44>>2]=v[b+4>>2];v[c+48>>2]=v[b+8>>2];f=f+1|0;continue}break}jb=g+48|0}function $ha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=jb-16|0;jb=g;i=qf(a,c);me(g,v[a+36>>2]);j=a;a:{if(!i){Rc(g,a+32|0,5);c=0;if(Bb(v[v[g>>2]>>2],v[g+4>>2])){break a}}e=jb-192|0;jb=e;f=Zl(e+80|0,v[a+36>>2]);v[23588]=0;a=Q(449,e- -64|0,27807)|0;c=v[23588];v[23588]=0;b:{c:{d:{e:{if((c|0)!=1){v[23588]=0;v[e>>2]=19988498;v[e+4>>2]=0;U(450,f|0,a|0,e|0);c=v[23588];v[23588]=0;if((c|0)==1){break e}_b(a);if(!Kk(w[f|0])){break d}break b}c=P()|0;O()|0;break c}c=P()|0;O()|0;_b(a);break c}t[e+63|0]=0;t[e+62|0]=0;v[23588]=0;a=Q(449,e+48|0,10044)|0;c=v[23588];v[23588]=0;f:{g:{h:{i:{if((c|0)!=1){v[23588]=0;U(489,f|0,e+63|0,a|0);c=v[23588];v[23588]=0;if((c|0)==1){break i}_b(a);if(!w[e+63|0]){break b}vf(e+63|0,50);v[23588]=0;a=Q(449,e+32|0,13140)|0;c=v[23588];v[23588]=0;if((c|0)==1){break f}v[23588]=0;U(489,f|0,e+62|0,a|0);c=v[23588];v[23588]=0;if((c|0)==1){break g}_b(a);a=v[b>>2];c=rj(a,v[b+4>>2]);h=w[e+63|0];if(c>>>0<h>>>0){a=Bz(e,v[b+12>>2]);v[23588]=0;U(490,b|0,h|0,a|0);c=v[23588];v[23588]=0;if((c|0)==1){break h}ql(a);a=v[b>>2]}k=x[xj(a,0)+28>>1];c=0;j:{while(1){a=c&255;if(a>>>0>=h>>>0){a=w[e+62|0];n=b,o=rj(v[b>>2],v[b+4>>2])>>>0>a>>>0?a:0,t[n+16|0]=o;break b}Ue(xj(v[b>>2],a),k);l=v[b>>2];v[23588]=0;R(491,e|0,c|0);m=v[23588];v[23588]=0;if((m|0)!=1){v[23588]=0;X(492,f|0,xj(l,a)|0,e|0,d|0);a=v[23588];v[23588]=0;if((a|0)==1){break j}c=c+1|0;_b(e);continue}break}c=P()|0;O()|0;break c}c=P()|0;O()|0;_b(e);break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;_b(a);break c}c=P()|0;O()|0;ql(a);break c}c=P()|0;O()|0;_b(a);break c}c=P()|0;O()|0}kh(f);T(c|0);L()}kh(f);jb=e+192|0;c=i}Xe(j,c);jb=g+16|0}function jda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0;g=jb-48|0;jb=g;o=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;h=e+(g+24|0)|0;e=a+e|0;v[h+4>>2]=v[e+44>>2];v[h+8>>2]=v[e+48>>2];b=b+1|0;continue}break}h=v[a+40>>2];k=v[a+36>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;p=v[a+32>>2];q=v[a+28>>2];r=v[a+72>>2];b=v[a+68>>2];s=b;t=b>>31;b=v[a+64>>2];w=b;x=b>>31;b=v[a+60>>2];y=b;z=b>>31;A=v[a+8>>2];C=v[a+12>>2];while(1){if(d){e=v[g+16>>2];m=((((v[g+20>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+o|0;b=e>>>21&2040;j=u[b+39718>>1];i=u[b+39716>>1];n=u[b+39714>>1];l=u[b+39712>>1];b=0;e=0;while(1){if((e|0)!=2){f=m+(e<<1)|0;v[(g+8|0)+(e<<2)>>2]=(((B(u[f>>1],n)+B(u[f-4>>1],l)|0)+B(i,u[f+4>>1])|0)+B(j,u[f+8>>1])|0)/16384;e=e+1|0;continue}break}while(1){if((b|0)!=2){m=(g+8|0)+(b<<2)|0;f=v[m>>2];e=(g+24|0)+(b<<3)|0;j=v[e+8>>2];i=v[e+4>>2];v[e+8>>2]=i;n=f<<8;f=n;f=Lka(y,z,f,f>>31);l=mb;D=e;e=Xb(i,-16777216,16776704);i=Lka(w,x,e,e>>31);f=i+f|0;e=mb+l|0;e=f>>>0<i>>>0?e+1|0:e;l=f;f=Xb(j,-16777216,16776704);j=Lka(s,t,f,f>>31);f=l+j|0;e=mb+e|0;e=f>>>0<j>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Xc(f,e,24);v[D+4>>2]=e-(n&r);v[m>>2]=(e|0)/256;b=b+1|0;continue}break}k=k+q|0;v[c>>2]=v[c>>2]+B(v[g+8>>2],k>>12);h=h+p|0;v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],h>>12);Qb(g+16|0,A,C);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;v[a+40>>2]=h;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+24>>2]=h>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}jb=g+48|0}function gN(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;c=jb-16|0;jb=c;d=a+1074376|0;e=B(b,872);a:{if(v[(d+e|0)+704>>2]&134218752){break a}h=v[(a+e|0)+1075648>>2];if(!pj(h)|w[h+15|0]&2){break a}d=Ol(a,d,b,2,1)-1|0;if((d&255)>>>0>249){break a}g=v[Ld(a+906300|0,d)>>2];if(!g){break a}f=B(b,872)+a|0;j=f+1075780|0;d=w[j|0];b:{if(w[f+1075782|0]==1){t[c+8|0]=64;e=w[Wb(f+1075784|0,c+8|0)|0];break b}e=255;if(w[f+1075783|0]!=13){break b}t[c+8|0]=64;e=w[Wb((B(b,872)+a|0)+1075785|0,c+8|0)|0]}i=a+1074312|0;Cb(c+8|0,i,2);if(Bb(v[v[c+8>>2]>>2],v[c+12>>2])){if(d){if(_c(d)){d=w[Kb(h+108|0,d-1|0)|0]}sm(a,b,d,x[(B(b,872)+a|0)+1075680>>1]);break a}if((e|0)==255){break a}nb[v[v[g>>2]+76>>2]](g,39,e,b);break a}k=v[h+4>>2];c:{if(!d){break c}f=w[h+35|0]?k<<2:v[(B(b,872)+a|0)+1075680>>2];l=u[(B(b,872)+a|0)+1075768>>1];Cb(c+8|0,i,28);m=c,n=f+(Bb(v[v[c+8>>2]>>2],v[c+12>>2])?l<<2:l)|0,v[m+4>>2]=n;oe(c+4|0,0,256);f=d;if(_c(d)){f=w[Kb(h+108|0,d-1|0)|0]}Cb(c+8|0,i,117);if(!Bb(v[v[c+8>>2]>>2],v[c+12>>2])){if(vm(w[j+2|0],w[j+3|0])){break c}}sm(a,b,f&255,x[c+4>>1])}f=w[h+35|0];Cb(c+8|0,i,101);if(Bb(v[v[c+8>>2]>>2],v[c+12>>2])){a=(d|0)!=0}else{a=_c(d)}if(a^1|(f|0)!=1?(a|(e|0)==255)==1:0){break a}d:{switch(w[h+36|0]){case 1:if((e|0)!=255){et(v[g+20>>2],C(C(C(e<<1)/C(-127))+C(1)));break a}et(v[g+20>>2],C(C(C(k<<1>>>0)/C(-127))+C(1)));break a;case 0:break d;default:break a}}if((e|0)!=255){t[c+8|0]=127;t[c+4|0]=e<<1;n=g,o=7,p=w[Wb(c+8|0,c+4|0)|0],q=b,m=v[v[g>>2]+76>>2],nb[m](n|0,o|0,p|0,q|0);break a}v[c+8>>2]=127;v[c+4>>2]=k<<1;q=g,p=7,o=w[Jb(c+8|0,c+4|0)|0],n=b,m=v[v[g>>2]+76>>2],nb[m](q|0,p|0,o|0,n|0)}jb=c+16|0}function kda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0;g=jb-48|0;jb=g;o=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;h=e+(g+24|0)|0;e=a+e|0;v[h+4>>2]=v[e+44>>2];v[h+8>>2]=v[e+48>>2];b=b+1|0;continue}break}h=v[a+40>>2];k=v[a+36>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;p=v[a+32>>2];q=v[a+28>>2];r=v[a+72>>2];b=v[a+68>>2];s=b;w=b>>31;b=v[a+64>>2];x=b;y=b>>31;b=v[a+60>>2];z=b;A=b>>31;C=v[a+8>>2];D=v[a+12>>2];while(1){if(d){e=v[g+16>>2];m=(((v[g+20>>2]&2147483647)<<1|e>>>31)&-2)+o|0;b=e>>>21&2040;j=u[b+39718>>1];i=u[b+39716>>1];n=u[b+39714>>1];l=u[b+39712>>1];b=0;e=0;while(1){if((e|0)!=2){f=e+m|0;v[(g+8|0)+(e<<2)>>2]=(((B(t[f|0],n)+B(t[f-2|0],l)|0)+B(i,t[f+2|0])|0)+B(j,t[f+4|0])<<8)/16384;e=e+1|0;continue}break}while(1){if((b|0)!=2){m=(g+8|0)+(b<<2)|0;f=v[m>>2];e=(g+24|0)+(b<<3)|0;j=v[e+8>>2];i=v[e+4>>2];v[e+8>>2]=i;n=f<<8;f=n;f=Lka(z,A,f,f>>31);l=mb;E=e;e=Xb(i,-16777216,16776704);i=Lka(x,y,e,e>>31);f=i+f|0;e=mb+l|0;e=f>>>0<i>>>0?e+1|0:e;l=f;f=Xb(j,-16777216,16776704);j=Lka(s,w,f,f>>31);f=l+j|0;e=mb+e|0;e=f>>>0<j>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Xc(f,e,24);v[E+4>>2]=e-(n&r);v[m>>2]=(e|0)/256;b=b+1|0;continue}break}k=k+q|0;v[c>>2]=v[c>>2]+B(v[g+8>>2],k>>12);h=h+p|0;v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],h>>12);Qb(g+16|0,C,D);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;v[a+40>>2]=h;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+24>>2]=h>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}jb=g+48|0}function sea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=jb-48|0;jb=h;k=c+484344|0;wg(k,w[b+70|0]|w[b+71|0]<<8);a:{b:{while(1){if((w[b+70|0]|w[b+71|0]<<8)>>>0<=j>>>0){break b}f=v[a+8>>2];e=Bg(a);Zb(a,1);c:{if((w[b+58|0]|w[b+59|0]<<8)==258){c=Le(a)+1|0;break c}c=Rg(a)}d=Rg(a);cd(a,e+f|0);$d(h,a,d);f=jc(h+24|0,h);Ab(h);v[23588]=0;c=W(226,k|0,j&65535,(c?c>>>0<1024?c:1024:64)|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){d:{if(!(c&(d|0)!=0)){break d}c=Yb(v[k>>2],j);m=h,n=Eb(v[c>>2]),v[m>>2]=n;l=Eb(v[c+4>>2]);while(1){c=v[h>>2];if(!Ob(c,l)){break d}v[23588]=0;d=S(206,f|0)|0;e=v[23588];v[23588]=0;e:{f:{g:{if((e|0)!=1){if(!(d&128)){break g}if(d&1){v[23588]=0;e=S(206,f|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break a}t[c|0]=e}if(d&2){break f}break e}break a}t[c|0]=d;d=255}v[23588]=0;e=S(206,f|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break a}t[c+1|0]=e}i=0;e=0;if(d&4){v[23588]=0;e=S(206,f|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break a}}if(d&8){v[23588]=0;i=S(206,f|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break a}}if(d&16){v[23588]=0;d=S(206,f|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break a}t[c+5|0]=d}h:{i:{d=w[c|0];if(!d){break i}g=255;if((d|0)==97){break h}if(d>>>0>96){break i}g=d+12|0;break h}g=0}t[c|0]=g;d=w[c+5|0];j:{if((d|i)&255){Of(c,i,d);break j}t[c+3|0]=0}if(w[c+1|0]==255){t[c+1|0]=0}d=e-16|0;k:{if((d&255)>>>0<=64){t[c+4|0]=d;t[c+2|0]=1;break k}if(e>>>0<96){break k}d=e&15;t[c+4|0]=d;e=e-96>>4;t[c+2|0]=w[e+27134|0];if((e|0)!=6){break k}t[c+4|0]=d<<2}Bk(h);continue}}Ab(f);j=j+1|0;continue}break}break a}jb=h+48|0;return}a=P()|0;O()|0;Ab(f);T(a|0);L()}function JL(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{b:{d=b;e=v[b>>2];if(e){if(!v[b+4>>2]){break b}g=v[b+4>>2];c:{if(!g){while(1){g=Bh(d);d=v[d+8>>2];if(!g){continue}break}break c}d=LT(g)}e=v[d>>2];if(e){break b}}e=v[d+4>>2];if(e){break b}e=0;g=1;break a}v[e+8>>2]=v[d+8>>2];g=0}d:{e:{if(Bh(d)){c=v[d+8>>2];v[c>>2]=e;if((a|0)==(d|0)){a=e;c=0;break d}c=c+4|0;break e}c=v[d+8>>2];v[c+4>>2]=e}c=v[c>>2]}h=!w[d+12|0];if((b|0)!=(d|0)){f=v[b+8>>2];v[d+8>>2]=f;i=f+(Bh(b)?0:4)|0,j=d,v[i>>2]=j;f=v[b>>2];v[d>>2]=f;lm(f,d);f=v[b+4>>2];v[d+4>>2]=f;if(f){lm(f,d)}t[d+12|0]=w[b+12|0];a=(a|0)==(b|0)?d:a}if(!(h|!a)){if(g){while(1){b=w[c+12|0];f:{g:{if(!Bh(c)){if(!b){t[c+12|0]=1;b=v[c+8>>2];t[b+12|0]=0;rq(b);b=v[c>>2];a=(b|0)==(a|0)?c:a;c=v[b+4>>2]}b=v[c>>2];h:{if(!(w[b+12|0]?0:b)){d=v[c+4>>2];if(w[d+12|0]?0:d){break h}t[c+12|0]=0;i:{b=v[c+8>>2];if((b|0)!=(a|0)){if(w[b+12|0]){break i}a=b}t[a+12|0]=1;return}if(!Bh(b)){break g}b=v[b+8>>2]+4|0;break f}d=v[c+4>>2];if(w[d+12|0]?0:d){break h}t[b+12|0]=1;t[c+12|0]=0;qq(c);c=v[c+8>>2];d=v[c+4>>2]}a=v[c+8>>2];t[c+12|0]=w[a+12|0];t[a+12|0]=1;t[d+12|0]=1;rq(a);return}if(!b){t[c+12|0]=1;b=v[c+8>>2];t[b+12|0]=0;qq(b);b=v[c+4>>2];a=(b|0)==(a|0)?c:a;c=v[b>>2]}d=v[c>>2];j:{if(w[d+12|0]?0:d){break j}b=v[c+4>>2];if(!(w[b+12|0]?0:b)){t[c+12|0]=0;b=v[c+8>>2];if(!((a|0)!=(b|0)?w[b+12|0]:0)){t[b+12|0]=1;return}if(Bh(b)){b=v[b+8>>2]+4|0;break f}b=v[b+8>>2];break f}if(w[d+12|0]?0:d){break j}t[b+12|0]=1;t[c+12|0]=0;rq(c);c=v[c+8>>2];d=v[c>>2]}a=v[c+8>>2];t[c+12|0]=w[a+12|0];t[a+12|0]=1;t[d+12|0]=1;qq(a);return}b=v[b+8>>2]}c=v[b>>2];continue}}t[e+12|0]=1}}function c$(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=jb-624|0;jb=a;v[a+608>>2]=c;v[a+616>>2]=b;v[a+16>>2]=1158;h=se(a+200|0,a+208|0,a+16|0);b=a+192|0;fd(b,e);v[23588]=0;i=S(1136,b|0)|0;b=v[23588];v[23588]=0;a:{b:{c:{d:{e:{f:{g:{if((b|0)!=1){t[a+191|0]=0;b=v[e+4>>2];v[23588]=0;b=qa(1166,a+616|0,c|0,d|0,a+192|0,b|0,f|0,a+191|0,i|0,h|0,a+196|0,a+608|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break d}if(!b){break e}b=w[14609]|w[14610]<<8|(w[14611]<<16|w[14612]<<24);t[a+183|0]=b;t[a+184|0]=b>>>8;t[a+185|0]=b>>>16;t[a+186|0]=b>>>24;b=w[14606]|w[14607]<<8|(w[14608]<<16|w[14609]<<24);v[a+176>>2]=w[14602]|w[14603]<<8|(w[14604]<<16|w[14605]<<24);v[a+180>>2]=b;v[23588]=0;X(1148,i|0,a+176|0,a+186|0,a+128|0);b=v[23588];v[23588]=0;if((b|0)==1){break g}v[a+4>>2]=1123;d=se(a+8|0,0,a+4|0);e=a+16|0;b=v[a+196>>2];c=b-v[h>>2]|0;if((c|0)<393){break f}Ze(d,Od((c>>2)+2|0));e=v[d>>2];if(e){break f}v[23588]=0;Z(1124);b=v[23588];v[23588]=0;if((b|0)==1){break c}break a}c=P()|0;O()|0;break b}c=P()|0;O()|0;break b}if(w[a+191|0]){t[e|0]=45;e=e+1|0}c=v[h>>2];while(1){if(b>>>0<=c>>>0){t[e|0]=0;v[a>>2]=g;if((PG(a+16|0,a)|0)!=1){v[23588]=0;Y(1160,7960);b=v[23588];v[23588]=0;if((b|0)!=1){break a}break c}Wc(d)}else{b=a+128|0;j=e,k=w[(a+176|0)+(ww(b,b+40|0,v[c>>2])-b>>2)|0],t[j|0]=k;e=e+1|0;c=c+4|0;b=v[a+196>>2];continue}break}}v[23588]=0;b=Q(1142,a+616|0,a+608|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break d}if(b){v[f>>2]=v[f>>2]|2}b=v[a+616>>2];$b(a+192|0);Wc(h);jb=a+624|0;return b|0}c=P()|0;O()|0;break b}c=P()|0;O()|0;Wc(d)}$b(a+192|0);Wc(h);T(c|0);L()}L()}function at(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=jb-144|0;jb=f;a:{b:{c:{d:{e:{f:{g:{h:{if(!c){break h}h=v[c+4>>2];if(!h&y[c>>2]>=y[b+4>>2]|h){break h}a=ba(8)|0;v[23588]=0;b=Q(27,a|0,21619)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break g}b=P()|0;O()|0;ca(a|0);break a}if(!v[b>>2]){a=ba(8)|0;v[23588]=0;b=S(815,a|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break f}b=P()|0;O()|0;ca(a|0);break a}d=jb-16|0;jb=d;h=v[b+4>>2];_g(d+8|0,v[b>>2],h);g=f+120|0;PD(g,v[d+8>>2],v[d+12>>2]);v[g+12>>2]=0;jb=d+16|0;i:{j:{if(a&2){b=$m(f+96|0,g);v[23588]=0;b=S(816,b|0)|0;e=v[23588];v[23588]=0;d=1;if((e|0)==1){break i}if((b|0)==1){break j}d=$m(f+72|0,g);v[23588]=0;e=S(817,d|0)|0;i=v[23588];v[23588]=0;d=1;if((i|0)==1){break e}k=(e|0)==1;if(k){break j}d=$m(f+48|0,g);v[23588]=0;i=Q(818,d|0,c|0)|0;j=v[23588];v[23588]=0;d=1;if((j|0)==1){break d}l=(i|0)==1;if(l){break j}d=$m(f+24|0,g);v[23588]=0;j=Q(819,d|0,c|0)|0;m=v[23588];v[23588]=0;d=1;if((m|0)==1){break c}if((j|0)==1){break j}b=(b|0)==-1?-1:0;b=k?b:(e|0)==-1?-1:b;e=(j|0)==-1?-1:l?b:(i|0)==-1?-1:b}k:{if(!(a&1)){break k}b=31552;while(1){if((b|0)==32092){break k}a=v[b>>2];if(a){d=$m(f,g);v[23588]=0;a=Q(a|0,d|0,c|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break b}d=1;if((a|0)==1){break j}e=(a|0)==-1?-1:e}b=b+12|0;continue}}a=h;if(c){d=0;if((e|0)!=-1){break j}d=Dc(v[c>>2],v[c+4>>2])>>>0>a>>>0?-1:0;break j}d=0;if((e|0)!=-1){break j}d=a>>>0>2047?1:-1}jb=f+144|0;return d}b=P()|0;O()|0;break a}ha(b|0,93240,25);L()}ha(b|0,93136,25);L()}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0}T(b|0);L()}function j$(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=jb-288|0;jb=a;v[a+272>>2]=c;v[a+280>>2]=b;v[a+16>>2]=1158;h=se(a+152|0,a+160|0,a+16|0);b=a+144|0;fd(b,e);v[23588]=0;i=S(19,b|0)|0;b=v[23588];v[23588]=0;a:{b:{c:{d:{e:{f:{g:{if((b|0)!=1){t[a+143|0]=0;b=v[e+4>>2];v[23588]=0;b=qa(1159,a+280|0,c|0,d|0,a+144|0,b|0,f|0,a+143|0,i|0,h|0,a+148|0,a+260|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break d}if(!b){break e}b=w[14609]|w[14610]<<8|(w[14611]<<16|w[14612]<<24);t[a+135|0]=b;t[a+136|0]=b>>>8;t[a+137|0]=b>>>16;t[a+138|0]=b>>>24;b=w[14606]|w[14607]<<8|(w[14608]<<16|w[14609]<<24);v[a+128>>2]=w[14602]|w[14603]<<8|(w[14604]<<16|w[14605]<<24);v[a+132>>2]=b;v[23588]=0;X(1134,i|0,a+128|0,a+138|0,a+118|0);b=v[23588];v[23588]=0;if((b|0)==1){break g}v[a+4>>2]=1123;d=se(a+8|0,0,a+4|0);e=a+16|0;b=v[a+148>>2];c=b-v[h>>2]|0;if((c|0)<99){break f}Ze(d,Od(c+2|0));e=v[d>>2];if(e){break f}v[23588]=0;Z(1124);b=v[23588];v[23588]=0;if((b|0)==1){break c}break a}c=P()|0;O()|0;break b}c=P()|0;O()|0;break b}if(w[a+143|0]){t[e|0]=45;e=e+1|0}c=v[h>>2];while(1){if(b>>>0<=c>>>0){t[e|0]=0;v[a>>2]=g;if((PG(a+16|0,a)|0)!=1){v[23588]=0;Y(1160,7960);b=v[23588];v[23588]=0;if((b|0)!=1){break a}break c}Wc(d)}else{b=a+118|0;j=e,k=w[((wi(b,VT(b),c)-a|0)+a|0)+10|0],t[j|0]=k;e=e+1|0;c=c+1|0;b=v[a+148>>2];continue}break}}v[23588]=0;b=Q(1126,a+280|0,a+272|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break d}if(b){v[f>>2]=v[f>>2]|2}b=v[a+280>>2];$b(a+144|0);Wc(h);jb=a+288|0;return b|0}c=P()|0;O()|0;break b}c=P()|0;O()|0;Wc(d)}$b(a+144|0);Wc(h);T(c|0);L()}L()}function K4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=jb-48|0;jb=c;g=Sb(a);a:{b:{c:{d=b+36|0;a=v[d>>2];f=v[b+40>>2];d:{if(Ob(a,f)){Gc(c+40|0);break d}v[23588]=0;R(1028,c+24|0,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break b}v[23588]=0;a=S(1012,c+24|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break c}v[c+40>>2]=a;Wf(c+24|0);f=v[b+40>>2];a=v[b+36>>2]}if(!Ob(a,f)){d=v[c+40>>2];a=v[d>>2]}f=v[d+4>>2];v[23588]=0;R(181,g|0,Qi(a,f)|0);a=v[23588];v[23588]=0;e:{if((a|0)!=1){i=c,j=Eb(v[d>>2]),v[i+16>>2]=j;f=Eb(v[d+4>>2]);f:{g:{h:{i:{j:{k:{while(1){a=v[c+16>>2];if(!Ob(a,f)){al(c+40|0);jb=c+48|0;return}d=w[a+16|0];e=v[v[b+24>>2]+484360>>2];v[23588]=0;d=xj(e,d);R(1029,c|0,d|0);e=v[23588];v[23588]=0;if((e|0)!=1){v[23588]=0;R(1015,c+24|0,c|0);e=v[23588];v[23588]=0;if((e|0)==1){break k}v[23588]=0;R(183,g|0,c+24|0);e=v[23588];v[23588]=0;if((e|0)==1){break j}yb(c+24|0);zb(c);l:{if(!Qe(px(v[g+4>>2]))){break l}e=w[a+12|0];v[23588]=0;e=Q(311,d|0,e|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break f}if(!e){break l}e=v[b+24>>2];h=v[e+1298404>>2];a=x[cc(v[d>>2],v[a+12>>2])>>1];d=v[e+484344>>2];v[23588]=0;R(1022,c|0,Yb(d,a)|0);a=v[23588];v[23588]=0;if((a|0)==1){break h}v[23588]=0;X(235,c+24|0,0,h|0,c|0);a=v[23588];v[23588]=0;if((a|0)==1){break g}a=c+24|0;Ac(px(v[g+4>>2]),a);yb(a);yb(c)}Ux(c+16|0);continue}break}a=P()|0;O()|0;break e}a=P()|0;O()|0;break i}a=P()|0;O()|0;yb(c+24|0)}zb(c);break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;yb(c);break e}a=P()|0;O()|0;break e}a=P()|0;O()|0}al(c+40|0);break a}a=P()|0;O()|0;Wf(c+24|0);break a}a=P()|0;O()|0}We(g);T(a|0);L()}function ny(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=jb-16|0;jb=e;i=qM(b,c);a:{if(!v[b+656>>2]|!(t[i+6|0]&1)){break a}f=v[i>>2];j=a+1074312|0;Cb(e+8|0,j,31);g=Bb(v[v[e+8>>2]>>2],v[e+12>>2]);d=iv(v[b+656>>2],c);if(oc(v[d>>2],v[d+4>>2])){break a}g=f+(g^1)|0;Cb(e+8|0,j,31);f=w[d+12|0];b:{c:{if(!Bb(v[v[e+8>>2]>>2],v[e+12>>2])){d:{if(!(f&2)){break d}h=w[d+14|0];k=!(v[a+480180>>2]&1048580)+x[Db(v[d>>2],h)>>1]|0;if(!(w[b+89|0]&8)|(!(f&4)|(h|0)!=w[d+16|0])){f=l}else{Cb(e+8|0,j,70);f=Bb(v[v[e+8>>2]>>2],v[e+12>>2])}if(f|(g|0)!=(k|0)){break d}g=x[Db(v[d>>2],w[d+13|0])>>1]}if(!(!(w[d+12|0]&4)|w[b+89|0]&8)){a=v[d>>2];if((x[Db(a,w[d+16|0])>>1]+1|0)!=(g|0)){break b}g=x[Db(a,w[d+15|0])>>1];Cb(e+8|0,j,93);if(!Bb(v[v[e+8>>2]>>2],v[e+12>>2])|(c|0)!=1|v[b+88>>2]&2048){break b}t[i+6|0]=w[i+6|0]&254;break b}k=1;f=x[Aj(v[d+4>>2])>>1];if(g>>>0>f>>>0){break c}break b}e:{f:{if(!(!(f&4)|w[b+669|0]&8)){if(x[i+4>>1]==65535){break f}Cb(e+8|0,j,97);if(Bb(v[v[e+8>>2]>>2],v[e+12>>2])){break f}f=w[d+12|0]}if(f&2){h=v[d>>2];f=x[Db(h,w[d+13|0])>>1];h=x[Db(h,w[d+14|0])>>1]+1|0;break e}f=x[Aj(v[d+4>>2])>>1];k=g>>>0>f>>>0;h=f;break e}h=v[d>>2];f=x[Db(h,w[d+15|0])>>1];h=x[Db(h,w[d+16|0])>>1]+1|0}f=g>>>0<h>>>0?g:f}g:{if(!k|c){break g}g=v[a+480180>>2];c=v[b+88>>2];if(!(!(g&16777248)&(!(c&2048)|(g|0)==16384))){c=c|4096;v[b+88>>2]=c}if(w[Aj(v[d+4>>2])+2|0]|!(v[a+480180>>2]&16777248?1:x[b+786>>1])){break g}v[b+696>>2]=0;v[b+720>>2]=0;v[b+680>>2]=0;v[b+88>>2]=c|4096}g=f}Cb(e+8|0,j,31);m=i,n=Bb(v[v[e+8>>2]>>2],v[e+12>>2])+g|0,v[m>>2]=n}jb=e+16|0}function zda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0;g=jb-48|0;jb=g;o=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;h=e+(g+24|0)|0;e=a+e|0;v[h+4>>2]=v[e+44>>2];v[h+8>>2]=v[e+48>>2];b=b+1|0;continue}break}h=v[a+40>>2];k=v[a+36>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;p=v[a+32>>2];q=v[a+28>>2];r=v[a+72>>2];b=v[a+68>>2];s=b;t=b>>31;b=v[a+64>>2];w=b;x=b>>31;b=v[a+60>>2];y=b;z=b>>31;A=v[a+8>>2];C=v[a+12>>2];while(1){if(d){b=v[g+16>>2];l=b>>>18|0;j=((((v[g+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+o|0;b=0;e=0;while(1){if((e|0)!=2){i=j+(e<<1)|0;f=u[i>>1];v[(g+8|0)+(e<<2)>>2]=f+((B(l,u[i+4>>1]-f|0)|0)/16384|0);e=e+1|0;continue}break}while(1){if((b|0)!=2){l=(g+8|0)+(b<<2)|0;f=v[l>>2];e=(g+24|0)+(b<<3)|0;j=v[e+8>>2];i=v[e+4>>2];v[e+8>>2]=i;n=f<<8;f=n;f=Lka(y,z,f,f>>31);m=mb;D=e;e=Xb(i,-16777216,16776704);i=Lka(w,x,e,e>>31);f=i+f|0;e=mb+m|0;e=f>>>0<i>>>0?e+1|0:e;m=f;f=Xb(j,-16777216,16776704);j=Lka(s,t,f,f>>31);f=m+j|0;e=mb+e|0;e=f>>>0<j>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Xc(f,e,24);v[D+4>>2]=e-(r&n);v[l>>2]=(e|0)/256;b=b+1|0;continue}break}k=k+q|0;v[c>>2]=v[c>>2]+B(v[g+8>>2],k>>12);h=h+p|0;v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],h>>12);Qb(g+16|0,A,C);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;v[a+40>>2]=h;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+24>>2]=h>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}jb=g+48|0}function Ada(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0;g=jb-48|0;jb=g;o=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;h=e+(g+24|0)|0;e=a+e|0;v[h+4>>2]=v[e+44>>2];v[h+8>>2]=v[e+48>>2];b=b+1|0;continue}break}h=v[a+40>>2];k=v[a+36>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;p=v[a+32>>2];q=v[a+28>>2];r=v[a+72>>2];b=v[a+68>>2];s=b;u=b>>31;b=v[a+64>>2];w=b;x=b>>31;b=v[a+60>>2];y=b;z=b>>31;A=v[a+8>>2];C=v[a+12>>2];while(1){if(d){b=v[g+16>>2];l=b>>>10&4194048;j=(((v[g+20>>2]&2147483647)<<1|b>>>31)&-2)+o|0;b=0;e=0;while(1){if((e|0)!=2){i=e+j|0;f=t[i|0];v[(g+8|0)+(e<<2)>>2]=((B(l,t[i+2|0]-f|0)|0)/16384|0)+(f<<8);e=e+1|0;continue}break}while(1){if((b|0)!=2){l=(g+8|0)+(b<<2)|0;f=v[l>>2];e=(g+24|0)+(b<<3)|0;j=v[e+8>>2];i=v[e+4>>2];v[e+8>>2]=i;n=f<<8;f=n;f=Lka(y,z,f,f>>31);m=mb;D=e;e=Xb(i,-16777216,16776704);i=Lka(w,x,e,e>>31);f=i+f|0;e=mb+m|0;e=f>>>0<i>>>0?e+1|0:e;m=f;f=Xb(j,-16777216,16776704);j=Lka(s,u,f,f>>31);f=m+j|0;e=mb+e|0;e=f>>>0<j>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Xc(f,e,24);v[D+4>>2]=e-(r&n);v[l>>2]=(e|0)/256;b=b+1|0;continue}break}k=k+q|0;v[c>>2]=v[c>>2]+B(v[g+8>>2],k>>12);h=h+p|0;v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],h>>12);Qb(g+16|0,A,C);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;v[a+40>>2]=h;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+24>>2]=h>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}jb=g+48|0}function Pda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0;g=jb-48|0;jb=g;p=v[a+16>>2];m=Sf(1,2);b=mb;q=b;Qb(a,m,b);b=0;while(1){if((b|0)!=2){e=b<<3;h=e+(g+24|0)|0;e=a+e|0;v[h+4>>2]=v[e+44>>2];v[h+8>>2]=v[e+48>>2];b=b+1|0;continue}break}h=v[a+40>>2];i=v[a+36>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;r=v[a+32>>2];s=v[a+28>>2];t=v[a+72>>2];b=v[a+68>>2];w=b;x=b>>31;b=v[a+64>>2];y=b;z=b>>31;b=v[a+60>>2];A=b;C=b>>31;D=v[a+8>>2];E=v[a+12>>2];while(1){if(d){d=d-1|0;f=((((v[g+20>>2]&2147483647)<<1|v[g+16>>2]>>>31)&2147483646)<<1)+p|0;b=0;e=0;while(1){if((e|0)!=2){v[(g+8|0)+(e<<2)>>2]=u[f+(e<<1)>>1];e=e+1|0;continue}break}while(1){if((b|0)!=2){n=(g+8|0)+(b<<2)|0;f=v[n>>2];e=(g+24|0)+(b<<3)|0;k=v[e+8>>2];j=v[e+4>>2];v[e+8>>2]=j;o=f<<8;f=o;f=Lka(A,C,f,f>>31);l=mb;F=e;e=Xb(j,-16777216,16776704);j=Lka(y,z,e,e>>31);f=j+f|0;e=mb+l|0;e=f>>>0<j>>>0?e+1|0:e;l=f;f=Xb(k,-16777216,16776704);k=Lka(w,x,f,f>>31);f=l+k|0;e=mb+e|0;e=f>>>0<k>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Xc(f,e,24);v[F+4>>2]=e-(t&o);v[n>>2]=(e|0)/256;b=b+1|0;continue}break}i=i+s|0;v[c>>2]=v[c>>2]+B(v[g+8>>2],i>>12);h=h+r|0;v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],h>>12);Qb(g+16|0,D,E);c=c+8|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;v[a+40>>2]=h;v[a+20>>2]=i>>12;v[a+36>>2]=i;v[a+24>>2]=h>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}lg(a,m,q);jb=g+48|0}function R_(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0,C=0;v[c>>2]=a;y=d&512;z=h<<2;while(1){if((x|0)==4){if(Gb(n)>>>0>1){f=he(n);e=jb-16|0;jb=e;v[e+8>>2]=f;f=v[Ke(e+8|0)>>2];jb=e+16|0;B=c,C=Pi(f,Tk(n),v[c>>2]),v[B>>2]=C}d=d&176;if((d|0)!=16){if((d|0)==32){a=v[c>>2]}v[b>>2]=a}}else{a:{b:{switch(t[i+x|0]){case 0:v[b>>2]=v[c>>2];break a;case 1:v[b>>2]=v[c>>2];h=_r(g,32);p=v[c>>2];v[c>>2]=p+4;v[p>>2]=h;break a;case 3:if(Qe(n)){break a}h=v[zi(n,0)>>2];p=v[c>>2];v[c>>2]=p+4;v[p>>2]=h;break a;case 2:if(Qe(m)|!y){break a}B=c,C=Pi(he(m),Tk(m),v[c>>2]),v[B>>2]=C;break a;case 4:break b;default:break a}}A=v[c>>2];e=e+z|0;h=e;while(1){c:{if(f>>>0<=h>>>0){break c}if(!Wk(g,64,v[h>>2])){break c}h=h+4|0;continue}break}if((o|0)>0){p=v[c>>2];q=o;while(1){if(!(!q|e>>>0>=h>>>0)){h=h-4|0;s=v[h>>2];r=p+4|0;v[c>>2]=r;v[p>>2]=s;q=q-1|0;p=r;continue}break}d:{if(!q){s=0;break d}s=_r(g,48);p=v[c>>2]}while(1){r=p+4|0;if((q|0)>0){v[p>>2]=s;q=q-1|0;p=r;continue}break}v[c>>2]=r;v[p>>2]=j}e:{if((e|0)==(h|0)){p=_r(g,48);q=v[c>>2];h=q+4|0;v[c>>2]=h;v[q>>2]=p;break e}if(Qe(l)){s=-1}else{s=t[gg(l,0)|0]}q=0;u=0;while(1){if((e|0)!=(h|0)){r=v[c>>2];f:{if((q|0)!=(s|0)){p=r;r=q;break f}p=r+4|0;v[c>>2]=p;v[r>>2]=k;r=0;u=u+1|0;if(Gb(l)>>>0<=u>>>0){s=q;break f}s=-1;if(w[gg(l,u)|0]==127){break f}s=t[gg(l,u)|0]}h=h-4|0;q=v[h>>2];v[c>>2]=p+4;v[p>>2]=q;q=r+1|0;continue}break}h=v[c>>2]}Sr(A,h)}x=x+1|0;continue}break}}function nda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0;g=jb-48|0;jb=g;m=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;f=e+(g+24|0)|0;e=a+e|0;v[f+4>>2]=v[e+44>>2];v[f+8>>2]=v[e+48>>2];b=b+1|0;continue}break}n=v[a+24>>2];o=v[a+20>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;p=v[a+72>>2];b=v[a+68>>2];q=b;r=b>>31;b=v[a+64>>2];s=b;t=b>>31;b=v[a+60>>2];w=b;x=b>>31;y=v[a+8>>2];z=v[a+12>>2];while(1){if(d){e=v[g+16>>2];k=((((v[g+20>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+m|0;b=e>>>21&2040;i=u[b+39718>>1];h=u[b+39716>>1];l=u[b+39714>>1];j=u[b+39712>>1];b=0;e=0;while(1){if((e|0)!=2){f=k+(e<<1)|0;v[(g+8|0)+(e<<2)>>2]=(((B(u[f>>1],l)+B(u[f-4>>1],j)|0)+B(h,u[f+4>>1])|0)+B(i,u[f+8>>1])|0)/16384;e=e+1|0;continue}break}while(1){if((b|0)!=2){k=(g+8|0)+(b<<2)|0;f=v[k>>2];e=(g+24|0)+(b<<3)|0;i=v[e+8>>2];h=v[e+4>>2];v[e+8>>2]=h;l=f<<8;f=l;f=Lka(w,x,f,f>>31);j=mb;A=e;e=Xb(h,-16777216,16776704);h=Lka(s,t,e,e>>31);f=h+f|0;e=mb+j|0;e=f>>>0<h>>>0?e+1|0:e;j=f;f=Xb(i,-16777216,16776704);i=Lka(q,r,f,f>>31);f=j+i|0;e=mb+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Xc(f,e,24);v[A+4>>2]=e-(l&p);v[k>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[g+8>>2],o);v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],n);Qb(g+16|0,y,z);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}jb=g+48|0}function PK(a){var b=C(0),c=0,d=0,e=0,f=0,g=C(0),h=0,i=0,k=0,l=C(0),m=0,n=C(0);c=jb-16|0;jb=c;e=a+4208|0;b=Fx(z[Db(e,2)>>2]);f=v[a+16>>2]+24620|0;z[c+12>>2]=b/C(y[f>>2]);v[c+8>>2]=1056964608;b=Bp(C(z[nm(c+12|0,c+8|0)>>2]*C(6.2831854820251465)));b=C(K(C(C(C(b+b)+C(3))/C(5))));z[a+4236>>2]=b;z[a+4240>>2]=K(C(C(1)-C(b*b)));b=C(C(z[Db(e,1)>>2]*C(29))+C(2));a:{if(b<C(4294967296)&b>=C(0)){i=~~b>>>0;break a}i=0}t[a+4272|0]=i;d=i;while(1){if(d&255){k=k+1|0;d=(d&254)>>>1|0;continue}break}t[a+4273|0]=k;l=te(C(10),C(C(C(z[e>>2]*C(60))+C(-60))/C(20)));m=c,n=C(Fx(z[Db(e,3)>>2])/C(y[f>>2])),z[m+12>>2]=n;v[c+8>>2]=1056964608;g=z[nm(c+12|0,c+8|0)>>2];m=c,n=C(Fx(z[Db(e,4)>>2])/C(y[f>>2])),z[m+12>>2]=n;v[c+8>>2]=1056964608;b=C(C(z[nm(c+12|0,c+8|0)>>2]*C(6.2831854820251465))*C(.5));f=jb-16|0;jb=f;e=(p(b),j(2));d=e&2147483647;b:{if(d>>>0<=1061752794){if(d>>>0<964689920){break b}b=En(+b,0);break b}if(d>>>0<=1081824209){h=+b;if(d>>>0<=1075235811){b=En(((e|0)<0?1.5707963267948966:-1.5707963267948966)+h,1);break b}b=En(((e|0)<0?3.141592653589793:-3.141592653589793)+h,0);break b}if(d>>>0<=1088565717){h=+b;if(d>>>0<=1085271519){b=En(((e|0)<0?4.71238898038469:-4.71238898038469)+h,1);break b}b=En(((e|0)<0?6.283185307179586:-6.283185307179586)+h,0);break b}if(d>>>0>=2139095040){b=C(b-b);break b}d=ax(b,f+8|0);b=En(A[f+8>>3],d&1)}jb=f+16|0;b=C(C(C(1)-b)/C(b+C(1)));z[a+4268>>2]=b;g=Bp(C(g*C(6.2831854820251465)));z[a+4264>>2]=-g;z[a+4260>>2]=C(C(l*C(K(C(C(1)-C(g*g)))))*C(K(C(C(1)-C(b*b)))))*z[(i<<2)+45600>>2];jb=c+16|0}function Qda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0;g=jb-48|0;jb=g;p=v[a+16>>2];m=Sf(1,2);b=mb;q=b;Qb(a,m,b);b=0;while(1){if((b|0)!=2){e=b<<3;h=e+(g+24|0)|0;e=a+e|0;v[h+4>>2]=v[e+44>>2];v[h+8>>2]=v[e+48>>2];b=b+1|0;continue}break}h=v[a+40>>2];i=v[a+36>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;r=v[a+32>>2];s=v[a+28>>2];u=v[a+72>>2];b=v[a+68>>2];w=b;x=b>>31;b=v[a+64>>2];y=b;z=b>>31;b=v[a+60>>2];A=b;C=b>>31;D=v[a+8>>2];E=v[a+12>>2];while(1){if(d){d=d-1|0;f=(((v[g+20>>2]&2147483647)<<1|v[g+16>>2]>>>31)&-2)+p|0;b=0;e=0;while(1){if((e|0)!=2){v[(g+8|0)+(e<<2)>>2]=t[e+f|0]<<8;e=e+1|0;continue}break}while(1){if((b|0)!=2){n=(g+8|0)+(b<<2)|0;f=v[n>>2];e=(g+24|0)+(b<<3)|0;k=v[e+8>>2];j=v[e+4>>2];v[e+8>>2]=j;o=f<<8;f=o;f=Lka(A,C,f,f>>31);l=mb;F=e;e=Xb(j,-16777216,16776704);j=Lka(y,z,e,e>>31);f=j+f|0;e=mb+l|0;e=f>>>0<j>>>0?e+1|0:e;l=f;f=Xb(k,-16777216,16776704);k=Lka(w,x,f,f>>31);f=l+k|0;e=mb+e|0;e=f>>>0<k>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Xc(f,e,24);v[F+4>>2]=e-(u&o);v[n>>2]=(e|0)/256;b=b+1|0;continue}break}i=i+s|0;v[c>>2]=v[c>>2]+B(v[g+8>>2],i>>12);h=h+r|0;v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],h>>12);Qb(g+16|0,D,E);c=c+8|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;v[a+40>>2]=h;v[a+20>>2]=i>>12;v[a+36>>2]=i;v[a+24>>2]=h>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}lg(a,m,q);jb=g+48|0}function Gaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-112|0;jb=c;Bj(c+88|0,b,1413829443);v[23588]=0;b=S(178,v[c+88>>2])|0;d=v[23588];v[23588]=0;a:{b:{c:{if((d|0)==1){break c}if(!b){v[23588]=0;U(771,c- -64|0,a+140|0,1413894985);a=v[23588];v[23588]=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{if((a|0)!=1){v[23588]=0;a=Q(848,c- -64|0,13560)|0;b=v[23588];v[23588]=0;if((b|0)==1){break e}b=28591;if(a){b=Lb(c+48|0);v[23588]=0;a=S(202,c- -64|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break m}v[23588]=0;U(268,c- -64|0,b|0,a|0);a=v[23588];v[23588]=0;if((a|0)==1){break m}v[23588]=0;d=Q(54,c+16|0,b|0)|0;a=v[23588];v[23588]=0;if((a|0)==1){break l}v[23588]=0;Y(849,c|0);a=v[23588];v[23588]=0;if((a|0)==1){break k}v[23588]=0;U(850,c+32|0,d|0,c|0);a=v[23588];v[23588]=0;if((a|0)==1){break j}a=c+32|0;e=Ac(b,a);yb(a);yb(c);yb(d);v[23588]=0;U(11,a|0,2,e|0);a=v[23588];v[23588]=0;if((a|0)==1){break h}v[23588]=0;a=S(742,c+32|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break g}zb(c+32|0);yb(e);b=a-1>>>0<19398657?1252:28591}Ab(c- -64|0);break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;break i}a=P()|0;O()|0;yb(c)}yb(d);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;zb(c+32|0)}yb(b);break d}a=P()|0;O()|0}Ab(c- -64|0);break b}v[23588]=0;a=W(156,v[c+88>>2],v[c+96>>2],2)|0;b=v[23588];v[23588]=0;if((b|0)==1){break c}b=28591;if(!a){break a}v[23588]=0;b=S(194,c+88|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){break a}a=P()|0;O()|0;break b}a=P()|0;O()|0}Ab(c+88|0);T(a|0);L()}Ab(c+88|0);jb=c+112|0;return b|0}function $J(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=C(0);e=jb-48|0;jb=e;a:{b:{c:{d:{e:{switch(b-1|0){case 1:b=(c<<7)/100|0;d=v[a+24>>2];if((b|0)==v[d+24604>>2]){break d}a=e+8|0;tc(a,d+24604|0,40);v[e+8>>2]=b;ry(d,a);break d;case 2:f=v[a+24>>2];d=f+24664|0;b=v[d+4>>2];v[e+24>>2]=v[d>>2];v[e+28>>2]=b;d=f+24656|0;b=v[d+4>>2];v[e+16>>2]=v[d>>2];v[e+20>>2]=b;b=v[f+24652>>2];v[e+8>>2]=v[f+24648>>2];v[e+12>>2]=b;d=jb-16|0;jb=d;b=3;f:{g:{h:{if(!c|(c|0)>7){break h}b=2;if((c|0)>2){break h}b=1;if((c|0)==2){break h}b=0;if((c|0)>0){break h}c=ba(8)|0;v[23588]=0;b=Q(55,d|0,10751)|0;a=v[23588];v[23588]=0;i:{if((a|0)!=1){a=rc(c,b);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break g}a=P()|0;O()|0;yb(b);break i}a=P()|0;O()|0;ca(c|0)}T(a|0);L()}jb=d+16|0;break f}L()}t[e+8|0]=b;a=v[a+24>>2];if(!xx(e+8|0,a+24648|0)){break d}py(a,e+8|0);break d;case 3:f=e+8|0;d=v[a+24>>2];tc(f,d+24604|0,40);b=jb-48|0;jb=b;j:{if((c|0)==-1){Bs(f,v[bq(b+8|0)+32>>2]);bo(f,v[bq(b+8|0)+36>>2]);break j}if((c|0)<=0){Bs(f,0);bo(f,0);break j}a=B(c,1e3);Bs(f,a);bo(f,a)}jb=b+48|0;if(v[d+24636>>2]==v[e+40>>2]&v[d+24640>>2]==v[e+44>>2]){break d}ry(d,e+8|0);break d;default:d=ba(8)|0;v[23588]=0;c=Q(55,e+8|0,10335)|0;a=v[23588];v[23588]=0;if((a|0)==1){break c}a=rc(d,c);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}b=P()|0;O()|0;yb(c);break b;case 0:break e}}g=a,h=te(C(10),C(C(C(c|0)*C(.0010000000474974513))*C(.5))),z[g+48>>2]=h}jb=e+48|0;return}b=P()|0;O()|0;ca(d|0)}T(b|0)}L()}function Wca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0;h=jb-16|0;jb=h;a:{b:{c:{i=v[a+12>>2];j=v[a+8>>2];d:{if((i|0)<=1&j>>>0<=805306368|(i|0)<=0){if((i|0)>=-2&j>>>0>=3489660928|(i|0)>-2){break c}if((i|0)==-2&j>>>0>2147483647|i>>>0>4294967294){break d}break b}if((i|0)==1&j>>>0>2147483648|i>>>0>1){break b}}p=b+196648|0;break a}p=b+131112|0;break a}p=b+262184|0}q=v[a+16>>2];f=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];b=v[a+44>>2];e=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=e;r=v[a+32>>2];s=v[a+28>>2];t=v[a+72>>2];e=v[a+68>>2];w=e;x=e>>31;e=v[a+64>>2];y=e;z=e>>31;e=v[a+60>>2];A=e;C=e>>31;while(1){e=b;if(d){b=Xb(e,-16777216,16776704);b=Lka(y,z,b,b>>31);m=mb;n=b;g=(v[h+12>>2]<<1)+q|0;b=(v[h+8>>2]>>>16&65520)+p|0;g=(((((((B(u[g-4>>1],u[b+2>>1])+B(u[g-6>>1],u[b>>1])|0)+B(u[g-2>>1],u[b+4>>1])|0)+B(u[g>>1],u[b+6>>1])|0)+B(u[g+2>>1],u[b+8>>1])|0)+B(u[g+4>>1],u[b+10>>1])|0)+B(u[g+6>>1],u[b+12>>1])|0)+B(u[g+8>>1],u[b+14>>1])|0)/32768<<8;b=g;b=Lka(b,b>>31,A,C);n=n+b|0;o=mb+m|0;o=b>>>0>n>>>0?o+1|0:o;b=Xb(f,-16777216,16776704);f=Lka(w,x,b,b>>31);m=f+n|0;b=mb+o|0;b=f>>>0>m>>>0?b+1|0:b;f=m+8388608|0;b=f>>>0<8388608?b+1|0:b;f=Xc(f,b,24);b=(f|0)/256|0;l=l+s|0;v[c>>2]=B(b,l>>12)+v[c>>2];k=k+r|0;v[c+4>>2]=v[c+4>>2]+B(b,k>>12);Qb(h+8|0,j,i);b=f-(g&t)|0;c=c+8|0;d=d-1|0;f=e;continue}break}b=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=b;v[a+40>>2]=k;v[a+20>>2]=l>>12;v[a+36>>2]=l;v[a+48>>2]=f;v[a+44>>2]=e;v[a+24>>2]=k>>12;jb=h+16|0}function Sea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=jb-16|0;jb=f;k=f,l=zj(b),v[k>>2]=l;e=jb-16|0;jb=e;h=a;c=Sd(a);a:{if(c){g=ic(h);while(1){a=c;c=a+14|0;if(Gt(b,c)){g=a;c=v[a>>2];if(c){continue}break a}if(!Gt(c,b)){break a}g=a+4|0;c=v[a+4>>2];if(c){continue}break}break a}a=ic(h);g=a}v[e+12>>2]=a;b=v[g>>2];if(!b){i=jb-16|0;jb=i;a=ic(h);j=lh(e,sc(48),mh(i+8|0,a));a=v[j>>2];b=v[f>>2];c=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);d=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[a+14|0]=d;t[a+15|0]=d>>>8;t[a+16|0]=d>>>16;t[a+17|0]=d>>>24;t[a+18|0]=c;t[a+19|0]=c>>>8;t[a+20|0]=c>>>16;t[a+21|0]=c>>>24;c=w[b+28|0]|w[b+29|0]<<8|(w[b+30|0]<<16|w[b+31|0]<<24);d=w[b+24|0]|w[b+25|0]<<8|(w[b+26|0]<<16|w[b+27|0]<<24);t[a+38|0]=d;t[a+39|0]=d>>>8;t[a+40|0]=d>>>16;t[a+41|0]=d>>>24;t[a+42|0]=c;t[a+43|0]=c>>>8;t[a+44|0]=c>>>16;t[a+45|0]=c>>>24;c=w[b+20|0]|w[b+21|0]<<8|(w[b+22|0]<<16|w[b+23|0]<<24);d=w[b+16|0]|w[b+17|0]<<8|(w[b+18|0]<<16|w[b+19|0]<<24);t[a+30|0]=d;t[a+31|0]=d>>>8;t[a+32|0]=d>>>16;t[a+33|0]=d>>>24;t[a+34|0]=c;t[a+35|0]=c>>>8;t[a+36|0]=c>>>16;t[a+37|0]=c>>>24;c=w[b+12|0]|w[b+13|0]<<8|(w[b+14|0]<<16|w[b+15|0]<<24);b=w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24);t[a+22|0]=b;t[a+23|0]=b>>>8;t[a+24|0]=b>>>16;t[a+25|0]=b>>>24;t[a+26|0]=c;t[a+27|0]=c>>>8;t[a+28|0]=c>>>16;t[a+29|0]=c>>>24;u[a+46>>1]=0;k=ic(j),l=1,t[k+4|0]=l;jb=i+16|0;Jg(h,v[e+12>>2],g,v[e>>2]);b=be(e);qk(e);d=1}Ig(f+8|0,v[ec(e,b)>>2],d);jb=e+16|0;a=qo(v[f+8>>2]);jb=f+16|0;return a+32|0}function pca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0;g=jb-16|0;jb=g;w=v[a+16>>2];x=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);p=v[a+128>>2];a:{if(!p){n=v[a+8>>2];s=v[a+12>>2];i=v[a>>2];e=v[a+4>>2];o=0;break a}b=v[a+12>>2];s=b;n=v[a+8>>2];q=kg(n,b,p);r=mb;k=v[a+76>>2];i=v[a>>2];e=v[a+4>>2];Pf(i,e,kf(n,b,d),mb);o=k>>>0<mb>>>0?d:0}h=a+112|0;f=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];b=v[a+44>>2];v[g>>2]=i;v[g+4>>2]=e;b:while(1){c:{k=b;if(!d){break c}d=d-1|0;v[g+8>>2]=i;v[g+12>>2]=0;o=o-1|0;b=o;q=b?q:0;r=b?r:0;e=(e<<1)+w|0;b=p;while(1)if((b|0)<=0){Qb(h,v[a+120>>2],v[a+124>>2]);b=v[a+116>>2];if(b){Rd(h,u[e+(v[g+12>>2]<<1)>>1]/4<<16>>16);Qd(h,b);v[h>>2]=v[h>>2];v[h+4>>2]=0}i=v[a+72>>2];y=v[a+32>>2];m=v[a+28>>2]+m|0;b=v[a+60>>2];e=b;j=b>>31;t=ig(h,x)<<8;b=t;b=Lka(e,j,b,b>>31);z=mb;e=b;b=v[a+64>>2];j=b;A=b>>31;b=Xb(k,-16777216,16776704);j=Lka(j,A,b,b>>31);e=e+j|0;b=mb+z|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=v[a+68>>2];f=Xb(f,-16777216,16776704);e=Lka(e,e>>31,f,f>>31);f=j+e|0;b=mb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Xc(f,b,24);f=(b|0)/256|0;v[c>>2]=B(m>>12,f)+v[c>>2];l=l+y|0;v[c+4>>2]=v[c+4>>2]+B(l>>12,f);Qb(g,n,s);b=b-(i&t)|0;c=c+8|0;i=v[g>>2];e=v[g+4>>2];f=k;continue b}else{Rd(h,u[e+(v[g+12>>2]<<1)>>1]/4<<16>>16);Qd(h,4);Qb(g+8|0,q,r);b=b-1|0;continue}}break}v[a>>2]=i;v[a+4>>2]=e;v[a+40>>2]=l;v[a+20>>2]=m>>12;v[a+36>>2]=m;v[a+48>>2]=f;v[a+44>>2]=k;v[a+24>>2]=l>>12;jb=g+16|0}function oda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0;g=jb-48|0;jb=g;m=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;f=e+(g+24|0)|0;e=a+e|0;v[f+4>>2]=v[e+44>>2];v[f+8>>2]=v[e+48>>2];b=b+1|0;continue}break}n=v[a+24>>2];o=v[a+20>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;p=v[a+72>>2];b=v[a+68>>2];q=b;r=b>>31;b=v[a+64>>2];s=b;w=b>>31;b=v[a+60>>2];x=b;y=b>>31;z=v[a+8>>2];A=v[a+12>>2];while(1){if(d){e=v[g+16>>2];k=(((v[g+20>>2]&2147483647)<<1|e>>>31)&-2)+m|0;b=e>>>21&2040;i=u[b+39718>>1];h=u[b+39716>>1];l=u[b+39714>>1];j=u[b+39712>>1];b=0;e=0;while(1){if((e|0)!=2){f=e+k|0;v[(g+8|0)+(e<<2)>>2]=(((B(t[f|0],l)+B(t[f-2|0],j)|0)+B(h,t[f+2|0])|0)+B(i,t[f+4|0])<<8)/16384;e=e+1|0;continue}break}while(1){if((b|0)!=2){k=(g+8|0)+(b<<2)|0;f=v[k>>2];e=(g+24|0)+(b<<3)|0;i=v[e+8>>2];h=v[e+4>>2];v[e+8>>2]=h;l=f<<8;f=l;f=Lka(x,y,f,f>>31);j=mb;C=e;e=Xb(h,-16777216,16776704);h=Lka(s,w,e,e>>31);f=h+f|0;e=mb+j|0;e=f>>>0<h>>>0?e+1|0:e;j=f;f=Xb(i,-16777216,16776704);i=Lka(q,r,f,f>>31);f=j+i|0;e=mb+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Xc(f,e,24);v[C+4>>2]=e-(l&p);v[k>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[g+8>>2],o);v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],n);Qb(g+16|0,z,A);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}jb=g+48|0}function Kba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,y=0,z=0,A=0;f=jb+-64|0;jb=f;a:{b:{c:{d:{e:{f:{g:{if(!a){break g}l=e<<2;if(l>>>0>d>>>0){break g}s=l-4|0;o=B(b,e);x=o-8|0;h:while(1){b=v[c+8>>2];h=v[c>>2];v[23588]=0;b=W(156,h|0,b|0,l|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break b}if(!(b&n>>>0<o>>>0)){break g}v[23588]=0;U(190,f+16|0,c|0,d|0);b=v[23588];v[23588]=0;if((b|0)==1){break c}b=f+16|0;h=jc(f+40|0,b);Ab(b);v[23588]=0;R(560,b|0,h|0);b=v[23588];v[23588]=0;if((b|0)==1){break e}y=Ie(f+16|0);p=v[f+16>>2];z=p-4|0;k=0;while(1){if((e|0)==(k|0)){Tc(f+16|0);Ab(h);n=(p-l<<1)+n|0;continue h}v[23588]=0;g=S(553,h|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){v[23588]=0;b=S(206,h|0)|0;j=v[23588];v[23588]=0;if((j|0)==1){break f}v[f+8>>2]=b;oe(f+8|0,0,89);v[23588]=0;Q(188,h|0,1)|0;b=v[23588];v[23588]=0;if((b|0)==1){break f}j=k+n|0;b=e+k<<2;i:while(1){j:{if(j>>>0>x>>>0){break j}m=0;if(b>>>0>z>>>0){break j}while(1)if((m|0)==8){b=b+s|0;continue i}else{q=v[f+8>>2];i=w[b+y|0];r=m&1;i=r?i>>>4|0:i&15;v[f+8>>2]=q+t[(i&7)+30264|0];A=g;g=u[(q<<1)+30272>>1];g=(((0-(i&1)&g>>2)+(g>>3)|0)+(i<<30>>31&g>>1)|0)+(g&i<<29>>31)|0;v[f+12>>2]=A+(i&8?0-g|0:g);oe(f+8|0,0,88);oe(f+12|0,-32768,32767);g=v[f+12>>2];u[(j<<1)+a>>1]=g;m=m+1|0;j=e+j|0;b=b+r|0;continue}}break}k=k+1|0;continue}break}break}break f}Ab(c);jb=f- -64|0;return}b=P()|0;O()|0;Tc(f+16|0);break d}b=P()|0;O()|0}Ab(h);break a}b=P()|0;O()|0;break a}b=P()|0;O()|0}Ab(c);T(b|0);L()}function gh(a,b,c,d,e){var f=0,g=0,h=0;if(!b){c=jb-16|0;jb=c;a:{if((d|0)==189){t[a+3843|0]=e>>>7;t[a+3844|0]=e>>>6&1;break a}b=d&224;if(!b){if((d|0)!=260){break a}b=0;d=1;while(1){if((b|0)==6){break a}f=B(b>>>0<3?b:b+6|0,44)+a|0;g=f+148|0;f=f+16|0;h=d&e;b:{if(h){bo(f,g);break b}bo(f,0)}t[g+40|0]=!h;b=b+1|0;d=d<<1&510;continue}}if(b-160>>>0<=32){b=d&15;if(b>>>0>8){break a}a=B(d&256?b+9|0:b,44)+a|0;v[c+8>>2]=a+16;b=v[a+52>>2];v[c+12>>2]=b;g=b?2:1;c:{b=d&240;if((b|0)!=160){if((b|0)==192){break c}if((b|0)!=176){break a}f=e&3;h=e>>>2&7;b=0;d=(e&32)!=0;while(1){if((b|0)==(g|0)){break a}a=v[(c+8|0)+(b<<2)>>2];YO(v[a>>2],d);YO(v[a+4>>2],d);u[a+22>>1]=h;tz(a);_O(a);t[a+21|0]=f;tz(a);_O(a);b=b+1|0;continue}}b=0;while(1){if((b|0)==(g|0)){break a}a=v[(c+8|0)+(b<<2)>>2];u[a+20>>1]=x[a+20>>1]&768|e&255;tz(a);b=b+1|0;continue}}t[a+58|0]=(e&32)>>>5;t[a+57|0]=(e&16)>>>4;b=e>>>1&7;u[a+46>>1]=b?9-b|0:0;u[a+48>>1]=e&1;break a}if((b|0)!=224&b>>>0>=129|-4144960>>>d&1){break a}f=a;a=t[(d&31)+28992|0];a=(f+B(d&256?a+18|0:a,84)|0)+808|0;d:{switch(b-32>>>5|0){case 0:t[a+79|0]=e>>>7;t[a+80|0]=(e&64)>>>6;t[a+78|0]=(e&32)>>>5;t[a+77|0]=(e&16)>>>4;co(a);u[a+14>>1]=x[((e&15)<<1)+29024>>1];break a;case 1:u[a+68>>1]=w[(e>>>6|0)+21604|0];ZO(a);u[a+22>>1]=(e&63)<<2;break a;case 2:u[a+24>>1]=e>>>4;co(a);u[a+26>>1]=e&15;co(a);break a;case 3:b=e>>>4|0;u[a+28>>1]=b>>>0<15?b<<4:496;u[a+30>>1]=e&15;co(a);break a;case 6:break d;default:break a}}u[a+12>>1]=e&7}jb=c+16|0;return}nb[v[v[b>>2]>>2]](b,c,d,e)}function OW(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=jb-48|0;jb=f;g=ti(b)^-1;a:{if(uc(v[d>>2],v[d+4>>2])>>>0<=g>>>0){_s(a);break a}ti(b);if((w[c+4|0]|w[c+5|0]<<8)>>>0>=60){Zb(b,4)}j=f,k=ti(b),v[j+44>>2]=k;Zb(b,4);h=ti(b);i=ti(b);if(!((h|0)>0&(i|0)>36)){_s(a);break a}if(xq(Md(v[e>>2],v[Db(v[d>>2],g)>>2]),13017)){_s(a);break a}Iv(f,b,i,h);d=jc(f+24|0,f);Ab(f);b=v[d>>2];v[23588]=0;b=S(178,b|0)|0;e=v[23588];v[23588]=0;b:{if((e|0)==1){break b}c:{d:{if(!b){v[23588]=0;S(187,a|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){break d}break b}b=w[c+4|0]|w[c+5|0]<<8;if(b>>>0<=39){v[23588]=0;Q(188,d|0,8)|0;b=v[23588];v[23588]=0;if((b|0)==1){break b}b=w[c+4|0]|w[c+5|0]<<8}if((b&65535)>>>0<=59){v[23588]=0;Q(188,d|0,16)|0;b=v[23588];v[23588]=0;if((b|0)==1){break b}}v[23588]=0;S(189,d|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break b}e:{f:{b=w[c+4|0]|w[c+5|0]<<8;g:{if(b>>>0>=120){v[23588]=0;S(189,d|0)|0;c=v[23588];v[23588]=0;b=8;break g}h:{if(b>>>0>=100){v[23588]=0;Q(188,d|0,4)|0;b=v[23588];v[23588]=0;if((b|0)==1){break b}break h}if(b>>>0<62){break f}}v[23588]=0;S(189,d|0)|0;c=v[23588];v[23588]=0;b=4}if((c|0)==1){break b}v[23588]=0;Q(188,d|0,b|0)|0;break e}v[23588]=0;S(189,d|0)|0}b=v[23588];v[23588]=0;if((b|0)==1){break b}v[23588]=0;b=S(189,d|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break c}v[23588]=0;U(190,f|0,d|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break c}j=jc(a,f),k=v[f+44>>2],v[j+20>>2]=k;Ab(f)}Ab(d);break a}}a=P()|0;O()|0;Ab(d);T(a|0);L()}jb=f+48|0}function Xca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0;h=jb-16|0;jb=h;a:{b:{c:{i=v[a+12>>2];k=v[a+8>>2];d:{if((i|0)<=1&k>>>0<=805306368|(i|0)<=0){if((i|0)>=-2&k>>>0>=3489660928|(i|0)>-2){break c}if((i|0)==-2&k>>>0>2147483647|i>>>0>4294967294){break d}break b}if((i|0)==1&k>>>0>2147483648|i>>>0>1){break b}}n=b+196648|0;break a}n=b+131112|0;break a}n=b+262184|0}o=v[a+16>>2];b=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];e=v[a+44>>2];f=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=f;p=v[a+32>>2];q=v[a+28>>2];r=v[a+72>>2];f=v[a+68>>2];s=f;w=f>>31;f=v[a+64>>2];x=f;y=f>>31;f=v[a+60>>2];z=f;A=f>>31;while(1){f=e;if(d){e=Xb(f,-16777216,16776704);e=Lka(x,y,e,e>>31);g=mb;j=e;b=Xb(b,-16777216,16776704);e=Lka(s,w,b,b>>31);j=j+e|0;b=mb+g|0;b=e>>>0>j>>>0?b+1|0:b;g=v[h+12>>2]+o|0;e=(v[h+8>>2]>>>16&65520)+n|0;g=(((((((B(t[g-2|0],u[e+2>>1])+B(t[g-3|0],u[e>>1])|0)+B(t[g-1|0],u[e+4>>1])|0)+B(t[g|0],u[e+6>>1])|0)+B(t[g+1|0],u[e+8>>1])|0)+B(t[g+2|0],u[e+10>>1])|0)+B(t[g+3|0],u[e+12>>1])|0)+B(t[g+4|0],u[e+14>>1])<<8)/32768<<8;e=g;e=Lka(e,e>>31,z,A);j=e+j|0;b=mb+b|0;b=e>>>0>j>>>0?b+1|0:b;e=j+8388608|0;b=e>>>0<8388608?b+1|0:b;e=Xc(e,b,24);b=(e|0)/256|0;m=m+q|0;v[c>>2]=B(b,m>>12)+v[c>>2];l=l+p|0;v[c+4>>2]=v[c+4>>2]+B(l>>12,b);Qb(h+8|0,k,i);e=e-(g&r)|0;c=c+8|0;d=d-1|0;b=f;continue}break}c=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=c;v[a+40>>2]=l;v[a+20>>2]=m>>12;v[a+36>>2]=m;v[a+48>>2]=b;v[a+44>>2]=f;v[a+24>>2]=l>>12;jb=h+16|0}function GV(){var a=0,b=0,c=0;if(!w[468e3]){a=jb-16|0;jb=a;Hs(467648);v[116924]=-1;v[116922]=467704;v[116920]=94048;v[116912]=78436;t[467700]=0;b=a+8|0;as(b,467648);c=v[v[116912]+8>>2];v[23588]=0;R(c|0,467648,b|0);b=v[23588];v[23588]=0;a:{if((b|0)!=1){$b(a+8|0);jb=a+16|0;break a}b=P()|0;O()|0;$b(a+8|0);Kn(467648);T(b|0);L()}Ms(466976);v[116744]=78568;v[116742]=78548;v[116743]=0;Jn(466976,467648);eH(467712,94192,467760);Kw(467144,467712);eH(467768,93888,467816);Kw(467312,467768);Kw(467480,v[(v[v[116828]-12>>2]+467312|0)+24>>2]);dH(v[v[116742]-12>>2]+466968|0);YH(v[v[116828]-12>>2]+467312|0);dH(v[v[116828]-12>>2]+467312|0);a=jb-16|0;jb=a;sH(467824);v[116968]=-1;v[116966]=467880;v[116964]=94048;v[116956]=78828;t[467876]=0;b=a+8|0;as(b,467824);c=v[v[116956]+8>>2];v[23588]=0;R(c|0,467824,b|0);b=v[23588];v[23588]=0;b:{if((b|0)!=1){$b(a+8|0);jb=a+16|0;break b}b=P()|0;O()|0;$b(a+8|0);ds(467824);T(b|0);L()}aH(467064);v[116766]=78960;v[116764]=78940;v[116765]=0;Jn(467064,467824);cH(467888,94192,467936);Jw(467228,467888);cH(467944,93888,467992);Jw(467396,467944);Jw(467564,v[(v[v[116849]-12>>2]+467396|0)+24>>2]);bH(v[v[116764]-12>>2]+467056|0);YH(v[v[116849]-12>>2]+467396|0);bH(v[v[116849]-12>>2]+467396|0);t[468e3]=1}a=jb-16|0;jb=a;c:{if(eb(a+12|0,a+8|0)|0){break c}b=Od((v[a+12>>2]<<2)+4|0);v[117002]=b;if(!b){break c}b=Od(v[a+8>>2]);if(b){c=v[117002];v[c+(v[a+12>>2]<<2)>>2]=0;if(!(db(c|0,b|0)|0)){break c}}v[117002]=0}jb=a+16|0;v[116072]=42;v[116090]=468100}function V_(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0,C=0;v[c>>2]=a;z=d&512;while(1){if((x|0)==4){if(Gb(n)>>>0>1){f=qt(n);e=jb-16|0;jb=e;v[e+8>>2]=f;f=v[Ge(e+8|0)>>2];jb=e+16|0;B=c,C=WF(f,pt(n),v[c>>2]),v[B>>2]=C}d=d&176;if((d|0)!=16){if((d|0)==32){a=v[c>>2]}v[b>>2]=a}return}a:{b:{switch(t[i+x|0]){case 0:v[b>>2]=v[c>>2];break a;case 1:v[b>>2]=v[c>>2];p=Jl(g,32);q=v[c>>2];v[c>>2]=q+1;t[q|0]=p;break a;case 3:if(Qe(n)){break a}p=w[gg(n,0)|0];q=v[c>>2];v[c>>2]=q+1;t[q|0]=p;break a;case 2:if(Qe(m)|!z){break a}B=c,C=WF(qt(m),pt(m),v[c>>2]),v[B>>2]=C;break a;case 4:break b;default:break a}}p=v[g+8>>2];A=v[c>>2];e=e+h|0;r=e;while(1){c:{if(f>>>0<=r>>>0){break c}if(!uh(p,64,t[r|0])){break c}r=r+1|0;continue}break}p=o;if((p|0)>0){while(1){if(!(!p|e>>>0>=r>>>0)){r=r-1|0;q=w[r|0];s=v[c>>2];v[c>>2]=s+1;t[s|0]=q;p=p-1|0;continue}break}if(p){q=Jl(g,48)}else{q=0}while(1){s=v[c>>2];v[c>>2]=s+1;if((p|0)>0){t[s|0]=q;p=p-1|0;continue}break}t[s|0]=j}d:{if((e|0)==(r|0)){p=Jl(g,48);q=v[c>>2];v[c>>2]=q+1;t[q|0]=p;break d}if(Qe(l)){q=-1}else{q=t[gg(l,0)|0]}p=0;u=0;while(1){if((e|0)==(r|0)){break d}e:{if((p|0)!=(q|0)){s=p;break e}q=v[c>>2];v[c>>2]=q+1;t[q|0]=k;s=0;u=u+1|0;if(Gb(l)>>>0<=u>>>0){q=p;break e}q=-1;if(w[gg(l,u)|0]==127){break e}q=t[gg(l,u)|0]}r=r-1|0;p=w[r|0];y=v[c>>2];v[c>>2]=y+1;t[y|0]=p;p=s+1|0;continue}}$l(A,v[c>>2])}x=x+1|0;continue}}function qca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0,A=0;g=jb-16|0;jb=g;w=v[a+16>>2];x=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);p=v[a+128>>2];a:{if(!p){n=v[a+8>>2];s=v[a+12>>2];i=v[a>>2];e=v[a+4>>2];o=0;break a}b=v[a+12>>2];s=b;n=v[a+8>>2];q=kg(n,b,p);r=mb;k=v[a+76>>2];i=v[a>>2];e=v[a+4>>2];Pf(i,e,kf(n,b,d),mb);o=k>>>0<mb>>>0?d:0}h=a+112|0;f=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];b=v[a+44>>2];v[g>>2]=i;v[g+4>>2]=e;b:while(1){c:{k=b;if(!d){break c}d=d-1|0;v[g+8>>2]=i;v[g+12>>2]=0;o=o-1|0;b=o;q=b?q:0;r=b?r:0;e=e+w|0;b=p;while(1)if((b|0)<=0){Qb(h,v[a+120>>2],v[a+124>>2]);b=v[a+116>>2];if(b){Rd(h,t[e+v[g+12>>2]|0]<<6);Qd(h,b);v[h>>2]=v[h>>2];v[h+4>>2]=0}i=v[a+72>>2];y=v[a+32>>2];m=v[a+28>>2]+m|0;b=v[a+60>>2];e=b;j=b>>31;u=ig(h,x)<<8;b=u;b=Lka(e,j,b,b>>31);z=mb;e=b;b=v[a+64>>2];j=b;A=b>>31;b=Xb(k,-16777216,16776704);j=Lka(j,A,b,b>>31);e=e+j|0;b=mb+z|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=v[a+68>>2];f=Xb(f,-16777216,16776704);e=Lka(e,e>>31,f,f>>31);f=j+e|0;b=mb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Xc(f,b,24);f=(b|0)/256|0;v[c>>2]=B(m>>12,f)+v[c>>2];l=l+y|0;v[c+4>>2]=v[c+4>>2]+B(l>>12,f);Qb(g,n,s);b=b-(i&u)|0;c=c+8|0;i=v[g>>2];e=v[g+4>>2];f=k;continue b}else{Rd(h,t[e+v[g+12>>2]|0]<<6);Qd(h,4);Qb(g+8|0,q,r);b=b-1|0;continue}}break}v[a>>2]=i;v[a+4>>2]=e;v[a+40>>2]=l;v[a+20>>2]=m>>12;v[a+36>>2]=m;v[a+48>>2]=f;v[a+44>>2]=k;v[a+24>>2]=l>>12;jb=g+16|0}function Y4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=jb-80|0;jb=e;f=Sb(a);a=0;c=v[b+24>>2];g=sj(Vb(v[c+484360>>2],w[c+484376|0]));v[23588]=0;R(181,f|0,g|0);c=v[23588];v[23588]=0;a:{if((c|0)!=1){while(1){b:{if((a|0)!=(g|0)){c=v[b+24>>2];d=v[c+484344>>2];h=v[c+484348>>2];c=x[cc(v[Vb(v[c+484360>>2],w[c+484376|0])>>2],a)>>1];if(Qm(d,h,c)){v[23588]=0;R(1022,e+48|0,Yb(d,c)|0);c=v[23588];v[23588]=0;c:{d:{e:{if((c|0)!=1){c=v[b+24>>2];v[23588]=0;U(1009,e- -64|0,c|0,e+48|0);c=v[23588];v[23588]=0;if((c|0)==1){break e}v[23588]=0;R(183,f|0,e- -64|0);c=v[23588];v[23588]=0;if((c|0)==1){break d}yb(e- -64|0);yb(e+48|0);break b}a=P()|0;O()|0;break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;yb(e- -64|0)}yb(e+48|0);break a}f:{switch(c-65534|0){case 0:v[23588]=0;c=Q(55,e+32|0,9200)|0;d=v[23588];v[23588]=0;g:{if((d|0)!=1){v[23588]=0;R(183,f|0,c|0);d=v[23588];v[23588]=0;if((d|0)==1){break g}yb(c);break b}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(c);break a;case 1:v[23588]=0;c=Q(55,e+16|0,9162)|0;d=v[23588];v[23588]=0;h:{if((d|0)!=1){v[23588]=0;R(183,f|0,c|0);d=v[23588];v[23588]=0;if((d|0)==1){break h}yb(c);break b}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(c);break a;default:break f}}v[23588]=0;c=Q(55,e|0,14571)|0;d=v[23588];v[23588]=0;i:{if((d|0)!=1){v[23588]=0;R(183,f|0,c|0);d=v[23588];v[23588]=0;if((d|0)==1){break i}yb(c);break b}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(c);break a}jb=e+80|0;return}a=a+1|0;continue}}a=P()|0;O()|0}We(f);T(a|0);L()}function Dda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0;g=jb-48|0;jb=g;m=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;f=e+(g+24|0)|0;e=a+e|0;v[f+4>>2]=v[e+44>>2];v[f+8>>2]=v[e+48>>2];b=b+1|0;continue}break}n=v[a+24>>2];o=v[a+20>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;p=v[a+72>>2];b=v[a+68>>2];q=b;r=b>>31;b=v[a+64>>2];s=b;t=b>>31;b=v[a+60>>2];w=b;x=b>>31;y=v[a+8>>2];z=v[a+12>>2];while(1){if(d){b=v[g+16>>2];j=b>>>18|0;i=((((v[g+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+m|0;b=0;e=0;while(1){if((e|0)!=2){h=i+(e<<1)|0;f=u[h>>1];v[(g+8|0)+(e<<2)>>2]=f+((B(j,u[h+4>>1]-f|0)|0)/16384|0);e=e+1|0;continue}break}while(1){if((b|0)!=2){j=(g+8|0)+(b<<2)|0;f=v[j>>2];e=(g+24|0)+(b<<3)|0;i=v[e+8>>2];h=v[e+4>>2];v[e+8>>2]=h;l=f<<8;f=l;f=Lka(w,x,f,f>>31);k=mb;A=e;e=Xb(h,-16777216,16776704);h=Lka(s,t,e,e>>31);f=h+f|0;e=mb+k|0;e=f>>>0<h>>>0?e+1|0:e;k=f;f=Xb(i,-16777216,16776704);i=Lka(q,r,f,f>>31);f=k+i|0;e=mb+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Xc(f,e,24);v[A+4>>2]=e-(p&l);v[j>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[g+8>>2],o);v[c+4>>2]=v[c+4>>2]+B(n,v[g+12>>2]);Qb(g+16|0,y,z);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}jb=g+48|0}function z$(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;m=b;i=jb-432|0;jb=i;v[i+424>>2]=37;v[i+428>>2]=0;l=Pr(i+424|1,13830,v[c+4>>2]);v[i+380>>2]=i+384;a=Gd();a:{if(l){b=v[c+8>>2];j=i- -64|0;v[j>>2]=g;v[j+4>>2]=h;v[i+56>>2]=e;v[i+60>>2]=f;v[i+48>>2]=b;j=$g(i+384|0,30,a,i+424|0,i+48|0);break a}v[i+80>>2]=e;v[i+84>>2]=f;v[i+88>>2]=g;v[i+92>>2]=h;j=$g(i+384|0,30,a,i+424|0,i+80|0)}v[i+128>>2]=1123;k=se(i+368|0,0,i+128|0);b=i+384|0;a=b;b:{c:{d:{e:{if((j|0)>=30){a=Gd();f:{if(l){j=v[c+8>>2];v[i+16>>2]=g;v[i+20>>2]=h;v[i+8>>2]=e;v[i+12>>2]=f;v[i>>2]=j;j=Zi(i+380|0,a,i+424|0,i);break f}v[i+32>>2]=e;v[i+36>>2]=f;v[i+40>>2]=g;v[i+44>>2]=h;j=Zi(i+380|0,a,i+424|0,i+32|0)}if((j|0)==-1){v[23588]=0;Z(1124);a=v[23588];v[23588]=0;if((a|0)==1){break d}break e}a=v[i+380>>2];Ze(k,a)}f=a+j|0;g=_i(a,f,c);v[i+116>>2]=1123;e=se(i+120|0,0,i+116|0);g:{h:{if((i+384|0)==(a|0)){j=i+128|0;break h}j=Od(j<<3);if(!j){v[23588]=0;Z(1124);a=v[23588];v[23588]=0;if((a|0)!=1){break e}a=P()|0;O()|0;break g}Ze(e,j);b=a}a=i+104|0;fd(a,c);v[23588]=0;ia(1156,b|0,g|0,f|0,j|0,i+116|0,i+112|0,a|0);a=v[23588];v[23588]=0;i:{if((a|0)!=1){$b(i+104|0);v[23588]=0;a=ka(1157,m|0,j|0,v[i+116>>2],v[i+112>>2],c|0,d|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break i}Wc(e);Wc(k);jb=i+432|0;break b}a=P()|0;O()|0;$b(i+104|0);break g}a=P()|0;O()|0}Wc(e);break c}L()}a=P()|0;O()|0}Wc(k);T(a|0);L()}return a|0}function J$(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;m=b;i=jb-256|0;jb=i;v[i+248>>2]=37;v[i+252>>2]=0;l=Pr(i+248|1,13830,v[c+4>>2]);v[i+204>>2]=i+208;a=Gd();a:{if(l){b=v[c+8>>2];j=i- -64|0;v[j>>2]=g;v[j+4>>2]=h;v[i+56>>2]=e;v[i+60>>2]=f;v[i+48>>2]=b;j=$g(i+208|0,30,a,i+248|0,i+48|0);break a}v[i+80>>2]=e;v[i+84>>2]=f;v[i+88>>2]=g;v[i+92>>2]=h;j=$g(i+208|0,30,a,i+248|0,i+80|0)}v[i+128>>2]=1123;k=se(i+192|0,0,i+128|0);b=i+208|0;a=b;b:{c:{d:{e:{if((j|0)>=30){a=Gd();f:{if(l){j=v[c+8>>2];v[i+16>>2]=g;v[i+20>>2]=h;v[i+8>>2]=e;v[i+12>>2]=f;v[i>>2]=j;j=Zi(i+204|0,a,i+248|0,i);break f}v[i+32>>2]=e;v[i+36>>2]=f;v[i+40>>2]=g;v[i+44>>2]=h;j=Zi(i+204|0,a,i+248|0,i+32|0)}if((j|0)==-1){v[23588]=0;Z(1124);a=v[23588];v[23588]=0;if((a|0)==1){break d}break e}a=v[i+204>>2];Ze(k,a)}f=a+j|0;g=_i(a,f,c);v[i+116>>2]=1123;e=se(i+120|0,0,i+116|0);g:{h:{if((i+208|0)==(a|0)){j=i+128|0;break h}j=Od(j<<1);if(!j){v[23588]=0;Z(1124);a=v[23588];v[23588]=0;if((a|0)!=1){break e}a=P()|0;O()|0;break g}Ze(e,j);b=a}a=i+104|0;fd(a,c);v[23588]=0;ia(1151,b|0,g|0,f|0,j|0,i+116|0,i+112|0,a|0);a=v[23588];v[23588]=0;i:{if((a|0)!=1){$b(i+104|0);v[23588]=0;a=ka(15,m|0,j|0,v[i+116>>2],v[i+112>>2],c|0,d|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break i}Wc(e);Wc(k);jb=i+256|0;break b}a=P()|0;O()|0;$b(i+104|0);break g}a=P()|0;O()|0}Wc(e);break c}L()}a=P()|0;O()|0}Wc(k);T(a|0);L()}return a|0}function Eda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0,A=0;g=jb-48|0;jb=g;m=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;f=e+(g+24|0)|0;e=a+e|0;v[f+4>>2]=v[e+44>>2];v[f+8>>2]=v[e+48>>2];b=b+1|0;continue}break}n=v[a+24>>2];o=v[a+20>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;p=v[a+72>>2];b=v[a+68>>2];q=b;r=b>>31;b=v[a+64>>2];s=b;u=b>>31;b=v[a+60>>2];w=b;x=b>>31;y=v[a+8>>2];z=v[a+12>>2];while(1){if(d){b=v[g+16>>2];j=b>>>10&4194048;i=(((v[g+20>>2]&2147483647)<<1|b>>>31)&-2)+m|0;b=0;e=0;while(1){if((e|0)!=2){h=e+i|0;f=t[h|0];v[(g+8|0)+(e<<2)>>2]=((B(j,t[h+2|0]-f|0)|0)/16384|0)+(f<<8);e=e+1|0;continue}break}while(1){if((b|0)!=2){j=(g+8|0)+(b<<2)|0;f=v[j>>2];e=(g+24|0)+(b<<3)|0;i=v[e+8>>2];h=v[e+4>>2];v[e+8>>2]=h;l=f<<8;f=l;f=Lka(w,x,f,f>>31);k=mb;A=e;e=Xb(h,-16777216,16776704);h=Lka(s,u,e,e>>31);f=h+f|0;e=mb+k|0;e=f>>>0<h>>>0?e+1|0:e;k=f;f=Xb(i,-16777216,16776704);i=Lka(q,r,f,f>>31);f=k+i|0;e=mb+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Xc(f,e,24);v[A+4>>2]=e-(p&l);v[j>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[g+8>>2],o);v[c+4>>2]=v[c+4>>2]+B(n,v[g+12>>2]);Qb(g+16|0,y,z);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}jb=g+48|0}function Tda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0;g=jb-48|0;jb=g;n=v[a+16>>2];k=Sf(1,2);b=mb;o=b;Qb(a,k,b);b=0;while(1){if((b|0)!=2){e=b<<3;f=e+(g+24|0)|0;e=a+e|0;v[f+4>>2]=v[e+44>>2];v[f+8>>2]=v[e+48>>2];b=b+1|0;continue}break}p=v[a+24>>2];q=v[a+20>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;r=v[a+72>>2];b=v[a+68>>2];s=b;t=b>>31;b=v[a+64>>2];w=b;x=b>>31;b=v[a+60>>2];y=b;z=b>>31;A=v[a+8>>2];C=v[a+12>>2];while(1){if(d){d=d-1|0;f=((((v[g+20>>2]&2147483647)<<1|v[g+16>>2]>>>31)&2147483646)<<1)+n|0;b=0;e=0;while(1){if((e|0)!=2){v[(g+8|0)+(e<<2)>>2]=u[f+(e<<1)>>1];e=e+1|0;continue}break}while(1){if((b|0)!=2){l=(g+8|0)+(b<<2)|0;f=v[l>>2];e=(g+24|0)+(b<<3)|0;i=v[e+8>>2];h=v[e+4>>2];v[e+8>>2]=h;m=f<<8;f=m;f=Lka(y,z,f,f>>31);j=mb;D=e;e=Xb(h,-16777216,16776704);h=Lka(w,x,e,e>>31);f=h+f|0;e=mb+j|0;e=f>>>0<h>>>0?e+1|0:e;j=f;f=Xb(i,-16777216,16776704);i=Lka(s,t,f,f>>31);f=j+i|0;e=mb+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Xc(f,e,24);v[D+4>>2]=e-(r&m);v[l>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[g+8>>2],q);v[c+4>>2]=v[c+4>>2]+B(p,v[g+12>>2]);Qb(g+16|0,A,C);c=c+8|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}lg(a,k,o);jb=g+48|0}function T$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=jb-384|0;jb=a;v[a+368>>2]=c;v[a+376>>2]=b;vw(a+216|0,d,a+240|0,a+236|0,a+232|0);d=Lb(a+200|0);b=ad(d);v[23588]=0;R(60,d|0,b|0);b=v[23588];v[23588]=0;a:{b:{c:{if((b|0)!=1){c=Sc(d,0);v[a+196>>2]=c;v[a+28>>2]=a+32;v[a+24>>2]=0;t[a+23|0]=1;t[a+22|0]=69;h=v[a+232>>2];i=v[a+236>>2];while(1){d:{v[23588]=0;b=Q(1141,a+376|0,a+368|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break d}if(!b){break c}g=v[a+196>>2];b=Gb(d);if((g|0)==(b+c|0)){v[23588]=0;R(60,d|0,b<<1);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=ad(d);v[23588]=0;R(60,d|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=Sc(d,0);v[a+196>>2]=b+c}v[23588]=0;b=S(1143,v[a+376>>2])|0;g=v[23588];v[23588]=0;if((g|0)==1){break d}if(uw(b,a+23|0,a+22|0,c,a+196|0,i,h,a+216|0,a+32|0,a+28|0,a+24|0,a+240|0)){break c}v[23588]=0;S(1145,a+376|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Gb(a+216|0)|!w[a+23|0]){break e}b=v[a+28>>2];if((b-(a+32|0)|0)>159){break e}v[a+28>>2]=b+4;v[b>>2]=v[a+24>>2]}rG(a,c,v[a+196>>2],e);b=v[a>>2];c=v[a+4>>2];h=v[a+12>>2];v[f+8>>2]=v[a+8>>2];v[f+12>>2]=h;v[f>>2]=b;v[f+4>>2]=c;Ff(a+216|0,a+32|0,v[a+28>>2],e);v[23588]=0;b=Q(1142,a+376|0,a+368|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+376>>2];yb(d);yb(a+216|0);jb=a+384|0;break a}}b=P()|0;O()|0;yb(d);yb(a+216|0);T(b|0);L()}return b|0}function a0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=jb-288|0;jb=a;v[a+272>>2]=c;v[a+280>>2]=b;zw(a+224|0,d,a+240|0,a+239|0,a+238|0);d=Lb(a+208|0);b=ad(d);v[23588]=0;R(60,d|0,b|0);b=v[23588];v[23588]=0;a:{b:{c:{if((b|0)!=1){c=Sc(d,0);v[a+204>>2]=c;v[a+28>>2]=a+32;v[a+24>>2]=0;t[a+23|0]=1;t[a+22|0]=69;h=t[a+238|0];i=t[a+239|0];while(1){d:{v[23588]=0;b=Q(1125,a+280|0,a+272|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break d}if(!b){break c}g=v[a+204>>2];b=Gb(d);if((g|0)==(b+c|0)){v[23588]=0;R(60,d|0,b<<1);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=ad(d);v[23588]=0;R(60,d|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=Sc(d,0);v[a+204>>2]=b+c}v[23588]=0;b=S(1127,v[a+280>>2])|0;g=v[23588];v[23588]=0;if((g|0)==1){break d}if(yw(b,a+23|0,a+22|0,c,a+204|0,i,h,a+224|0,a+32|0,a+28|0,a+24|0,a+240|0)){break c}v[23588]=0;S(1129,a+280|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Gb(a+224|0)|!w[a+23|0]){break e}b=v[a+28>>2];if((b-(a+32|0)|0)>159){break e}v[a+28>>2]=b+4;v[b>>2]=v[a+24>>2]}rG(a,c,v[a+204>>2],e);b=v[a>>2];c=v[a+4>>2];h=v[a+12>>2];v[f+8>>2]=v[a+8>>2];v[f+12>>2]=h;v[f>>2]=b;v[f+4>>2]=c;Ff(a+224|0,a+32|0,v[a+28>>2],e);v[23588]=0;b=Q(1126,a+280|0,a+272|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+280>>2];yb(d);yb(a+224|0);jb=a+288|0;break a}}b=P()|0;O()|0;yb(d);yb(a+224|0);T(b|0);L()}return b|0}function P7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;j=jb-16|0;jb=j;i=jb-32|0;jb=i;h=of(i+16|0,1,0);a:{b:{c:{while(1){g=zc(h);d=g+Gb(h)|0;c=v[b>>2];f=v[b+4>>2];if(!((f|0)>0|(f|0)>=0|(d|0)==(g|0))){t[g|0]=45;e=c;c=0-c|0;g=g+1|0;f=0-(f+((e|0)!=0)|0)|0}k=d-g|0;d:{if((k|0)<=19){e=E(f);e=B(64-((e|0)==32?E(c|1)+32|0:e)|0,1233)>>12;n=(e<<3)+25792|0;l=k;k=v[n+4>>2];m=61;if((l|0)<(((f|0)==(k|0)&c>>>0>=y[n>>2]|f>>>0>k>>>0)+e|0)){break d}}e:{if(!f&c>>>0<=99999999){d=Zw(g,c);break e}if((f|0)==2328306&c>>>0<=1874919423|f>>>0<2328306){d=Oka(c,f,1e8,0);e=mb;l=Zw(g,d);d=Lka(d,e,-1e8,0)+c|0;c=d;d=(c>>>0)/1e4|0;d=dj(dj(l,d),c+B(d,-1e4)|0);break e}d=Oka(c,f,1874919424,2328306);e=mb;g=Yw(g,d);d=Lka(d,e,-1874919424,-2328307)+c|0;e=f+mb|0;e=c>>>0>d>>>0?e+1|0:e;c=Oka(d,e,1e8,0);e=mb;f=(c>>>0)/1e4|0;l=dj(dj(g,f),c+B(f,-1e4)|0);c=Lka(c,e,-1e8,0)+d|0;d=(c>>>0)/1e4|0;d=dj(dj(l,d),c+B(d,-1e4)|0)}m=0}v[i+12>>2]=m;v[i+8>>2]=d;if(!v[i+12>>2]){break c}c=ch(Gb(h));v[23588]=0;R(59,h|0,c|0);c=v[23588];v[23588]=0;if((c|0)!=1){continue}break}break b}b=v[i+8>>2];c=zc(h);v[23588]=0;R(60,h|0,b-c|0);b=v[23588];v[23588]=0;f:{if((b|0)!=1){v[23588]=0;R(61,j|0,h|0);b=v[23588];v[23588]=0;if((b|0)!=1){break f}break b}break b}yb(h);jb=i+32|0;break a}a=P()|0;O()|0;yb(h);T(a|0);L()}v[23588]=0;R(58,a|0,j|0);a=v[23588];v[23588]=0;if((a|0)!=1){yb(j);jb=j+16|0;return}a=P()|0;O()|0;yb(j);T(a|0);L()}function tj(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{if(!Zd(v[a>>2],v[a+20>>2])){break a}Ck(a);b:{switch(Zm(x[a+34>>1])-1|0){case 1:e=jb+-64|0;jb=e;h=v[a+20>>2];c=v[a>>2];d=Kd(x[a+34>>1]);f=h+(B(c,d)<<1)|0;while(1){c:{d:{if((g|0)!=16){i=B(d,g);j=B(d,g^-1);c=0;break d}g=f+(d<<5)|0;c=x[a+34>>1];if(c&2){i=v[a+8>>2];f=v[a+4>>2];Cb(e+32|0,b+1074312|0,33);sP(e+40|0,g,h+(B(d,f)<<1)|0,i-f|0,d,(c&4)>>>2|0,Bb(v[v[e+32>>2]>>2],v[e+36>>2]));c=x[a+34>>1]}if(c&8){f=v[a+16>>2];a=v[a+12>>2];Cb(e+32|0,b+1074312|0,33);sP(e+8|0,g+(d<<7)|0,h+(B(a,d)<<1)|0,f-a|0,d,(c&16)>>>4|0,Bb(v[v[e+32>>2]>>2],v[e+36>>2]))}jb=e- -64|0;break c}while(1){if((c|0)!=(d|0)){u[f+(c+i<<1)>>1]=x[f+(c-d<<1)>>1];u[h+(c+j<<1)>>1]=x[h+(c<<1)>>1];c=c+1|0;continue}break}g=g+1|0;continue}break};return;case 0:break b;default:break a}}e=jb+-64|0;jb=e;h=v[a+20>>2];c=v[a>>2];d=Kd(x[a+34>>1]);f=h+B(c,d)|0;while(1){e:{f:{if((g|0)!=16){i=B(d,g);j=B(d,g^-1);c=0;break f}g=f+(d<<4)|0;c=x[a+34>>1];if(c&2){i=v[a+8>>2];f=v[a+4>>2];Cb(e+32|0,b+1074312|0,33);rP(e+40|0,g,h+B(d,f)|0,i-f|0,d,(c&4)>>>2|0,Bb(v[v[e+32>>2]>>2],v[e+36>>2]));c=x[a+34>>1]}if(c&8){f=v[a+16>>2];a=v[a+12>>2];Cb(e+32|0,b+1074312|0,33);rP(e+8|0,g+(d<<6)|0,h+B(a,d)|0,f-a|0,d,(c&16)>>>4|0,Bb(v[v[e+32>>2]>>2],v[e+36>>2]))}jb=e- -64|0;break e}while(1){if((c|0)!=(d|0)){t[f+(c+i|0)|0]=w[f+(c-d|0)|0];t[h+(c+j|0)|0]=w[c+h|0];c=c+1|0;continue}break}g=g+1|0;continue}break}}}function kW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=jb-32|0;jb=f;yc(c);while(1){a:{if(!Pb(v[c>>2],v[c+8>>2],3)){break a}d=f+24|0;Wq(d,c);i=Nc(d);h=Se(d);d=w[f+24|0];if(d>>>0>=y[a+12>>2]){break a}g=id(v[a>>2],v[v[a+48>>2]+12>>2],d,b);d=w[i|0];if(d>>>0<=126){if(!(d|w[h|0])){t[g|0]=254;continue}t[g|0]=d+1;if(w[h|0]==255){continue}t[g+2|0]=1;t[g+4|0]=w[h|0];continue}b:{switch(d-127|0){case 1:t[g+1|0]=w[h|0]+1;continue;case 0:continue;default:break b}}e=t[h|0];t[f+23|0]=e;h=0;j=w[i|0];d=j&127;if(d>>>0<=23){h=w[d+26192|0]}c:{d:{e:{f:{g:{switch(d-2|0){case 0:case 8:case 9:if((e|0)>=0){break f}d=0-e&15;break e;case 1:t[f+16|0]=64;e=w[Wb(f+23|0,f+16|0)|0];if(w[g+2|0]>1){break d}t[g+4|0]=e;t[g+2|0]=1;continue;case 2:d=3;if((e|0)>=0){break c}d=0-e&127;break e;case 15:if(!e){continue}d=0-e|-16;if((e|0)<0){break e}d=e<<4|15;break e;case 16:case 20:if(!e){continue}d=(e|0)>=0;if(!d){e=0-e&15;t[f+23|0]=e;j=w[i|0]}d=d?3:2;e=((j|0)==22?-32:-16)|e;t[f+23|0]=e;break c;case 17:d=e&15|-48;break e;case 18:d=e&15|-64;break e;case 21:break g;default:break d}}d=164;if((e|0)==100){break e}v[f+16>>2]=e- -64;v[f+12>>2]=0;v[f+8>>2]=128;e=v[Ij(f+16|0,f+12|0,f+8|0)>>2];if(!w[g+3|0]){break d}h:{switch(w[g+2|0]){case 0:case 2:break h;default:continue}}t[g+2|0]=2;t[g+4|0]=(e&254)>>>1;continue}d=e<<4}e=d;t[f+23|0]=e}d=h;if(!d){continue}}t[g+5|0]=e;t[g+3|0]=d;continue}break}jb=f+32|0}function Uda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0;g=jb-48|0;jb=g;n=v[a+16>>2];k=Sf(1,2);b=mb;o=b;Qb(a,k,b);b=0;while(1){if((b|0)!=2){e=b<<3;f=e+(g+24|0)|0;e=a+e|0;v[f+4>>2]=v[e+44>>2];v[f+8>>2]=v[e+48>>2];b=b+1|0;continue}break}p=v[a+24>>2];q=v[a+20>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;r=v[a+72>>2];b=v[a+68>>2];s=b;u=b>>31;b=v[a+64>>2];w=b;x=b>>31;b=v[a+60>>2];y=b;z=b>>31;A=v[a+8>>2];C=v[a+12>>2];while(1){if(d){d=d-1|0;f=(((v[g+20>>2]&2147483647)<<1|v[g+16>>2]>>>31)&-2)+n|0;b=0;e=0;while(1){if((e|0)!=2){v[(g+8|0)+(e<<2)>>2]=t[e+f|0]<<8;e=e+1|0;continue}break}while(1){if((b|0)!=2){l=(g+8|0)+(b<<2)|0;f=v[l>>2];e=(g+24|0)+(b<<3)|0;i=v[e+8>>2];h=v[e+4>>2];v[e+8>>2]=h;m=f<<8;f=m;f=Lka(y,z,f,f>>31);j=mb;D=e;e=Xb(h,-16777216,16776704);h=Lka(w,x,e,e>>31);f=h+f|0;e=mb+j|0;e=f>>>0<h>>>0?e+1|0:e;j=f;f=Xb(i,-16777216,16776704);i=Lka(s,u,f,f>>31);f=j+i|0;e=mb+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Xc(f,e,24);v[D+4>>2]=e-(r&m);v[l>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[g+8>>2],q);v[c+4>>2]=v[c+4>>2]+B(p,v[g+12>>2]);Qb(g+16|0,A,C);c=c+8|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}lg(a,k,o);jb=g+48|0}function Oq(a,b,c,d){var e=0,f=0;e=jb-16|0;jb=e;t[e+15|0]=c;a:{b:{c:{d:{switch(b-2|0){case 11:t[e+14|0]=64;de(a,1,Wb(e+15|0,e+14|0));break a;case 0:if(!(c&3|c>>>0>223?d:1)){break c}t[e+14|0]=c>>>2;de(a,12,e+14|0);break a;case 1:if(!(c&3|c>>>0>223?d:1)){break c}t[e+14|0]=c>>>2;de(a,13,e+14|0);break a;case 2:if(c>>>0>=240){t[e+14|0]=9;de(a,11,e+14|0);break a}b=0;while(1){if((b|0)==10){break c}f=w[b+43744|0];e:{if(d){if(c>>>0>f>>>0){break e}break b}if((c|0)==(f|0)){break b}}b=b+1|0;continue};case 3:f:{if(d){t[e+14|0]=c&15;t[e+13|0]=9;c=w[Wb(e+14|0,e+13|0)|0];t[e+15|0]=c;break f}if(c&240|(c&14)>>>0>9){break c}}t[e+14|0]=c&15;de(a,8,e+14|0);break a;case 24:g:{if(d){t[e+15|0]=0;break g}if(c){break c}}de(a,8,e+15|0);break a;case 7:t[e+15|0]=(c|0)==255?64:c>>>2|0;de(a,2,e+15|0);break a;case 9:if(!c){break c}b=c&15;if(!b){t[e+14|0]=c>>>4;de(a,3,e+14|0);break a}d=c&240;if(!d){de(a,4,e+15|0);break a}if((b|0)==15){t[e+14|0]=c>>>4;de(a,5,e+14|0);break a}if((d|0)!=240){break c}t[e+14|0]=c&15;de(a,6,e+14|0);break a;case 18:if((c&240)!=128){break c}t[e+14|0]=c<<2&60|2;de(a,2,e+14|0);break a;case 17:break d;default:break c}}h:{switch((c>>>4|0)-8|0){case 0:t[e+14|0]=c<<2&60|2;de(a,2,e+14|0);break a;case 2:t[e+14|0]=c&15;de(a,5,e+14|0);break a;case 3:break h;default:break c}}t[e+14|0]=c&15;de(a,6,e+14|0);break a}t[e+14|0]=0;de(a,0,e+14|0);break a}t[e+14|0]=b;de(a,11,e+14|0)}jb=e+16|0}function uca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0;g=jb-16|0;jb=g;s=v[a+16>>2];t=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);n=v[a+128>>2];a:{if(!n){k=v[a+8>>2];l=v[a+12>>2];i=v[a>>2];e=v[a+4>>2];m=0;break a}k=v[a+8>>2];l=v[a+12>>2];o=kg(k,l,n);p=mb;b=v[a+76>>2];i=v[a>>2];e=v[a+4>>2];Pf(i,e,kf(k,l,d),mb);m=b>>>0<mb>>>0?d:0}h=a+112|0;f=v[a+48>>2];w=v[a+24>>2];x=v[a+20>>2];b=v[a+44>>2];v[g>>2]=i;v[g+4>>2]=e;b:while(1){c:{q=b;if(!d){break c}d=d-1|0;v[g+8>>2]=i;v[g+12>>2]=0;m=m-1|0;b=m;o=b?o:0;p=b?p:0;e=(e<<1)+s|0;b=n;while(1)if((b|0)<=0){Qb(h,v[a+120>>2],v[a+124>>2]);b=v[a+116>>2];if(b){Rd(h,u[e+(v[g+12>>2]<<1)>>1]/4<<16>>16);Qd(h,b);v[h>>2]=v[h>>2];v[h+4>>2]=0}i=v[a+72>>2];b=v[a+60>>2];e=b;j=b>>31;r=ig(h,t)<<8;b=r;b=Lka(e,j,b,b>>31);y=mb;e=b;b=v[a+64>>2];j=b;z=b>>31;b=Xb(q,-16777216,16776704);j=Lka(j,z,b,b>>31);e=e+j|0;b=mb+y|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=v[a+68>>2];f=Xb(f,-16777216,16776704);e=Lka(e,e>>31,f,f>>31);f=j+e|0;b=mb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Xc(f,b,24);f=(b|0)/256|0;v[c>>2]=B(f,x)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(f,w);Qb(g,k,l);b=b-(i&r)|0;c=c+8|0;i=v[g>>2];e=v[g+4>>2];f=q;continue b}else{Rd(h,u[e+(v[g+12>>2]<<1)>>1]/4<<16>>16);Qd(h,4);Qb(g+8|0,o,p);b=b-1|0;continue}}break}v[a>>2]=i;v[a+4>>2]=e;v[a+48>>2]=f;v[a+44>>2]=q;jb=g+16|0}function S$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=jb-352|0;jb=a;v[a+336>>2]=c;v[a+344>>2]=b;h=Lb(a+208|0);b=a+16|0;fd(b,d);v[23588]=0;b=S(1136,b|0)|0;c=v[23588];v[23588]=0;a:{b:{c:{d:{if((c|0)==1){break d}v[23588]=0;X(1148,b|0,82976,83002,a+224|0);b=v[23588];v[23588]=0;if((b|0)==1){break d}$b(a+16|0);c=Lb(a+192|0);b=ad(c);v[23588]=0;R(60,c|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break b}b=Sc(c,0);v[a+188>>2]=b;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){e:{v[23588]=0;d=Q(1141,a+344|0,a+336|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break e}if(!d){break c}g=v[a+188>>2];d=Gb(c);if((g|0)==(d+b|0)){v[23588]=0;R(60,c|0,d<<1);b=v[23588];v[23588]=0;if((b|0)==1){break b}b=ad(c);v[23588]=0;R(60,c|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break b}b=Sc(c,0);v[a+188>>2]=d+b}v[23588]=0;d=S(1143,v[a+344>>2])|0;g=v[23588];v[23588]=0;if((g|0)==1){break e}if(xn(d,16,b,a+188|0,a+8|0,0,h,a+16|0,a+12|0,a+224|0)){break c}v[23588]=0;S(1145,a+344|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){continue}}break}break b}b=P()|0;O()|0;$b(a+16|0);break a}v[23588]=0;R(60,c|0,v[a+188>>2]-b|0);b=v[23588];v[23588]=0;f:{if((b|0)==1){break f}b=Lc(c);d=Gd();v[a>>2]=f;if((qG(b,d,a)|0)!=1){v[e>>2]=4}v[23588]=0;b=Q(1142,a+344|0,a+336|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];yb(c);yb(h);jb=a+352|0;return b|0}}b=P()|0;O()|0;yb(c)}yb(h);T(b|0);L()}function hE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-96|0;jb=c;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(!b){xc(a,9700);break j}if(!(b&65535)){d=jb-16|0;jb=d;e=xc(d,4402);$c(c+80|0,e);zb(e);jb=d+16|0;v[23588]=0;v[c+24>>2]=b>>>24;R(109,c- -64|0,c+24|0);d=v[23588];v[23588]=0;k:{l:{m:{n:{if((d|0)!=1){v[23588]=0;v[c+8>>2]=b>>>16&255;R(110,c+48|0,c+8|0);b=v[23588];v[23588]=0;if((b|0)==1){break n}v[23588]=0;X(111,a|0,c+80|0,c- -64|0,c+48|0);a=v[23588];v[23588]=0;if((a|0)==1){break m}zb(c+48|0);zb(c- -64|0);ac(c+80|0);break j}b=P()|0;O()|0;break k}b=P()|0;O()|0;break l}b=P()|0;O()|0;zb(c+48|0)}zb(c- -64|0)}break a}d=jb-16|0;jb=d;e=xc(d,4126);$c(c+80|0,e);zb(e);jb=d+16|0;v[23588]=0;v[c+44>>2]=b>>>24;R(109,c- -64|0,c+44|0);d=v[23588];v[23588]=0;if((d|0)==1){break i}v[23588]=0;v[c+40>>2]=b>>>16&255;R(110,c+48|0,c+40|0);d=v[23588];v[23588]=0;if((d|0)==1){break h}v[23588]=0;v[c+20>>2]=b>>>8&255;R(110,c+24|0,c+20|0);d=v[23588];v[23588]=0;if((d|0)==1){break g}v[23588]=0;v[c+4>>2]=b&255;R(110,c+8|0,c+4|0);b=v[23588];v[23588]=0;if((b|0)==1){break f}v[23588]=0;ma(112,a|0,c+80|0,c- -64|0,c+48|0,c+24|0,c+8|0);a=v[23588];v[23588]=0;if((a|0)==1){break e}zb(c+8|0);zb(c+24|0);zb(c+48|0);zb(c- -64|0);ac(c+80|0)}jb=c+96|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;zb(c+8|0)}zb(c+24|0)}zb(c+48|0)}zb(c- -64|0)}ac(c+80|0);T(b|0);L()}function _ca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0;h=jb-16|0;jb=h;a:{b:{c:{i=v[a+12>>2];j=v[a+8>>2];d:{if((i|0)<=1&j>>>0<=805306368|(i|0)<=0){if((i|0)>=-2&j>>>0>=3489660928|(i|0)>-2){break c}if((i|0)==-2&j>>>0>2147483647|i>>>0>4294967294){break d}break b}if((i|0)==1&j>>>0>2147483648|i>>>0>1){break b}}n=b+196648|0;break a}n=b+131112|0;break a}n=b+262184|0}o=v[a+16>>2];f=v[a+48>>2];p=v[a+24>>2];q=v[a+20>>2];b=v[a+44>>2];e=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=e;r=v[a+72>>2];e=v[a+68>>2];s=e;t=e>>31;e=v[a+64>>2];w=e;x=e>>31;e=v[a+60>>2];y=e;z=e>>31;while(1){e=b;if(d){b=Xb(e,-16777216,16776704);b=Lka(w,x,b,b>>31);k=mb;l=b;g=(v[h+12>>2]<<1)+o|0;b=(v[h+8>>2]>>>16&65520)+n|0;g=(((((((B(u[g-4>>1],u[b+2>>1])+B(u[g-6>>1],u[b>>1])|0)+B(u[g-2>>1],u[b+4>>1])|0)+B(u[g>>1],u[b+6>>1])|0)+B(u[g+2>>1],u[b+8>>1])|0)+B(u[g+4>>1],u[b+10>>1])|0)+B(u[g+6>>1],u[b+12>>1])|0)+B(u[g+8>>1],u[b+14>>1])|0)/32768<<8;b=g;b=Lka(b,b>>31,y,z);l=l+b|0;m=mb+k|0;m=b>>>0>l>>>0?m+1|0:m;b=Xb(f,-16777216,16776704);f=Lka(s,t,b,b>>31);k=f+l|0;b=mb+m|0;b=f>>>0>k>>>0?b+1|0:b;f=k+8388608|0;b=f>>>0<8388608?b+1|0:b;f=Xc(f,b,24);b=(f|0)/256|0;v[c>>2]=B(b,q)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(b,p);Qb(h+8|0,j,i);b=f-(g&r)|0;c=c+8|0;d=d-1|0;f=e;continue}break}b=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=b;v[a+48>>2]=f;v[a+44>>2]=e;jb=h+16|0}function $$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=jb-272|0;jb=a;v[a+256>>2]=c;v[a+264>>2]=b;h=Lb(a+208|0);b=a+16|0;fd(b,d);v[23588]=0;b=S(19,b|0)|0;c=v[23588];v[23588]=0;a:{b:{c:{d:{if((c|0)==1){break d}v[23588]=0;X(1134,b|0,82976,83002,a+224|0);b=v[23588];v[23588]=0;if((b|0)==1){break d}$b(a+16|0);c=Lb(a+192|0);b=ad(c);v[23588]=0;R(60,c|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break b}b=Sc(c,0);v[a+188>>2]=b;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){e:{v[23588]=0;d=Q(1125,a+264|0,a+256|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break e}if(!d){break c}g=v[a+188>>2];d=Gb(c);if((g|0)==(d+b|0)){v[23588]=0;R(60,c|0,d<<1);b=v[23588];v[23588]=0;if((b|0)==1){break b}b=ad(c);v[23588]=0;R(60,c|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break b}b=Sc(c,0);v[a+188>>2]=d+b}v[23588]=0;d=S(1127,v[a+264>>2])|0;g=v[23588];v[23588]=0;if((g|0)==1){break e}if(yn(d,16,b,a+188|0,a+8|0,0,h,a+16|0,a+12|0,a+224|0)){break c}v[23588]=0;S(1129,a+264|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){continue}}break}break b}b=P()|0;O()|0;$b(a+16|0);break a}v[23588]=0;R(60,c|0,v[a+188>>2]-b|0);b=v[23588];v[23588]=0;f:{if((b|0)==1){break f}b=Lc(c);d=Gd();v[a>>2]=f;if((qG(b,d,a)|0)!=1){v[e>>2]=4}v[23588]=0;b=Q(1126,a+264|0,a+256|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];yb(c);yb(h);jb=a+272|0;return b|0}}b=P()|0;O()|0;yb(c)}yb(h);T(b|0);L()}function $X(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=Lb(a);a=w[b+11|0];g=v[b+4>>2];v[23588]=0;k=Fk(g,a);R(115,h|0,k|0);a=v[23588];v[23588]=0;a:{b:{if((a|0)!=1){g=0;a=0;while(1){c:{if((a|0)==(k|0)){a=!f;if(!(l?a&(m^-1):a)){break c}return}e=w[od(b)+a|0];d:{e:{f:{g:{switch(f+1|0){case 1:f=1;h:{switch(e-123|0){case 2:break h;case 0:break d;default:break f}}f=3;break d;case 2:i:{switch(e-123|0){case 2:m=1;e=g+1|0;f=0;if(d>>>0<=g>>>0){g=e;break d}v[23588]=0;Q(116,h|0,Md(c,g)|0)|0;j=v[23588];v[23588]=0;g=e;if((j|0)!=1){break d}a=P()|0;O()|0;break b;case 0:break f;default:break i}}f=-1;e=e-48|0;if((e&255)>>>0>9){break d}l=1;f=2;i=e;break d;case 3:f=-1;j:{switch(e-123|0){case 2:f=0;if(d>>>0<=i>>>0){break d}v[23588]=0;Q(116,h|0,Md(c,i)|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){break d}a=P()|0;O()|0;break b;case 0:break d;default:break j}}if((e-48&255)>>>0>9){break d}i=(B(i,10)+e|0)-48|0;l=1;f=2;break d;case 4:break g;case 0:break e;default:break d}}j=(e|0)!=125;f=-1;e=125;if(j){break d}}f=0;v[23588]=0;Q(117,h|0,e|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){break d}a=P()|0;O()|0;break b}f=-1}a=a+1|0;continue}break}b=ba(8)|0;v[23588]=0;a=S(118,b|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){v[23588]=0;U(119,a|0,41812,25);a=v[23588];v[23588]=0;if((a|0)!=1){break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;ca(b|0);break b}a=P()|0;O()|0}zb(h);T(a|0)}L()}function hea(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=jb-48|0;jb=e;u[e+46>>1]=254;c=sj(a);f=e+32|0;v[f>>2]=0;v[f+4>>2]=0;Gc(f+8|0);if(c){hq(f,c);sC(f,c)}a:{b:{while(1){c:{if((b|0)==(c|0)){if(!(d&65535)){break a}c=Eb(v[a>>2]);d=Eb(v[a+4>>2]);b=jb-16|0;jb=b;c=cA(c,d,x[e+46>>1]);v[b+8>>2]=c;if(Ob(c,d)){v[b>>2]=c;while(1){c=v[Re(b)>>2];if(Ob(c,d)){c=x[c>>1];if((c|0)==x[e+46>>1]){continue}u[v[b+8>>2]>>1]=c;Re(b+8|0);continue}break}c=v[b+8>>2]}jb=b+16|0;b=ec(e+24|0,c);c=v[ec(e+16|0,Eb(v[a+4>>2]))>>2];d=v[b>>2];b=v[a>>2];b=(yo(d,Eb(b))<<1)+b|0;if(Ob(d,c)){Nd(a,Pi(b+(yo(c,d)<<1)|0,v[a+4>>2],b))}Eb(b);k=e,l=Eb(v[a>>2]),v[k+8>>2]=l;d=Eb(v[a+4>>2]);break c}k=cc(v[f>>2],b),l=b-d|0,u[k>>1]=l;g=v[a+4>>2];h=v[a>>2];v[23588]=0;g=W(748,h|0,g|0,b|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break b}b=b+1|0;d=(x[g>>1]==254)+d|0;continue}break}while(1){b=v[e+8>>2];if(!Ob(b,d)){b=v[f>>2];d=Qc(b,v[f+4>>2]);c=x[a+28>>1];if(d>>>0<=c>>>0){break a}k=a,l=x[cc(b,c)>>1],u[k+28>>1]=l;break a}d:{c=v[a+24>>2];g=v[c+484344>>2];b=x[b>>1];if(!xe(g,v[c+484348>>2],b)){break d}b=Yb(g,b);k=e,l=Eb(v[b>>2]),v[k>>2]=l;g=Eb(v[b+4>>2]);h=v[f+4>>2];c=v[f>>2];while(1){b=v[e>>2];if(!Ob(b,g)){break d}e:{if(w[b+3|0]!=12){break e}j=Qc(c,h);i=w[b+5|0];if(j>>>0<=i>>>0){break e}k=b,l=w[cc(c,i)|0],t[k+5|0]=l}Bk(e);continue}}Re(e+8|0);continue}}a=P()|0;O()|0;nd(f);T(a|0);L()}nd(f);jb=e+48|0}function _y(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=jb-16|0;jb=h;f=v[c+656>>2];a:{if(!vj(f)){i=v[c+704>>2];f=jb-16|0;jb=f;v[f+12>>2]=d;g=0;b:{if(!d){break b}j=v[b+480180>>2];if(j&20){e=b+1074312|0;Cb(f,e,73);d=Bb(v[v[f>>2]>>2],v[f+4>>2])?d&65535:d;if(w[b+480208|0]&16){Cb(f,e,73);e=Bb(v[v[f>>2]>>2],v[f+4>>2])?14-((9983-d>>>0)/768|0)&31:((d>>>0)/768|0)+2|0;g=v[((d>>>0)%768<<2)+33936>>2]<<6>>>e|0;break b}if(!d){v[f+12>>2]=1;d=1}g=229079296/(d>>>0)|0;break b}g=227001280/(d>>>0)|0;if(Jm(j)){break b}g=(d+i<<4)-133808|0;if((j|0)==64){break b}wc(f+12|0,16777215);if(j&17408){g=Dc(Oka(Lka(i?i:8363,0,3506176,0),mb,(v[f+12>>2]<<8)+e|0,0),mb);break b}if(nj(b)){d=v[f+12>>2];i=d>>>24|0;j=d<<8;d=j+e|0;e=i+(e>>31)|0;g=((d>>>0<j>>>0?e+1|0:e)&15)<<28|d>>>4;break b}if(w[b+480208|0]&16){g=Dc(Oka(Lka(i?i:8363,0,7012352,0),mb,(v[f+12>>2]<<8)+e|0,0),mb);break b}g=Dc(Oka(-1485242368,13,(v[f+12>>2]<<8)+e|0,0),mb)}e=g;jb=f+16|0;f=v[c+656>>2];break a}e=v[c+700>>2]}v[h+12>>2]=e;c=u[c+774>>1];c:{if(!c){break c}c=f?B(t[f+33|0],c):c;if(!c){break c}e=Pe(mi(+(c|0)/393216)*+(e>>>0));v[h+12>>2]=e}d:{if(!f){break d}c=v[f+40>>2];if(!c){break d}d=(c|0)/2|0;f=v[b+1074420>>2];e=Lka(f,f>>31,e,e>>31);f=d+e|0;d=mb+(d>>31)|0;k=h,l=Hc(Mka(f,e>>>0>f>>>0?d+1|0:d,c,c>>31),mb),v[k+12>>2]=l}wc(h+12|0,2147483647);c=v[h+12>>2];b=Sf(c,v[b+24620>>2]<<4);v[a+8>>2]=c;v[a>>2]=b;v[a+4>>2]=mb;jb=h+16|0}function CR(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;j=jb-16|0;jb=j;a:{if((b|0)==(c|0)){break a}v[j+12>>2]=-1953789045;Zz(b,c,j+12|0);c=c-b|0;e=c>>2;v[j+8>>2]=e;f=uc(v[a>>2],v[a+4>>2]);g=11;b:{if(c>>>0>2488){break b}g=7;if(c>>>0>268){break b}g=5;if(c>>>0>152){break b}g=3;if(c>>>0>24){break b}g=e-1>>>1|0}c=f+1|0;v[j+4>>2]=c;n=v[Yc(j+4|0,j+8|0)>>2];k=e-g>>>1|0;d=(k<<2)+b|0;h=v[d>>2];i=B(Ut(v[((e<<2)+b|0)-4>>2]^(h^v[b>>2])),1664525);v[d>>2]=i+h;g=g+k|0;d=(g<<2)+b|0;f=f+i|0;v[d>>2]=f+v[d>>2];v[b>>2]=f;i=v[a>>2];a=1;while(1)if((a|0)==(c|0)){while(1)if(c>>>0>=n>>>0){c=n;while(1){if(e+n>>>0<=c>>>0){break a}d=((c+k>>>0)%(e>>>0)<<2)+b|0;h=v[d>>2];f=(c>>>0)%(e>>>0)|0;i=(f<<2)+b|0;a=B(Ut(v[((c-1>>>0)%(e>>>0)<<2)+b>>2]+(h+v[i>>2]|0)|0),1566083941);v[d>>2]=a^h;d=((c+g>>>0)%(e>>>0)<<2)+b|0;a=a-f|0;v[d>>2]=a^v[d>>2];v[i>>2]=a;c=c+1|0;continue}}else{d=((c+k>>>0)%(e>>>0)<<2)+b|0;h=v[d>>2];f=(c>>>0)%(e>>>0)|0;i=(f<<2)+b|0;a=B(Ut(v[((c-1>>>0)%(e>>>0)<<2)+b>>2]^(h^v[i>>2])),1664525);v[d>>2]=a+h;d=((c+g>>>0)%(e>>>0)<<2)+b|0;a=a+f|0;v[d>>2]=a+v[d>>2];v[i>>2]=a;c=c+1|0;continue}}else{d=a-1|0;l=((a+k>>>0)%(e>>>0)<<2)+b|0;m=v[l>>2];h=(a>>>0)%(e>>>0)|0;o=(h<<2)+b|0;f=B(Ut(v[((d>>>0)%(e>>>0)<<2)+b>>2]^(m^v[o>>2])),1664525);v[l>>2]=f+m;l=((a+g>>>0)%(e>>>0)<<2)+b|0;m=v[l>>2];f=v[Db(i,d)>>2]+(f+h|0)|0;v[l>>2]=f+m;v[o>>2]=f;a=a+1|0;continue}}jb=j+16|0}function $ca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0;h=jb-16|0;jb=h;a:{b:{c:{i=v[a+12>>2];k=v[a+8>>2];d:{if((i|0)<=1&k>>>0<=805306368|(i|0)<=0){if((i|0)>=-2&k>>>0>=3489660928|(i|0)>-2){break c}if((i|0)==-2&k>>>0>2147483647|i>>>0>4294967294){break d}break b}if((i|0)==1&k>>>0>2147483648|i>>>0>1){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}m=v[a+16>>2];b=v[a+48>>2];n=v[a+24>>2];o=v[a+20>>2];e=v[a+44>>2];f=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=f;p=v[a+72>>2];f=v[a+68>>2];q=f;r=f>>31;f=v[a+64>>2];s=f;w=f>>31;f=v[a+60>>2];x=f;y=f>>31;while(1){f=e;if(d){e=Xb(f,-16777216,16776704);e=Lka(s,w,e,e>>31);g=mb;j=e;b=Xb(b,-16777216,16776704);e=Lka(q,r,b,b>>31);j=j+e|0;b=mb+g|0;b=e>>>0>j>>>0?b+1|0:b;g=v[h+12>>2]+m|0;e=(v[h+8>>2]>>>16&65520)+l|0;g=(((((((B(t[g-2|0],u[e+2>>1])+B(t[g-3|0],u[e>>1])|0)+B(t[g-1|0],u[e+4>>1])|0)+B(t[g|0],u[e+6>>1])|0)+B(t[g+1|0],u[e+8>>1])|0)+B(t[g+2|0],u[e+10>>1])|0)+B(t[g+3|0],u[e+12>>1])|0)+B(t[g+4|0],u[e+14>>1])<<8)/32768<<8;e=g;e=Lka(e,e>>31,x,y);j=e+j|0;b=mb+b|0;b=e>>>0>j>>>0?b+1|0:b;e=j+8388608|0;b=e>>>0<8388608?b+1|0:b;e=Xc(e,b,24);b=(e|0)/256|0;v[c>>2]=B(b,o)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(b,n);Qb(h+8|0,k,i);e=e-(g&p)|0;c=c+8|0;d=d-1|0;b=f;continue}break}c=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=c;v[a+48>>2]=b;v[a+44>>2]=f;jb=h+16|0}function tka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=Lb(a);k=Gb(b);v[23588]=0;R(297,h|0,k|0);a=v[23588];v[23588]=0;a:{b:{if((a|0)!=1){a=0;while(1){c:{if((a|0)==(k|0)){a=!f;if(!(l?a&(m^-1):a)){break c}return}e=t[gg(b,a)|0];g=e&255;d:{e:{f:{g:{switch(f+1|0){case 1:f=1;h:{switch(g-123|0){case 2:break h;case 0:break d;default:break f}}f=3;break d;case 2:i:{switch(g-123|0){case 2:m=1;e=i+1|0;f=0;if(d>>>0<=i>>>0){i=e;break d}v[23588]=0;Q(298,h|0,Md(c,i)|0)|0;g=v[23588];v[23588]=0;i=e;if((g|0)!=1){break d}a=P()|0;O()|0;break b;case 0:break f;default:break i}}f=-1;e=e-48|0;if((e&255)>>>0>9){break d}l=1;f=2;j=e;break d;case 3:f=-1;j:{switch(g-123|0){case 2:f=0;if(d>>>0<=j>>>0){break d}v[23588]=0;Q(298,h|0,Md(c,j)|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){break d}a=P()|0;O()|0;break b;case 0:break d;default:break j}}if((e-48&255)>>>0>9){break d}j=(B(j,10)+e|0)-48|0;l=1;f=2;break d;case 4:break g;case 0:break e;default:break d}}g=(e|0)!=125;f=-1;e=125;if(g){break d}}f=0;v[23588]=0;Q(299,h|0,e|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){break d}a=P()|0;O()|0;break b}f=-1}a=a+1|0;continue}break}b=ba(8)|0;v[23588]=0;a=S(118,b|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){v[23588]=0;U(119,a|0,41812,25);a=v[23588];v[23588]=0;if((a|0)!=1){break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;ca(b|0);break b}a=P()|0;O()|0}yb(h);T(a|0)}L()}function uZ(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;n=jb-16|0;jb=n;b=c;while(1){a:{if((b|0)==(d|0)){b=d;break a}if(!v[b>>2]){break a}b=b+4|0;continue}break}v[h>>2]=f;v[e>>2]=c;while(1){b:{c:{if(!((c|0)==(d|0)|(f|0)==(g|0))){q=1;r=jb-16|0;jb=r;s=ji(r+8|0,v[a+8>>2]);i=f;j=g-f|0;m=0;o=jb-16|0;jb=o;k=v[e>>2];p=b-c>>2;d:{if(!k|!p){break d}j=i?j:0;while(1){l=$w(j>>>0<4?o+12|0:i,v[k>>2]);if((l|0)==-1){m=-1;break d}if(i){if(j>>>0<=3){if(j>>>0<l>>>0){break d}tc(i,o+12|0,l)}j=j-l|0;i=i+l|0}else{i=0}if(!v[k>>2]){k=0;break d}m=m+l|0;k=k+4|0;p=p-1|0;if(p){continue}break}}if(i){v[e>>2]=k}jb=o+16|0;ii(s);jb=r+16|0;e:{f:{g:{h:{switch(m+1|0){case 0:v[h>>2]=f;while(1){i:{if(v[e>>2]==(c|0)){break i}b=qw(f,v[c>>2],v[a+8>>2]);if((b|0)==-1){break i}f=b+v[h>>2]|0;v[h>>2]=f;c=c+4|0;continue}break};v[e>>2]=c;break g;case 1:break c;default:break h}}f=m+v[h>>2]|0;v[h>>2]=f;if((f|0)==(g|0)){break e}if((b|0)==(d|0)){c=v[e>>2];b=d;continue}b=qw(n+12|0,0,v[a+8>>2]);if((b|0)!=-1){break f}}q=2;break c}c=n+12|0;if(g-v[h>>2]>>>0<b>>>0){break c}while(1){if(b){f=w[c|0];i=v[h>>2];v[h>>2]=i+1;t[i|0]=f;b=b-1|0;c=c+1|0;continue}break}c=v[e>>2]+4|0;v[e>>2]=c;b=c;while(1){if((b|0)==(d|0)){b=d;break b}if(!v[b>>2]){break b}b=b+4|0;continue}}c=v[e>>2]}q=(c|0)!=(d|0)}jb=n+16|0;return q|0}f=v[h>>2];continue}}function SN(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=jb-32|0;jb=e;f=v[b+64>>2];a:{b:{h=v[b+60>>2];g=x[b+68>>1];if(!((h|0)==-1&(g|0)==65535)){c:{if((f|0)==-1){break c}f=a+1074312|0;Cb(e+24|0,f,68);if(Bb(v[v[e+24>>2]>>2],v[e+28>>2])){break c}Cb(e+16|0,f,103);if(i=Bb(v[v[e+16>>2]>>2],v[e+20>>2]),j=0,k=(g|0)!=65535,k?i:j){break c}Cb(e+8|0,f,49);if(i=Bb(v[v[e+8>>2]>>2],v[e+12>>2]),j=0,k=(g|0)!=65535,k?i:j){break c}f=v[b+64>>2];break b}if((g|0)==65535){u[b+68>>1]=x[b+72>>1]+1}if((h|0)==-1){v[b+60>>2]=0}g=Qc(v[c>>2],v[c+4>>2]);f=x[b+68>>1];if(g>>>0<=f>>>0){f=x[c+28>>1];u[b+68>>1]=f}d:{if(x[b+72>>1]==(f&65535)){break d}c=a+1074312|0;Cb(e+24|0,c,26);if(Bb(v[v[e+24>>2]>>2],v[e+28>>2])){break d}Cb(e+16|0,c,68);if(Bb(v[v[e+16>>2]>>2],v[e+20>>2])|v[a+480180>>2]==1){break d}c=x[a+480188>>1];f=0;while(1){if((c|0)==(f|0)){break d}t[(B(f,872)+b|0)+1457|0]=0;f=f+1|0;continue}}v[b+52>>2]=v[b+60>>2];if(d){c=1;if(w[a+480208|0]&32){break a}}u[b+74>>1]=x[b+68>>1];c=1;break a}if((f|0)!=-1){break b}c=0;break a}v[b+52>>2]=f;u[b+74>>1]=x[b+72>>1];e:{if(!v[b+20>>2]){break e}c=v[a+480180>>2];if((c|0)==32){Cb(e+24|0,a+1074312|0,103);if(Bb(v[v[e+24>>2]>>2],v[e+28>>2])){break e}c=v[a+480180>>2]}if((c|0)==2){break e}v[b+52>>2]=v[b+52>>2]+1}c=0;if(y[b+64>>2]<y[Yb(v[a+484344>>2],x[b+70>>1])+12>>2]){break a}v[b+52>>2]=0;u[b+74>>1]=x[b+74>>1]+1;c=0}jb=e+32|0;return c}function vca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0;g=jb-16|0;jb=g;s=v[a+16>>2];u=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);n=v[a+128>>2];a:{if(!n){k=v[a+8>>2];l=v[a+12>>2];i=v[a>>2];e=v[a+4>>2];m=0;break a}k=v[a+8>>2];l=v[a+12>>2];o=kg(k,l,n);p=mb;b=v[a+76>>2];i=v[a>>2];e=v[a+4>>2];Pf(i,e,kf(k,l,d),mb);m=b>>>0<mb>>>0?d:0}h=a+112|0;f=v[a+48>>2];w=v[a+24>>2];x=v[a+20>>2];b=v[a+44>>2];v[g>>2]=i;v[g+4>>2]=e;b:while(1){c:{q=b;if(!d){break c}d=d-1|0;v[g+8>>2]=i;v[g+12>>2]=0;m=m-1|0;b=m;o=b?o:0;p=b?p:0;e=e+s|0;b=n;while(1)if((b|0)<=0){Qb(h,v[a+120>>2],v[a+124>>2]);b=v[a+116>>2];if(b){Rd(h,t[e+v[g+12>>2]|0]<<6);Qd(h,b);v[h>>2]=v[h>>2];v[h+4>>2]=0}i=v[a+72>>2];b=v[a+60>>2];e=b;j=b>>31;r=ig(h,u)<<8;b=r;b=Lka(e,j,b,b>>31);y=mb;e=b;b=v[a+64>>2];j=b;z=b>>31;b=Xb(q,-16777216,16776704);j=Lka(j,z,b,b>>31);e=e+j|0;b=mb+y|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=v[a+68>>2];f=Xb(f,-16777216,16776704);e=Lka(e,e>>31,f,f>>31);f=j+e|0;b=mb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Xc(f,b,24);f=(b|0)/256|0;v[c>>2]=B(f,x)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(f,w);Qb(g,k,l);b=b-(i&r)|0;c=c+8|0;i=v[g>>2];e=v[g+4>>2];f=q;continue b}else{Rd(h,t[e+v[g+12>>2]|0]<<6);Qd(h,4);Qb(g+8|0,o,p);b=b-1|0;continue}}break}v[a>>2]=i;v[a+4>>2]=e;v[a+48>>2]=f;v[a+44>>2]=q;jb=g+16|0}function vy(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=89;i=88;j=92;k=91;l=85;m=84;n=83;o=5;p=113;q=111;r=107;s=106;t=96;u=82;v=80;w=78;x=79;y=77;z=57;A=47;d=10;e=8;f=7;c=hr(a);a:{b:{c:{d:{switch(b-1|0){default:a=(b|0)==16777216;if(!a&(b|0)!=32){break c}Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(c,0,1),7,1),8,1),9,1),10,1),11,1),12,1),13,1),14,1),15,1),16,1),17,1),18,1),19,1),20,1),21,1),22,1),23,1),24,1),25,1),26,1),27,1),28,1),29,1),30,1),31,1),32,1),33,1),34,1),35,1),36,1),37,1),38,1),39,1),40,1),41,1),42,1),43,1),44,1),45,1),46,1),47,1),48,1),103,1),50,1),87,1),88,1),100,1),102,1),104,1),115,1);if(!a){break a}d=111;e=105;f=99;break b;case 3:Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(c,0,1),4,1),8,1),9,1),10,1),17,1),40,1),51,1),52,1),53,1),54,1),55,1),56,1),57,1),58,1),59,1),60,1),61,1),62,1),63,1),64,1),65,1),66,1),67,1);p=112;q=98;r=93;s=90;t=89;u=86;v=76;w=75;x=74;y=73;z=72;A=71;d=70;e=69;g=68;case 1:Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(c,g,1),e,1),d,1),A,1),z,1),y,1),x,1),w,1);m=88;o=v;n=u;l=t;k=s;j=r;i=q;h=p;break;case 2:break c;case 0:break d}}Nb(Nb(Nb(Nb(c,o,1),n,1),m,1),l,1);g=k;f=j;e=i;d=h}Nb(c,g,1)}Nb(Nb(Nb(c,f,1),e,1),d,1)}}function EI(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=jb-16|0;jb=h;g=v[a+32>>2];f=Gs(g);if(!f){f=Fs(g)}a:{b:{c:{if(b>>>0>=f>>>0){b=ba(8)|0;v[23588]=0;c=Q(55,h|0,6003)|0;a=v[23588];v[23588]=0;if((a|0)==1){break c}a=rc(b,c);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}if(c>>>0>=120){b=ba(8)|0;v[23588]=0;c=Q(55,h|0,11238)|0;a=v[23588];v[23588]=0;if((a|0)!=1){a=rc(b,c);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}a=P()|0;O()|0;ca(b|0);break b}f=Hy(g,65535);j=(f|0)==65535?255:f;u[h>>1]=j;f=g+B(j,872)|0;i=f+1074992|0;eo(i,g,65535,1024);c=c+1|0;t[f+1075794|0]=c;t[f+1075791|0]=c;u[f+1075778>>1]=0;tm(i);Tp(v[a+32>>2],i,b+1|0,0,1,1);v[f+1075688>>2]=65536;nt(v[a+32>>2],i,c,0,1,1,65535);l=f+1075684|0,m=yl(su(e*128,-128,128)+128),v[l>>2]=m;l=f+1075680|0,m=yl(su(d*256,0,256)),v[l>>2]=m;c=v[a+32>>2];i=c+1074478|0;b=i;c=b+(x[c+480212>>1]<<1)|0;g=x[h>>1];f=g;while(1){d:{e:{if((b|0)!=(c|0)){if((f|0)!=x[b>>1]){break e}}else{b=c}break d}b=b+2|0;continue}break}f:{if((b|0)==(c|0)){break f}f=b;while(1){f=f+2|0;if((f|0)==(c|0)){c=b;break f}k=x[f>>1];if((k|0)==(g|0)){continue}u[b>>1]=k;b=b+2|0;g=x[h>>1];continue}}l=v[a+32>>2],m=fz(i,c),u[l+480212>>1]=m;jb=h+16|0;return j|0}a=P()|0;O()|0;ca(b|0)}T(a|0)}L()}function Oia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-80|0;jb=d;b=b&4095;u[d+78>>1]=b;a:{b:{c:{d:{if(b>>>0>=81){e=jb-16|0;jb=e;f=xc(e,4454);$c(d- -64|0,f);zb(f);jb=e+16|0;v[23588]=0;e=((b|0)==4095?c:b-80|0)+734016|0;c=Lka(e,e>>31,1e4,0)+14780|0;b=mb;b=Mka(c,c>>>0<14780?b+1|0:b,3652425,0);c=(((e+((b|0)/-4|0)|0)+B(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0;if((c|0)<0){b=b-1|0;c=(((e+((b|0)/-4|0)|0)+B(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0}g=b;b=(B(c,100)+52|0)/3060|0;e=b+2|0;f=(e|0)/12|0;v[d+44>>2]=g+f;R(97,d+48|0,d+44|0);g=v[23588];v[23588]=0;e:{f:{g:{h:{i:{j:{if((g|0)!=1){v[23588]=0;v[d+28>>2]=(e+B(f,-12)|0)+1;R(99,d+32|0,d+28|0);e=v[23588];v[23588]=0;if((e|0)==1){break j}v[23588]=0;v[d+12>>2]=(((B(b,306)+5|0)/-10|0)+c|0)+1;R(99,d+16|0,d+12|0);b=v[23588];v[23588]=0;if((b|0)==1){break i}v[23588]=0;ea(403,a|0,d- -64|0,d+48|0,d+32|0,d+16|0);a=v[23588];v[23588]=0;if((a|0)==1){break h}zb(d+16|0);zb(d+32|0);break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;break g}b=P()|0;O()|0;zb(d+16|0)}zb(d+32|0)}zb(d+48|0)}break a}Rf(d- -64|0,4434);v[23588]=0;R(404,d+48|0,d+78|0);b=v[23588];v[23588]=0;if((b|0)==1){break c}v[23588]=0;U(145,a|0,d- -64|0,d+48|0);a=v[23588];v[23588]=0;if((a|0)==1){break b}}zb(d+48|0);ac(d- -64|0);jb=d+80|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;zb(d+48|0)}ac(d- -64|0);T(b|0);L()}function Vea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,z=0,A=0,C=0;i=jb-16|0;jb=i;md(d,32);g=i+8|0;qQ(g,w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24),w[a+28|0]|w[a+29|0]<<8|(w[a+30|0]<<16|w[a+31|0]<<24),v[b>>2]);g=ic(g);qQ(i,w[a+40|0]|w[a+41|0]<<8|(w[a+42|0]<<16|w[a+43|0]<<24),w[a+44|0]|w[a+45|0]<<8|(w[a+46|0]<<16|w[a+47|0]<<24),v[c>>2]);a=0;g=v[g>>2];if(g-838861>>>0>=4294128436){a=v[ic(i)>>2];v[d>>2]=B(g,320);u[d+34>>1]=1;a:{m=Ng(d);if(!m){break a}l=g<<2;e=+(l>>>0);q=+(a>>>0)/e;r=+(g>>>0)/e;s=1/+y[d>>2];t=+y[i>>2];z=+y[i+8>>2];g=0;b:while(1){if((g|0)==(l|0)){break a}n=+(g>>>0);o=0;p=0;a=v[b+20>>2];if(Zd(v[b>>2],a)){e=n*r+z;c:{if(e<4294967296&e>=0){f=~~e>>>0;break c}f=0}k=x[b+34>>1];j=Kd(k);h=B(f,j);e=e-+(f>>>0);d:{if(k&1){f=x[a+(h<<1)>>1];a=x[a+(h+j<<1)>>1];break d}f=w[a+h|0]<<8;a=w[a+(h+j|0)|0]<<8}p=+(f<<16>>16)*(1-e)+e*+(a<<16>>16)}a=v[c+20>>2];if(Zd(v[c>>2],a)){e=n*q+t;e:{if(e<4294967296&e>=0){f=~~e>>>0;break e}f=0}k=x[c+34>>1];j=Kd(k);h=B(f,j);e=e-+(f>>>0);f:{if(k&1){f=x[a+(h<<1)>>1];a=x[a+(h+j<<1)>>1];break f}f=w[a+h|0]<<8;a=w[a+(h+j|0)|0]<<8}o=+(f<<16>>16)*(1-e)+e*+(a<<16>>16)}f=0;a=g;while(1)if((f|0)==80){g=g+1|0;continue b}else{e=s*+(a>>>0);A=v[d+20>>2]+(a<<1)|0,C=Qz(p*(1-e)+o*e),u[A>>1]=C;a=a+l|0;f=f+1|0;continue}}}a=(m|0)!=0}jb=i+16|0;return a|0}function WA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;j=jb-16|0;jb=j;a:{if(b&4){break a}c=w[a+14|0];b:{if(c>>>0>=w[a+15|0]){break b}d=w[a+12|0];if(!(d&2)){break b}t[a+12|0]=d&251}if(!(w[a+12|0]&2)|c>>>0<=w[a+13|0]){break a}e=v[a>>2];d=v[a+4>>2];if(_d(e,d)>>>0<=c>>>0){break a}e=x[Oc(e,d,c)>>1];d=Oc(v[a>>2],v[a+4>>2],w[a+14|0]-1|0);c=w[a+14|0];if(x[d>>1]<(e-1|0)){c=x[Oc(v[a>>2],v[a+4>>2],c)>>1]-1&65535;e=$p(a,c,64,64);d=ec(j+8|0,ym(Eb(v[a>>2]),w[a+14|0]));k=zl(j,c,e&255);m=jb-32|0;jb=m;c=v[d>>2];d=v[a>>2];c=(bu(c,Eb(d))<<2)+d|0;h=v[a+4>>2];c:{d:{if(h>>>0<y[Fb(a)>>2]){if((c|0)!=(h|0)){break d}OS(a,k);break c}d=Fb(a);f=Uf(m+8|0,pg(a,uc(v[a>>2],h)+1|0),c-v[a>>2]>>2,d);v[23588]=0;R(750,f|0,k|0);d=v[23588];v[23588]=0;if((d|0)!=1){d=v[f+4>>2];i=f+4|0;dq(v[a>>2],c,i);e=v[a+4>>2];g=f+8|0;while(1){if((c|0)!=(e|0)){Hm(v[g>>2],x[c>>1]|x[c+2>>1]<<16);v[g>>2]=v[g>>2]+4;c=c+4|0;continue}break}pc(a,i);pc(a+4|0,g);pc(Fb(a),Bc(f));v[f>>2]=v[f+4>>2];c=d;Tf(f);break c}a=P()|0;O()|0;Tf(f);T(a|0);L()}f=jb-16|0;jb=f;i=v[a+4>>2];d=(i-(c+4|0)|0)+c|0;g=Ah(f,a,h-d>>2);l=v[g+4>>2];e=d;while(1){if(e>>>0>=h>>>0){kc(g);Aq(c,d,i);jb=f+16|0}else{Hm(l,x[e>>1]|x[e+2>>1]<<16);l=l+4|0;v[g+4>>2]=l;e=e+4|0;continue}break}t[c+2|0]=w[k+2|0];u[c>>1]=x[k>>1]}Eb(c);jb=m+32|0;break a}t[a+14|0]=c-1}if((b|0)!=16777216){t[a+17|0]=255}jb=j+16|0}function Yga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=jb-16|0;jb=e;a:{if((c|0)!=4){g=b+236|0;h=b+108|0;while(1){if((d|0)==120){break a}f=(d<<2)+a|0;i=Kb(h,d),j=w[f+4|0]+1|0,t[i|0]=j;i=cc(g,d),j=(w[f+6|0]|w[f+7|0]<<8)+1|0,u[i>>1]=j;d=d+1|0;continue}}f=b+236|0;while(1){if((d|0)==96){break a}g=(d<<2)+a|0;i=cc(f,d+12|0),j=(w[g+6|0]|w[g+7|0]<<8)+1|0,u[i>>1]=j;d=d+1|0;continue}}oA(a+484|0,b+48|0,0);oA(a+590|0,b+68|0,0);oA(a+696|0,b+88|0,5);v[b>>2]=w[a+806|0]|w[a+807|0]<<8;d=t[a+808|0];b:{if((d|0)<0){t[b+34|0]=d-127;break b}if(d>>>0>16){break b}if(t[a|0]&1){t[b+31|0]=d+1;break b}if(!d){break b}t[b+31|0]=d+1}if(w[b+31|0]){c:{d:{if((c|0)==4){d=w[a+810|0];break d}d=t[a+809|0];if((d|0)>=0){u[b+28>>1]=(d&255)+1}d=t[a+810|0];if((d|0)<0){break c}}t[b+30|0]=d+1}t[b+33|0]=w[a+811|0]}if((c|0)==32){t[e+15|0]=w[a+812|0];t[e+14|0]=128;i=b,j=w[Wb(e+15|0,e+14|0)|0]>>>1|0,v[i+4>>2]=j}c=w[a+813|0]|w[a+814|0]<<8;if(c>>>0<=256){v[b+8>>2]=c;t[b+15|0]=w[b+15|0]|1}t[b+16|0]=w[a+815|0];t[b+26|0]=w[a+816|0];t[b+27|0]=w[a+817|0];t[b+17|0]=w[a+818|0];t[b+18|0]=w[a+819|0];u[e+12>>1]=w[a+820|0]|w[a+821|0]<<8;u[e+10>>1]=100;i=b,j=w[Vc(e+12|0,e+10|0)|0],t[i+20|0]=j;u[e+8>>1]=w[a+822|0]|w[a+823|0]<<8;u[e+6>>1]=256;i=b,j=x[Vc(e+8|0,e+6|0)>>1]>>>2|0,t[i+19|0]=j;c=w[a+824|0];Lj(b,c&127,c>>>7|0);a=w[a+825|0];Kj(b,a&127,a>>>7|0);jb=e+16|0}function HF(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0;a=jb-16|0;jb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;a:{b:{c:{while(1){c=v[a+12>>2];if(!(c>>>0>=d>>>0|f>>>0>=g>>>0)){i=t[c|0];j=i&255;d:{if((i|0)>=0){u[f>>1]=j;b=c+1|0;break d}b=2;if(i>>>0<4294967234){break b}if(i>>>0<=4294967263){if((d-c|0)<2){break c}i=w[c+1|0];if((i&192)!=128){break a}u[f>>1]=i&63|j<<6&1984;b=c+2|0;break d}if(i>>>0<=4294967279){if((d-c|0)<3){break c}k=w[c+2|0];i=w[c+1|0];e:{f:{if((j|0)!=237){if((j|0)!=224){break f}if((i&224)==160){break e}break a}if((i&224)==128){break e}break a}if((i&192)!=128){break a}}if((k&192)!=128){break a}u[f>>1]=k&63|((i&63)<<6|j<<12);b=c+3|0;break d}if(i>>>0>4294967284){break b}b=1;if((d-c|0)<4){break a}k=w[c+3|0];i=w[c+2|0];c=w[c+1|0];g:{h:{switch(j-240|0){case 0:if((c+112&255)>>>0>=48){break b}break g;case 4:if((c&240)!=128){break b}break g;default:break h}}if((c&192)!=128){break b}}if((i&192)!=128|(k&192)!=128){break b}if((g-f|0)<4){break a}b=2;j=j&7;if((c<<12&196608|j<<18)>>>0>1114111){break a}b=c<<2;u[f>>1]=(i>>>4&3|(b&192|j<<8|b&60))+16320|55296;v[a+8>>2]=f+2;u[f+2>>1]=i<<6&960|k&63|56320;b=v[a+12>>2]+4|0}v[a+12>>2]=b;f=v[a+8>>2]+2|0;v[a+8>>2]=f;continue}break}b=c>>>0<d>>>0;break a}b=1;break a}b=2}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];jb=a+16|0;return b|0}function Zn(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=jb-16|0;jb=d;h=a+1074312|0;Cb(d+8|0,h,96);i=b,j=(k=0,l=v[b+660>>2],m=Bb(v[v[d+8>>2]>>2],v[d+12>>2]),m?k:l)+c|0,v[i+660>>2]=j;g=v[a+480180>>2];e=v[b+84>>2];if(!(!(g&18)|e>>>0>c>>>0|(!(w[b+88|0]&2)|!e))){f=c;c=v[b+80>>2];c=((f-c>>>0)%(e-c>>>0)|0)+c|0}c=c>>>(v[b+88>>2]&1&(g|0)==16384)|0;a:{b:{if(!_c(w[b+788|0])){Cb(d+8|0,h,114);if(!Bb(v[v[d+8>>2]>>2],v[d+12>>2])){break b}}e=v[b+656>>2];c:{if(!e){break c}g=w[b+788|0];if(!_c(g)){break c}e=x[cc(e+236|0,g-1|0)>>1];if(!e|e>>>0>x[a+480190>>1]){break a}}d:{if(w[a+480210|0]&32){f=c;c=v[b+660>>2];v[b+660>>2]=f+c;f=0;break d}f=0}v[b>>2]=f;v[b+4>>2]=c;if((!(w[b+88|0]&2)|c>>>0<y[b+84>>2])&c>>>0<y[b+76>>2]){break a}Cb(d+8|0,h,57);e:{if(!Bb(v[v[d+8>>2]>>2],v[d+12>>2])){c=v[a+480180>>2];if((c|0)!=16){break e}}v[b+700>>2]=0;v[b+88>>2]=v[b+88>>2]|2097152;break a}if(!(c&1048581)){Cb(d+8|0,h,27);if(Bb(v[v[d+8>>2]>>2],v[d+12>>2])){if(w[a+480208|0]&4){c=v[b+76>>2];v[b>>2]=0;v[b+4>>2]=c;break a}v[b>>2]=0;v[b+4>>2]=0;break a}c=v[b+80>>2];v[b>>2]=0;v[b+4>>2]=c;if(!(w[a+480208|0]&4)){break a}a=v[b+76>>2];if(a>>>0<5){break a}v[b>>2]=0;v[b+4>>2]=a-2;break a}if(!(w[b+88|0]&2)|(c|0)!=1){break a}c=v[b+80>>2];v[b>>2]=0;v[b+4>>2]=c;break a}if(!(v[a+480180>>2]&268582928)|c>>>0>=y[b+76>>2]){break a}v[b>>2]=0;v[b+4>>2]=c}jb=d+16|0}function qz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a:{e=a;b:{c:{h=a+62|0;f=Kb(h,b);a=t[f|0];if((a|0)==-1){break c}if((a|0)>=0){break b}a=a&127;d=cc(e+26|0,a);g=x[d>>1];if((g|0)!=65535&(b|0)!=(g|0)){break c}u[d>>1]=b;t[f|0]=a;break b}l=e+8|0;i=e+26|0;d=255;a=0;g=255;while(1){if((a|0)!=18){j=cc(i,a);k=x[j>>1];if((k|0)==65535){u[j>>1]=b;t[f|0]=a;break b}else{if(!(w[Kb(l,a)|0]&32)){g=t[Kb(h,k)|0]<0?a:g;d=a}a=a+1|0;continue}}break}if((d&255)!=255){a=(g&255)==255?d:g;d=cc(i,a&255);m=Kb(h,x[d>>1]),n=255,t[m|0]=n;u[d>>1]=b;t[f|0]=a}a=ol(e,b)}g=a&255;if((g|0)==255){break a}if(ik(v[e>>2])){break a}d=Md(e+318|0,g);a=w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24);t[d+8|0]=a;t[d+9|0]=a>>>8;t[d+10|0]=a>>>16;t[d+11|0]=a>>>24;a=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);f=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[d|0]=f;t[d+1|0]=f>>>8;t[d+2|0]=f>>>16;t[d+3|0]=f>>>24;t[d+4|0]=a;t[d+5|0]=a>>>8;t[d+6|0]=a>>>16;t[d+7|0]=a>>>24;f=UO(g);h=f+3|0;a=0;while(1){if((a|0)==2){gh(v[e>>2],v[e+4>>2],b,yt(g)|192,w[Kb(c,10)|0])}else{d=a?h:f;gh(v[e>>2],v[e+4>>2],b,d|32,w[Kb(c,a)|0]);gh(v[e>>2],v[e+4>>2],b,d|64,w[Kb(c,a+2|0)|0]);gh(v[e>>2],v[e+4>>2],b,d|96,w[Kb(c,a+4|0)|0]);gh(v[e>>2],v[e+4>>2],b,d|128,w[Kb(c,a+6|0)|0]);gh(v[e>>2],v[e+4>>2],b,d|224,w[Kb(c,a+8|0)|0]);a=a+1|0;continue}break}}}function V$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=C(0);a=jb-368|0;jb=a;v[a+352>>2]=c;v[a+360>>2]=b;vw(a+200|0,d,a+224|0,a+220|0,a+216|0);d=Lb(a+184|0);b=ad(d);v[23588]=0;R(60,d|0,b|0);b=v[23588];v[23588]=0;a:{b:{c:{if((b|0)!=1){c=Sc(d,0);v[a+180>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;h=v[a+216>>2];i=v[a+220>>2];while(1){d:{v[23588]=0;b=Q(1141,a+360|0,a+352|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break d}if(!b){break c}g=v[a+180>>2];b=Gb(d);if((g|0)==(b+c|0)){v[23588]=0;R(60,d|0,b<<1);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=ad(d);v[23588]=0;R(60,d|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=Sc(d,0);v[a+180>>2]=b+c}v[23588]=0;b=S(1143,v[a+360>>2])|0;g=v[23588];v[23588]=0;if((g|0)==1){break d}if(uw(b,a+7|0,a+6|0,c,a+180|0,i,h,a+200|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}v[23588]=0;S(1145,a+360|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Gb(a+200|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}j=f,k=uG(c,v[a+180>>2],e),z[j>>2]=k;Ff(a+200|0,a+16|0,v[a+12>>2],e);v[23588]=0;b=Q(1142,a+360|0,a+352|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+360>>2];yb(d);yb(a+200|0);jb=a+368|0;break a}}b=P()|0;O()|0;yb(d);yb(a+200|0);T(b|0);L()}return b|0}function rfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=jb-48|0;jb=e;md(b,2);f=e+16|0;tk(f,2,a+1|0);d=e+32|0;Ec(d,f);Be(b+43|0,d);yb(d);a:{b:{c:{d:{switch(w[a|0]){case 0:f=v[b+4>>2];d=v[b+8>>2];break c;case 2:break b;case 1:break d;default:break a}}d=w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24);v[b>>2]=d;v[e+32>>2]=w[a+20|0]|w[a+21|0]<<8|(w[a+22|0]<<16|w[a+23|0]<<24);v[e+16>>2]=d-1;d=e+32|0;f=v[Jb(d,e+16|0)>>2];v[b+4>>2]=f;v[e+32>>2]=w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24);d=v[Jb(d,b)>>2];v[b+8>>2]=d;u[b+34>>1]=x[b+34>>1]&65533|w[a+31|0]<<1&2}if(d>>>0>f>>>0&d>>>0>=2){break a}u[b+34>>1]=0;v[b+4>>2]=0;v[b+8>>2]=0;break a}f=e+16|0;Jh(f,a+16|0);d=v[e+16>>2];v[e+32>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);Jh(f,a+20|0);d=v[e+16>>2];v[e+36>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);Jh(f,a+24|0);d=v[e+16>>2];d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[e+40>>2]=d;v[e+8>>2]=d;d=v[e+36>>2];v[e>>2]=v[e+32>>2];v[e+4>>2]=d;Fl(b,1,e)}t[e+32|0]=w[a+28|0];t[e+16|0]=64;g=b,h=w[Wb(e+32|0,e+16|0)|0]<<2,u[g+30>>1]=h;d=w[a+32|0]|w[a+33|0]<<8|(w[a+34|0]<<16|w[a+35|0]<<24);v[b+24>>2]=d;b=b+24|0;e:{if(!c){break e}if(w[a|0]==2){d=d&65535;v[b>>2]=d;break e}if(y[b>>2]>=65536){v[b>>2]=65535}d=v[b>>2]}f:{g:{if(!d){a=8363;break g}a=1024;if(d>>>0>1023){break f}}v[b>>2]=a}jb=e+48|0}function c0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=C(0);a=jb-272|0;jb=a;v[a+256>>2]=c;v[a+264>>2]=b;zw(a+208|0,d,a+224|0,a+223|0,a+222|0);d=Lb(a+192|0);b=ad(d);v[23588]=0;R(60,d|0,b|0);b=v[23588];v[23588]=0;a:{b:{c:{if((b|0)!=1){c=Sc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;h=t[a+222|0];i=t[a+223|0];while(1){d:{v[23588]=0;b=Q(1125,a+264|0,a+256|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break d}if(!b){break c}g=v[a+188>>2];b=Gb(d);if((g|0)==(b+c|0)){v[23588]=0;R(60,d|0,b<<1);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=ad(d);v[23588]=0;R(60,d|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=Sc(d,0);v[a+188>>2]=b+c}v[23588]=0;b=S(1127,v[a+264>>2])|0;g=v[23588];v[23588]=0;if((g|0)==1){break d}if(yw(b,a+7|0,a+6|0,c,a+188|0,i,h,a+208|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}v[23588]=0;S(1129,a+264|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Gb(a+208|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}j=f,k=uG(c,v[a+188>>2],e),z[j>>2]=k;Ff(a+208|0,a+16|0,v[a+12>>2],e);v[23588]=0;b=Q(1126,a+264|0,a+256|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];yb(d);yb(a+208|0);jb=a+272|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);T(b|0);L()}return b|0}function U$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=jb-368|0;jb=a;v[a+352>>2]=c;v[a+360>>2]=b;vw(a+200|0,d,a+224|0,a+220|0,a+216|0);d=Lb(a+184|0);b=ad(d);v[23588]=0;R(60,d|0,b|0);b=v[23588];v[23588]=0;a:{b:{c:{if((b|0)!=1){c=Sc(d,0);v[a+180>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;h=v[a+216>>2];i=v[a+220>>2];while(1){d:{v[23588]=0;b=Q(1141,a+360|0,a+352|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break d}if(!b){break c}g=v[a+180>>2];b=Gb(d);if((g|0)==(b+c|0)){v[23588]=0;R(60,d|0,b<<1);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=ad(d);v[23588]=0;R(60,d|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=Sc(d,0);v[a+180>>2]=b+c}v[23588]=0;b=S(1143,v[a+360>>2])|0;g=v[23588];v[23588]=0;if((g|0)==1){break d}if(uw(b,a+7|0,a+6|0,c,a+180|0,i,h,a+200|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}v[23588]=0;S(1145,a+360|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Gb(a+200|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}j=f,k=sG(c,v[a+180>>2],e),A[j>>3]=k;Ff(a+200|0,a+16|0,v[a+12>>2],e);v[23588]=0;b=Q(1142,a+360|0,a+352|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+360>>2];yb(d);yb(a+200|0);jb=a+368|0;break a}}b=P()|0;O()|0;yb(d);yb(a+200|0);T(b|0);L()}return b|0}function yha(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=v[a>>2];b=eu(c,v[a+4>>2]);if(b>>>0<=63){g=jb-32|0;jb=g;f=64-b|0;c=v[Fb(a)>>2];d=v[a+4>>2];a:{if(f>>>0<=(c-d|0)/33>>>0){b=jb-16|0;jb=b;v[b>>2]=a;a=v[a+4>>2];v[b+4>>2]=a;v[b+8>>2]=a+B(f,33);a=v[b+4>>2];c=v[b+8>>2];while(1){if((a|0)==(c|0)){kc(b);jb=b+16|0}else{NS(a);a=a+33|0;v[b+4>>2]=a;continue}break}break a}i=Fb(a);c=g+8|0;h=eu(v[a>>2],d)+f|0;d=jb-16|0;jb=d;v[d+12>>2]=h;e=jb-16|0;jb=e;v[e+12>>2]=130150524;v[e+8>>2]=2147483647;b=v[Jb(e+12|0,e+8|0)>>2];jb=e+16|0;b:{if(b>>>0>=h>>>0){e=SS(a);if(e>>>0<b>>>1>>>0){v[d+8>>2]=e<<1;b=v[Yc(d+8|0,d+12|0)>>2]}jb=d+16|0;break b}bd();L()}e=eu(v[a>>2],v[a+4>>2]);og(c+12|0,i);if(b){if(b>>>0>=130150525){Lg();L()}d=sc(B(b,33))}else{d=0}v[c>>2]=d;e=d+B(e,33)|0;v[c+8>>2]=e;v[c+4>>2]=e;j=Bc(c),k=d+B(b,33)|0,v[j>>2]=k;b=jb-16|0;jb=b;v[b>>2]=v[c+8>>2];d=v[c+8>>2];v[b+8>>2]=c+8;v[b+4>>2]=d+B(f,33);d=v[b>>2];while(1){if(v[b+4>>2]!=(d|0)){NS(d);d=v[b>>2]+33|0;v[b>>2]=d;continue}break}Td(b);jb=b+16|0;b=c+4|0;f=v[a>>2];d=v[a+4>>2]-f|0;e=v[b>>2]+B((d|0)/-33|0,33)|0;v[b>>2]=e;if((d|0)>0){tc(e,f,d)}pc(a,b);pc(a+4|0,c+8|0);pc(Fb(a),Bc(c));v[c>>2]=v[c+4>>2];b=v[c+4>>2];a=v[c+8>>2];while(1){if((a|0)!=(b|0)){a=a-33|0;v[c+8>>2]=a;continue}break}a=v[c>>2];if(a){Bc(c);Mb(a)}}jb=g+32|0;return}if((b|0)!=64){Nd(a,c+2112|0)}}function b0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=jb-272|0;jb=a;v[a+256>>2]=c;v[a+264>>2]=b;zw(a+208|0,d,a+224|0,a+223|0,a+222|0);d=Lb(a+192|0);b=ad(d);v[23588]=0;R(60,d|0,b|0);b=v[23588];v[23588]=0;a:{b:{c:{if((b|0)!=1){c=Sc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;h=t[a+222|0];i=t[a+223|0];while(1){d:{v[23588]=0;b=Q(1125,a+264|0,a+256|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break d}if(!b){break c}g=v[a+188>>2];b=Gb(d);if((g|0)==(b+c|0)){v[23588]=0;R(60,d|0,b<<1);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=ad(d);v[23588]=0;R(60,d|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=Sc(d,0);v[a+188>>2]=b+c}v[23588]=0;b=S(1127,v[a+264>>2])|0;g=v[23588];v[23588]=0;if((g|0)==1){break d}if(yw(b,a+7|0,a+6|0,c,a+188|0,i,h,a+208|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}v[23588]=0;S(1129,a+264|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Gb(a+208|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}j=f,k=sG(c,v[a+188>>2],e),A[j>>3]=k;Ff(a+208|0,a+16|0,v[a+12>>2],e);v[23588]=0;b=Q(1126,a+264|0,a+256|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];yb(d);yb(a+208|0);jb=a+272|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);T(b|0);L()}return b|0}function nI(a){var b=0,c=0,d=0,e=0;Ce(v[a+80>>2],v[a+20>>2]);while(1){c=v[a+28>>2];if((b|0)<v[a+24>>2]){Ce(v[a+80>>2],v[c+(b<<2)>>2]);b=b+1|0;continue}break}Ce(v[a+80>>2],c);a:{if(!v[a+396>>2]){break a}c=0;while(1){if(v[a+264>>2]<=(c|0)){break a}e=v[a+396>>2]+B(c,24)|0;d=v[e+16>>2];if(d){b=0;while(1){if((b|0)<v[(v[a+124>>2]+B(w[e+13|0],2096)|0)+4>>2]){Ce(v[a+80>>2],v[(b<<2)+d>>2]);b=b+1|0;d=v[e+16>>2];continue}break}Ce(v[a+80>>2],d)}Ce(v[a+80>>2],v[e+20>>2]);c=c+1|0;continue}}d=v[a+124>>2];if(d){c=0;while(1){if((c|0)<v[a+120>>2]){b=B(c,2096)+d|0;Ce(v[a+80>>2],v[b+8>>2]);Ce(v[a+80>>2],v[b+28>>2]);Ce(v[a+80>>2],v[b+32>>2]);Ce(v[a+80>>2],v[b+2084>>2]);b=v[b+2088>>2];Ce(v[a+80>>2],b?b-4|0:0);c=c+1|0;d=v[a+124>>2];continue}break}Ce(v[a+80>>2],d)}Ce(v[a+80>>2],v[a+260>>2]);Ce(v[a+80>>2],v[a+396>>2]);c=v[a+404>>2];if(c){b=0;while(1){if((b|0)<v[a+400>>2]){Ce(v[a+80>>2],v[(B(b,40)+c|0)+4>>2]);b=b+1|0;c=v[a+404>>2];continue}break}Ce(v[a+80>>2],c)}c=0;b=0;while(1){if(!(v[a+4>>2]<=(b|0)|b>>>0>15)){d=(b<<2)+a|0;Ce(v[a+80>>2],v[d+800>>2]);Ce(v[a+80>>2],v[d+928>>2]);Ce(v[a+80>>2],v[d+996>>2]);b=b+1|0;continue}break}while(1){if((c|0)!=2){b=(c<<2)+a|0;Ce(v[a+80>>2],v[b+1068>>2]);Ce(v[a+80>>2],v[b+1076>>2]);Ce(v[a+80>>2],v[b+1084>>2]);Ce(v[a+80>>2],v[b+1092>>2]);Ce(v[a+80>>2],v[b+1100>>2]);c=c+1|0;continue}break}}function XO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;h=jb-16|0;jb=h;c=v[a>>2];a:{if(ik(c)){i=jb-16|0;jb=i;e=sc(3848);d=e+808|0;c=e+16|0;while(1){v[c+16>>2]=0;v[c+20>>2]=0;v[c+36>>2]=0;t[c+42|0]=1;u[c+40>>1]=257;v[c+24>>2]=0;v[c+28>>2]=0;u[c+32>>1]=0;c=c+44|0;if((c|0)!=(d|0)){continue}break}c=e+3832|0;while(1){v[d>>2]=0;v[d+4>>2]=0;v[d+68>>2]=0;v[d+72>>2]=0;v[d+24>>2]=0;v[d+28>>2]=0;u[d+20>>1]=511;v[d+16>>2]=-1;u[d+14>>1]=1;u[d+6>>1]=0;u[d+8>>1]=0;u[d+10>>1]=0;u[d+12>>1]=0;t[d+73|0]=0;t[d+74|0]=0;t[d+75|0]=0;t[d+76|0]=0;t[d+77|0]=0;t[d+78|0]=0;t[d+79|0]=0;t[d+80|0]=0;d=d+84|0;if((c|0)!=(d|0)){continue}break}v[e+3832>>2]=0;v[e+3836>>2]=0;c=e+3837|0;t[c|0]=0;t[c+1|0]=0;t[c+2|0]=0;t[c+3|0]=0;t[c+4|0]=0;t[c+5|0]=0;t[c+6|0]=0;t[c+7|0]=0;while(1){if((g|0)==36){while(1){if((f|0)==18){b:{f=0;g=0;while(1)if((f|0)==18){while(1){if((g|0)==36){break b}co((e+B(g,84)|0)+808|0);g=g+1|0;continue}}else{d=(e+B(f,44)|0)+16|0;c=v[(f<<2)+28912>>2];c:{if(!(!(1<<f&3591)|f>>>0>11)){c=e+B(c,84)|0;aP(d,c+808|0,c+1060|0,c+1312|0,c+1564|0);break c}c=e+B(c,84)|0;aP(d,c+808|0,c+1060|0,0,0)}f=f+1|0;continue}}}else{v[(e+B(f,44)|0)+32>>2]=e;f=f+1|0;continue}break}$O(e,b)}else{ud((e+B(g,84)|0)+808|0,e);g=g+1|0;continue}break}b=v[Lf(i+8|0,e)>>2];jb=i+16|0;v[h+8>>2]=b;b=h+8|0;rA(a,b);yj(b);break a}$O(c,b)}WO(a);jb=h+16|0}function Dz(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=jb-32|0;jb=e;if(b&5){if((b|0)==1){d=Lka(v[a+24>>2],0,8363,0)+4136|0;c=mb;h=a,i=Dc(Oka(d,d>>>0<4136?c+1|0:c,8272,0),mb),v[h+24>>2]=i}d=jb-16|0;jb=d;g=d+8|0;c=jb-16|0;jb=c;f=v[a+24>>2];a:{if(!f){Fo(g);break a}yB(c+8|0,Xb(yl(zp(+(f>>>0)*.00011957431543704412)*2215.9795828054475),-16384,16383),128);f=v[c+8>>2];t[c+7|0]=v[c+12>>2];de(g,f,c+7|0)}jb=c+16|0;qB(d,a+36|0,a+37|0);pB(d,g);jb=d+16|0}if(b&3){u[a+38>>1]=0;u[a+40>>1]=0;t[a+36|0]=0;u[a+34>>1]=x[a+34>>1]&65499}if(b&7){u[a+32>>1]=64;c=x[a+34>>1];if(c&8){d=v[a+16>>2];v[a+4>>2]=v[a+12>>2];v[a+8>>2]=d;c=c&16?c|6:c&65529|2}v[a+12>>2]=0;v[a+16>>2]=0;u[a+34>>1]=c&65511}b:{if(!(b&4)){break b}c=x[a+34>>1];if(!(c&32)){u[a+28>>1]=128;u[a+34>>1]=c|32}vf(a+40|0,15);vf(a+41|0,63);if(!w[a+41|0]){break b}d=w[a+40|0];if(!d){break b}c=w[a+39|0];if(c){c=Ll(Dc(((d<<8|c>>>1)>>>0)/(c>>>0)|0,0))}else{c=255}t[a+39|0]=c}c:{d:{if((b|0)!=4){if((b|0)==16777216){break c}if((b|0)!=32|w[a+38|0]!=2){break d}t[a+38|0]=3;break d}if(w[a+38|0]!=4){break d}t[a+38|0]=0}u[a+34>>1]=x[a+34>>1]&49151}e:{if(!(!(w[a+35|0]&2)|b&16777218)){v[e+24>>2]=0;v[e+8>>2]=0;v[e+16>>2]=0;v[e+20>>2]=0;v[e>>2]=0;v[e+4>>2]=0;Fl(a,0,e);break e}if(!(w[a+35|0]&2)|(b|0)!=2){break e}a=a+68|0;b=Kb(a,8);t[b|0]=w[b|0]&3;a=Kb(a,9);t[a|0]=w[a|0]&3}jb=e+32|0}function xca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;f=jb-16|0;jb=f;s=v[a+16>>2];u=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);n=v[a+128>>2];a:{if(!n){k=v[a+8>>2];l=v[a+12>>2];e=v[a>>2];b=v[a+4>>2];m=0;break a}k=v[a+8>>2];l=v[a+12>>2];o=kg(k,l,n);p=mb;g=v[a+76>>2];e=v[a>>2];b=v[a+4>>2];Pf(e,b,kf(k,l,d),mb);m=g>>>0<mb>>>0?d:0}h=a+112|0;i=v[a+40>>2];j=v[a+36>>2];v[f>>2]=e;v[f+4>>2]=b;while(1){if(d){d=d-1|0;v[f+8>>2]=e;v[f+12>>2]=0;m=m-1|0;g=m;o=g?o:0;p=g?p:0;r=(((b&2147483647)<<1|e>>>31)&-2)+s|0;g=n;b:{c:while(1){d:{if((g|0)<=0){Qb(h,v[a+120>>2],v[a+124>>2]);g=v[a+116>>2];if(!g){break b}q=((v[f+12>>2]&2147483647)<<1|v[f+8>>2]>>>31)&-2;e=0;b=0;break d}q=((v[f+12>>2]&2147483647)<<1|v[f+8>>2]>>>31)&-2;b=0;e=0;while(1)if((b|0)==2){Rd(h,(e|0)/8<<16>>16);Qd(h,4);Qb(f+8|0,o,p);g=g-1|0;continue c}else{e=(t[(b+q|0)+r|0]<<8)+e|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){e=(t[(b+q|0)+r|0]<<8)+e|0;b=b+1|0;continue}break}Rd(h,(e|0)/8<<16>>16);Qd(h,g);v[h>>2]=v[h>>2];v[h+4>>2]=0}b=v[a+32>>2];j=v[a+28>>2]+j|0;g=ig(h,u);v[c>>2]=B(j>>12,g)+v[c>>2];i=b+i|0;v[c+4>>2]=v[c+4>>2]+B(g,i>>12);Qb(f,k,l);c=c+8|0;e=v[f>>2];b=v[f+4>>2];continue}break}v[a>>2]=e;v[a+4>>2]=b;v[a+40>>2]=i;v[a+20>>2]=j>>12;v[a+36>>2]=j;v[a+24>>2]=i>>12;jb=f+16|0}function PP(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=jb-240|0;jb=e;if(!w[94512]){if(!w[94388]){c=jb-16|0;jb=c;Lb(94364);v[23594]=0;t[94380]=0;v[23596]=0;v[23588]=0;b=ga(29)|0;a=v[23588];v[23588]=0;a:{b:{c:{d:{e:{f:{if((a|0)!=1){v[c+8>>2]=b;b=c+8|0;HA(94376,be(b));yj(b);t[94380]=0;break f}a=Da(92948,93532)|0;b=O()|0;if((da(92948)|0)==(b|0)){_(a|0)|0;v[23588]=0;Z(30);c=v[23588];v[23588]=0;if((c|0)==1){break d}L()}if((da(93532)|0)!=(b|0)){break c}_(a|0)|0;v[23588]=0;t[94380]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)==1){a=P()|0;O()|0;break c}if(w[94380]){break e}}v[23588]=0;Y(31,94360);b=v[23588];v[23588]=0;if((b|0)!=1){break e}a=P()|0;O()|0;break c}jb=c+16|0;break a}a=P()|0;O()|0;v[23588]=0;Z(18);c=v[23588];v[23588]=0;if((c|0)==1){break b}}yj(94384);yj(94376);yb(94364);T(a|0);L()}V(0)|0;O()|0;Ub();L()}t[94388]=1}c=jb+-64|0;jb=c;b=c+16|0;g=jb-16|0;jb=g;h=EP(g+8|0);j=e+120|0;while(1){if((i|0)==12){jb=g+16|0}else{f=jb-48|0;jb=f;a=v[h+4>>2];d=v[h>>2];g:{if((a|0)==(d|0)){break g}a=(a-d|0)+1|0;if(!a){a=CP(DP(f+8|0,32));break g}d=E(a);d=DP(f+8|0,(a<<d+1?32:31)-d|0);while(1){k=CP(d);if(a>>>0<=k>>>0){continue}break}a=v[h>>2]+k|0}jb=f+48|0;l=Db(b,i),m=a,v[l>>2]=m;i=i+1|0;continue}break}b=HP(c,b,JP(b));FP(j,b);Fm(b);jb=c- -64|0;tc(94392,tc(e,j,120),116);t[94512]=1}jb=e+240|0}function aia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=jb-16|0;jb=e;h=qf(a,c);me(e,v[a+36>>2]);i=a;a:{if(!h){Rc(e,a+32|0,5);c=0;if(Bb(v[v[e>>2]>>2],v[e+4>>2])){break a}}d=jb-160|0;jb=d;f=Zl(d+48|0,v[a+36>>2]);v[23588]=0;a=Q(449,d+32|0,43811)|0;c=v[23588];v[23588]=0;b:{c:{d:{e:{if((c|0)!=1){v[23588]=0;v[d+16>>2]=19988498;v[d+20>>2]=0;U(450,f|0,a|0,d+16|0);c=v[23588];v[23588]=0;if((c|0)==1){break e}_b(a);if(!Kk(w[f|0])){break d}break b}c=P()|0;O()|0;break c}c=P()|0;O()|0;_b(a);break c}k=d,l=Af(v[b>>2],v[b+4>>2]),u[k+30>>1]=l;u[d+28>>1]=65535;v[23588]=0;a=Q(449,d+16|0,10055)|0;c=v[23588];v[23588]=0;f:{if((c|0)!=1){v[23588]=0;c=W(479,f|0,d+28|0,a|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break f}_b(a);if(c){u[d+30>>1]=x[d+28>>1]}Ef(d+30|0,4e3);a=x[d+30>>1];g:{if(Af(v[b>>2],v[b+4>>2])>>>0>=a>>>0){break g}v[23588]=0;R(225,b|0,a|0);c=v[23588];v[23588]=0;if((c|0)!=1){break g}c=P()|0;O()|0;break c}c=0;h:{while(1){if((a|0)==(c|0)){break b}g=v[b>>2];v[23588]=0;R(480,d|0,c|0);j=v[23588];v[23588]=0;if((j|0)!=1){v[23588]=0;X(481,f|0,Yb(g,c)|0,d|0,482);g=v[23588];v[23588]=0;if((g|0)==1){break h}c=c+1|0;_b(d);continue}break}c=P()|0;O()|0;break c}c=P()|0;O()|0;_b(d);break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;_b(a)}kh(f);T(c|0);L()}kh(f);jb=d+160|0;c=h}Xe(i,c);jb=e+16|0}function f5(a){a=a|0;var b=0,c=0,d=0,e=0;e=jb-160|0;jb=e;d=Mc(e,11520);v[23588]=0;b=d+12|0;Q(55,b|0,10926)|0;c=v[23588];v[23588]=0;a:{b:{if((c|0)==1){break a}v[23588]=0;b=d+24|0;Q(55,b|0,11350)|0;c=v[23588];v[23588]=0;if((c|0)==1){break a}v[23588]=0;b=d+36|0;Q(55,b|0,10918)|0;c=v[23588];v[23588]=0;if((c|0)==1){break a}v[23588]=0;b=d+48|0;Q(55,b|0,8203)|0;c=v[23588];v[23588]=0;if((c|0)==1){break a}v[23588]=0;b=d+60|0;Q(55,b|0,10903)|0;c=v[23588];v[23588]=0;if((c|0)==1){break a}v[23588]=0;b=d+72|0;Q(55,b|0,8269)|0;c=v[23588];v[23588]=0;if((c|0)==1){break a}v[23588]=0;b=d+84|0;Q(55,b|0,5623)|0;c=v[23588];v[23588]=0;if((c|0)==1){break a}v[23588]=0;b=d+96|0;Q(55,b|0,11924)|0;c=v[23588];v[23588]=0;if((c|0)==1){break a}v[23588]=0;b=d+108|0;Q(55,b|0,11293)|0;c=v[23588];v[23588]=0;if((c|0)==1){break a}v[23588]=0;b=d+120|0;Q(55,b|0,12125)|0;c=v[23588];v[23588]=0;if((c|0)==1){break a}v[23588]=0;b=d+132|0;Q(55,b|0,5475)|0;c=v[23588];v[23588]=0;if((c|0)==1){break a}v[23588]=0;b=d+144|0;Q(55,b|0,7295)|0;c=v[23588];v[23588]=0;if((c|0)==1){break a}v[23588]=0;W(1019,a|0,d|0,13)|0;a=v[23588];v[23588]=0;if((a|0)==1){break b}b=d+156|0;while(1){b=yb(b-12|0);if((d|0)!=(b|0)){continue}break}jb=e+160|0;return}b=d+156|0}a=P()|0;O()|0;while(1){b=yb(b-12|0);if((d|0)!=(b|0)){continue}break}T(a|0);L()}function nO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=jb-48|0;jb=f;n=lz(v[a+24>>2],w[a+32|0]);o=sj(n);a:{while(1){b:{u[b>>1]=m;e=m&65535;if(e>>>0>=o>>>0){break b}c:{if(!Gq(n,e)){break c}e=v[a>>2];d=xd(e,v[a+4>>2]);g=x[b>>1];if(d>>>0<=g>>>0){v[c>>2]=0;break a}l=Md(e,g);ul(f+32|0,v[l>>2]);Cm(f+24|0,v[l>>2],v[l+4>>2]);e=v[f+36>>2];v[f+8>>2]=v[f+32>>2];v[f+12>>2]=e;g=v[f+24>>2];d=v[f+28>>2];e=jb-32|0;jb=e;i=v[f+12>>2];h=v[f+8>>2];v[e+24>>2]=h;v[e+28>>2]=i;j=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=j;j=f+40|0;g=tl(g,d,h,i);i=jb-16|0;jb=i;v[i+12>>2]=g;d=v[e+12>>2];d:{if(d){h=32-d|0;v[i+8>>2]=h;k=-1<<d;d=v[Jb(i+8|0,i+12|0)>>2];k=k&-1>>>h-d;h=v[e+8>>2];k=k&v[h>>2];if(k){gc(j,h,Kka(k));break d}if((d|0)==(g|0)){d=v[e+12>>2];v[j>>2]=v[e+8>>2];v[j+4>>2]=d;NP(j,g);break d}g=g-d|0;v[i+12>>2]=g;d=h+4|0}else{d=v[e+8>>2]}while(1){if(g>>>0>=32){h=v[d>>2];if(h){gc(j,d,Kka(h));break d}else{d=d+4|0;v[e+8>>2]=d;g=g-32|0;v[i+12>>2]=g;continue}}break}if(!g){gc(j,d,0);break d}h=v[d>>2]&-1>>>32-g;if(!h){gc(j,d,g);break d}gc(j,d,Kka(h))}jb=i+16|0;jb=e+32|0;Cm(f+16|0,v[l>>2],v[l+4>>2]);if(!(v[f+40>>2]==v[f+16>>2]&v[f+44>>2]==v[f+20>>2])){break c}v[c>>2]=0;break a}m=x[b>>1]+1|0;continue}break}u[b>>1]=65535;v[c>>2]=-1}jb=f+48|0;return(m&65535)>>>0<o>>>0|0}function Y$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=jb-352|0;jb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=bj(d);i=mp(d,a+224|0);lp(a+208|0,d,a+332|0);d=Lb(a+192|0);c=ad(d);v[23588]=0;R(60,d|0,c|0);c=v[23588];v[23588]=0;a:{b:{c:{if((c|0)!=1){c=Sc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[23588]=0;g=Q(1141,a+344|0,a+336|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=Gb(d);if((h|0)==(g+c|0)){v[23588]=0;R(60,d|0,g<<1);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=ad(d);v[23588]=0;R(60,d|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=Sc(d,0);v[a+188>>2]=g+c}v[23588]=0;g=S(1143,v[a+344>>2])|0;h=v[23588];v[23588]=0;if((h|0)==1){break d}if(xn(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,i)){break c}v[23588]=0;S(1145,a+344|0)|0;g=v[23588];v[23588]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Gb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}k=f,l=AG(c,v[a+188>>2],e,b),v[k>>2]=l;v[f+4>>2]=mb;Ff(a+208|0,a+16|0,v[a+12>>2],e);v[23588]=0;b=Q(1142,a+344|0,a+336|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];yb(d);yb(a+208|0);jb=a+352|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);T(b|0);L()}return b|0}function W$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=jb-352|0;jb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=bj(d);i=mp(d,a+224|0);lp(a+208|0,d,a+332|0);d=Lb(a+192|0);c=ad(d);v[23588]=0;R(60,d|0,c|0);c=v[23588];v[23588]=0;a:{b:{c:{if((c|0)!=1){c=Sc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[23588]=0;g=Q(1141,a+344|0,a+336|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=Gb(d);if((h|0)==(g+c|0)){v[23588]=0;R(60,d|0,g<<1);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=ad(d);v[23588]=0;R(60,d|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=Sc(d,0);v[a+188>>2]=g+c}v[23588]=0;g=S(1143,v[a+344>>2])|0;h=v[23588];v[23588]=0;if((h|0)==1){break d}if(xn(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,i)){break c}v[23588]=0;S(1145,a+344|0)|0;g=v[23588];v[23588]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Gb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}k=f,l=vG(c,v[a+188>>2],e,b),v[k>>2]=l;v[f+4>>2]=mb;Ff(a+208|0,a+16|0,v[a+12>>2],e);v[23588]=0;b=Q(1142,a+344|0,a+336|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];yb(d);yb(a+208|0);jb=a+352|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);T(b|0);L()}return b|0}function gea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=jb-48|0;jb=d;l=a+480190|0;c=x[l>>1];t[d+32|0]=0;CO(b,c+1|0,d+32|0);a:{j=a+480192|0;if(!x[j>>1]){break a}h=Sb(d+32|0);p=d,q=Eb(v[a+484344>>2]),v[p+24>>2]=q;o=Eb(v[a+484348>>2]);m=a+480188|0;while(1){i=v[d+24>>2];if(!Ob(i,o)){c=x[a+480190>>1];while(1)if(c){Cb(d+8|0,v[b>>2],c);if(!Bb(v[v[d+8>>2]>>2],v[d+12>>2])){e=f;f=B(c,104)+a|0;f=e+Zd(v[f+484380>>2],v[f+484400>>2])|0}c=c-1|0;continue}else{hc(h);break a}}b:{if(!Ob(v[i>>2],v[i+4>>2])){break b}c=x[m>>1];v[23588]=0;t[d+8|0]=0;U(749,h|0,c|0,d+8|0);c=v[23588];v[23588]=0;if((c|0)!=1){p=d,q=Eb(v[i>>2]),v[p+16>>2]=q;k=0;c:while(1){f=0;if(y[i+12>>2]<=k>>>0){break b}while(1){if(x[m>>1]<=f>>>0){k=k+1|0;continue c}d:{c=v[d+16>>2];if(!_c(w[c|0])){break d}e:{f:{c=w[c+1|0];if(c){g=x[j>>1];break f}g=x[j>>1];c=w[Kb(v[h>>2],f)|0];if(c){break f}c=1;break e}p=Kb(v[h>>2],f),q=c,t[p|0]=q;g=g&65535;e=g>>>0<c>>>0;g=e?g:c;c=e?1:c}while(1){e=c&65535;if(e>>>0>(g&65535)>>>0){break d}e=v[((e<<2)+a|0)+900380>>2];g:{if(!e){break g}e=x[cc(e+236|0,w[v[d+16>>2]]-1|0)>>1];if(e>>>0>x[l>>1]){break g}n=d+8|0;Cb(n,v[b>>2],e);Ye(n,1)}c=c+1|0;continue}}f=f+1|0;bA(d+16|0);continue}}}a=P()|0;O()|0;hc(h);T(a|0);L()}LM(d+24|0);continue}}jb=d+48|0;return f&65535}function Jfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(v[a+4>>2]!=v[Fb(a)>>2]){c=jb-16|0;jb=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+56;a=v[c+4>>2];v[23588]=0;R(656,a|0,b|0);a=v[23588];v[23588]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+56;kc(c);jb=c+16|0;break a}a=P()|0;O()|0;kc(c);T(a|0);L()}return}h=jb-32|0;jb=h;i=Fb(a);f=h+8|0;g=gq(v[a>>2],v[a+4>>2])+1|0;d=jb-16|0;jb=d;v[d+12>>2]=g;e=jb-16|0;jb=e;v[e+12>>2]=76695844;v[e+8>>2]=2147483647;c=v[Jb(e+12|0,e+8|0)>>2];jb=e+16|0;b:{if(c>>>0>=g>>>0){e=qR(a);if(e>>>0<c>>>1>>>0){v[d+8>>2]=e<<1;c=v[Yc(d+8|0,d+12|0)>>2]}jb=d+16|0;break b}bd();L()}e=gq(v[a>>2],v[a+4>>2]);og(f+12|0,i);if(c){if(c>>>0>=76695845){Lg();L()}d=sc(B(c,56))}else{d=0}v[f>>2]=d;e=d+B(e,56)|0;v[f+8>>2]=e;v[f+4>>2]=e;j=Bc(f),k=d+B(c,56)|0,v[j>>2]=k;c=v[f+8>>2];v[23588]=0;R(656,c|0,b|0);b=v[23588];v[23588]=0;c:{if((b|0)!=1){v[f+8>>2]=v[f+8>>2]+56;e=v[a>>2];b=v[a+4>>2];d=f+4|0;while(1){if((b|0)!=(e|0)){b=b-56|0;c=vl(v[d>>2]-56|0,b);vl(c+12|0,b+12|0);Xz(c+24|0,b+24|0);u[c+52>>1]=x[b+52>>1];g=v[b+48>>2];v[c+44>>2]=v[b+44>>2];v[c+48>>2]=g;g=v[b+40>>2];v[c+36>>2]=v[b+36>>2];v[c+40>>2]=g;v[d>>2]=v[d>>2]-56;continue}break}pc(a,d);pc(a+4|0,f+8|0);pc(Fb(a),Bc(f));v[f>>2]=v[f+4>>2];pR(f);jb=h+32|0;break c}a=P()|0;O()|0;pR(f);T(a|0);L()}}function oG(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=jb-352|0;jb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=bj(d);i=mp(d,a+224|0);lp(a+208|0,d,a+332|0);d=Lb(a+192|0);c=ad(d);v[23588]=0;R(60,d|0,c|0);c=v[23588];v[23588]=0;a:{b:{c:{if((c|0)!=1){c=Sc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[23588]=0;g=Q(1141,a+344|0,a+336|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=Gb(d);if((h|0)==(g+c|0)){v[23588]=0;R(60,d|0,g<<1);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=ad(d);v[23588]=0;R(60,d|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=Sc(d,0);v[a+188>>2]=g+c}v[23588]=0;g=S(1143,v[a+344>>2])|0;h=v[23588];v[23588]=0;if((h|0)==1){break d}if(xn(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,i)){break c}v[23588]=0;S(1145,a+344|0)|0;g=v[23588];v[23588]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Gb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}k=f,l=wG(c,v[a+188>>2],e,b),v[k>>2]=l;Ff(a+208|0,a+16|0,v[a+12>>2],e);v[23588]=0;b=Q(1142,a+344|0,a+336|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];yb(d);yb(a+208|0);jb=a+352|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);T(b|0);L()}return b|0}function Z$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=jb-352|0;jb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=bj(d);i=mp(d,a+224|0);lp(a+208|0,d,a+332|0);d=Lb(a+192|0);c=ad(d);v[23588]=0;R(60,d|0,c|0);c=v[23588];v[23588]=0;a:{b:{c:{if((c|0)!=1){c=Sc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[23588]=0;g=Q(1141,a+344|0,a+336|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=Gb(d);if((h|0)==(g+c|0)){v[23588]=0;R(60,d|0,g<<1);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=ad(d);v[23588]=0;R(60,d|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=Sc(d,0);v[a+188>>2]=g+c}v[23588]=0;g=S(1143,v[a+344>>2])|0;h=v[23588];v[23588]=0;if((h|0)==1){break d}if(xn(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,i)){break c}v[23588]=0;S(1145,a+344|0)|0;g=v[23588];v[23588]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Gb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}k=f,l=CG(c,v[a+188>>2],e,b),v[k>>2]=l;Ff(a+208|0,a+16|0,v[a+12>>2],e);v[23588]=0;b=Q(1142,a+344|0,a+336|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];yb(d);yb(a+208|0);jb=a+352|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);T(b|0);L()}return b|0}function X$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=jb-352|0;jb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=bj(d);i=mp(d,a+224|0);lp(a+208|0,d,a+332|0);d=Lb(a+192|0);c=ad(d);v[23588]=0;R(60,d|0,c|0);c=v[23588];v[23588]=0;a:{b:{c:{if((c|0)!=1){c=Sc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[23588]=0;g=Q(1141,a+344|0,a+336|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=Gb(d);if((h|0)==(g+c|0)){v[23588]=0;R(60,d|0,g<<1);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=ad(d);v[23588]=0;R(60,d|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=Sc(d,0);v[a+188>>2]=g+c}v[23588]=0;g=S(1143,v[a+344>>2])|0;h=v[23588];v[23588]=0;if((h|0)==1){break d}if(xn(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,i)){break c}v[23588]=0;S(1145,a+344|0)|0;g=v[23588];v[23588]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Gb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}k=f,l=zG(c,v[a+188>>2],e,b),u[k>>1]=l;Ff(a+208|0,a+16|0,v[a+12>>2],e);v[23588]=0;b=Q(1142,a+344|0,a+336|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];yb(d);yb(a+208|0);jb=a+352|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);T(b|0);L()}return b|0}function IF(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;a=jb-16|0;jb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;c=v[a+12>>2];a:{while(1){if(c>>>0>=d>>>0){f=0;break a}b:{b=x[c>>1];c:{if(b>>>0<=127){f=1;c=v[a+8>>2];if((g-c|0)<=0){break a}v[a+8>>2]=c+1;t[c|0]=b;break c}if(b>>>0<=2047){c=v[a+8>>2];if((g-c|0)<2){break b}v[a+8>>2]=c+1;t[c|0]=b>>>6|192;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128;break c}if(b>>>0<=55295){c=v[a+8>>2];if((g-c|0)<3){break b}v[a+8>>2]=c+1;t[c|0]=b>>>12|224;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>6&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128;break c}d:{e:{if(b>>>0<=56319){f=1;if((d-c|0)<4){break a}i=x[c+2>>1];if((i&64512)!=56320){break e}if((g-v[a+8>>2]|0)<4){break a}v[a+12>>2]=c+2;c=v[a+8>>2];v[a+8>>2]=c+1;f=c;c=(b>>>6&15)+1|0;t[f|0]=c>>>2|240;f=v[a+8>>2];v[a+8>>2]=f+1;t[f|0]=c<<4&48|b>>>2&15|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=i>>>6&15|b<<4&48|128;b=v[a+8>>2];v[a+8>>2]=b+1;t[b|0]=i&63|128;break c}if(b>>>0>=57344){break d}}f=2;break a}c=v[a+8>>2];if((g-c|0)<3){break b}v[a+8>>2]=c+1;t[c|0]=b>>>12|224;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>6&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128}c=v[a+12>>2]+2|0;v[a+12>>2]=c;continue}break}f=1}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];jb=a+16|0;return f|0}function f0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=jb-240|0;jb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=bj(d);np(a+208|0,d,a+223|0);d=Lb(a+192|0);c=ad(d);v[23588]=0;R(60,d|0,c|0);c=v[23588];v[23588]=0;a:{b:{c:{if((c|0)!=1){c=Sc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;i=t[a+223|0];while(1){d:{v[23588]=0;g=Q(1125,a+232|0,a+224|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=Gb(d);if((h|0)==(g+c|0)){v[23588]=0;R(60,d|0,g<<1);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=ad(d);v[23588]=0;R(60,d|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=Sc(d,0);v[a+188>>2]=g+c}v[23588]=0;g=S(1127,v[a+232>>2])|0;h=v[23588];v[23588]=0;if((h|0)==1){break d}if(yn(g,b,c,a+188|0,a+8|0,i,a+208|0,a+16|0,a+12|0,82976)){break c}v[23588]=0;S(1129,a+232|0)|0;g=v[23588];v[23588]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Gb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}j=f,k=AG(c,v[a+188>>2],e,b),v[j>>2]=k;v[f+4>>2]=mb;Ff(a+208|0,a+16|0,v[a+12>>2],e);v[23588]=0;b=Q(1126,a+232|0,a+224|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];yb(d);yb(a+208|0);jb=a+240|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);T(b|0);L()}return b|0}function d0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=jb-240|0;jb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=bj(d);np(a+208|0,d,a+223|0);d=Lb(a+192|0);c=ad(d);v[23588]=0;R(60,d|0,c|0);c=v[23588];v[23588]=0;a:{b:{c:{if((c|0)!=1){c=Sc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;i=t[a+223|0];while(1){d:{v[23588]=0;g=Q(1125,a+232|0,a+224|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=Gb(d);if((h|0)==(g+c|0)){v[23588]=0;R(60,d|0,g<<1);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=ad(d);v[23588]=0;R(60,d|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=Sc(d,0);v[a+188>>2]=g+c}v[23588]=0;g=S(1127,v[a+232>>2])|0;h=v[23588];v[23588]=0;if((h|0)==1){break d}if(yn(g,b,c,a+188|0,a+8|0,i,a+208|0,a+16|0,a+12|0,82976)){break c}v[23588]=0;S(1129,a+232|0)|0;g=v[23588];v[23588]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Gb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}j=f,k=vG(c,v[a+188>>2],e,b),v[j>>2]=k;v[f+4>>2]=mb;Ff(a+208|0,a+16|0,v[a+12>>2],e);v[23588]=0;b=Q(1126,a+232|0,a+224|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];yb(d);yb(a+208|0);jb=a+240|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);T(b|0);L()}return b|0}function HW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;g=jb-1088|0;jb=g;e=Ih(a);Tb(e+20|0,0,1040);v[e+1064>>2]=0;v[e+1068>>2]=0;v[e+1060>>2]=c;t[e+1084|0]=d;a=e+1072|0;v[a>>2]=0;v[a+4>>2]=0;v[e+1080>>2]=0;i=e+1064|0;a=c;d=0;a:{b:{c:while(1){if(Kd(x[a+34>>1])>>>0<=d>>>0){break a}v[e+1064>>2]=0;v[e+1068>>2]=0;a=0;while(1){d:{e:{f:{g:{h:{i:{j:{if(y[c>>2]<=a>>>0){break j}a=v[b+8>>2];f=v[b>>2];v[23588]=0;a=W(156,f|0,a|0,2)|0;f=v[23588];v[23588]=0;if((f|0)==1){break i}if(!a){break j}v[23588]=0;a=S(194,b|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break h}if(!a){break e}v[23588]=0;U(190,g|0,b|0,a|0);a=v[23588];v[23588]=0;if((a|0)==1){break g}a=qr(g+24|0,g);f=gd(e,a);tc(f+20|0,a+20|0,1040);Ab(a);Ab(g);v[e+1076>>2]=0;v[e+1080>>2]=0;h=v[e+1060>>2];a=v[h+20>>2];if(Zm(x[h+34>>1])>>>0>=2){v[23588]=0;R(195,f|0,a+(d<<1)|0);a=v[23588];v[23588]=0;if((a|0)!=1){break e}break f}v[23588]=0;R(196,f|0,a+d|0);a=v[23588];v[23588]=0;if((a|0)==1){break f}break e}d=d+1|0;a=v[e+1060>>2];continue c}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=V(30480)|0;if((O()|0)!=(da(30480)|0)){break b}_(a|0)|0;v[23588]=0;Z(18);a=v[23588];v[23588]=0;if((a|0)==1){break d}}a=v[i>>2];continue}break}break}a=P()|0;O()|0}Ab(e);T(a|0);L()}jb=g+1088|0;return e|0}function Gca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0;h=jb-16|0;jb=h;f=v[a+48>>2];i=v[a+40>>2];j=v[a+36>>2];e=v[a+44>>2];l=v[a+16>>2];g=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=g;m=b+24|0;n=v[a+32>>2];o=v[a+28>>2];p=v[a+72>>2];b=v[a+68>>2];q=b;r=b>>31;b=v[a+64>>2];s=b;t=b>>31;b=v[a+60>>2];w=b;x=b>>31;y=v[a+8>>2];z=v[a+12>>2];while(1){b=e;if(d){e=Xb(b,-16777216,16776704);e=Lka(s,t,e,e>>31);g=mb;f=Xb(f,-16777216,16776704);k=Lka(q,r,f,f>>31);e=k+e|0;f=mb+g|0;f=e>>>0<k>>>0?f+1|0:f;A=e;e=(v[h+12>>2]<<1)+l|0;g=(((v[h+8>>2]>>>16|0)+4&131064)<<1)+m|0;g=(((((B(u[e+4>>1],u[g+10>>1])+B(u[e+2>>1],u[g+8>>1])|0)+B(u[e+6>>1],u[g+12>>1])|0)+B(u[e+8>>1],u[g+14>>1])|0)/2|0)+((((B(u[e-4>>1],u[g+2>>1])+B(u[e-6>>1],u[g>>1])|0)+B(u[e-2>>1],u[g+4>>1])|0)+B(u[e>>1],u[g+6>>1])|0)/2|0)|0)/16384<<8;e=g;k=Lka(e,e>>31,w,x);e=A+k|0;f=mb+f|0;f=e>>>0<k>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Xc(e,f,24);e=(f|0)/256|0;j=j+o|0;v[c>>2]=B(e,j>>12)+v[c>>2];i=i+n|0;v[c+4>>2]=v[c+4>>2]+B(i>>12,e);Qb(h+8|0,y,z);e=f-(g&p)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=c;v[a+40>>2]=i;v[a+20>>2]=j>>12;v[a+36>>2]=j;v[a+48>>2]=f;v[a+44>>2]=b;v[a+24>>2]=i>>12;jb=h+16|0}function TK(a){var b=0,c=C(0),d=0,e=0,f=0,g=C(0),h=0,i=0,k=C(0),m=0,n=0,o=C(0);d=jb-16|0;jb=d;b=v[v[a+16>>2]+24620>>2];e=a+4208|0;n=a,o=te(C(10),C(C(C(z[Db(e,0)>>2]*C(120))+C(-60))/C(20))),z[n+4232>>2]=o;k=C(C(b>>>0)/C(1e3));n=a,o=te(C(10),C(C(-1)/C(k*C(C(z[Db(e,1)>>2]*C(499.989990234375))+C(.009999999776482582))))),z[n+4236>>2]=o;n=a,o=te(C(10),C(C(-1)/C(k*C(C(z[Db(e,2)>>2]*C(2950))+C(50))))),z[n+4240>>2]=o;v[d+12>>2]=1325400064;c=C(te(C(10),C(C(C(z[Db(e,3)>>2]*C(60))+C(-60))/C(20)))*C(2147483648));b=(p(c),j(2));g=C(0);a:{if((b|0)==1065353216){break a}b:{if(b-2139095040>>>0<=2164260863){f=b<<1;if(!f){b=jb-16|0;z[b+12>>2]=-1;g=C(z[b+12>>2]/C(0));break a}if((b|0)==2139095040){break b}if(!(f>>>0<4278190080&(b|0)>=0)){g=LJ(c);break a}b=(p(C(c*C(8388608))),j(2))-192937984|0}f=b-1060306944|0;h=f>>>15&240;i=+(l(2,b-(f&-8388608)|0),q())*A[h+3568>>3]+-1;m=i*i;c=C((A[479]*m+(A[480]*i+A[481]))*m+(+(f>>23)*A[478]+A[h+3576>>3]+i))}g=c}z[d+8>>2]=C(C(g*C(67108864))/C(.6931471824645996))+C(67108864);n=a,o=C(z[nm(d+12|0,d+8|0)>>2]*C(4.656612873077393e-10)),z[n+4244>>2]=o;n=a,o=C(C(C(-1)/C(C(z[Db(e,4)>>2]*C(99))+C(1)))+C(1)),z[n+4248>>2]=o;c=C(C(C(z[Db(e,5)>>2]*C(4))*k)+C(2));c:{if(C(D(c))<C(2147483648)){h=~~c;break c}h=-2147483648}v[a+4252>>2]=h;jb=d+16|0}function te(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=C(0),k=0;f=(p(b),j(2));d=qF(f);a:{b:{c:{d:{c=(p(a),j(2));e:{if(c-2139095040>>>0>=2164260864){if(d){break e}break c}if(!d){break d}}i=C(1);if((c|0)==1065353216){break b}e=f<<1;if(!e){break b}d=e>>>0<4278190081;e=c<<1;a=C(a+b);if(!(d&e>>>0<=4278190080)){break a}if((e|0)==2130706432){break b}a=e>>>0>2130706431^(f|0)>=0?C(0):C(b*b);break a}if(qF(c)){i=C(a*a);if((c|0)<0){i=(pF(f)|0)==1?C(-i):i}if((f|0)>=0){break b}a=TH(C(C(1)/i));break a}if((c|0)<0){e=pF(f);if(!e){a=LJ(a);break a}c=c&2147483647;e=((e|0)==1)<<16}if(c>>>0>8388607){break c}c=((p(C(a*C(8388608))),j(2))&2147483647)-192937984|0}f=c-1060306944|0;d=f>>>15&240;g=+(l(2,c-(f&-8388608)|0),q())*A[d+93576>>3]+-1;h=g*g;h=((g*.288457581109214+-.36092606229713164)*(h*h)+((g*.480898481472577+-.7213474675006291)*h+(g*1.4426950408774342+(A[d+93584>>3]+ +(f>>23)))))*+b;o(+h);d=j(1)|0;j(0)|0;f:{d=d&2147450880;if((d|0)==1079967744|d>>>0<1079967744){break f}if(h>127.99999995700433){a=GD(e);break a}if(!(h<=-150)){break f}a=fD(e);break a}k=h;g=A[160];h=g+h;g=k-(h-g);k=(A[161]*g+A[162])*(g*g)+(A[163]*g+1);o(+h);j(1)|0;c=j(0)|0;f=e+c|0;f=f<<15;d=((c&31)<<3)+1024|0;e=v[d>>2];c=e;d=v[d+4>>2]+f|0;l(0,c|0);l(1,(c>>>0<c>>>0?d+1|0:d)|0);i=C(k*+n())}a=i}return a}function xG(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=jb-240|0;jb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=bj(d);np(a+208|0,d,a+223|0);d=Lb(a+192|0);c=ad(d);v[23588]=0;R(60,d|0,c|0);c=v[23588];v[23588]=0;a:{b:{c:{if((c|0)!=1){c=Sc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;i=t[a+223|0];while(1){d:{v[23588]=0;g=Q(1125,a+232|0,a+224|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=Gb(d);if((h|0)==(g+c|0)){v[23588]=0;R(60,d|0,g<<1);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=ad(d);v[23588]=0;R(60,d|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=Sc(d,0);v[a+188>>2]=g+c}v[23588]=0;g=S(1127,v[a+232>>2])|0;h=v[23588];v[23588]=0;if((h|0)==1){break d}if(yn(g,b,c,a+188|0,a+8|0,i,a+208|0,a+16|0,a+12|0,82976)){break c}v[23588]=0;S(1129,a+232|0)|0;g=v[23588];v[23588]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Gb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}j=f,k=wG(c,v[a+188>>2],e,b),v[j>>2]=k;Ff(a+208|0,a+16|0,v[a+12>>2],e);v[23588]=0;b=Q(1126,a+232|0,a+224|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];yb(d);yb(a+208|0);jb=a+240|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);T(b|0);L()}return b|0}function h0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=jb-240|0;jb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=bj(d);np(a+208|0,d,a+223|0);d=Lb(a+192|0);c=ad(d);v[23588]=0;R(60,d|0,c|0);c=v[23588];v[23588]=0;a:{b:{c:{if((c|0)!=1){c=Sc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;i=t[a+223|0];while(1){d:{v[23588]=0;g=Q(1125,a+232|0,a+224|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=Gb(d);if((h|0)==(g+c|0)){v[23588]=0;R(60,d|0,g<<1);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=ad(d);v[23588]=0;R(60,d|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=Sc(d,0);v[a+188>>2]=g+c}v[23588]=0;g=S(1127,v[a+232>>2])|0;h=v[23588];v[23588]=0;if((h|0)==1){break d}if(yn(g,b,c,a+188|0,a+8|0,i,a+208|0,a+16|0,a+12|0,82976)){break c}v[23588]=0;S(1129,a+232|0)|0;g=v[23588];v[23588]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Gb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}j=f,k=CG(c,v[a+188>>2],e,b),v[j>>2]=k;Ff(a+208|0,a+16|0,v[a+12>>2],e);v[23588]=0;b=Q(1126,a+232|0,a+224|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];yb(d);yb(a+208|0);jb=a+240|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);T(b|0);L()}return b|0}function e0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=jb-240|0;jb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=bj(d);np(a+208|0,d,a+223|0);d=Lb(a+192|0);c=ad(d);v[23588]=0;R(60,d|0,c|0);c=v[23588];v[23588]=0;a:{b:{c:{if((c|0)!=1){c=Sc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;i=t[a+223|0];while(1){d:{v[23588]=0;g=Q(1125,a+232|0,a+224|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=Gb(d);if((h|0)==(g+c|0)){v[23588]=0;R(60,d|0,g<<1);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=ad(d);v[23588]=0;R(60,d|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=Sc(d,0);v[a+188>>2]=g+c}v[23588]=0;g=S(1127,v[a+232>>2])|0;h=v[23588];v[23588]=0;if((h|0)==1){break d}if(yn(g,b,c,a+188|0,a+8|0,i,a+208|0,a+16|0,a+12|0,82976)){break c}v[23588]=0;S(1129,a+232|0)|0;g=v[23588];v[23588]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Gb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}j=f,k=zG(c,v[a+188>>2],e,b),u[j>>1]=k;Ff(a+208|0,a+16|0,v[a+12>>2],e);v[23588]=0;b=Q(1126,a+232|0,a+224|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];yb(d);yb(a+208|0);jb=a+240|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);T(b|0);L()}return b|0}function F$(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=jb-16|0;jb=k;l=Qw(g);g=xw(g);bh(k,g);a:{b:{if(Qe(k)){v[23588]=0;X(1148,l|0,a|0,c|0,d|0);g=v[23588];v[23588]=0;if((g|0)==1){break b}g=(c-a<<2)+d|0;v[f>>2]=g;break a}v[f>>2]=d;c:{d:{j=a;h=w[j|0];switch(h-43|0){case 0:case 2:break d;default:break c}}v[23588]=0;j=Q(1154,l|0,h<<24>>24)|0;h=v[23588];v[23588]=0;if((h|0)==1){break b}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=j;j=a+1|0}if(!(w[j|0]!=48|(c-j|0)<2|(w[j+1|0]|32)!=120)){v[23588]=0;h=Q(1154,l|0,48)|0;i=v[23588];v[23588]=0;if((i|0)==1){break b}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=h;h=t[j+1|0];v[23588]=0;h=Q(1154,l|0,h|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break b}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=h;j=j+2|0}$l(j,c);i=0;v[23588]=0;o=S(1146,g|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break b}h=0;g=j;while(1){if(c>>>0<=g>>>0){Sr((j-a<<2)+d|0,v[f>>2]);g=v[f>>2];break a}e:{if(!w[Sc(k,h)|0]){break e}if(t[Sc(k,h)|0]!=(i|0)){break e}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=o;h=(Gb(k)-1>>>0>h>>>0)+h|0;i=0}n=t[g|0];v[23588]=0;n=Q(1154,l|0,n|0)|0;m=v[23588];v[23588]=0;if((m|0)!=1){m=v[f>>2];v[f>>2]=m+4;v[m>>2]=n;g=g+1|0;i=i+1|0;continue}break}}a=P()|0;O()|0;yb(k);T(a|0);L()}v[e>>2]=(b|0)==(c|0)?g:(b-a<<2)+d|0;yb(k);jb=k+16|0}function cI(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=C(0),k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=C(0);d=(b<<2)+a|0;h=d+1068|0;k=c<<1&-4;p=h,q=fe(a,k),v[p>>2]=q;g=d+1076|0;p=g,q=fe(a,k),v[p>>2]=q;i=fe(a,c&-4);v[d+1084>>2]=i;a:{h=v[h>>2];if(!h){break a}g=v[g>>2];if(!g|!i){break a}d=c>>2;o=(d|0)>0?d:0;j=C(c|0);d=0;while(1){if((e|0)==(o|0)){d=0;e=c>>3;h=(e|0)>0?e:0;e=0;while(1){if((d|0)!=(h|0)){g=e|1;f=+C(C(C(g<<1)*C(3.1415927410125732))/j);p=i+(e<<2)|0,r=C($e(f)),z[p>>2]=r;p=i+(g<<2)|0,r=C(-C(Ci(f))),z[p>>2]=r;e=e+2|0;d=d+1|0;continue}break}}else{l=d<<2;f=+C(C(C(e<<2)*C(3.1415927410125732))/j);p=h+l|0,r=C($e(f)),z[p>>2]=r;m=d|1;n=m<<2;p=h+n|0,r=C(-C(Ci(f))),z[p>>2]=r;f=+C(C(C(C(m|0)*C(3.1415927410125732))/j)*C(.5));p=g+l|0,r=C(C($e(f))*C(.5)),z[p>>2]=r;p=g+n|0,r=C(C(Ci(f))*C(.5)),z[p>>2]=r;d=d+2|0;e=e+1|0;continue}break}i=(b<<2)+a|0;d=fe(a,k);v[i+1092>>2]=d;if(!d){break a}b=0;e=c>>1;k=(e|0)>0?e:0;f=+(e|0);while(1){if((b|0)!=(k|0)){j=C(Ci((+(b|0)+.5)/f*.5*3.1415927410125732));p=d+(b<<2)|0,r=C(Ci(+C(j*j)*1.5707963705062866)),z[p>>2]=r;b=b+1|0;continue}break}b=fe(a,c>>2&-2);v[i+1100>>2]=b;if(!b){break a}a=0;d=c>>3;d=(d|0)>0?d:0;c=36-im(c)|0;while(1){if((a|0)!=(d|0)){p=b+(a<<1)|0,q=gm(a)>>>c<<2,u[p>>1]=q;a=a+1|0;continue}break}return 1}dc(a,3);return 0}function e4(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=jb-80|0;jb=e;a:{b:{c:{d:{f=a+36|0;d=v[f>>2];c=v[a+40>>2];e:{if(Ob(d,c)){Gc(e+72|0);break e}c=e+32|0;In(c,a);v[23588]=0;c=S(1012,c|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break d}v[e+72>>2]=c;Wf(e+32|0);c=v[a+40>>2];d=v[a+36>>2]}c=(k=f,l=v[e+72>>2],m=Ob(d,c),m?k:l);f=v[a+8>>2];if((f|0)==-1){d=v[c+4>>2];f=d-24|0;g=v[c>>2];i=Qi(g,d);j=A[f>>3];d=0;while(1){if((d|0)==(i|0)){c=f;break c}c=lf(g,d);if(h+A[c>>3]>b){break c}d=d+1|0;h=h+j;continue}}c=lf(v[c>>2],f);break b}d=P()|0;O()|0;Wf(e+32|0);break a}b=b-h}f=x[c+12>>1];d=v[a+24>>2];v[23588]=0;R(1045,d|0,f|0);f=v[23588];v[23588]=0;if((f|0)!=1){f:{f=v[a+24>>2];d=w[a+64|0];c=vM(aS(e+32|0,b),w[c+16|0],x[c+12>>1],v[c+8>>2]);v[23588]=0;g=v[c+12>>2];v[e+16>>2]=v[c+8>>2];v[e+20>>2]=g;g=v[c+20>>2];v[e+24>>2]=v[c+16>>2];v[e+28>>2]=g;g=v[c+4>>2];v[e+8>>2]=v[c>>2];v[e+12>>2]=g;X(1046,e+56|0,f|0,(d?7:1)|0,e+8|0);c=v[23588];v[23588]=0;if((c|0)==1){break f}c=wM(v[e+60>>2]);f=t[c+26|0]&1;d=v[(f?c+8|0:c+12|0)>>2];f=x[(f?c+20|0:c+22|0)>>1];b=A[c>>3];Di(e+56|0);c=v[a+24>>2];u[c+1074450>>1]=f;u[c+1074448>>1]=f;v[c+1074428>>2]=d;v[c+1074392>>2]=-2;b=h+b;A[a+16>>3]=b;al(e+72|0);jb=e+80|0;return+b}}d=P()|0;O()|0;al(e+72|0)}T(d|0);L()}function Hca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0;h=jb-16|0;jb=h;f=v[a+48>>2];i=v[a+40>>2];j=v[a+36>>2];e=v[a+44>>2];l=v[a+16>>2];g=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=g;m=b+24|0;n=v[a+32>>2];o=v[a+28>>2];p=v[a+72>>2];b=v[a+68>>2];q=b;r=b>>31;b=v[a+64>>2];s=b;w=b>>31;b=v[a+60>>2];x=b;y=b>>31;z=v[a+8>>2];A=v[a+12>>2];while(1){b=e;if(d){e=Xb(b,-16777216,16776704);e=Lka(s,w,e,e>>31);g=mb;f=Xb(f,-16777216,16776704);k=Lka(q,r,f,f>>31);e=k+e|0;f=mb+g|0;f=e>>>0<k>>>0?f+1|0:f;C=e;e=v[h+12>>2]+l|0;g=(((v[h+8>>2]>>>16|0)+4&131064)<<1)+m|0;g=(((((B(t[e+2|0],u[g+10>>1])+B(t[e+1|0],u[g+8>>1])|0)+B(t[e+3|0],u[g+12>>1])|0)+B(t[e+4|0],u[g+14>>1])<<8)/2|0)+((((B(t[e-2|0],u[g+2>>1])+B(t[e-3|0],u[g>>1])|0)+B(t[e-1|0],u[g+4>>1])|0)+B(t[e|0],u[g+6>>1])<<8)/2|0)|0)/16384<<8;e=g;k=Lka(e,e>>31,x,y);e=C+k|0;f=mb+f|0;f=e>>>0<k>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Xc(e,f,24);e=(f|0)/256|0;j=j+o|0;v[c>>2]=B(e,j>>12)+v[c>>2];i=i+n|0;v[c+4>>2]=v[c+4>>2]+B(i>>12,e);Qb(h+8|0,z,A);e=f-(g&p)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=c;v[a+40>>2]=i;v[a+20>>2]=j>>12;v[a+36>>2]=j;v[a+48>>2]=f;v[a+44>>2]=b;v[a+24>>2]=i>>12;jb=h+16|0}function eh(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;f=jb-16|0;jb=f;v[f+12>>2]=d;e=0;a:{if(b-251>>>0<4294967046){break a}e=b-1|0;g=v[a+480180>>2];if(!Jm(g)){if(g&17408){a=((e&255)>>>0)/12|0;e=x[((B(a,-12)+e&255)<<1)+33248>>1]<<4>>>a|0;break a}if(!d){v[f+12>>2]=8363;d=8363}if(nj(a)){a=((e&255)>>>0)/12|0;b=Lka(v[(B(a,-12)+e<<6&960)+37136>>2]<<a,0,d,0);a=mb;c=a>>>21|0;h=f,i=Dc((a&2097151)<<11|b>>>21,c),v[h>>2]=i;wc(f,2147483647);e=v[f>>2];break a}if(w[a+480208|0]&16){a=e&255;e=x[((a>>>0)%12<<1)+33248>>1]<<5>>>(a>>>0)/12|0;break a}a=((e&255)>>>0)/12|0;wc(f+12|0,-1>>>a|0);e=Dc(Oka(Lka(x[((B(a,-12)+e&255)<<1)+33248>>1],0,267616,0),mb,v[f+12>>2]<<a,0),mb);break a}if(g&20){d=e>>>0>12;if((g|0)==16){b=c<<4}else{Cb(f,a+1074312|0,76);b=Bb(v[v[f>>2]>>2],v[f+4>>2])?c&-8:c}c=d?e:12;if(w[a+480208|0]&16){a=(((b|0)/-2|0)-(c<<6)|0)+8448|0;e=(a|0)>1?a:1;break a}a=c-12|0;c=((a&255)>>>0)/12|0;d=((b|0)/16|0)+(B(c,-12)+a<<3&248)|0;v[f>>2]=d+8;oe(f,0,103);a=b>>31;b=(a^b)-a&15;a=d+(a|1)|0;a=(a|0)>-8?a:-8;e=B(b,x[(((a|0)<95?a:95)<<1)+33744>>1])+B(x[(v[f>>2]<<1)+33728>>1],16-b|0)<<1>>>c|0;break a}if(!((c&255)>>>0<16&b-25>>>0<=83)){a=((e&255)>>>0)/12|0;e=x[(B((c&240)>>>4|0,12)+(B(a,-12)+e&255)<<1)+32848>>1]<<5>>>a|0;break a}e=x[(b<<1)+32622>>1]<<2}jb=f+16|0;return e}function jJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0;c=jb+-64|0;jb=c;d=v[a>>2];a=v[d>>2];f=v[a+4>>2];v[c+40>>2]=v[a+20>>2];g=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=g;Hf(c+48|0,c+32|0,f);a=v[d+4>>2];f=v[a+8>>2];g=v[a+4>>2];d=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=d;d=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=d;v[c+8>>2]=v[a+8>>2];d=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=d;a=jb-32|0;jb=a;a:{b:{c:{d:{k=v[c+4>>2];if(k>>>0>=g>>>0){l=v[c+20>>2];if(l>>>0<g>>>0){break d}if(f>>>0>y[c+8>>2]){break c}m=v[c+28>>2];if(f>>>0>v[c+24>>2]-m>>>0){break b}n=b+12|0;o=v[c+16>>2];p=v[c>>2];e:while(1){if((f|0)==(h|0)){break a}q=B(h,k);r=B(h+m|0,l);d=0;while(1)if((d|0)==(g|0)){h=h+1|0;continue e}else{e=Db(v[b>>2],d);i=we(mg(A[(d+q<<3)+p>>3])*134217728);j=e;e=(v[e>>2]>>1)+Im(i)|0;s=e;e=ws(n)+e&-4096;v[j>>2]=s-e;A[a+24>>3]=+(e|0)*7.450580596923828e-9;v[a+16>>2]=0;v[a+20>>2]=-1074790400;v[a+8>>2]=0;v[a+12>>2]=1072693248;j=(d+r<<1)+o|0;i=we(A[Gg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(D(i)<2147483648){e=~~i;break f}e=-2147483648}t=j,w=dd(e),u[t>>1]=w;d=d+1|0;continue}}}aa(7192,9005,77,8685);L()}aa(7157,9005,78,8685);L()}aa(5900,9005,79,8685);L()}aa(5870,9005,80,8685);L()}jb=a+32|0;jb=c- -64|0}function sJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;c=jb+-64|0;jb=c;d=v[a>>2];a=v[d>>2];f=v[a+4>>2];v[c+40>>2]=v[a+20>>2];g=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=g;Hf(c+48|0,c+32|0,f);a=v[d+4>>2];f=v[a+8>>2];g=v[a+4>>2];d=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=d;d=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=d;v[c+8>>2]=v[a+8>>2];d=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=d;a=jb-32|0;jb=a;a:{b:{c:{d:{l=v[c+4>>2];if(l>>>0>=g>>>0){if(y[c+20>>2]<g>>>0){break d}if(f>>>0>y[c+8>>2]){break c}m=v[c+28>>2];if(f>>>0>v[c+24>>2]-m>>>0){break b}n=b+12|0;o=v[c+16>>2];p=v[c>>2];e:while(1){if((f|0)==(h|0)){break a}q=h+m|0;r=B(h,l);d=0;while(1)if((d|0)==(g|0)){h=h+1|0;continue e}else{e=Db(v[b>>2],d);i=we(mg(A[(d+r<<3)+p>>3])*134217728);j=e;e=(v[e>>2]>>1)+Im(i)|0;k=e;e=ws(n)+e&-4096;v[j>>2]=k-e;A[a+24>>3]=+(e|0)*7.450580596923828e-9;v[a+16>>2]=0;v[a+20>>2]=-1074790400;v[a+8>>2]=0;v[a+12>>2]=1072693248;j=q<<1;k=(d<<2)+o|0;i=we(A[Gg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(D(i)<2147483648){e=~~i;break f}e=-2147483648}s=j+v[k>>2]|0,t=dd(e),u[s>>1]=t;d=d+1|0;continue}}}aa(7192,9005,77,8685);L()}aa(7157,9005,78,8685);L()}aa(5900,9005,79,8685);L()}aa(5870,9005,80,8685);L()}jb=a+32|0;jb=c- -64|0}function jS(a,b){var c=0;a:{b:{c:{d:{if(ne(a,16692)){break d}if(ne(a,17461)){break d}if(ne(a,13490)){break d}if(ne(a,13645)){break d}if(!ne(a,14214)){break c}}u[b+10>>1]=4;v[b>>2]=11956;break b}e:{f:{if(ne(a,17456)){break f}if(ne(a,13500)){break f}if(!ne(a,16677)){break e}}t[b+12|0]=1;v[b>>2]=8351;u[b+10>>1]=4;return 1}g:{if(!ne(a,14260)){if(!ne(a,14265)){break g}}u[b+10>>1]=8;v[b>>2]=8129;break b}h:{if(!ne(a,15341)){if(!ne(a,15346)){break h}}v[b>>2]=17064;u[b+10>>1]=t[a+2|0]-48;break b}i:{if(!ne(a,26874)){if(!ne(a,26879)){break i}}v[b+4>>2]=1;v[b>>2]=16870;u[b+10>>1]=w[a|0]==56?8:4;return 1}if(!(Rb(a,15453,3)|(w[a+3|0]-52&255)>>>0>4)){v[b>>2]=8469;a=t[a+3|0];u[b+8>>1]=1088;u[b+10>>1]=a-48;break b}j:{if(Rb(a,13573,3)){if(Rb(a,13707,3)){break j}}if((w[a+3|0]-52&255)>>>0>5){break j}t[b+15|0]=1;t[b+13|0]=1;v[b>>2]=8228;u[b+10>>1]=t[a+3|0]-48;return 1}k:{if((w[a|0]-49&255)>>>0>8){break k}if(!Rb(a+1|0,13731,3)){t[b+14|0]=1;v[b>>2]=8533;u[b+10>>1]=t[a|0]-48;return 1}if((w[a+1|0]-48&255)>>>0>9){break k}c=a+2|0;if(Rb(c,14063,2)){if(Rb(c,13735,2)){break k}}t[b+14|0]=1;v[b>>2]=8533;u[b+10>>1]=(t[a+1|0]+B(t[a|0],10)|0)-528;return 1}c=0;if(Rb(a,13356,3)|(w[a+3|0]-49&255)>>>0>8){break a}v[b>>2]=8378;u[b+10>>1]=t[a+3|0]-48}c=1}return c}function Q_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=jb-496|0;jb=a;g=a+488|0;fd(g,d);v[23588]=0;m=S(1136,g|0)|0;g=v[23588];v[23588]=0;a:{b:{c:{d:{e:{f:{g:{if((g|0)!=1){if(Gb(f)){g=v[zi(f,0)>>2];v[23588]=0;h=Q(1154,m|0,45)|0;k=v[23588];v[23588]=0;if((k|0)==1){break g}n=(g|0)==(h|0)}k=Lb(a+456|0);g=Lb(a+440|0);h=Lb(a+424|0);v[23588]=0;na(1175,c|0,n|0,a+488|0,a+480|0,a+476|0,a+472|0,k|0,g|0,h|0,a+420|0);c=v[23588];v[23588]=0;if((c|0)==1){break f}v[a+4>>2]=1123;c=se(a+8|0,0,a+4|0);j=Gb(f);l=v[a+420>>2];h:{if((j|0)>(l|0)){i=((Gb(h)+(j-l<<1)|0)+Gb(g)|0)+1|0;break h}i=(Gb(h)+Gb(g)|0)+2|0}j=a+16|0;i=i+l|0;if(i>>>0<101){break e}Ze(c,Od(i<<2));j=v[c>>2];if(j){break e}v[23588]=0;Z(1124);b=v[23588];v[23588]=0;if((b|0)==1){break d}L()}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break c}o=v[d+4>>2];i=zc(f);f=Gb(f);v[23588]=0;pa(1176,j|0,a+4|0,a|0,o|0,i|0,i+(f<<2)|0,m|0,n|0,a+480|0,v[a+476>>2],v[a+472>>2],k|0,g|0,h|0,l|0);f=v[23588];v[23588]=0;if((f|0)!=1){v[23588]=0;b=ka(1157,b|0,j|0,v[a+4>>2],v[a>>2],d|0,e|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){break a}}}f=P()|0;O()|0;Wc(c)}Fc(h);Fc(g);yb(k)}$b(a+488|0);T(f|0);L()}Wc(c);Fc(h);Fc(g);yb(k);$b(a+488|0);jb=a+496|0;return b|0}function DM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;f=a+484376|0;while(1){a:{c=Vb(v[a+484360>>2],w[f|0]);e=b&65535;if(Qc(v[c>>2],v[c+4>>2])>>>0>e>>>0){if(!Gq(c,e)){break a}c=Vb(v[a+484360>>2],w[a+484376|0])}if(Qc(v[c>>2],v[c+4>>2])>>>0>e>>>0){e=a+1074312|0;f=a+1298224|0;c=a+1074992|0;b:{while(1){c:{if((c|0)==(f|0)){CM(a);if(b&65535){break c}b=0;while(1){if((b|0)==256){$n(a+1298264|0,1);v[a+1074456>>2]=v[a+480200>>2];v[a+1074416>>2]=v[a+480196>>2];v[a+1074420>>2]=v[a+480204>>2];v[a+480208>>2]=v[a+480208>>2]&-769;Wy(a+1074376|0);u[a+1074450>>1]=0;v[a+1074392>>2]=-2;b=a+1074428|0;v[b>>2]=0;v[b+4>>2]=0;b=a+1074396|0;v[b>>2]=0;v[b+4>>2]=0;v[a+1074376>>2]=0;v[a+1074380>>2]=0}else{eo((B(b,872)+a|0)+1074992|0,a,b&65535,134217728);b=b+1|0;continue}break}break b}t[c+797|0]=0;v[c+700>>2]=0;t[c+841|0]=0;t[c+805|0]=0;v[c+708>>2]=0;t[c+821|0]=0;v[c+764>>2]=0;t[c+819|0]=0;t[c+820|0]=0;Cb(d+8|0,e,23);if(Bb(v[v[d+8>>2]>>2],v[d+12>>2])){t[c+807|0]=1;t[c+808|0]=0}t[c+839|0]=0;c=c+872|0;continue}break}u[a+1074450>>1]=b;u[a+1074446>>1]=0;b=a+1074424|0;v[b>>2]=0;v[b+4>>2]=0;v[a+1074392>>2]=-2;v[a+1074432>>2]=0;b=a+1074396|0;v[b>>2]=0;v[b+4>>2]=0;v[a+1074380>>2]=0}v[a+480208>>2]=v[a+480208>>2]&-769}jb=d+16|0;return}b=b+1|0;continue}}function P$(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=jb-16|0;jb=k;l=hv(g);g=Dw(g);bh(k,g);a:{b:{if(Qe(k)){v[23588]=0;X(1134,l|0,a|0,c|0,d|0);g=v[23588];v[23588]=0;if((g|0)==1){break b}g=(c-a|0)+d|0;v[f>>2]=g;break a}v[f>>2]=d;c:{d:{j=a;h=w[j|0];switch(h-43|0){case 0:case 2:break d;default:break c}}v[23588]=0;j=Q(20,l|0,h<<24>>24)|0;h=v[23588];v[23588]=0;if((h|0)==1){break b}h=v[f>>2];v[f>>2]=h+1;t[h|0]=j;j=a+1|0}if(!(w[j|0]!=48|(c-j|0)<2|(w[j+1|0]|32)!=120)){v[23588]=0;h=Q(20,l|0,48)|0;i=v[23588];v[23588]=0;if((i|0)==1){break b}i=v[f>>2];v[f>>2]=i+1;t[i|0]=h;h=t[j+1|0];v[23588]=0;h=Q(20,l|0,h|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break b}i=v[f>>2];v[f>>2]=i+1;t[i|0]=h;j=j+2|0}$l(j,c);i=0;v[23588]=0;o=S(1132,g|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break b}h=0;g=j;while(1){if(c>>>0<=g>>>0){$l((j-a|0)+d|0,v[f>>2]);g=v[f>>2];break a}e:{if(!w[Sc(k,h)|0]){break e}if(t[Sc(k,h)|0]!=(i|0)){break e}i=v[f>>2];v[f>>2]=i+1;t[i|0]=o;h=(Gb(k)-1>>>0>h>>>0)+h|0;i=0}n=t[g|0];v[23588]=0;n=Q(20,l|0,n|0)|0;m=v[23588];v[23588]=0;if((m|0)!=1){m=v[f>>2];v[f>>2]=m+1;t[m|0]=n;g=g+1|0;i=i+1|0;continue}break}}a=P()|0;O()|0;yb(k);T(a|0);L()}v[e>>2]=(b|0)==(c|0)?g:(b-a|0)+d|0;yb(k);jb=k+16|0}function Er(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a:{e=jb-96|0;jb=e;i=v[c>>2];g=jb-32|0;jb=g;f=e- -64|0;j=Lb(f+16|0);v[f>>2]=v[c>>2];v[f+4>>2]=v[c+4>>2];v[f+8>>2]=v[c+8>>2];v[f+12>>2]=v[c+12>>2];v[23588]=0;c=Q(54,g|0,c+16|0)|0;h=v[23588];v[23588]=0;b:{c:{d:{if((h|0)!=1){v[23588]=0;R(58,g+16|0,c|0);h=v[23588];v[23588]=0;if((h|0)==1){break d}f=g+16|0;Ac(j,f);yb(f);yb(c);jb=g+32|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;yb(c)}jm(f);T(a|0);L()}v[23588]=0;U(d|0,e|0,b|0,(i&2?16:10)|0);b=v[23588];v[23588]=0;e:{f:{g:{h:{i:{j:{if((b|0)!=1){c=e+16|0;b=jb-16|0;jb=b;k:{if(!(v[e+64>>2]&32)){break k}k=b,l=he(e),v[k+8>>2]=l;k=b,l=yh(e),v[k>>2]=l;while(1){if(!yi(b+8|0,b)){break k}d=v[b+8>>2];f=w[d|0];if((f-97&255)>>>0<=25){t[d|0]=f-32}Ge(b+8|0);continue}}$c(c,e);jb=b+16|0;v[23588]=0;X(75,e+32|0,c|0,v[e+64>>2],v[e+68>>2]);b=v[23588];v[23588]=0;if((b|0)==1){break j}v[23588]=0;U(76,e+48|0,e+32|0,e- -64|0);b=v[23588];v[23588]=0;if((b|0)==1){break i}v[23588]=0;R(58,a|0,e+48|0);a=v[23588];v[23588]=0;if((a|0)==1){break h}yb(e+48|0);yb(e+32|0);yb(e+16|0);yb(e);jm(e- -64|0);jb=e+96|0;break a}a=P()|0;O()|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;break g}a=P()|0;O()|0;yb(e+48|0)}yb(e+32|0)}yb(e+16|0);yb(e)}jm(e- -64|0);T(a|0);L()}}function SG(a,b){var c=0,d=0,e=0,f=0,g=0;a:{b:{c:{d:{e:{f:{g:{c=v[a+4>>2];h:{if((c|0)!=v[a+104>>2]){v[a+4>>2]=c+1;c=w[c|0];break h}c=rd(a)}switch(c-43|0){case 0:case 2:break g;default:break f}}f=(c|0)==45;g=!b;c=v[a+4>>2];i:{if((c|0)!=v[a+104>>2]){v[a+4>>2]=c+1;c=w[c|0];break i}c=rd(a)}b=c-58|0;if(g|b>>>0>4294967285){break e}b=v[a+116>>2];if((b|0)>0|(b|0)>=0){break d}break a}b=c-58|0}if(b>>>0<4294967286){break c}b=c-48|0;if(b>>>0<10){while(1){e=(B(e,10)+c|0)-48|0;d=(e|0)<214748364;c=v[a+4>>2];j:{if((c|0)!=v[a+104>>2]){v[a+4>>2]=c+1;c=w[c|0];break j}c=rd(a)}b=c-48|0;if(d&b>>>0<=9){continue}break}d=e>>31}k:{if(b>>>0>=10){break k}while(1){b=Lka(e,d,10,0);c=b+c|0;d=mb;d=b>>>0>c>>>0?d+1|0:d;b=c;e=b-48|0;d=d-(b>>>0<48)|0;b=v[a+4>>2];l:{if((b|0)!=v[a+104>>2]){v[a+4>>2]=b+1;c=w[b|0];break l}c=rd(a)}b=c-48|0;if(b>>>0>9){break k}if(e>>>0<2061584302&(d|0)<=21474836|(d|0)<21474836){continue}break}}if(b>>>0<10){while(1){b=v[a+4>>2];m:{if((b|0)!=v[a+104>>2]){v[a+4>>2]=b+1;b=w[b|0];break m}b=rd(a)}if(b-48>>>0<10){continue}break}}b=v[a+116>>2];if((b|0)>0|(b|0)>=0){v[a+4>>2]=v[a+4>>2]-1}mb=f?0-(((e|0)!=0)+d|0)|0:d;return f?0-e|0:e}v[a+4>>2]=v[a+4>>2]-1;break b}if(v[a+116>>2]<0){break a}}v[a+4>>2]=v[a+4>>2]-1}mb=-2147483648;return 0}function Yaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;i=jb-16|0;jb=i;d=v[b+1298304>>2];if(!Ed(d)){e=jb-16|0;jb=e;c=sc(12);v[23588]=0;d=S(907,c|0)|0;f=v[23588];v[23588]=0;a:{if((f|0)!=1){c=v[Lf(e+8|0,d)>>2];jb=e+16|0;break a}a=P()|0;O()|0;Mb(c);T(a|0);L()}v[i+8>>2]=c;c=b+1298304|0;e=i+8|0;SM(c,be(e));By(e);d=v[c>>2]}f=jb-48|0;jb=f;c=f+16|0;HM(c,a);v[23588]=0;U(8,f+32|0,0,c|0);c=v[23588];v[23588]=0;b:{c:{if((c|0)!=1){zb(f+16|0);m=f,n=Eb(v[d>>2]),v[m+8>>2]=n;l=Eb(v[d+4>>2]);c=0;d=0;while(1){d:{h=v[f+8>>2];if(!Ob(h,l)){e:{if(!d){break e}c=v[d+4>>2];if(!c){break e}v[23588]=0;a=W(c|0,d|0,b|0,a|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break d}if(!a){break e}b=v[d>>2];v[a+4>>2]=b;if(b){v[b+8>>2]=a}v[d>>2]=a}yb(f+32|0);jb=f+48|0;break b}j=0;e=v[h>>2];if(v[e+32>>2]==v[a+16>>2]){j=v[e+36>>2]==v[a+20>>2]}v[23588]=0;R(908,f+16|0,e+8|0);e=v[23588];v[23588]=0;if((e|0)!=1){g=jb-16|0;jb=g;k=f+16|0;Fe(g+8|0,k);Fe(g,f+32|0);e=aN(v[g+8>>2],v[g+12>>2],v[g>>2],v[g+4>>2]);jb=g+16|0;yb(k);f:{if(!(!j|(e|0)!=0)){d=v[h>>2];c=3;break f}if((c|0)<2&j){d=v[h>>2];c=2;break f}e=!e&(c|0)<=0;d=e?v[h>>2]:d;c=e?1:c}Ke(f+8|0);continue}}break}d=P()|0;O()|0;yb(f+32|0);break c}d=P()|0;O()|0;zb(f+16|0)}T(d|0);L()}jb=i+16|0}function U_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=jb-192|0;jb=a;g=a+184|0;fd(g,d);v[23588]=0;m=S(19,g|0)|0;g=v[23588];v[23588]=0;a:{b:{c:{d:{e:{f:{g:{if((g|0)!=1){if(Gb(f)){g=w[gg(f,0)|0];v[23588]=0;h=Q(20,m|0,45)|0;k=v[23588];v[23588]=0;if((k|0)==1){break g}n=(g|0)==(h&255)}k=Lb(a+160|0);g=Lb(a+144|0);h=Lb(a+128|0);v[23588]=0;na(1173,c|0,n|0,a+184|0,a+176|0,a+175|0,a+174|0,k|0,g|0,h|0,a+124|0);c=v[23588];v[23588]=0;if((c|0)==1){break f}v[a+4>>2]=1123;c=se(a+8|0,0,a+4|0);j=Gb(f);l=v[a+124>>2];h:{if((j|0)>(l|0)){i=((Gb(h)+(j-l<<1)|0)+Gb(g)|0)+1|0;break h}i=(Gb(h)+Gb(g)|0)+2|0}j=a+16|0;i=i+l|0;if(i>>>0<101){break e}Ze(c,Od(i));j=v[c>>2];if(j){break e}v[23588]=0;Z(1124);b=v[23588];v[23588]=0;if((b|0)==1){break d}L()}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break c}o=v[d+4>>2];i=Lc(f);f=Gb(f);v[23588]=0;pa(1174,j|0,a+4|0,a|0,o|0,i|0,f+i|0,m|0,n|0,a+176|0,t[a+175|0],t[a+174|0],k|0,g|0,h|0,l|0);f=v[23588];v[23588]=0;if((f|0)!=1){v[23588]=0;b=ka(15,b|0,j|0,v[a+4>>2],v[a>>2],d|0,e|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){break a}}}f=P()|0;O()|0;Wc(c)}yb(h);yb(g);yb(k)}$b(a+184|0);T(f|0);L()}Wc(c);yb(h);yb(g);yb(k);$b(a+184|0);jb=a+192|0;return b|0}function bda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0;f=jb-16|0;jb=f;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}l=v[a+16>>2];j=v[a+40>>2];k=v[a+36>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;m=v[a+32>>2];n=v[a+28>>2];while(1){if(d){h=v[f+8>>2];o=((((v[f+12>>2]&2147483647)<<1|h>>>31)&2147483646)<<1)+l|0;e=(h>>>16&65520)+b|0;p=u[e+14>>1];q=u[e+12>>1];r=u[e+10>>1];s=u[e+8>>1];t=u[e+6>>1];w=u[e+4>>1];x=u[e+2>>1];y=u[e>>1];h=0;while(1){if((h|0)!=2){e=(h<<1)+o|0;v[(h<<2)+f>>2]=(((((((B(u[e-8>>1],x)+B(u[e-12>>1],y)|0)+B(u[e-4>>1],w)|0)+B(u[e>>1],t)|0)+B(u[e+4>>1],s)|0)+B(u[e+8>>1],r)|0)+B(u[e+12>>1],q)|0)+B(u[e+16>>1],p)|0)/32768;h=h+1|0;continue}break}k=k+n|0;v[c>>2]=v[c>>2]+B(v[f>>2],k>>12);j=j+m|0;v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],j>>12);Qb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;v[a+40>>2]=j;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+24>>2]=j>>12;jb=f+16|0}function Qba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;l=jb-16|0;jb=l;k=jb-32|0;jb=k;h=k+28|0;f=k+24|0;g=jb-16|0;jb=g;a:{b:{if(!oc(b,v[ec(g+8|0,Yf(a))>>2])){e=x[c>>1];i=v[c+4>>2];j=vd(b);m=x[j>>1];j=v[j+4>>2];if(!ll(e,i,m,j)){break b}}v[g+8>>2]=b;e=ec(g,Eb(v[a>>2]));c:{f=v[g+8>>2];if(!oc(f,v[e>>2])){f=v[jz(g+8|0)>>2];e=vd(f);j=x[e>>1];m=v[e+4>>2];e=x[c>>1];i=v[c+4>>2];if(!ll(j,m,e,i)){break c}}if(!v[b>>2]){v[h>>2]=b;break a}v[h>>2]=f;b=f+4|0;break a}b=iz(a,h,e,i);break a}if(ll(m,j,e,i)){d:{f=hz(b);if(!oc(f,v[ec(g+8|0,Yf(a))>>2])){e=x[c>>1];i=v[c+4>>2];j=vd(f);if(!ll(e,i,x[j>>1],v[j+4>>2])){break d}}if(!v[b+4>>2]){v[h>>2]=b;b=b+4|0;break a}v[h>>2]=f;b=f;break a}b=iz(a,h,e,i);break a}v[h>>2]=b;v[f>>2]=b;b=f}jb=g+16|0;f=b;b=v[b>>2];if(!b){b=jb-16|0;jb=b;g=ic(a);h=k+8|0;e=lh(h,sc(36),mh(b+8|0,g));g=v[e>>2]+16|0;i=v[c+4>>2];v[g>>2]=v[c>>2];v[g+4>>2]=i;vl(g+8|0,d);o=ic(e),p=1,t[o+4|0]=p;jb=b+16|0;Jg(a,v[k+28>>2],f,v[k+8>>2]);b=be(h);wO(h);n=1}Ig(l,v[ec(k+8|0,b)>>2],n);jb=k+32|0;if(!w[ic(l)|0]){a=vd(v[l>>2])+8|0;vO(a);v[a>>2]=v[d>>2];v[a+4>>2]=v[d+4>>2];b=Fb(d);o=Fb(a),p=v[b>>2],v[o>>2]=p;v[b>>2]=0;v[d>>2]=0;v[d+4>>2]=0}a=v[ec(l+8|0,v[l>>2])>>2];jb=l+16|0;return a|0}function Jka(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{e=b;if(e){if(!c){break j}f=d;if(!f){break i}e=E(f)-E(e)|0;if(e>>>0<=31){break h}break b}if((d|0)==1|d>>>0>1){break b}b=(a>>>0)/(c>>>0)|0;kb=a-B(b,c)|0;lb=0;mb=0;return b}f=d;if(!a){break g}if(!f){break f}g=f-1|0;if(g&f){break f}kb=a;lb=e&g;a=e>>>Kka(f)|0;mb=0;return a}f=c-1|0;if(!(f&c)){break e}h=(E(c)+33|0)-E(e)|0;g=0-h|0;break c}h=e+1|0;g=63-e|0;break c}kb=0;a=(e>>>0)/(f>>>0)|0;lb=e-B(a,f)|0;mb=0;return a}e=E(f)-E(e)|0;if(e>>>0<31){break d}break b}kb=a&f;lb=0;if((c|0)==1){break a}d=a;c=Kka(c);a=c&31;if((c&63)>>>0>=32){e=0;a=b>>>a|0}else{e=b>>>a|0;a=((1<<a)-1&b)<<32-a|d>>>a}mb=e;return a}h=e+1|0;g=63-e|0}i=a;e=h&63;f=e&31;if((e&63)>>>0>=32){e=0;k=b>>>f|0}else{e=b>>>f|0;k=((1<<f)-1&b)<<32-f|i>>>f}f=e;e=g&63;a=e&31;if((e&63)>>>0>=32){e=i<<a;a=0}else{e=(1<<a)-1&i>>>32-a|b<<a;a=i<<a}b=e;if(h){e=d-1|0;g=c-1|0;e=(g|0)!=-1?e+1|0:e;i=e;while(1){j=k;e=f<<1|j>>>31;f=j<<1;j=e;f=b>>>31|f;e=i-((f>>>0>g>>>0)+e|0)>>31;l=e;m=c&e;k=f-m|0;f=j-((d&e)+(f>>>0<m>>>0)|0)|0;e=b<<1|a>>>31;a=n|a<<1;b=e|o;j=0;l=l&1;n=l;h=h-1|0;if(h){continue}break}}kb=k;lb=f;e=b<<1|a>>>31;a=l|a<<1;mb=e|j;return a}kb=a;lb=b;a=0;b=0}mb=b;return a}function B$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;k=b;f=jb-384|0;jb=f;v[f+376>>2]=37;v[f+380>>2]=0;h=Pr(f+376|1,21619,v[c+4>>2]);v[f+332>>2]=f+336;a=Gd();a:{if(h){b=v[c+8>>2];A[f+40>>3]=e;v[f+32>>2]=b;g=$g(f+336|0,30,a,f+376|0,f+32|0);break a}A[f+48>>3]=e;g=$g(f+336|0,30,a,f+376|0,f+48|0)}v[f+80>>2]=1123;i=se(f+320|0,0,f+80|0);b=f+336|0;a=b;b:{c:{d:{e:{if((g|0)>=30){a=Gd();f:{if(h){g=v[c+8>>2];A[f+8>>3]=e;v[f>>2]=g;g=Zi(f+332|0,a,f+376|0,f);break f}A[f+16>>3]=e;g=Zi(f+332|0,a,f+376|0,f+16|0)}if((g|0)==-1){v[23588]=0;Z(1124);a=v[23588];v[23588]=0;if((a|0)==1){break d}break e}a=v[f+332>>2];Ze(i,a)}j=a+g|0;l=_i(a,j,c);v[f+68>>2]=1123;h=se(f+72|0,0,f+68|0);g:{h:{if((f+336|0)==(a|0)){g=f+80|0;break h}g=Od(g<<3);if(!g){v[23588]=0;Z(1124);a=v[23588];v[23588]=0;if((a|0)!=1){break e}a=P()|0;O()|0;break g}Ze(h,g);b=a}a=f+56|0;fd(a,c);v[23588]=0;ia(1156,b|0,l|0,j|0,g|0,f+68|0,f- -64|0,a|0);a=v[23588];v[23588]=0;i:{if((a|0)!=1){$b(f+56|0);v[23588]=0;a=ka(1157,k|0,g|0,v[f+68>>2],v[f+64>>2],c|0,d|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break i}Wc(h);Wc(i);jb=f+384|0;break b}a=P()|0;O()|0;$b(f+56|0);break g}a=P()|0;O()|0}Wc(h);break c}L()}a=P()|0;O()|0}Wc(i);T(a|0);L()}return a|0}function L$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;k=b;f=jb-208|0;jb=f;v[f+200>>2]=37;v[f+204>>2]=0;h=Pr(f+200|1,21619,v[c+4>>2]);v[f+156>>2]=f+160;a=Gd();a:{if(h){b=v[c+8>>2];A[f+40>>3]=e;v[f+32>>2]=b;g=$g(f+160|0,30,a,f+200|0,f+32|0);break a}A[f+48>>3]=e;g=$g(f+160|0,30,a,f+200|0,f+48|0)}v[f+80>>2]=1123;i=se(f+144|0,0,f+80|0);b=f+160|0;a=b;b:{c:{d:{e:{if((g|0)>=30){a=Gd();f:{if(h){g=v[c+8>>2];A[f+8>>3]=e;v[f>>2]=g;g=Zi(f+156|0,a,f+200|0,f);break f}A[f+16>>3]=e;g=Zi(f+156|0,a,f+200|0,f+16|0)}if((g|0)==-1){v[23588]=0;Z(1124);a=v[23588];v[23588]=0;if((a|0)==1){break d}break e}a=v[f+156>>2];Ze(i,a)}j=a+g|0;l=_i(a,j,c);v[f+68>>2]=1123;h=se(f+72|0,0,f+68|0);g:{h:{if((f+160|0)==(a|0)){g=f+80|0;break h}g=Od(g<<1);if(!g){v[23588]=0;Z(1124);a=v[23588];v[23588]=0;if((a|0)!=1){break e}a=P()|0;O()|0;break g}Ze(h,g);b=a}a=f+56|0;fd(a,c);v[23588]=0;ia(1151,b|0,l|0,j|0,g|0,f+68|0,f- -64|0,a|0);a=v[23588];v[23588]=0;i:{if((a|0)!=1){$b(f+56|0);v[23588]=0;a=ka(15,k|0,g|0,v[f+68>>2],v[f+64>>2],c|0,d|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break i}Wc(h);Wc(i);jb=f+208|0;break b}a=P()|0;O()|0;$b(f+56|0);break g}a=P()|0;O()|0}Wc(h);break c}L()}a=P()|0;O()|0}Wc(i);T(a|0);L()}return a|0}function Bca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;e=jb-16|0;jb=e;q=v[a+16>>2];r=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);l=v[a+128>>2];a:{if(!l){j=v[a+8>>2];k=v[a+12>>2];f=v[a>>2];g=v[a+4>>2];i=0;break a}j=v[a+8>>2];k=v[a+12>>2];m=kg(j,k,l);n=mb;b=v[a+76>>2];f=v[a>>2];g=v[a+4>>2];Pf(f,g,kf(j,k,d),mb);i=b>>>0<mb>>>0?d:0}h=a+112|0;s=v[a+24>>2];u=v[a+20>>2];v[e>>2]=f;v[e+4>>2]=g;while(1){if(d){b=v[e+4>>2];f=v[e>>2];v[e+8>>2]=f;v[e+12>>2]=0;i=i-1|0;m=i?m:0;n=i?n:0;d=d-1|0;p=(((b&2147483647)<<1|f>>>31)&-2)+q|0;f=l;b:{c:while(1){d:{if((f|0)<=0){Qb(h,v[a+120>>2],v[a+124>>2]);f=v[a+116>>2];if(!f){break b}o=((v[e+12>>2]&2147483647)<<1|v[e+8>>2]>>>31)&-2;g=0;b=0;break d}o=((v[e+12>>2]&2147483647)<<1|v[e+8>>2]>>>31)&-2;b=0;g=0;while(1)if((b|0)==2){Rd(h,(g|0)/8<<16>>16);Qd(h,4);Qb(e+8|0,m,n);f=f-1|0;continue c}else{g=(t[(b+o|0)+p|0]<<8)+g|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){g=(t[(b+o|0)+p|0]<<8)+g|0;b=b+1|0;continue}break}Rd(h,(g|0)/8<<16>>16);Qd(h,f);v[h>>2]=v[h>>2];v[h+4>>2]=0}f=v[c>>2];b=ig(h,r);v[c>>2]=f+B(b,u);v[c+4>>2]=v[c+4>>2]+B(b,s);Qb(e,j,k);c=c+8|0;continue}break}b=v[e+4>>2];v[a>>2]=v[e>>2];v[a+4>>2]=b;jb=e+16|0}function DY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;if(Zg(a,v[b+8>>2],e)){nw(b,c,d);return}a:{if(Zg(a,v[b>>2],e)){if(!(v[b+16>>2]!=(c|0)&v[b+20>>2]!=(c|0))){if((d|0)!=1){break a}v[b+32>>2]=1;return}v[b+32>>2]=d;if(v[b+44>>2]!=4){f=a+16|0;h=f+(v[a+12>>2]<<3)|0;d=0;b:{c:{while(1){d:{if(f>>>0>=h>>>0){break d}u[b+52>>1]=0;kw(v[f>>2],v[f+4>>2],b,c,c,1,e);if(w[b+54|0]){break d}e:{if(!w[b+53|0]){break e}if(w[b+52|0]){d=1;if(v[b+24>>2]==1){break c}g=1;if(w[a+8|0]&2){break e}break c}g=1;if(!(t[a+8|0]&1)){break c}}f=f+8|0;continue}break}a=4;if(!g){break b}}a=3}v[b+44>>2]=a;if(d&1){break a}}v[b+20>>2]=c;v[b+40>>2]=v[b+40>>2]+1;if(v[b+36>>2]!=1|v[b+24>>2]!=2){break a}t[b+54|0]=1;return}g=v[a+12>>2];h=a+16|0;Jr(v[h>>2],v[a+20>>2],b,c,d,e);f=a+24|0;g=h+(g<<3)|0;if(f>>>0>=g>>>0){break a}a=v[a+8>>2];if(!(!(a&2)&v[b+36>>2]!=1)){while(1){if(w[b+54|0]){break a}Jr(v[f>>2],v[f+4>>2],b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}break a}if(!(a&1)){while(1){if(w[b+54|0]|v[b+36>>2]==1){break a}Jr(v[f>>2],v[f+4>>2],b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break a}}while(1){if(w[b+54|0]|v[b+36>>2]==1&v[b+24>>2]==1){break a}Jr(v[f>>2],v[f+4>>2],b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}}}function a4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;b=jb-2160|0;jb=b;Tb(b+112|0,0,2048);a:{b:{c:{f=v[c+4>>2];if(!f){a=ba(8)|0;v[23588]=0;b=Q(55,b+96|0,10403)|0;c=v[23588];v[23588]=0;if((c|0)==1){break c}a=rc(a,b);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}c=P()|0;O()|0;yb(b);break b}g=v[c>>2];d=v[c+12>>2];e=v[c+8>>2];v[b+88>>2]=e;v[b+92>>2]=d;c=v[b+92>>2];v[b+40>>2]=v[b+88>>2];v[b+44>>2]=c;v[b+84>>2]=f;v[b+80>>2]=g;c=v[b+84>>2];v[b+32>>2]=v[b+80>>2];v[b+36>>2]=c;h=eJ(b+32|0);if(h){c=b- -64|0;v[c>>2]=e;v[b+68>>2]=d;d=v[c+4>>2];v[b+24>>2]=v[c>>2];v[b+28>>2]=d;v[b+60>>2]=f;v[b+56>>2]=g;c=v[b+60>>2];v[b+16>>2]=v[b+56>>2];v[b+20>>2]=c;c=$I(b+16|0)}else{c=0}v[b+72>>2]=c;v[b+76>>2]=0;d=0;c=2048;while(1){if(c){e=nb[f|0](g,(b+112|0)+d|0,c)|0;c=c-e|0;d=d+e|0;if(e){continue}}break}c=gc(b+48|0,b+112|0,d);d=v[c+4>>2];v[b+8>>2]=v[c>>2];v[b+12>>2]=d;a=at(a,b+8|0,h?b+72|0:0);if(a+1>>>0>=3){a=ba(8)|0;v[23588]=0;b=Q(55,b+96|0,8017)|0;c=v[23588];v[23588]=0;if((c|0)!=1){a=rc(a,b);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}c=P()|0;O()|0;yb(b);break b}c=P()|0;O()|0;ca(a|0);break b}jb=b+2160|0;return a|0}c=P()|0;O()|0;ca(a|0)}T(c|0)}L()}function Cr(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;a:{e=jb-96|0;jb=e;i=v[c>>2];g=jb-32|0;jb=g;f=e- -64|0;j=Lb(f+16|0);v[f>>2]=v[c>>2];v[f+4>>2]=v[c+4>>2];v[f+8>>2]=v[c+8>>2];v[f+12>>2]=v[c+12>>2];v[23588]=0;c=Q(3,g|0,c+16|0)|0;h=v[23588];v[23588]=0;b:{c:{d:{if((h|0)!=1){v[23588]=0;R(71,g+16|0,c|0);h=v[23588];v[23588]=0;if((h|0)==1){break d}f=g+16|0;Ib(j,f);zb(f);zb(c);jb=g+32|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;zb(c)}Oj(f);T(a|0);L()}v[23588]=0;U(d|0,e|0,b|0,(i&2?16:10)|0);b=v[23588];v[23588]=0;e:{f:{g:{h:{i:{j:{if((b|0)!=1){d=e+16|0;c=jb-16|0;jb=c;k:{if(!(v[e+64>>2]&32)){break k}b=Oi(e);v[c+8>>2]=b;f=gr(e);while(1){if(!Ob(b,f)){break k}g=w[b|0];if((g-97&255)>>>0<=25){t[b|0]=g-32}b=v[Ge(c+8|0)>>2];continue}}$c(d,e);jb=c+16|0;v[23588]=0;X(82,e+32|0,d|0,v[e+64>>2],v[e+68>>2]);b=v[23588];v[23588]=0;if((b|0)==1){break j}v[23588]=0;U(83,e+48|0,e+32|0,e- -64|0);b=v[23588];v[23588]=0;if((b|0)==1){break i}v[23588]=0;R(71,a|0,e+48|0);a=v[23588];v[23588]=0;if((a|0)==1){break h}zb(e+48|0);zb(e+32|0);zb(e+16|0);zb(e);Oj(e- -64|0);jb=e+96|0;break a}a=P()|0;O()|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;break g}a=P()|0;O()|0;zb(e+48|0)}zb(e+32|0)}zb(e+16|0);zb(e)}Oj(e- -64|0);T(a|0);L()}}function wca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=jb-16|0;jb=f;q=v[a+16>>2];r=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);n=v[a+128>>2];a:{if(!n){l=v[a+8>>2];m=v[a+12>>2];e=v[a>>2];b=v[a+4>>2];h=0;break a}l=v[a+8>>2];m=v[a+12>>2];o=kg(l,m,n);p=mb;h=v[a+76>>2];e=v[a>>2];b=v[a+4>>2];Pf(e,b,kf(l,m,d),mb);h=h>>>0<mb>>>0?d:0}g=a+112|0;i=v[a+40>>2];j=v[a+36>>2];v[f>>2]=e;v[f+4>>2]=b;b:while(1){if(d){d=d-1|0;v[f+8>>2]=e;v[f+12>>2]=0;h=h-1|0;o=h?o:0;p=h?p:0;e=((((b&2147483647)<<1|e>>>31)&2147483646)<<1)+q|0;b=n;while(1)if((b|0)<=0){Qb(g,v[a+120>>2],v[a+124>>2]);b=v[a+116>>2];if(b){k=(v[f+12>>2]&2147483647)<<1|v[f+8>>2]>>>31;Rd(g,(u[(k<<1|2)+e>>1]+u[e+((k&2147483646)<<1)>>1]|0)/8<<16>>16);Qd(g,b);v[g>>2]=v[g>>2];v[g+4>>2]=0}b=v[a+32>>2];j=v[a+28>>2]+j|0;e=ig(g,r);v[c>>2]=B(j>>12,e)+v[c>>2];i=b+i|0;v[c+4>>2]=v[c+4>>2]+B(e,i>>12);Qb(f,l,m);c=c+8|0;e=v[f>>2];b=v[f+4>>2];continue b}else{k=(v[f+12>>2]&2147483647)<<1|v[f+8>>2]>>>31;Rd(g,(u[(k<<1|2)+e>>1]+u[e+((k&2147483646)<<1)>>1]|0)/8<<16>>16);Qd(g,4);Qb(f+8|0,o,p);b=b-1|0;continue}}break}v[a>>2]=e;v[a+4>>2]=b;v[a+40>>2]=i;v[a+20>>2]=j>>12;v[a+36>>2]=j;v[a+24>>2]=i>>12;jb=f+16|0}function q3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;c=jb+-64|0;jb=c;d=v[a>>2];a=v[d>>2];e=v[a+4>>2];v[c+40>>2]=v[a+20>>2];f=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=f;Hf(c+48|0,c+32|0,e);a=v[d+4>>2];e=v[a+8>>2];f=v[a+4>>2];d=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=d;d=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=d;v[c+8>>2]=v[a+8>>2];d=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=d;a=jb-32|0;jb=a;a:{b:{c:{d:{g=v[c+4>>2];if(f>>>0<=g>>>0){if(f>>>0>y[c+20>>2]){break d}if(y[c+8>>2]<e>>>0){break c}h=v[c+28>>2];if(v[c+24>>2]-h>>>0<e>>>0){break b}k=b+12|0;l=v[c+16>>2];m=v[c>>2];b=0;e:while(1){if((b|0)==(e|0)){break a}n=b+h|0;o=B(b,g);d=0;while(1)if((d|0)==(f|0)){b=b+1|0;continue e}else{r=a,s=+(Im(we(mg(A[(d+o<<3)+m>>3])*134217728))+kd(vs(k),21)|0)*7.450580596923828e-9,A[r+24>>3]=s;v[a+16>>2]=0;v[a+20>>2]=-1074790400;v[a+8>>2]=0;v[a+12>>2]=1072693248;p=n<<1;q=(d<<2)+l|0;i=we(A[Gg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(D(i)<2147483648){j=~~i;break f}j=-2147483648}r=v[q>>2]+p|0,t=dd(j),u[r>>1]=t;d=d+1|0;continue}}}aa(7192,9005,77,8685);L()}aa(7157,9005,78,8685);L()}aa(5900,9005,79,8685);L()}aa(5870,9005,80,8685);L()}jb=a+32|0;jb=c- -64|0}function cda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0;f=jb-16|0;jb=f;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}l=v[a+16>>2];j=v[a+40>>2];k=v[a+36>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;m=v[a+32>>2];n=v[a+28>>2];while(1){if(d){h=v[f+8>>2];o=(((v[f+12>>2]&2147483647)<<1|h>>>31)&-2)+l|0;e=(h>>>16&65520)+b|0;p=u[e+14>>1];q=u[e+12>>1];r=u[e+10>>1];s=u[e+8>>1];w=u[e+6>>1];x=u[e+4>>1];y=u[e+2>>1];z=u[e>>1];h=0;while(1){if((h|0)!=2){e=h+o|0;v[(h<<2)+f>>2]=(((((((B(t[e-4|0],y)+B(t[e-6|0],z)|0)+B(t[e-2|0],x)|0)+B(t[e|0],w)|0)+B(t[e+2|0],s)|0)+B(t[e+4|0],r)|0)+B(t[e+6|0],q)|0)+B(t[e+8|0],p)<<8)/32768;h=h+1|0;continue}break}k=k+n|0;v[c>>2]=v[c>>2]+B(v[f>>2],k>>12);j=j+m|0;v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],j>>12);Qb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;v[a+40>>2]=j;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+24>>2]=j>>12;jb=f+16|0}function h3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;c=jb+-64|0;jb=c;d=v[a>>2];a=v[d>>2];e=v[a+4>>2];v[c+40>>2]=v[a+20>>2];f=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=f;Hf(c+48|0,c+32|0,e);a=v[d+4>>2];e=v[a+8>>2];f=v[a+4>>2];d=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=d;d=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=d;v[c+8>>2]=v[a+8>>2];d=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=d;a=jb-32|0;jb=a;a:{b:{c:{d:{g=v[c+4>>2];if(f>>>0<=g>>>0){h=v[c+20>>2];if(f>>>0>h>>>0){break d}if(y[c+8>>2]<e>>>0){break c}i=v[c+28>>2];if(v[c+24>>2]-i>>>0<e>>>0){break b}l=b+12|0;m=v[c+16>>2];n=v[c>>2];b=0;e:while(1){if((b|0)==(e|0)){break a}o=B(b,g);p=B(b+i|0,h);d=0;while(1)if((d|0)==(f|0)){b=b+1|0;continue e}else{r=a,s=+(Im(we(mg(A[(d+o<<3)+n>>3])*134217728))+kd(vs(l),21)|0)*7.450580596923828e-9,A[r+24>>3]=s;v[a+16>>2]=0;v[a+20>>2]=-1074790400;v[a+8>>2]=0;v[a+12>>2]=1072693248;q=(d+p<<1)+m|0;j=we(A[Gg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(D(j)<2147483648){k=~~j;break f}k=-2147483648}r=q,t=dd(k),u[r>>1]=t;d=d+1|0;continue}}}aa(7192,9005,77,8685);L()}aa(7157,9005,78,8685);L()}aa(5900,9005,79,8685);L()}aa(5870,9005,80,8685);L()}jb=a+32|0;jb=c- -64|0}function qf(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=jb-96|0;jb=c;d=v[a+36>>2];Sl(v[v[d>>2]-12>>2]+d|0,0);d=a+32|0;Rc(c+56|0,d,4);if(!Bb(v[v[c+56>>2]>>2],v[c+60>>2])){Yv(a)}a:{if(!v[a+8>>2]){break a}Rc(c+56|0,d,6);if(Bb(v[v[c+56>>2]>>2],v[c+60>>2])){break a}Rc(c+88|0,d,7);if(Bb(v[v[c+88>>2]>>2],v[c+92>>2])){break a}h=v[a+36>>2];e=v[a+92>>2];g=B(v[a+28>>2],v[a+8>>2]);f=g+v[a+88>>2]|0;e=Xg(c+72|0,f,f>>>0<g>>>0?e+1|0:e);f=v[e+12>>2];v[c+32>>2]=v[e+8>>2];v[c+36>>2]=f;f=v[e+4>>2];v[c+24>>2]=v[e>>2];v[c+28>>2]=f;Xj(h,c+24|0)}Rc(c+56|0,d,5);e=0;b:{if(!Bb(v[v[c+56>>2]>>2],v[c+60>>2])){break b}f=Qi(v[a+52>>2],v[a+56>>2]);d=0;while(1){if((d|0)==(f|0)){break b}h=(v[a+108>>2]+d>>>0)%(f>>>0)|0;i=lf(v[a+52>>2],h);g=v[i>>2];c:{j=v[a+40>>2];if(ed(j,v[a+44>>2])>>>0<=g>>>0){break c}g=Lk(c+56|0,Kb(j,g),x[i+20>>1]);i=cw(b,g);_b(g);if(!i){break c}v[a+108>>2]=(h+1>>>0)%(f>>>0);e=lf(v[a+52>>2],h);d=e;b=v[d+12>>2];d=v[d+8>>2];if(!(b|d)){break b}e=v[a+36>>2];b=v[a+20>>2]+b|0;f=v[a+16>>2];d=f+d|0;b=Xg(c+40|0,d,d>>>0<f>>>0?b+1|0:b);d=v[b+12>>2];v[c+16>>2]=v[b+8>>2];v[c+20>>2]=d;d=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=d;Xj(e,c+8|0);e=lf(v[a+52>>2],h);break b}d=d+1|0;continue}}jb=c+96|0;return e}function Gja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=jb-288|0;jb=f;_f(b);a:{if(!Pb(v[a>>2],v[a+8>>2],1)){break a}while(1){d=f+32|0;sn(f+8|0,d,yq(d));k=v[a>>2];g=v[a+8>>2];d=jb-32|0;jb=d;_g(d+16|0,v[f+8>>2],v[f+12>>2]);e=v[v[k>>2]+28>>2];l=v[d+20>>2];v[d+8>>2]=v[d+16>>2];v[d+12>>2]=l;nb[e|0](d+24|0,k,g,d+8|0);_g(f+16|0,v[d+24>>2],v[d+28>>2]);jb=d+32|0;v[f+28>>2]=v[f+20>>2];o=f,p=c-Gb(b)|0,v[o+4>>2]=p;d=v[Jb(f+28|0,f+4|0)>>2];if(!d){break a}t[f+16|0]=0;k=f+32|0;m=k+d|0;d=f+16|0;l=wi(k,m,d);o=f,p=yh(b),v[o+16>>2]=p;e=v[lj(f,d)>>2];g=jb-32|0;jb=g;v[g+24>>2]=e;o=g,p=he(b),v[o+8>>2]=p;h=Nn(g+24|0,g+8|0);b:{c:{d=k;i=Rh(d,l);if(!i){break c}if(!Zs(b,d)){e=Gb(b);j=ad(b);d:{if(i>>>0<=j-e>>>0){j=zc(b);if((e|0)==(h|0)){break d}n=h+j|0;Wh(i+n|0,n,e-h|0);break d}rm(b,j,(e+i|0)-j|0,e,h,0,i);j=v[b>>2]}e=e+i|0;Qh(b,e);t[g+8|0]=0;ie(e+j|0,g+8|0);e=h+j|0;while(1){if((d|0)==(l|0)){break c}ie(e,d);d=d+1|0;e=e+1|0;continue}}d=Th(g+8|0,d,l);h=Lc(d);i=Gb(d);v[23588]=0;fa(356,b|0,e|0,h|0,h+i|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){yb(d);break b}a=P()|0;O()|0;yb(d);T(a|0);L()}he(b)}jb=g+32|0;Zb(a,l-k|0);if(l>>>0>=m>>>0){continue}break}Zb(a,1)}jb=f+288|0}function KF(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;a=jb-16|0;jb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;a:{b:{while(1){j=v[a+12>>2];if(!(j>>>0>=d>>>0|f>>>0>=g>>>0)){i=t[j|0];c=i&255;c:{if((i|0)>=0){i=1;break c}b=2;if(i>>>0<4294967234){break a}if(i>>>0<=4294967263){if((d-j|0)<2){break b}i=w[j+1|0];if((i&192)!=128){break a}c=i&63|c<<6&1984;i=2;break c}if(i>>>0<=4294967279){if((d-j|0)<3){break b}k=w[j+2|0];i=w[j+1|0];d:{e:{if((c|0)!=237){if((c|0)!=224){break e}if((i&224)==160){break d}break a}if((i&224)==128){break d}break a}if((i&192)!=128){break a}}if((k&192)!=128){break a}c=k&63|(c<<12&61440|(i&63)<<6);i=3;break c}if(i>>>0>4294967284){break a}if((d-j|0)<4){break b}l=w[j+3|0];m=w[j+2|0];k=w[j+1|0];f:{g:{switch(c-240|0){case 0:if((k+112&255)>>>0<48){break f}break a;case 4:if((k&240)==128){break f}break a;default:break g}}if((k&192)!=128){break a}}if((m&192)!=128|(l&192)!=128){break a}i=4;c=l&63|(m<<6&4032|(c<<18&1835008|(k&63)<<12));if(c>>>0>1114111){break a}}v[f>>2]=c;v[a+12>>2]=i+j;f=v[a+8>>2]+4|0;v[a+8>>2]=f;continue}break}b=d>>>0>j>>>0;break a}b=1}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];jb=a+16|0;return b|0}function D7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=C(0),q=C(0),r=0,s=0,t=0,u=C(0),w=0;i=jb-16|0;jb=i;a:{if(!$h(a+44|0)){break a}n=v[a+44>>2];j=Jc(n,0);k=Jc(n,1);n=v[a+56>>2];t=Jc(n,0);n=Jc(n,1);u=z[Db(a+4208|0,1)>>2];v[i+12>>2]=d;s=v[a+4220>>2];q=C(C(1)/C(s>>>0));w=v[a+4216>>2];o=d;f=n;g=t;while(1){if(!o){ri(a,b,c,t,n,d);break a}h=v[a+4224>>2];b:{if(s>>>0>h>>>0){v[i+8>>2]=s-h;r=v[Jb(i+12|0,i+8|0)>>2];m=0;c:{if(u<C(1)){l=h+r|0;e=h>>>0>l>>>0?h:l;while(1){if((h|0)==(e|0)){break c}p=C(h>>>0);z[g>>2]=q*C(z[j>>2]*p);z[f>>2]=q*C(z[k>>2]*p);h=h+1|0;f=f+4|0;k=k+4|0;g=g+4|0;j=j+4|0;continue}}while(1){if((m|0)!=(r|0)){z[g>>2]=z[j>>2];z[f>>2]=z[k>>2];m=m+1|0;f=f+4|0;k=k+4|0;g=g+4|0;j=j+4|0;continue}break}l=h+r|0}o=o-r|0;v[i+12>>2]=o;break b}m=w-h|0;v[i+4>>2]=m;l=v[Jb(i+12|0,i+4|0)>>2];e=0;d:{if(u<C(1)){e=m-l|0;while(1){if(e>>>0>=m>>>0){break d}p=C(m>>>0);z[g>>2]=q*C(z[j>>2]*p);z[f>>2]=q*C(z[k>>2]*p);m=m-1|0;f=f+4|0;k=k+4|0;g=g+4|0;j=j+4|0;continue}}while(1){if((e|0)!=(l|0)){v[g>>2]=0;v[f>>2]=0;e=e+1|0;f=f+4|0;g=g+4|0;continue}break}e=l<<2;k=e+k|0;j=j+e|0}o=o-l|0;v[i+12>>2]=o;e=h+l|0;l=e>>>0<w>>>0?e:0}v[a+4224>>2]=l;continue}}jb=i+16|0}function fba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;l=jb-16|0;jb=l;v[l+8>>2]=b;q=wf(a);while(1){if(Hg(b,c)){b=v[ec(l,q)>>2];k=vd(v[l+8>>2]);o=jb-16|0;jb=o;p=0;m=jb-16|0;jb=m;i=jb-32|0;jb=i;g=i+28|0;d=i+24|0;e=jb-16|0;jb=e;a:{b:{if(!oc(b,v[ec(e+8|0,Yf(a))>>2])){f=w[k|0];j=v[k+4>>2];h=vd(b);n=w[h|0];h=v[h+4>>2];if(!Qn(f,j,n,h)){break b}}v[e+8>>2]=b;f=ec(e,Eb(v[a>>2]));c:{d=v[e+8>>2];if(!oc(d,v[f>>2])){d=v[jz(e+8|0)>>2];f=vd(d);h=w[f|0];n=v[f+4>>2];f=w[k|0];j=v[k+4>>2];if(!Qn(h,n,f,j)){break c}}if(!v[b>>2]){v[g>>2]=b;break a}v[g>>2]=d;b=d+4|0;break a}b=Iy(a,g,f,j);break a}if(Qn(n,h,f,j)){d:{d=hz(b);if(!oc(d,v[ec(e+8|0,Yf(a))>>2])){f=w[k|0];j=v[k+4>>2];h=vd(d);if(!Qn(f,j,w[h|0],v[h+4>>2])){break d}}if(!v[b+4>>2]){v[g>>2]=b;b=b+4|0;break a}v[g>>2]=d;b=d;break a}b=Iy(a,g,f,j);break a}v[g>>2]=b;v[d>>2]=b;b=d}jb=e+16|0;d=b;b=v[b>>2];if(!b){b=jb-16|0;jb=b;e=ic(a);g=i+8|0;e=lh(g,sc(28),mh(b+8|0,e));Tz(v[e>>2]+16|0,k);r=ic(e),s=1,t[r+4|0]=s;jb=b+16|0;Jg(a,v[i+28>>2],d,v[i+8>>2]);b=be(g);qk(g);p=1}Ig(m+8|0,v[ec(i+8|0,b)>>2],p);jb=i+32|0;jb=m+16|0;ec(o+8|0,v[m+8>>2]);jb=o+16|0;b=v[Kg(l+8|0)>>2];continue}else{jb=l+16|0}break}}function Wga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;md(b,0);Ko(b);f=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);a:{if(c&34){if(d){v[b+24>>2]=f;break a}g=b,h=Pe(mi(+(f+1408|0)/1536)*8363),v[g+24>>2]=h;break a}t[b+37|0]=(c|0)==16?f:f^128;t[b+36|0]=w[a+4|0]}t[e+15|0]=w[a+5|0];t[e+14|0]=64;g=b,h=w[Wb(e+15|0,e+14|0)|0]<<2,u[g+30>>1]=h;d=w[a+6|0]|w[a+7|0]<<8;if(d>>>0<=256){u[b+28>>1]=d;u[b+34>>1]=x[b+34>>1]|32}v[b>>2]=w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24);v[b+4>>2]=w[a+12|0]|w[a+13|0]<<8|(w[a+14|0]<<16|w[a+15|0]<<24);v[b+8>>2]=w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24);d=w[a+20|0]|w[a+21|0]<<8;if(d&16){u[b+34>>1]=x[b+34>>1]|2;d=w[a+20|0]|w[a+21|0]<<8}if(d&32){u[b+34>>1]=x[b+34>>1]|4;d=w[a+20|0]|w[a+21|0]<<8}if(d&256){u[b+34>>1]=x[b+34>>1]|8;d=w[a+20|0]|w[a+21|0]<<8}if(d&512){u[b+34>>1]=x[b+34>>1]|16}t[b+38|0]=w[(w[a+22|0]&7)+39696|0];t[b+39|0]=w[a+23|0];t[b+40|0]=w[a+24|0];t[b+41|0]=w[a+25|0];if((c|0)==32){t[e+13|0]=w[a+26|0];t[e+12|0]=64;g=b,h=w[Wb(e+13|0,e+12|0)|0],u[g+32>>1]=h}v[b+12>>2]=w[a+27|0]|w[a+28|0]<<8|(w[a+29|0]<<16|w[a+30|0]<<24);v[b+16>>2]=w[a+31|0]|w[a+32|0]<<8|(w[a+33|0]<<16|w[a+34|0]<<24);jb=e+16|0}function yQ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=v[a>>2];e=zh(c,v[a+4>>2]);if(e>>>0<b>>>0){g=jb-32|0;jb=g;f=b-e|0;b=v[Fb(a)>>2];c=v[a+4>>2];a:{if(f>>>0<=b-c>>8>>>0){b=jb-16|0;jb=b;v[b>>2]=a;a=v[a+4>>2];v[b+4>>2]=a;v[b+8>>2]=a+(f<<8);a=v[b+4>>2];e=v[b+8>>2];while(1){if((a|0)==(e|0)){kc(b);jb=b+16|0}else{hQ(a);a=a+256|0;v[b+4>>2]=a;continue}break}break a}i=Fb(a);b=g+8|0;e=a;h=zh(v[a>>2],c)+f|0;c=jb-16|0;jb=c;v[c+12>>2]=h;d=jb-16|0;jb=d;v[d+12>>2]=16777215;v[d+8>>2]=2147483647;a=v[Jb(d+12|0,d+8|0)>>2];jb=d+16|0;b:{if(a>>>0>=h>>>0){d=Sz(e);if(d>>>0<a>>>1>>>0){v[c+8>>2]=d<<1;a=v[Yc(c+8|0,c+12|0)>>2]}jb=c+16|0;break b}bd();L()}d=zh(v[e>>2],v[e+4>>2]);og(b+12|0,i);if(a){if(a>>>0>=16777216){Lg();L()}c=sc(a<<8)}else{c=0}v[b>>2]=c;d=c+(d<<8)|0;v[b+8>>2]=d;v[b+4>>2]=d;j=Bc(b),k=c+(a<<8)|0,v[j>>2]=k;a=jb-16|0;jb=a;v[a>>2]=v[b+8>>2];c=v[b+8>>2];v[a+8>>2]=b+8;v[a+4>>2]=c+(f<<8);c=v[a>>2];while(1){if(v[a+4>>2]!=(c|0)){hQ(c);c=v[a>>2]+256|0;v[a>>2]=c;continue}break}Td(a);jb=a+16|0;Dd(e,b);e=v[b+4>>2];a=v[b+8>>2];while(1){if((a|0)!=(e|0)){a=a-256|0;v[b+8>>2]=a;continue}break}a=v[b>>2];if(a){Bc(b);Mb(a)}}jb=g+32|0;return}if(b>>>0<e>>>0){Nd(a,c+(b<<8)|0)}}function CW(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-32|0;jb=d;if(!Rb(a,13603,4)){md(b,32);Ko(b);Zh(d,1,a+4|0);c=d+16|0;Ec(c,d);Be(b+43|0,c);yb(c);u[b+30>>1]=w[a+19|0]<<2;Ef(b+30|0,256);u[b+32>>1]=w[a+17|0];Ef(b+32|0,64);u[b+28>>1]=(w[a+47|0]&127)<<2;Ef(b+28|0,256);if(t[a+47|0]<0){u[b+34>>1]=x[b+34>>1]|32}c=w[a+18|0];if(c&16){u[b+34>>1]=x[b+34>>1]|2;c=w[a+18|0]}if(c&32){u[b+34>>1]=x[b+34>>1]|8;c=w[a+18|0]}if(c&64){u[b+34>>1]=x[b+34>>1]|4;c=w[a+18|0]}if(c<<24>>24<0){u[b+34>>1]=x[b+34>>1]|16}c=w[a+60|0]|w[a+61|0]<<8|(w[a+62|0]<<16|w[a+63|0]<<24);v[b+24>>2]=c?c>>>0>256?c:256:8363;v[b>>2]=w[a+48|0]|w[a+49|0]<<8|(w[a+50|0]<<16|w[a+51|0]<<24);v[b+4>>2]=w[a+52|0]|w[a+53|0]<<8|(w[a+54|0]<<16|w[a+55|0]<<24);v[b+8>>2]=w[a+56|0]|w[a+57|0]<<8|(w[a+58|0]<<16|w[a+59|0]<<24);v[b+12>>2]=w[a+64|0]|w[a+65|0]<<8|(w[a+66|0]<<16|w[a+67|0]<<24);v[b+16>>2]=w[a+68|0]|w[a+69|0]<<8|(w[a+70|0]<<16|w[a+71|0]<<24);Ck(b);t[b+38|0]=w[(w[a+79|0]&7)+39696|0];t[b+41|0]=w[a+76|0];t[b+40|0]=w[a+77|0]&127;t[b+39|0]=w[a+78|0];c=w[a+46|0];a:{if((c|0)==64){c=512}else{if((c|0)!=128){break a}c=16384}u[b+34>>1]=c|x[b+34>>1]}c=w[a+72|0]|w[a+73|0]<<8|(w[a+74|0]<<16|w[a+75|0]<<24)}jb=d+32|0;return c|0}function yea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=jb-48|0;jb=k;if(Af(v[b>>2],v[b+4>>2])>>>0>c>>>0){while(1){i=m&65535;if(i>>>0<=c>>>0){g=ag(v[b>>2],i);e=v[g>>2];if(Ob(e,v[g+4>>2])){n=k+24|0;e=Eb(e);o=Eb(v[ag(v[b>>2],i)+4>>2]);f=YP(k,d);l=jb-16|0;jb=l;v[l+8>>2]=e;while(1){if(Ob(e,o)){j=jb-16|0;jb=j;if(!(w[e+5|0]|w[e+3|0]!=4)){g=j+8|0;Cb(g,v[f>>2],x[f+14>>1]);Ye(g,0);t[e+3|0]=0}h=w[e+2|0];if(!(w[e+4|0]|(h|0)!=11)){g=j+8|0;Cb(g,v[f>>2],x[f+14>>1]);Ye(g,0);t[e+2|0]=0;h=0}a:{b:{if(!w[e|0]){Cb(j+8|0,v[f>>2],x[f+14>>1]);if(Bb(v[v[j+8>>2]>>2],v[j+12>>2])){break b}h=w[e+2|0]}i=w[e+3|0];g=j+8|0;Cb(g,v[f>>2],x[f+14>>1]);Ye(g,(i|0)==4|(h|0)==11);h=w[e+3|0];break a}h=w[e+3|0];g=w[e+2|0];if(!(h|(g|0)==11)){t[e+5|0]=0;h=4;t[e+3|0]=4;break a}if(g|(h|0)==4){break a}t[e+4|0]=0;t[e+2|0]=11}c:{d:{e:{if(!(!w[f+16|0]|h)){t[e+3|0]=17;i=0;h=125;break e}i=0;f:{switch(h-16|0){case 1:break d;case 0:break f;default:break c}}if(w[e+5|0]){break c}i=1;h=6}t[e+5|0]=h}t[f+16|0]=i}u[f+14>>1]=(x[f+14>>1]+1>>>0)%x[f+12>>1];jb=j+16|0;e=v[Bk(l+8|0)>>2];continue}break}WP(n,f);jb=l+16|0;Ve(n);Ve(f)}m=m+1|0;continue}break}}WP(a,d);jb=k+48|0}function Ad(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb+-64|0;jb=d;v[a+480180>>2]=b;b=wq(a);vq(d,b);e=v[d+12>>2];c=a+1074320|0;v[c>>2]=v[d+8>>2];v[c+4>>2]=e;c=v[d+4>>2];v[a+1074312>>2]=v[d>>2];v[a+1074316>>2]=c;bt(a+8|0,b);b=1;while(1){c=b&65535;if(c>>>0>x[a+480192>>1]){v[a+480184>>2]=0;v[a+480188>>2]=0;v[a+480236>>2]=65536;v[a+480228>>2]=48;v[a+480232>>2]=48;t[a+480268|0]=5;v[a+480260>>2]=16;v[a+480264>>2]=32767;v[a+480204>>2]=125e4;v[a+480208>>2]=0;v[a+480196>>2]=6;v[a+480200>>2]=256;v[a+1074304>>2]=0;v[a+1074308>>2]=0;u[a+480192>>1]=0;wy(a,4);e=jb+-64|0;jb=e;b=a+484344|0;dt(b);f=xk(v[b>>2],v[b+4>>2]);c=_x(e+8|0,b);v[23588]=0;U(814,b|0,f|0,c|0);b=v[23588];v[23588]=0;a:{if((b|0)!=1){gl(c);jb=e- -64|0;break a}a=P()|0;O()|0;gl(c);T(a|0);L()}iP(a+484360|0);_f(a+1298308|0);nA(a+1298320|0);_f(a+1298332|0);c=Tb(d,0,64);b=_M(c);d=Ib(a+1298344|0,b);Ib(d+12|0,b+12|0);Ib(d+24|0,b+24|0);Ib(d+36|0,b+36|0);Ib(d+48|0,b+48|0);v[d+60>>2]=v[b+60>>2];Cy(b);Kc(a+1298408|0);Kc(a+480248|0);if(v[a+480180>>2]&738230281){v[a+480208>>2]=v[a+480208>>2]|8388608}jb=c- -64|0;return}c=((c<<2)+a|0)+900380|0;e=v[c>>2];if(e){Mb(cu(e))}v[c>>2]=0;b=b+1|0;continue}}function Kca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0;h=jb-16|0;jb=h;f=v[a+48>>2];j=v[a+24>>2];k=v[a+20>>2];e=v[a+44>>2];l=v[a+16>>2];g=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=g;m=b+24|0;n=v[a+72>>2];b=v[a+68>>2];o=b;p=b>>31;b=v[a+64>>2];q=b;r=b>>31;b=v[a+60>>2];s=b;t=b>>31;w=v[a+8>>2];x=v[a+12>>2];while(1){b=e;if(d){e=Xb(b,-16777216,16776704);e=Lka(q,r,e,e>>31);g=mb;f=Xb(f,-16777216,16776704);i=Lka(o,p,f,f>>31);e=i+e|0;f=mb+g|0;f=e>>>0<i>>>0?f+1|0:f;y=e;e=(v[h+12>>2]<<1)+l|0;g=(((v[h+8>>2]>>>16|0)+4&131064)<<1)+m|0;g=(((((B(u[e+4>>1],u[g+10>>1])+B(u[e+2>>1],u[g+8>>1])|0)+B(u[e+6>>1],u[g+12>>1])|0)+B(u[e+8>>1],u[g+14>>1])|0)/2|0)+((((B(u[e-4>>1],u[g+2>>1])+B(u[e-6>>1],u[g>>1])|0)+B(u[e-2>>1],u[g+4>>1])|0)+B(u[e>>1],u[g+6>>1])|0)/2|0)|0)/16384<<8;e=g;i=Lka(e,e>>31,s,t);e=y+i|0;f=mb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Xc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(e,k)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(e,j);Qb(h+8|0,w,x);e=f-(g&n)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=c;v[a+48>>2]=f;v[a+44>>2]=b;jb=h+16|0}function lda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0;h=jb-16|0;jb=h;f=v[a+48>>2];i=v[a+40>>2];j=v[a+36>>2];e=v[a+44>>2];n=v[a+16>>2];b=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=b;o=v[a+32>>2];p=v[a+28>>2];q=v[a+72>>2];b=v[a+68>>2];r=b;s=b>>31;b=v[a+64>>2];t=b;w=b>>31;b=v[a+60>>2];x=b;y=b>>31;z=v[a+8>>2];A=v[a+12>>2];while(1){b=e;if(d){e=Xb(b,-16777216,16776704);e=Lka(t,w,e,e>>31);k=mb;C=e;e=(v[h+12>>2]<<1)+n|0;g=v[h+8>>2]>>>21&2040;l=(((B(u[e>>1],u[g+39714>>1])+B(u[e-2>>1],u[g+39712>>1])|0)+B(u[e+2>>1],u[g+39716>>1])|0)+B(u[e+4>>1],u[g+39718>>1])|0)/16384<<8;e=l;m=Lka(e,e>>31,x,y);g=C+m|0;e=mb+k|0;e=g>>>0<m>>>0?e+1|0:e;f=Xb(f,-16777216,16776704);k=Lka(r,s,f,f>>31);g=k+g|0;f=mb+e|0;f=g>>>0<k>>>0?f+1|0:f;e=g+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Xc(e,f,24);e=(f|0)/256|0;j=j+p|0;v[c>>2]=B(e,j>>12)+v[c>>2];i=i+o|0;v[c+4>>2]=v[c+4>>2]+B(e,i>>12);Qb(h+8|0,z,A);e=f-(q&l)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=c;v[a+40>>2]=i;v[a+20>>2]=j>>12;v[a+36>>2]=j;v[a+48>>2]=f;v[a+44>>2]=b;v[a+24>>2]=i>>12;jb=h+16|0}function Lca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0;h=jb-16|0;jb=h;f=v[a+48>>2];j=v[a+24>>2];k=v[a+20>>2];e=v[a+44>>2];l=v[a+16>>2];g=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=g;m=b+24|0;n=v[a+72>>2];b=v[a+68>>2];o=b;p=b>>31;b=v[a+64>>2];q=b;r=b>>31;b=v[a+60>>2];s=b;w=b>>31;x=v[a+8>>2];y=v[a+12>>2];while(1){b=e;if(d){e=Xb(b,-16777216,16776704);e=Lka(q,r,e,e>>31);g=mb;f=Xb(f,-16777216,16776704);i=Lka(o,p,f,f>>31);e=i+e|0;f=mb+g|0;f=e>>>0<i>>>0?f+1|0:f;z=e;e=v[h+12>>2]+l|0;g=(((v[h+8>>2]>>>16|0)+4&131064)<<1)+m|0;g=(((((B(t[e+2|0],u[g+10>>1])+B(t[e+1|0],u[g+8>>1])|0)+B(t[e+3|0],u[g+12>>1])|0)+B(t[e+4|0],u[g+14>>1])<<8)/2|0)+((((B(t[e-2|0],u[g+2>>1])+B(t[e-3|0],u[g>>1])|0)+B(t[e-1|0],u[g+4>>1])|0)+B(t[e|0],u[g+6>>1])<<8)/2|0)|0)/16384<<8;e=g;i=Lka(e,e>>31,s,w);e=z+i|0;f=mb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Xc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(e,k)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(e,j);Qb(h+8|0,x,y);e=f-(g&n)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=c;v[a+48>>2]=f;v[a+44>>2]=b;jb=h+16|0}function Pea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=jb-16|0;jb=f;u[f+12>>1]=c;u[f+14>>1]=b;u[f+10>>1]=d;h=x[v[v[a+24>>2]+8>>2]+12>>1];a:{if(h>>>0<=b>>>0){break a}if(!c|sj(a)>>>0>=h>>>0){break a}Ef(f+12|0,h-b&65535);p=f,q=Dl(v[a>>2],v[a+4>>2]),u[p+8>>1]=q;g=x[f+12>>1];CS(a,g+x[ke(f+14|0,f+8|0)>>1]|0);c=v[a>>2];e=a;if(Qc(c,v[a+4>>2])>>>0<b>>>0){ug(e,b);c=v[e>>2]}a=Eb(c);c=jb-16|0;jb=c;v[c+8>>2]=a;a=v[lP(c+8|0,b)>>2];jb=c+16|0;a=v[ec(f,a)>>2];i=f+10|0;l=jb-32|0;jb=l;b=a;a=v[e>>2];d=(yo(b,Eb(a))<<1)+a|0;a=g;b:{if(!a){break b}b=v[Fb(e)>>2];g=v[e+4>>2];if(a>>>0<=b-g>>1>>>0){b=a;c=g-d>>1;if(c>>>0<a>>>0){Go(e,a-c|0,i);b=c;if((d|0)==(g|0)){break b}}m=jb-16|0;jb=m;c=g;o=v[e+4>>2];g=(o-((a<<1)+d|0)|0)+d|0;n=_h(m,e,c-g>>1);j=v[n+4>>2];k=g;while(1){if(c>>>0<=k>>>0){kc(n);Aq(d,g,o);jb=m+16|0}else{Mi(j,x[k>>1]);j=j+2|0;v[n+4>>2]=j;k=k+2|0;continue}break}$t(d,b,((d>>>0<=i>>>0?y[e+4>>2]>i>>>0?a:0:0)<<1)+i|0);break b}b=Fb(e);b=Mj(l+8|0,Nj(e,Qc(v[e>>2],g)+a|0),d-v[e>>2]>>1,b);KC(b,a,i);d=jP(e,b,d);Ni(b)}Eb(d);jb=l+32|0;if(Qc(v[e>>2],v[e+4>>2])>>>0<=h>>>0){break a}ug(e,h)}jb=f+16|0}function dja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;md(b,32);to(b);f=b,g=pe((w[a+50|0]|w[a+51|0]<<8)<<16>>16)>>>2|0,u[f+32>>1]=g;if((pe((w[a+32|0]|w[a+33|0]<<8)<<16>>16)|0)>0){u[b+34>>1]=x[b+34>>1]|32;c=pe((w[a+32|0]|w[a+33|0]<<8)<<16>>16);e=c>>>24|0;d=(c<<8&-256)+2047|0;c=e&255;f=b,g=Dc(Oka(d,d>>>0<2047?c+1|0:c,4095,0),mb),u[f+28>>1]=g}c=bc(w[a+38|0]|w[a+39|0]<<8|(w[a+40|0]<<16|w[a+41|0]<<24));v[b>>2]=c;d=bc(w[a+42|0]|w[a+43|0]<<8|(w[a+44|0]<<16|w[a+45|0]<<24));v[b+4>>2]=d;e=bc(w[a+42|0]|w[a+43|0]<<8|(w[a+44|0]<<16|w[a+45|0]<<24))+bc(w[a+46|0]|w[a+47|0]<<8|(w[a+48|0]<<16|w[a+49|0]<<24))|0;v[b+8>>2]=e;if((Hb(w[a+34|0]|w[a+35|0]<<8)|0)==16){v[b+8>>2]=e>>>1;v[b+4>>2]=d>>>1;v[b>>2]=c>>>1}a:{b:{if(bc(w[a+42|0]|w[a+43|0]<<8|(w[a+44|0]<<16|w[a+45|0]<<24))){c=x[b+34>>1];break b}c=x[b+34>>1];if(bc(w[a+46|0]|w[a+47|0]<<8|(w[a+48|0]<<16|w[a+49|0]<<24))>>>0>=3){break b}c=c&-3;break a}c=c|2}u[b+34>>1]=c;f=b,g=c&65531|Hb(w[a+30|0]|w[a+31|0]<<8)<<1&4,u[f+34>>1]=g;f=b,g=Hb(w[a+36|0]|w[a+37|0]<<8)<<1,v[f+24>>2]=g;c=pe((w[a+52|0]|w[a+53|0]<<8)<<16>>16);if(c){Al(b,+(c|0)/96);c=pe((w[a+52|0]|w[a+53|0]<<8)<<16>>16)}t[b+37|0]=c<<4}function e9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=jb-16|0;jb=h;if(!w[a+4242|0]){Nx(a);a:{if(!w[a+4240|0]){break a}e=EM(v[a+16>>2]);if(e==A[a+4288>>3]){break a}A[a+4288>>3]=e;Rs(a)}f=a+4256|0;b:{if(w[a+4244|0]){if(A[f>>3]>1){v[f>>2]=0;v[f+4>>2]=1072693248}break b}i=(v[a+4232>>2]&-2)!=4;e=A[f>>3];c:{if(D(e)<2147483648){g=~~e;break c}g=-2147483648}if(!(i|(g|0)<=0)){Mx(a);e=A[a+4256>>3]}A[f>>3]=e-+(g|0)}e=0;d:{e:{switch(v[a+4232>>2]){case 0:e=Ci(A[f>>3]*6.283185307179586);break d;case 1:e=D(A[f>>3]+-.5)*-4+1;break d;case 2:e=A[f>>3];e=e+e+-1;break d;case 3:e=A[f>>3]<.5?-1:1;break d;case 4:e=A[a+4272>>3];break d;case 5:break e;default:break d}}e=A[a+4256>>3];e=e*(e*e)*(e*(e*6+-15)+10);e=A[a+4280>>3]*e+A[a+4272>>3]*(1-e)}A[h+8>>3]=(w[a+4241|0]?-e:e)*+z[a+4220>>2]+ +z[a+4224>>2];eO(h+8|0,1);g=kj(a);f:{if(!g){break f}f=v[a+4236>>2];if(w[a+4243|0]){k=g,l=(f>>>8&15|176)&191|(f&127)<<8|sk(A[h+8>>3]*127)<<16,j=v[v[g>>2]+68>>2],nb[j](k|0,l|0)|0;break f}nb[v[v[g>>2]+44>>2]](g,f,C(A[h+8>>3]))}A[a+4256>>3]=A[a+4264>>3]*+(d>>>0)+A[a+4256>>3]}g=a;a=v[a+44>>2];ri(g,b,c,Jc(a,0),Jc(a,1),d);jb=h+16|0}function RS(a,b,c){var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;t[d+15|0]=c;a:{if(b>>>0>=22){t[d+14|0]=0;de(a,0,d+14|0);break a}e=w[b+26672|0];b:{c:{switch(b-8|0){case 0:t[d+15|0]=c<<1;break b;case 4:t[d+15|0]=c+1>>>1;break b;case 5:t[d+15|0]=B(c>>>4|0,10)+(c&15);break b;case 6:d:{switch((c>>>4|0)-1|0){default:e=0;break b;case 0:t[d+13|0]=c&15;t[d+12|0]=14;f=d,g=w[Wb(d+13|0,d+12|0)|0]<<4|15,t[f+15|0]=g;e=29;break b;case 1:t[d+11|0]=c&15;t[d+10|0]=14;f=d,g=w[Wb(d+11|0,d+10|0)|0]|240,t[f+15|0]=g;e=29;break b;case 3:t[d+15|0]=c&15|48;break b;case 4:t[d+15|0]=c<<4^128;e=35;break b;case 5:t[d+15|0]=c&15|176;break b;case 6:t[d+15|0]=c&15|64;break b;case 8:e=15;t[d+15|0]=c&15;break b;case 9:t[d+15|0]=(c<<3&120)+8&240;e=24;break b;case 10:t[d+15|0]=(c&15)+1>>>1;e=24;break b;case 14:break d;case 11:case 12:case 13:break b}}e=10;break b;case 8:if(c>>>0<=223){b=c>>>2|0;t[d+15|0]=(b>>>0<15?b:15)<<4;break b}if(c>>>0<=239){t[d+15|0]=c<<2&48|15;break b}t[d+15|0]=c<<4|15;break b;case 9:break c;default:break b}}if(c>>>0<=223){b=c>>>2|0;t[d+15|0]=b>>>0<15?b:15;break b}if(c>>>0>239){break b}t[d+15|0]=c>>>2&3|240}de(a,e,d+15|0)}jb=d+16|0}function mda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0;g=jb-16|0;jb=g;f=v[a+48>>2];i=v[a+40>>2];j=v[a+36>>2];e=v[a+44>>2];l=v[a+16>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;m=v[a+32>>2];n=v[a+28>>2];o=v[a+72>>2];b=v[a+68>>2];p=b;q=b>>31;b=v[a+64>>2];r=b;s=b>>31;b=v[a+60>>2];w=b;x=b>>31;y=v[a+8>>2];z=v[a+12>>2];while(1){b=e;if(d){e=Xb(b,-16777216,16776704);e=Lka(r,s,e,e>>31);h=mb;f=Xb(f,-16777216,16776704);k=Lka(p,q,f,f>>31);e=k+e|0;f=mb+h|0;f=e>>>0<k>>>0?f+1|0:f;A=e;e=v[g+12>>2]+l|0;h=v[g+8>>2]>>>21&2040;h=(((B(t[e|0],u[h+39714>>1])+B(t[e-1|0],u[h+39712>>1])|0)+B(t[e+1|0],u[h+39716>>1])|0)+B(t[e+2|0],u[h+39718>>1])<<8)/16384<<8;e=h;k=Lka(e,e>>31,w,x);e=A+k|0;f=mb+f|0;f=e>>>0<k>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Xc(e,f,24);e=(f|0)/256|0;j=j+n|0;v[c>>2]=B(e,j>>12)+v[c>>2];i=i+m|0;v[c+4>>2]=v[c+4>>2]+B(i>>12,e);Qb(g+8|0,y,z);e=f-(h&o)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=c;v[a+40>>2]=i;v[a+20>>2]=j>>12;v[a+36>>2]=j;v[a+48>>2]=f;v[a+44>>2]=b;v[a+24>>2]=i>>12;jb=g+16|0}function Aca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=jb-16|0;jb=e;o=v[a+16>>2];p=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);l=v[a+128>>2];a:{if(!l){j=v[a+8>>2];k=v[a+12>>2];f=v[a>>2];g=v[a+4>>2];i=0;break a}j=v[a+8>>2];k=v[a+12>>2];m=kg(j,k,l);n=mb;b=v[a+76>>2];f=v[a>>2];g=v[a+4>>2];Pf(f,g,kf(j,k,d),mb);i=b>>>0<mb>>>0?d:0}h=a+112|0;q=v[a+24>>2];r=v[a+20>>2];v[e>>2]=f;v[e+4>>2]=g;b:while(1){if(d){b=v[e+4>>2];f=v[e>>2];v[e+8>>2]=f;v[e+12>>2]=0;i=i-1|0;m=i?m:0;n=i?n:0;d=d-1|0;f=((((b&2147483647)<<1|f>>>31)&2147483646)<<1)+o|0;b=l;while(1)if((b|0)<=0){Qb(h,v[a+120>>2],v[a+124>>2]);b=v[a+116>>2];if(b){g=(v[e+12>>2]&2147483647)<<1|v[e+8>>2]>>>31;Rd(h,(u[(g<<1|2)+f>>1]+u[((g&2147483646)<<1)+f>>1]|0)/8<<16>>16);Qd(h,b);v[h>>2]=v[h>>2];v[h+4>>2]=0}f=v[c>>2];b=ig(h,p);v[c>>2]=f+B(b,r);v[c+4>>2]=v[c+4>>2]+B(b,q);Qb(e,j,k);c=c+8|0;continue b}else{g=(v[e+12>>2]&2147483647)<<1|v[e+8>>2]>>>31;Rd(h,(u[(g<<1|2)+f>>1]+u[((g&2147483646)<<1)+f>>1]|0)/8<<16>>16);Qd(h,4);Qb(e+8|0,m,n);b=b-1|0;continue}}break}b=v[e+4>>2];v[a>>2]=v[e>>2];v[a+4>>2]=b;jb=e+16|0}function O9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;j=jb-16|0;jb=j;c=qf(a,c);me(j,v[a+36>>2]);a:{b:{if(!c){Rc(j,a+32|0,5);d=-1;if(!Bb(v[v[j>>2]>>2],v[j+4>>2])){break b}break a}d=v[c+16>>2]}e=v[a+36>>2];c:{if(!((d|0)!=4&(d|0)!=-1)){d=jb-16|0;jb=d;v[d+8>>2]=0;Dp(e,d+8|0);z[b>>2]=z[d+8>>2];jb=d+16|0;break c}f=jb-16|0;jb=f;v[f+12>>2]=d;v[f+8>>2]=4;h=v[Jb(f+12|0,f+8|0)>>2];k=jb-16|0;jb=k;cG(k+8|0,e);d=v[k+12>>2];if(zr(-1,2147483647,h,0)^1){i=zr(h,0,0,-2147483648)^1}else{i=0}if(i){d:{e=jb-48|0;jb=e;i=d+v[v[d>>2]-12>>2]|0;g=v[i+16>>2]&-3;Sl(i,g);e:{f:{if(Pd(w[fm(e+40|0,d,1)|0])){i=v[(d+v[v[d>>2]-12>>2]|0)+24>>2];v[23588]=0;Nk(107,e+24|0,i,h,0);h=v[23588];v[23588]=0;g:{if((h|0)!=1){g=iE(e+24|0,Xg(e+8|0,-1,-1))?g|4:g;break g}h=V(0)|0;O()|0;_(h|0)|0;g=g|1;dm(d+v[v[d>>2]-12>>2]|0,g);if(v[(d+v[v[d>>2]-12>>2]|0)+20>>2]&1){v[23588]=0;Z(105);a=v[23588];v[23588]=0;if((a|0)!=1){break e}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)==1){break f}T(a|0);L()}$()}Ki(d+v[v[d>>2]-12>>2]|0,g)}jb=e+48|0;break d}V(0)|0;O()|0;Ub()}L()}}jb=k+16|0;v[b>>2]=0;jb=f+16|0}f=c}Xe(a,f);jb=j+16|0}function HG(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;k=jb-16|0;jb=k;f=w[a|0];a:{if(!f){g=a;break a}g=a;b:{while(1){if(!Vk(f<<24>>24)){break b}f=w[g+1|0];g=g+1|0;if(f){continue}break}break a}c:{f=f&255;switch(f-43|0){case 0:case 2:break c;default:break a}}m=(f|0)==45?-1:0;g=g+1|0}d:{if(!((c|16)!=16|w[g|0]!=48)){n=1;if((w[g+1|0]&223)==88){g=g+2|0;l=16;break d}g=g+1|0;l=c?c:8;break d}l=c?c:10}c=0;while(1){e:{f=-48;i=t[g|0];f:{if((i-48&255)>>>0<10){break f}f=-87;if((i-97&255)>>>0<26){break f}f=-55;if((i-65&255)>>>0>25){break e}}i=f+i|0;if((i|0)>=(l|0)){break e}uf(k,l,0,0,0,j,h,0,0);f=1;g:{if(v[k+8>>2]|v[k+12>>2]){break g}o=Lka(j,h,l,0);p=mb;if((p|0)==-1&(i^-1)>>>0<o>>>0){break g}h=p;f=i+o|0;h=f>>>0<i>>>0?h+1|0:h;j=f;n=1;f=c}g=g+1|0;c=f;continue}break}if(b){v[b>>2]=n?g:a}h:{i:{j:{if(c){v[116064]=68;a=d&1;m=a?0:m;j=d;h=e;break j}if((e|0)==(h|0)&d>>>0>j>>>0|e>>>0>h>>>0){break i}a=d&1}if(!(a|m)){v[116064]=68;a=d;d=a-1|0;e=e-!a|0;break h}if((e|0)==(h|0)&d>>>0>=j>>>0|e>>>0>h>>>0){break i}v[116064]=68;break h}a=m;b=a^j;d=b-a|0;c=a>>31;e=(c^h)-((a>>>0>b>>>0)+c|0)|0}jb=k+16|0;mb=e;return d}function r3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=jb+-64|0;jb=b;c=v[a>>2];a=v[c>>2];d=v[a+4>>2];v[b+40>>2]=v[a+20>>2];e=v[a+16>>2];v[b+32>>2]=v[a+12>>2];v[b+36>>2]=e;Hf(b+48|0,b+32|0,d);a=v[c+4>>2];d=v[a+8>>2];e=v[a+4>>2];c=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=c;c=v[b+52>>2];v[b+16>>2]=v[b+48>>2];v[b+20>>2]=c;v[b+8>>2]=v[a+8>>2];c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;a=jb-32|0;jb=a;a:{b:{c:{d:{g=v[b+4>>2];if(g>>>0>=e>>>0){if(y[b+20>>2]<e>>>0){break d}if(d>>>0>y[b+8>>2]){break c}h=v[b+28>>2];if(d>>>0>v[b+24>>2]-h>>>0){break b}k=v[b+16>>2];l=v[b>>2];e:while(1){if((d|0)==(f|0)){break a}m=f+h|0;n=B(f,g);c=0;while(1)if((c|0)==(e|0)){f=f+1|0;continue e}else{A[a+24>>3]=A[(c+n<<3)+l>>3];v[a+16>>2]=0;v[a+20>>2]=-1074790400;v[a+8>>2]=0;v[a+12>>2]=1072693248;o=m<<1;p=(c<<2)+k|0;i=we(A[Gg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(D(i)<2147483648){j=~~i;break f}j=-2147483648}q=v[p>>2]+o|0,r=dd(j),u[q>>1]=r;c=c+1|0;continue}}}aa(7192,9005,77,8685);L()}aa(7157,9005,78,8685);L()}aa(5900,9005,79,8685);L()}aa(5870,9005,80,8685);L()}jb=a+32|0;jb=b- -64|0}function fda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0;f=jb-16|0;jb=f;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;while(1){if(d){h=v[f+8>>2];m=((((v[f+12>>2]&2147483647)<<1|h>>>31)&2147483646)<<1)+j|0;e=(h>>>16&65520)+b|0;n=u[e+14>>1];o=u[e+12>>1];p=u[e+10>>1];q=u[e+8>>1];r=u[e+6>>1];s=u[e+4>>1];t=u[e+2>>1];w=u[e>>1];h=0;while(1){if((h|0)!=2){e=(h<<1)+m|0;v[(h<<2)+f>>2]=(((((((B(u[e-8>>1],t)+B(u[e-12>>1],w)|0)+B(u[e-4>>1],s)|0)+B(u[e>>1],r)|0)+B(u[e+4>>1],q)|0)+B(u[e+8>>1],p)|0)+B(u[e+12>>1],o)|0)+B(u[e+16>>1],n)|0)/32768;h=h+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[f>>2],l);v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],k);Qb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;jb=f+16|0}function i3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=jb+-64|0;jb=b;c=v[a>>2];a=v[c>>2];d=v[a+4>>2];v[b+40>>2]=v[a+20>>2];e=v[a+16>>2];v[b+32>>2]=v[a+12>>2];v[b+36>>2]=e;Hf(b+48|0,b+32|0,d);a=v[c+4>>2];d=v[a+8>>2];e=v[a+4>>2];c=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=c;c=v[b+52>>2];v[b+16>>2]=v[b+48>>2];v[b+20>>2]=c;v[b+8>>2]=v[a+8>>2];c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;a=jb-32|0;jb=a;a:{b:{c:{d:{g=v[b+4>>2];if(g>>>0>=e>>>0){h=v[b+20>>2];if(h>>>0<e>>>0){break d}if(d>>>0>y[b+8>>2]){break c}i=v[b+28>>2];if(d>>>0>v[b+24>>2]-i>>>0){break b}l=v[b+16>>2];m=v[b>>2];e:while(1){if((d|0)==(f|0)){break a}n=B(f,g);o=B(f+i|0,h);c=0;while(1)if((c|0)==(e|0)){f=f+1|0;continue e}else{A[a+24>>3]=A[(c+n<<3)+m>>3];v[a+16>>2]=0;v[a+20>>2]=-1074790400;v[a+8>>2]=0;v[a+12>>2]=1072693248;p=(c+o<<1)+l|0;j=we(A[Gg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(D(j)<2147483648){k=~~j;break f}k=-2147483648}q=p,r=dd(k),u[q>>1]=r;c=c+1|0;continue}}}aa(7192,9005,77,8685);L()}aa(7157,9005,78,8685);L()}aa(5900,9005,79,8685);L()}aa(5870,9005,80,8685);L()}jb=a+32|0;jb=b- -64|0}function P8(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;b=jb+-64|0;jb=b;g=Sb(a);v[23588]=0;Y(909,g|0);a=v[23588];v[23588]=0;a:{if((a|0)!=1){a=44576;b:{c:{d:{e:{f:{g:{h:{i:{j:{while(1){if((a|0)==44888){jb=b- -64|0;return g|0}k:{h=$s(44);if(h){d=v[a>>2];e=v[a+4>>2];v[23588]=0;e=Q(55,b+32|0,e|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break k}v[23588]=0;R(910,b+48|0,e|0);c=v[23588];v[23588]=0;if((c|0)==1){break j}c=v[a+8>>2];v[23588]=0;c=Q(55,b|0,c|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break i}v[23588]=0;R(910,b+16|0,c|0);f=v[23588];v[23588]=0;if((f|0)==1){break h}v[23588]=0;d=fa(911,h|0,d|0,b+48|0,b+16|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break g}ac(b+16|0);yb(c);ac(b+48|0);yb(e);v[b+60>>2]=d;v[23588]=0;R(912,g|0,b+60|0);e=v[23588];v[23588]=0;if((e|0)==1){break b}v[d+32>>2]=v[a+12>>2];v[d+36>>2]=v[a+16>>2];t[d+40|0]=w[a+20|0];t[d+41|0]=w[d+41|0]&253|w[a+21|0]<<1}a=a+24|0;continue}break}a=P()|0;O()|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;ac(b+16|0)}yb(c)}ac(b+48|0)}yb(e)}Mb(h);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}vc(g);T(a|0);L()}function Tja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=jb-1072|0;jb=d;v[d+1068>>2]=c;o=d,p=Le(b),t[o+8|0]=p;t[d+4|0]=1;c=d+8|0;g=w[jf(c,d+4|0)|0];f=wB(c,b);l=Dq(f);v[23588]=0;c=S(202,b|0)|0;e=v[23588];v[23588]=0;a:{if((e|0)!=1){v[d+4>>2]=c;v[d>>2]=536870911;wc(d+1068|0,v[Jb(d+4|0,d)>>2]<<3);v[23588]=0;m=v[d+1068>>2];k=Q(335,a|0,m|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){v[23588]=0;c=8;h=Q(164,f|0,8)|0;a=v[23588];v[23588]=0;b:{if((a|0)!=1){c:{o=Kb(v[k>>2],0),p=h,t[o|0]=p;i=1;a=g;while(1){c=c&255;n=c>>>0>9?c:9;e=a;d:{e:{while(1){if(i>>>0>=m>>>0){break d}v[23588]=0;j=Q(164,f|0,c|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){if(j){break e}if((c|0)==(n|0)){break d}c=c+1|0;e=g;continue}break}break c}a=j>>>1|0;h=(j&1?0-a|0:a)+h|0;o=Kb(v[k>>2],i),p=h,t[o|0]=p;i=i+1|0;a=g;if(j>>>c-1|0){continue}a=e-1|0;e=a&255;a=e?a:g;c=c-(!e&(c&255)>>>0>1)|0;continue}break}a=Dq(f);v[23588]=0;Q(155,b|0,((a-l|0)+3&-4)+l|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){break b}}}c=P()|0;O()|0;hc(k);break a}Ab(f);jb=d+1072|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0}Ab(f);T(c|0);L()}function __(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;a=jb-448|0;jb=a;v[a+432>>2]=c;v[a+440>>2]=b;v[a+20>>2]=1158;b=se(a+24|0,a+32|0,a+20|0);h=a+16|0;fd(h,e);v[23588]=0;h=S(1136,h|0)|0;i=v[23588];v[23588]=0;if((i|0)!=1){a:{t[a+15|0]=0;e=v[e+4>>2];v[23588]=0;c=qa(1166,a+440|0,c|0,d|0,a+16|0,e|0,f|0,a+15|0,h|0,b|0,a+20|0,a+432|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break a}b:{c:{if(!c){break c}d:{if(ef(g)){ud(v[g>>2],0);Fd(g,0);break d}ud(g,0);ce(g,0)}if(w[a+15|0]){v[23588]=0;c=Q(1154,h|0,45)|0;d=v[23588];v[23588]=0;if((d|0)==1){break a}v[23588]=0;R(49,g|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break a}}v[23588]=0;d=Q(1154,h|0,48)|0;c=v[23588];v[23588]=0;if((c|0)==1){break b}e=v[a+20>>2];h=e-4|0;c=v[b>>2];while(1){if(!((d|0)!=v[c>>2]|c>>>0>=h>>>0)){c=c+4|0;continue}break}v[23588]=0;W(1171,g|0,c|0,e|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break c}break a}v[23588]=0;c=Q(1142,a+440|0,a+432|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break a}if(c){v[f>>2]=v[f>>2]|2}c=v[a+440>>2];$b(a+16|0);Wc(b);jb=a+448|0;return c|0}}}c=P()|0;O()|0;$b(a+16|0);Wc(b);T(c|0);L()}function In(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=jb-80|0;jb=c;g=Sb(a);a=v[b+24>>2];a:{b:{if(rj(v[a+484360>>2],v[a+484364>>2])){c:{d:{e:while(1){if(rj(v[a+484360>>2],v[a+484364>>2])>>>0<=f>>>0){break d}d=vM(bS(c+40|0,1),f&255,0,0);v[23588]=0;e=v[d+12>>2];v[c+16>>2]=v[d+8>>2];v[c+20>>2]=e;e=v[d+20>>2];v[c+24>>2]=v[d+16>>2];v[c+28>>2]=e;e=v[d+4>>2];v[c+8>>2]=v[d>>2];v[c+12>>2]=e;X(1046,c- -64|0,a|0,0,c+8|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}j=c,k=Eb(v[c+64>>2]),v[j+32>>2]=k;d=Eb(v[c+68>>2]);while(1){a=v[c+32>>2];if(!Ob(a,d)){f=f+1|0;Di(c- -64|0);a=v[b+24>>2];continue e}h=A[a>>3];e=v[a+16>>2];i=x[a+24>>1];a=c+40|0;v[a+16>>2]=f;v[a+12>>2]=i;v[a+8>>2]=e;A[a>>3]=h;v[23588]=0;R(1061,g|0,a|0);a=v[23588];v[23588]=0;if((a|0)!=1){Az(c+32|0);continue}break}break}a=P()|0;O()|0;Di(c- -64|0);break b}jb=c+80|0;return}a=P()|0;O()|0;break b}b=ba(8)|0;v[23588]=0;d=Q(55,c+40|0,7270)|0;a=v[23588];v[23588]=0;if((a|0)!=1){a=rc(b,d);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(d);break b}a=P()|0;O()|0;ca(b|0)}Wf(g);T(a|0)}L()}function gba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;i=jb-16|0;jb=i;v[i+8>>2]=b;o=wf(a);while(1){if(Hg(b,c)){b=v[ec(i,o)>>2];j=vd(v[i+8>>2]);m=jb-16|0;jb=m;n=0;k=jb-16|0;jb=k;h=jb-32|0;jb=h;f=h+28|0;d=h+24|0;e=jb-16|0;jb=e;a:{b:{if(!oc(b,v[ec(e+8|0,Yf(a))>>2])){g=w[j|0];l=w[vd(b)|0];if(!Rn(g,l)){break b}}v[e+8>>2]=b;g=ec(e,Eb(v[a>>2]));c:{d=v[e+8>>2];if(!oc(d,v[g>>2])){d=v[jz(e+8|0)>>2];l=w[vd(d)|0];g=w[j|0];if(!Rn(l,g)){break c}}if(!v[b>>2]){v[f>>2]=b;break a}v[f>>2]=d;b=d+4|0;break a}b=Jy(a,f,g);break a}if(Rn(l,g)){d:{d=hz(b);if(!oc(d,v[ec(e+8|0,Yf(a))>>2])){g=w[j|0];if(!Rn(g,w[vd(d)|0])){break d}}if(!v[b+4>>2]){v[f>>2]=b;b=b+4|0;break a}v[f>>2]=d;b=d;break a}b=Jy(a,f,g);break a}v[f>>2]=b;v[d>>2]=b;b=d}jb=e+16|0;d=b;b=v[b>>2];if(!b){b=jb-16|0;jb=b;e=ic(a);f=h+8|0;e=lh(f,sc(24),mh(b+8|0,e));lN(v[e>>2]+16|0,v[j>>2],v[j+4>>2]);p=ic(e),q=1,t[p+4|0]=q;jb=b+16|0;Jg(a,v[h+28>>2],d,v[h+8>>2]);b=be(f);qk(f);n=1}Ig(k+8|0,v[ec(h+8|0,b)>>2],n);jb=h+32|0;jb=k+16|0;ec(m+8|0,v[k+8>>2]);jb=m+16|0;b=v[Kg(i+8|0)>>2];continue}else{jb=i+16|0}break}}function pS(a,b,c,d,e){var f=0,g=0;f=jb-16|0;jb=f;a:{if((d&255)>>>0<=4){while(1){d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){if(!nf(a,f+15|0)){break a}d=w[f+15|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;u[c>>1]=w[c|0]}u[e>>1]=t[b|0]+(x[e>>1]<<1);d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){if(!nf(a,f+14|0)){break a}d=w[f+14|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;u[c>>1]=w[c|0]}u[e>>1]=t[b|0]+(x[e>>1]<<1);d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){d=nf(a,f+13|0);if(d){g=w[f+13|0];u[c>>1]=g<<1|1;t[b|0]=g>>>7;u[c>>1]=w[c|0]}if(!d){break a}if(w[b|0]){continue}break a}if(w[b|0]){continue}break a}}while(1){d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){if(!nf(a,f+12|0)){break a}d=w[f+12|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;u[c>>1]=w[c|0]}u[e>>1]=t[b|0]+(x[e>>1]<<1);d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){d=nf(a,f+11|0);if(d){g=w[f+11|0];u[c>>1]=g<<1|1;t[b|0]=g>>>7;u[c>>1]=w[c|0]}if(!d){break a}if(w[b|0]){continue}break a}if(w[b|0]){continue}break}}jb=f+16|0}function MV(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=jb-32|0;jb=g;t[g+12|0]=0;m=Om(g+16|0,d,g+12|0);f=v[m>>2];v[g+12>>2]=d;h=d;while(1){if(!(!b|!h)){a:{i=b-1|0;k=w[a|0];if(!(!i|(k|0)!=(e&255))){v[g+8>>2]=w[a+1|0];i=a+2|0;j=Jb(g+8|0,g+12|0);b:{k=b-2|0;if(!k){break b}j=v[j>>2];if(!(j&255)){break b}i=w[i|0];while(1){if(!(j&255)){break a}t[f|0]=i;h=v[g+12>>2]-1|0;v[g+12>>2]=h;f=f+1|0;j=j-1|0;continue}}t[f|0]=e;h=v[g+12>>2]-1|0;v[g+12>>2]=h;f=f+1|0;b=k;a=i;continue}a=a+1|0;t[f|0]=k;h=v[g+12>>2]-1|0;v[g+12>>2]=h;f=f+1|0;b=i;continue}b=b-3|0;a=a+3|0;continue}break}e=d-h|0;a=v[m>>2];k=0;f=128;b=0;i=0;c:while(1){if((e|0)==(i|0)){while(1){if(e){d=k<<24>>24;b=t[c|0];a=128;d:{if((b|0)==-128){break d}a=b;if((b|0)>=0){break d}a=0-(b&127)|0}k=d-(a&255)|0;t[c|0]=k;e=e-1|0;c=c+1|0;continue}break}hc(m);jb=g+32|0;return}n=w[a|0];h=0;j=0;while(1)if((j&65535)>>>0>=8){f=f&65535;f=(f<<8|f)>>>h&255;i=i+1|0;a=a+1|0;continue c}else{l=b+c|0;t[l|0]=w[l|0]|B(f&n,257)>>>(h-j&7);l=b+1|0;b=d>>>0>l>>>0?l:0;j=j+1|0;h=(d>>>0<=l>>>0)+h|0;f=(f<<8|f)>>>1&255;continue}}}function jaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;j=jb-32|0;jb=j;e=b;b=v[a>>2];f=B(Ys(e,Eb(b)),6)+b|0;a:{if(!c){break a}b=v[Fb(a)>>2];g=v[a+4>>2];if((b-g|0)/6>>>0>=c>>>0){b=c;e=(g-f|0)/6|0;if(e>>>0<c>>>0){NA(a,c-e|0,d);b=e;if((f|0)==(g|0)){break a}}k=jb-16|0;jb=k;m=v[a+4>>2];h=B((m-(B(c,6)+f|0)|0)/6|0,6)+f|0;l=Fq(k,a,(g-h|0)/6|0);i=v[l+4>>2];e=h;while(1){if(e>>>0>=g>>>0){kc(l);if((f|0)!=(h|0)){e=h-f|0;gj(m+B((e|0)/-6|0,6)|0,f,e)}jb=k+16|0}else{hu(i,e);i=i+6|0;v[l+4>>2]=i;e=e+6|0;continue}break}e=f;a=B(e>>>0<=d>>>0?y[a+4>>2]>d>>>0?c:0:0,6)+d|0;while(1){if(b){c=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);t[e|0]=c;t[e+1|0]=c>>>8;t[e+2|0]=c>>>16;t[e+3|0]=c>>>24;c=w[a+4|0]|w[a+5|0]<<8;t[e+4|0]=c;t[e+5|0]=c>>>8;b=b-1|0;e=e+6|0;continue}break}break a}b=Fb(a);e=iT(j+8|0,IA(a,pk(v[a>>2],g)+c|0),(f-v[a>>2]|0)/6|0,b);hT(e,c,d);b=v[e+4>>2];d=e+4|0;fT(v[a>>2],f,d);h=v[a+4>>2];c=e+8|0;while(1){if((f|0)!=(h|0)){hu(v[c>>2],f);v[c>>2]=v[c>>2]+6;f=f+6|0;continue}break}pc(a,d);pc(a+4|0,c);pc(Fb(a),Bc(e));v[e>>2]=v[e+4>>2];f=b;gT(e)}Eb(f);jb=j+32|0}function gda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0;f=jb-16|0;jb=f;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;while(1){if(d){h=v[f+8>>2];m=(((v[f+12>>2]&2147483647)<<1|h>>>31)&-2)+j|0;e=(h>>>16&65520)+b|0;n=u[e+14>>1];o=u[e+12>>1];p=u[e+10>>1];q=u[e+8>>1];r=u[e+6>>1];s=u[e+4>>1];w=u[e+2>>1];x=u[e>>1];h=0;while(1){if((h|0)!=2){e=h+m|0;v[(h<<2)+f>>2]=(((((((B(t[e-4|0],w)+B(t[e-6|0],x)|0)+B(t[e-2|0],s)|0)+B(t[e|0],r)|0)+B(t[e+2|0],q)|0)+B(t[e+4|0],p)|0)+B(t[e+6|0],o)|0)+B(t[e+8|0],n)<<8)/32768;h=h+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[f>>2],l);v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],k);Qb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;jb=f+16|0}function B8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=0,i=0,j=0,k=0,l=0,m=C(0),n=0,o=0,p=C(0),q=C(0),r=C(0),s=C(0),t=C(0),u=0,x=0,y=0,A=C(0);i=v[a+44>>2];h=Jc(i,0);i=Jc(i,1);j=v[a+56>>2];n=Jc(j,0);j=Jc(j,1);k=a+4208|0;g=uc(v[k>>2],v[a+4212>>2]);o=B(v[v[a+16>>2]+1074404>>2],w[a+4233|0]);e=o<<1;if(g>>>0<e>>>0){ck(k,e)}l=w[a+4232|0];a:{if(l){e=v[a+4220>>2];k=v[a+4208>>2];u=l-1|0;l=0;while(1){if((d|0)==(l|0)){break a}r=z[i>>2];e=e>>>0<o>>>0?e:0;g=e-o|0;g=((g|0)<0?e:g)<<1;x=Db(k,g);f=z[Db(k,g|1)>>2];s=z[h>>2];t=z[x>>2];p=C(s+t);z[n>>2]=p;q=C(r+f);z[j>>2]=q;f=C(0);m=C(0);b:{c:{switch(u|0){case 0:f=z[a+4224>>2];m=C(q*f);f=C(p*f);break b;case 1:case 2:f=z[a+4224>>2];m=C(p*f);f=C(q*f);break b;case 3:break c;default:break b}}f=C(C(C(C(s+r)*C(.5))+t)*z[a+4224>>2]);m=f}j=j+4|0;n=n+4|0;i=i+4|0;h=h+4|0;g=e<<1;y=Db(k,g),A=C(D(f))<C(10000000195414814e-40)?C(0):f,z[y>>2]=A;y=Db(k,g|1),A=C(D(m))<C(10000000195414814e-40)?C(0):m,z[y>>2]=A;e=e+1|0;v[a+4220>>2]=e;l=l+1|0;continue}}e=h;h=d<<2;ph(e,e+h|0,n);ph(i,i+h|0,j)}h=a;a=v[a+56>>2];ri(h,b,c,Jc(a,0),Jc(a,1),d)}function RA(a,b,c,d){t[a+5|0]=c;a:{b:{switch((b|64)+-64|0){case 0:t[a+3|0]=c?37:0;return;case 1:t[a+3|0]=16;return;case 2:t[a+3|0]=12;return;case 3:t[a+3|0]=14;if(d){break a}t[a+5|0]=B(c>>>4|0,10)+(c&15);return;case 4:t[a+3|0]=11;return;case 5:t[a+3|0]=3;return;case 6:t[a+3|0]=2;return;case 7:t[a+3|0]=4;return;case 8:t[a+3|0]=5;return;case 9:t[a+3|0]=18;return;case 10:t[a+3|0]=1;return;case 11:t[a+3|0]=7;return;case 12:t[a+3|0]=6;return;case 13:t[a+3|0]=21;return;case 14:t[a+3|0]=22;return;case 15:t[a+3|0]=10;return;case 16:t[a+3|0]=29;return;case 17:t[a+3|0]=15;return;case 18:t[a+3|0]=8;return;case 19:t[a+3|0]=20;return;case 20:t[a+3|0]=17;return;case 21:t[a+3|0]=26;return;case 22:t[a+3|0]=23;return;case 23:t[a+3|0]=24;return;case 24:t[a+3|0]=9;return;case 25:t[a+3|0]=27;return;case 26:t[a+3|0]=31;return;case 28:t[a+3|0]=d?32:31;return;case 29:t[a+3|0]=d?33:0;return;case 27:t[a+3|0]=d?34:0;return;case 30:t[a+3|0]=d?35:0;return;case 31:t[a+3|0]=d?36:0;return;case 50:t[a+3|0]=d?25:0;return;case 51:t[a+3|0]=d?30:0;return;default:break b}}t[a+3|0]=0}}function g8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=0,g=C(0),h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=C(0),t=0,u=0,w=0,x=0,y=0,A=C(0);a:{j=v[a+4272>>2];if(!j){break a}if(!$h(a+44|0)){break a}f=v[a+44>>2];l=Jc(f,0);m=Jc(f,1);u=v[a+4252>>2]-1|0;i=v[a+4268>>2];k=v[a+4256>>2];n=d;f=v[a+56>>2];q=Jc(f,0);o=q;r=Jc(f,1);p=r;while(1){if(n){e=z[m>>2];f=i<<1;h=Db(k,f);g=z[l>>2];z[h>>2]=g;y=Db(k,f|1),A=e,z[y>>2]=A;s=z[a+4276>>2];e=C(C(D(SK(C(C(C(D(g))+C(D(e)))*C(536870912)),31,5)))*C(4.656612873077393e-10));e=C(C(C(s-e)*z[(e>=s?4236:4240)+a>>2])+e);z[a+4276>>2]=e;g=z[a+4244>>2];e=C(C(C(C(g-(e<g?g:e))*z[a+4248>>2])+C(.9999998807907104))*C(2147483648));b:{if(e<C(4294967296)&e>=C(0)){f=~~e>>>0;break b}f=0}t=((((i<<12)+u|0)+j|0)/4096|0)%(j|0)<<1;g=z[Db(k,t)>>2];h=f<<5;w=h;x=h|-2147483648;h=f>>>0<67108864;e=C(z[a+4232>>2]*C(C((h?w:x)>>>(h?31:32-(f>>>26|0)|0)>>>0)*C(4.656612873077393e-10)));z[o>>2]=g*e;y=p,A=C(z[Db(k,t|1)>>2]*e),z[y>>2]=A;i=((i?0:j)+i|0)-1|0;v[a+4268>>2]=i;n=n-1|0;p=p+4|0;o=o+4|0;m=m+4|0;l=l+4|0;continue}else{ri(a,b,c,q,r,d)}break}}}function WX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-32|0;jb=d;f=Sb(a);a=0;a:{b:{c:{d:{e:{while(1){if((Uv(b,c,a)|0)==-1){break b}e=Uv(b,c,a);v[23588]=0;X(122,d|0,b|0,a|0,e-a|0);e=v[23588];v[23588]=0;if((e|0)!=1){v[23588]=0;R(123,d+16|0,d|0);e=v[23588];v[23588]=0;if((e|0)==1){break e}v[23588]=0;R(124,f|0,d+16|0);e=v[23588];v[23588]=0;if((e|0)==1){break d}zb(d+16|0);zb(d);a=Uv(b,c,a)+Fk(v[c+4>>2],w[c+11|0])|0;continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;zb(d+16|0)}zb(d);break a}f:{g:{h:{i:{j:{k:{if(oc(v[f>>2],v[f+4>>2])){v[23588]=0;X(122,d+16|0,b|0,a|0,-1);c=v[23588];v[23588]=0;if((c|0)==1){break j}c=Fk(v[d+20>>2],w[d+27|0]);zb(d+16|0);if(!c){break k}}v[23588]=0;X(122,d|0,b|0,a|0,-1);a=v[23588];v[23588]=0;if((a|0)==1){break i}v[23588]=0;R(123,d+16|0,d|0);a=v[23588];v[23588]=0;if((a|0)==1){break h}v[23588]=0;R(124,f|0,d+16|0);a=v[23588];v[23588]=0;if((a|0)==1){break g}zb(d+16|0);zb(d)}jb=d+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break f}a=P()|0;O()|0;zb(d+16|0)}zb(d)}Rl(f);T(a|0);L()}function Bia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=jb-48|0;jb=d;i=a+484344|0;j=a+480280|0;k=a+906300|0;while(1){a:{if(Pb(v[b>>2],v[b+8>>2],9)){e=d+44|0;no(b,e);c=Bg(b);b:{if(!Rb(e,13951,4)){break b}if(!Rb(d+44|0,13603,4)){break b}if(!Rb(d+44|0,13779,4)){break b}if(!Rb(d+44|0,13784,4)){break b}if(Pb(v[b>>2],v[b+8>>2],c)){break a}}yg(b,8)}jb=d+48|0;return l|0}$d(d,b,c);e=jc(d+24|0,d);Ab(d);c=j;c:{d:{e:{if(!Rb(d+44|0,13469,4)){while(1){if((c|0)==(i|0)){break c}v[23588]=0;f=S(157,e|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break e}t[c+8|0]=f;c=c+32|0;continue}}if(w[d+44|0]!=70){break d}f=w[d+45|0];h=(f|0)==88;f:{if(!h){if((f-48&255)>>>0>9){break d}c=t[d+46|0];if((c|0)>47){break f}break d}c=t[d+46|0];if((c|0)<48){break d}}if(c>>>0>57){break d}g=t[d+47|0];if((g|0)<48|(g|0)>57){break d}c=(g+(h?-16:B(f,100)+48|0)|0)+B(c,10)&255;if(c>>>0>249){break c}v[23588]=0;R(439,e|0,Ld(k,c)|0);c=v[23588];v[23588]=0;if((c|0)!=1){break c}}a=P()|0;O()|0;Ab(e);T(a|0);L()}if(Rb(d+44|0,13485,4)){break c}v[a+1074308>>2]=0;l=1}Ab(e);continue}}function TM(a){var b=0,c=0,d=0,e=0,f=0,g=0;while(1){if((f|0)!=4e3){g=jb-32|0;jb=g;b=zt(g);d=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);c=(f<<5)+a|0;e=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[c|0]=e;t[c+1|0]=e>>>8;t[c+2|0]=e>>>16;t[c+3|0]=e>>>24;t[c+4|0]=d;t[c+5|0]=d>>>8;t[c+6|0]=d>>>16;t[c+7|0]=d>>>24;d=w[b+28|0]|w[b+29|0]<<8|(w[b+30|0]<<16|w[b+31|0]<<24);e=w[b+24|0]|w[b+25|0]<<8|(w[b+26|0]<<16|w[b+27|0]<<24);t[c+24|0]=e;t[c+25|0]=e>>>8;t[c+26|0]=e>>>16;t[c+27|0]=e>>>24;t[c+28|0]=d;t[c+29|0]=d>>>8;t[c+30|0]=d>>>16;t[c+31|0]=d>>>24;d=w[b+20|0]|w[b+21|0]<<8|(w[b+22|0]<<16|w[b+23|0]<<24);e=w[b+16|0]|w[b+17|0]<<8|(w[b+18|0]<<16|w[b+19|0]<<24);t[c+16|0]=e;t[c+17|0]=e>>>8;t[c+18|0]=e>>>16;t[c+19|0]=e>>>24;t[c+20|0]=d;t[c+21|0]=d>>>8;t[c+22|0]=d>>>16;t[c+23|0]=d>>>24;d=w[b+12|0]|w[b+13|0]<<8|(w[b+14|0]<<16|w[b+15|0]<<24);b=w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24);t[c+8|0]=b;t[c+9|0]=b>>>8;t[c+10|0]=b>>>16;t[c+11|0]=b>>>24;t[c+12|0]=d;t[c+13|0]=d>>>8;t[c+14|0]=d>>>16;t[c+15|0]=d>>>24;jb=g+32|0;f=f+1|0;continue}break}}function iI(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=0,o=C(0),p=0;a:{if(w[b+21|0]){p=B(d,g);j=v[e>>2];l=v[f>>2];m=v[b>>2];b:{while(1){if((h|0)>0){if(v[a+1396>>2]<=9){$k(a)}g=v[a+1392>>2];k=u[(((g&1023)<<1)+b|0)+36>>1];c:{if((k|0)>=0){i=g;k=k&65535;g=w[k+v[b+8>>2]|0];v[a+1392>>2]=i>>>g;g=v[a+1396>>2]-g|0;v[a+1396>>2]=(g|0)>0?g:0;k=(g|0)>=0?k:-1;break c}k=hm(a,b)}if((k|0)>=v[b+2092>>2]?w[b+23|0]:0){break a}if((k|0)<0){if(!w[a+1376|0]){b=0;if(v[a+1384>>2]){break b}}dc(a,21);return 0}g=0;n=B(d,l);m=((m+n|0)+j|0)>(p|0)?(p-n|0)+j|0:m;n=(m|0)>0?m:0;k=B(k,v[b>>2]);o=C(0);d:{if(w[b+22|0]){while(1){if((g|0)==(n|0)){break d}o=C(o+z[v[b+28>>2]+(g+k<<2)>>2]);i=v[(j<<2)+c>>2];if(i){i=i+(l<<2)|0;z[i>>2]=o+z[i>>2]}j=j+1|0;i=(j|0)==(d|0);j=i?0:j;g=g+1|0;l=i+l|0;continue}}while(1){if((g|0)==(n|0)){break d}i=v[(j<<2)+c>>2];if(i){i=i+(l<<2)|0;z[i>>2]=z[i>>2]+C(z[v[b+28>>2]+(g+k<<2)>>2]+C(0))}j=j+1|0;i=(j|0)==(d|0);j=i?0:j;g=g+1|0;l=i+l|0;continue}}h=h-m|0;continue}break}v[e>>2]=j;v[f>>2]=l;b=1}return b}dc(a,21);return 0}aa(7512,13110,1887,6554);L()}function Cda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0;g=jb-16|0;jb=g;f=v[a+48>>2];j=v[a+40>>2];k=v[a+36>>2];e=v[a+44>>2];l=v[a+16>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;m=v[a+32>>2];n=v[a+28>>2];o=v[a+72>>2];b=v[a+68>>2];p=b;q=b>>31;b=v[a+64>>2];r=b;s=b>>31;b=v[a+60>>2];u=b;w=b>>31;x=v[a+8>>2];y=v[a+12>>2];while(1){b=e;if(d){e=Xb(b,-16777216,16776704);e=Lka(r,s,e,e>>31);i=mb;f=Xb(f,-16777216,16776704);h=Lka(p,q,f,f>>31);e=h+e|0;f=mb+i|0;f=e>>>0<h>>>0?f+1|0:f;i=e;h=v[g+12>>2]+l|0;e=t[h|0];z=i;i=((B(t[h+1|0]-e|0,v[g+8>>2]>>>10&4194048)|0)/16384|0)+(e<<8)<<8;e=i;h=Lka(e,e>>31,u,w);e=z+h|0;f=mb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Xc(e,f,24);e=(f|0)/256|0;k=k+n|0;v[c>>2]=B(e,k>>12)+v[c>>2];j=j+m|0;v[c+4>>2]=v[c+4>>2]+B(j>>12,e);Qb(g+8|0,x,y);e=f-(i&o)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=c;v[a+40>>2]=j;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+48>>2]=f;v[a+44>>2]=b;v[a+24>>2]=j>>12;jb=g+16|0}function YN(a,b){var c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;a:{b:{switch(w[a+480224|0]-1|0){default:c=v[a+24620>>2];v[d+12>>2]=1;v[d+8>>2]=v[b+44>>2]<<1;c=Lka(c,c>>31,5e4,0);e=mb;b=v[Yc(d+12|0,d+8|0)>>2];c=Hc(Mka(c,e,b,b>>31),mb);break a;case 0:c=v[a+24620>>2];v[d+12>>2]=1;v[d+8>>2]=v[b+44>>2];c=Lka(c,c>>31,1e4,0);e=mb;b=v[Yc(d+12|0,d+8|0)>>2];c=Hc(Mka(c,e,b,b>>31),mb);break a;case 1:break b}}f=60/(+y[b+44>>2]/1e4*(+(Lka(v[b+32>>2],0,v[b+40>>2],0)>>>0)+ +(mb>>>0)*4294967296))*+y[a+24620>>2];c:{d:{c=v[a+484344>>2];e=x[b+70>>1];if(!xe(c,v[a+484348>>2],e)){break d}c=Yb(c,e);if(!Ob(v[c+24>>2],v[c+28>>2])){break d}c=c+24|0;break c}c=a+480248|0}e=v[c>>2];c=v[c+4>>2];if(!oc(e,c)){f=f*+y[Db(e,y[b+48>>2]%(uc(e,c)>>>0)|0)>>2]*5.960464477539063e-8}e:{if(D(f)<2147483648){c=~~f;break e}c=-2147483648}f=A[b+8>>3]+(f-+(c>>>0));A[b+8>>3]=f;if(f>=1){A[b+8>>3]=f+-1;c=c+1|0;break a}if(!(A[a+1074384>>3]<=-1)){break a}A[b+8>>3]=f+1;c=c-1|0}b=Lka(v[a+480244>>2],0,c,0)+32768|0;a=mb;a=b>>>0<32768?a+1|0:a;a=Dc((a&65535)<<16|b>>>16,a>>>16|0);jb=d+16|0;return a?a:1}function V9(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=C(0),m=0,n=0,o=C(0);h=u[d>>1];j=u[d+2>>1];a:{if((h|0)>(j|0)){break a}k=v[b>>2];g=uc(k,v[b+4>>2]);if(!g){break a}i=u[e>>1];if((i|0)<(h|0)|(i|0)>(j|0)|(g-1&65535)>>>0>(j-i&65535)>>>0|y[a+36>>2]>65535){break a}b:{while(1){if((f|0)==(g|0)){break b}i=Db(k,f);f=f+1|0;if(!(z[i>>2]<C(0))){continue}break}return 0}i=(f|0)!=(g|0);f=0;if(i){break a}l=z[c>>2];if(l<=C(0)){break a}u[a+28>>1]=h;u[a>>1]=1;m=a,n=OL(g),u[m+30>>1]=n;z[a+32>>2]=D(l);ck(a+4|0,(j-h|0)+1|0);ph(Eb(v[b>>2]),Eb(v[b+4>>2]),ym(Eb(v[a+4>>2]),u[e>>1]-u[d>>1]|0));c=v[a+4>>2];g=u[a+30>>1];h=u[a+28>>1];b=u[e>>1];f=b;while(1){if((b&65535)!=32768&(f|0)>(h|0)){f=f-1|0;b=f-h|0;j=Db(c,b+g|0);m=Db(c,b),o=C(z[j>>2]/z[a+32>>2]),z[m>>2]=o;b=u[e>>1];continue}else{c=u[a+30>>1];e=u[a+28>>1];h=c+e|0;f=g;g=b<<16>>16;f=f+g|0;b=v[a+4>>2];d=u[d+2>>1];c=(g|0)<=(32767-c|0);while(1){if(c&(d|0)>=(f|0)){g=Db(b,f-h|0);m=Db(b,f-e|0),o=C(z[a+32>>2]*z[g>>2]),z[m>>2]=o;f=f+1|0;continue}else{Ep(a)}break}}break}f=1}return f|0}function e$(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;a=jb-160|0;jb=a;v[a+144>>2]=c;v[a+152>>2]=b;v[a+20>>2]=1158;b=se(a+24|0,a+32|0,a+20|0);h=a+16|0;fd(h,e);v[23588]=0;h=S(19,h|0)|0;i=v[23588];v[23588]=0;if((i|0)!=1){a:{t[a+15|0]=0;e=v[e+4>>2];v[23588]=0;c=qa(1159,a+152|0,c|0,d|0,a+16|0,e|0,f|0,a+15|0,h|0,b|0,a+20|0,a+132|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break a}b:{c:{if(!c){break c}_f(g);if(w[a+15|0]){v[23588]=0;c=Q(20,h|0,45)|0;d=v[23588];v[23588]=0;if((d|0)==1){break a}v[23588]=0;R(47,g|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break a}}v[23588]=0;d=Q(20,h|0,48)|0;c=v[23588];v[23588]=0;if((c|0)==1){break b}e=v[a+20>>2];h=e-1|0;c=v[b>>2];d=d&255;while(1){if(!((d|0)!=w[c|0]|c>>>0>=h>>>0)){c=c+1|0;continue}break}v[23588]=0;W(1165,g|0,c|0,e|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break c}break a}v[23588]=0;c=Q(1126,a+152|0,a+144|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break a}if(c){v[f>>2]=v[f>>2]|2}c=v[a+152>>2];$b(a+16|0);Wc(b);jb=a+160|0;return c|0}}}c=P()|0;O()|0;$b(a+16|0);Wc(b);T(c|0);L()}function Bda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0;g=jb-16|0;jb=g;f=v[a+48>>2];j=v[a+40>>2];k=v[a+36>>2];e=v[a+44>>2];l=v[a+16>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;m=v[a+32>>2];n=v[a+28>>2];o=v[a+72>>2];b=v[a+68>>2];p=b;q=b>>31;b=v[a+64>>2];r=b;s=b>>31;b=v[a+60>>2];t=b;w=b>>31;x=v[a+8>>2];y=v[a+12>>2];while(1){b=e;if(d){e=Xb(b,-16777216,16776704);e=Lka(r,s,e,e>>31);i=mb;f=Xb(f,-16777216,16776704);h=Lka(p,q,f,f>>31);e=h+e|0;f=mb+i|0;f=e>>>0<h>>>0?f+1|0:f;i=e;h=(v[g+12>>2]<<1)+l|0;e=u[h>>1];z=i;i=e+((B(u[h+2>>1]-e|0,v[g+8>>2]>>>18|0)|0)/16384|0)<<8;e=i;h=Lka(e,e>>31,t,w);e=z+h|0;f=mb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Xc(e,f,24);e=(f|0)/256|0;k=k+n|0;v[c>>2]=B(e,k>>12)+v[c>>2];j=j+m|0;v[c+4>>2]=v[c+4>>2]+B(j>>12,e);Qb(g+8|0,x,y);e=f-(i&o)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=c;v[a+40>>2]=j;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+48>>2]=f;v[a+44>>2]=b;v[a+24>>2]=j>>12;jb=g+16|0}function Yy(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=jb-16|0;jb=e;f=a+1074312|0;Cb(e+8|0,f,77);a:{if(j=Bb(v[v[e+8>>2]>>2],v[e+12>>2]),k=0,l=v[c+88>>2]&134218752,l?j:k){break a}b:{c:{if(d){g=w[c+841|0];if(!g){break c}d=g-1|0;t[c+841|0]=d;if(d&255){break b}Cb(e+8|0,f,16);if(!Bb(v[v[e+8>>2]>>2],v[e+12>>2])&v[a+480180>>2]!=2){break a}a=v[b+48>>2]+1|0}else{a=v[b+48>>2]}v[c+764>>2]=a;break a}Cb(e+8|0,f,17);d:{if(Bb(v[v[e+8>>2]>>2],v[e+12>>2])|v[a+480180>>2]&3){break d}g=b+616|0;i=x[a+480188>>1];while(1){if((h&65535)>>>0>=i>>>0){break d}if(w[g+841|0]?(c|0)!=(g|0):0){break a}g=g+872|0;h=h+1|0;continue}}t[c+841|0]=d}d=v[c+764>>2];v[b+56>>2]=d;e:{if((d|0)==-1){break e}f:{if(v[b+60>>2]==-1){break f}Cb(e+8|0,f,68);if(!Bb(v[v[e+8>>2]>>2],v[e+12>>2])){break f}v[b+60>>2]=d}v[b+64>>2]=d;Cb(e+8|0,f,103);if(!Bb(v[v[e+8>>2]>>2],v[e+12>>2])){break e}u[b+68>>1]=65535}if(v[a+480180>>2]!=2){break a}d=x[a+480188>>1];a=0;while(1){if((a|0)==(d|0)){break a}f=B(a,872)+b|0;v[f+1380>>2]=v[c+764>>2];t[f+1457|0]=w[c+841|0];a=a+1|0;continue}}jb=e+16|0}function dI(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=jb-208|0;jb=d;v[d+8>>2]=1;v[d+12>>2]=0;h=b<<2;a:{if(!h){break a}v[d+16>>2]=4;v[d+20>>2]=4;b=4;f=4;e=2;while(1){g=b;b=(b+f|0)+4|0;v[(d+16|0)+(e<<2)>>2]=b;e=e+1|0;f=g;if(b>>>0<h>>>0){continue}break}f=(a+h|0)-4|0;b:{if(f>>>0<=a>>>0){f=0;e=1;h=0;b=1;g=0;break b}e=1;b=1;while(1){c:{if((e&3)==3){dx(a,c,b,d+16|0);ns(d+8|0,2);b=b+2|0;break c}g=b-1|0;d:{if(y[(d+16|0)+(g<<2)>>2]>=f-a>>>0){ms(a,c,e,v[d+12>>2],b,0,d+16|0);break d}dx(a,c,b,d+16|0)}if((b|0)==1){ls(d+8|0,1);b=0;break c}ls(d+8|0,g);b=1}g=v[d+8>>2];e=g|1;v[d+8>>2]=e;a=a+4|0;if(f>>>0>a>>>0){continue}break}h=g>>>0>1;f=v[d+12>>2];g=(f|0)!=0}ms(a,c,e,f,b,0,d+16|0);if(!(g?1:(b|0)!=1|h)){break a}while(1){e:{if((b|0)<=1){g=XH(e,f);ns(d+8|0,g);f=v[d+12>>2];e=v[d+8>>2];b=b+g|0;break e}e=d+8|0;ls(e,2);v[d+8>>2]=v[d+8>>2]^7;ns(e,1);f=a-4|0;h=d+16|0;g=b-2|0;ms(f-v[h+(g<<2)>>2]|0,c,v[d+8>>2],v[d+12>>2],b-1|0,1,h);ls(e,1);e=v[d+8>>2]|1;v[d+8>>2]=e;b=f;f=v[d+12>>2];ms(b,c,e,f,g,1,h);b=g}a=a-4|0;if((b|0)!=1|(e|0)!=1|f){continue}break}}jb=d+208|0}function g6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;v[23588]=0;Y(977,a|0);e=v[23588];v[23588]=0;a:{b:{c:{d:{e:{if((e|0)==1){break e}v[23588]=0;Y(953,b|0);e=v[23588];v[23588]=0;if((e|0)==1){break e}e=0;v[23588]=0;Y(978,c|0);f=v[23588];v[23588]=0;if((f|0)==1){break e}a=Tb(c,0,d);if(!w[b|0]){break b}if(vi(b,7226)|(d|0)!=8){break d}v[a+4>>2]=979;v[a>>2]=980;break c}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,12196,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();return 0}if(!(vi(b,11161)|(d|0)!=64)){v[a+60>>2]=981;v[a+56>>2]=982;v[a+52>>2]=983;v[a+48>>2]=984;v[a+44>>2]=985;v[a+40>>2]=986;v[a+36>>2]=987;v[a+32>>2]=988;v[a+28>>2]=989;v[a+24>>2]=990;v[a+20>>2]=991;v[a+16>>2]=992;v[a+12>>2]=993;v[a+8>>2]=994;v[a+4>>2]=995;v[a>>2]=996;break c}if(!(vi(b,15151)|(d|0)!=24)){v[a+20>>2]=997;v[a+16>>2]=998;v[a+12>>2]=999;v[a+8>>2]=1e3;v[a+4>>2]=1001;v[a>>2]=1002;break c}if(vi(b,14952)|(d|0)!=4){break b}v[a>>2]=1003}e=1}return e|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function cR(a){a=a|0;var b=0,c=0,d=0,e=0;c=jb-80|0;jb=c;v[c+72>>2]=0;v[c+76>>2]=0;b=c- -64|0;v[b>>2]=0;v[b+4>>2]=0;v[c+56>>2]=0;v[c+60>>2]=0;v[c+48>>2]=0;v[c+52>>2]=0;Gz(a,Hz(a),c+48|0);b=qc(c+40|0,14144);gf(ye(a,0),v[b>>2],v[b+4>>2]);b=qc(c+32|0,14248);gf(ye(a,1),v[b>>2],v[b+4>>2]);b=qc(c+24|0,5499);gf(ye(a,3),v[b>>2],v[b+4>>2]);b=qc(c+16|0,15671);gf(ye(a,4),v[b>>2],v[b+4>>2]);b=qc(c+8|0,9225);gf(ye(a,8),v[b>>2],v[b+4>>2]);e=ye(a+288|0,0);b=jb-16|0;jb=b;d=e;e=qc(b+8|0,4935);gf(d,v[e>>2],v[e+4>>2]);jb=b+16|0;e=a+800|0;b=0;a=jb-80|0;jb=a;a:{b:{while(1){if((b|0)==128){break a}v[a+76>>2]=b<<3;c:{d:{if(b>>>0<=15){Ju(a+32|0,4087);v[23588]=0;R(287,a+16|0,a+76|0);d=v[23588];v[23588]=0;if((d|0)==1){break c}v[23588]=0;U(288,a+48|0,a+32|0,a+16|0);d=v[23588];v[23588]=0;if((d|0)!=1){d=a+48|0;Fe(a- -64|0,d);gf(ye(e,b),v[a+64>>2],v[a+68>>2]);yb(d);yb(a+16|0);_b(a+32|0);break d}b=P()|0;O()|0;yb(a+16|0);break b}d=qc(a+8|0,21619);gf(ye(e,b),v[d>>2],v[a+12>>2])}b=b+1|0;continue}break}b=P()|0;O()|0}_b(a+32|0);T(b|0);L()}jb=a+80|0;jb=c+80|0}function eo(a,b,c,d){var e=0;e=jb-16|0;jb=e;t[a+841|0]=0;v[a+708>>2]=0;t[a+797|0]=0;v[a+764>>2]=0;v[a+800>>2]=0;v[a+696>>2]=0;v[a+668>>2]=0;u[a+804>>1]=0;v[a+88>>2]=v[a+88>>2]|6144;Cb(e+8|0,b+1074312|0,23);if(Bb(v[v[e+8>>2]>>2],v[e+12>>2])){t[a+807|0]=1;t[a+808|0]=0}t[a+846|0]=0;t[a+839|0]=0;u[a+774>>1]=0;t[a+850|0]=255;v[a+660>>2]=0;t[a+851|0]=w[a+851|0]&224;io(a+788|0);v[a+84>>2]=0;v[a+76>>2]=0;v[a+80>>2]=0;v[a+700>>2]=0;v[a+656>>2]=0;v[a+104>>2]=0;v[a+92>>2]=0;v[a+96>>2]=0;v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;t[a+845|0]=0;t[a+838|0]=0;t[a+821|0]=0;v[a+688>>2]=0;v[a+672>>2]=0;v[a+676>>2]=0;u[a+836>>1]=32512;t[a+819|0]=0;t[a+820|0]=0;u[a+842>>1]=0;v[a+28>>2]=0;v[a+32>>2]=0;v[a+20>>2]=0;v[a+24>>2]=0;v[a+852>>2]=0;v[a+856>>2]=0;t[a+851|0]=w[a+851|0]&159;a:{if(c>>>0<=126){b=(c<<5)+b|0;c=v[b+480280>>2];v[a+88>>2]=c;v[a+692>>2]=x[b+480284>>1];v[a+748>>2]=x[b+480286>>1];if(!(c&1024)){break a}v[a+88>>2]=c&-1025|d;break a}v[a+748>>2]=64;v[a+692>>2]=128;v[a+88>>2]=0}u[a+784>>1]=0;t[a+795|0]=0;t[a+796|0]=0;jb=e+16|0}function Rda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0;g=jb-16|0;jb=g;o=v[a+16>>2];l=Sf(1,2);b=mb;p=b;Qb(a,l,b);f=v[a+48>>2];i=v[a+40>>2];j=v[a+36>>2];e=v[a+44>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;q=v[a+32>>2];r=v[a+28>>2];s=v[a+72>>2];b=v[a+68>>2];t=b;w=b>>31;b=v[a+64>>2];x=b;y=b>>31;b=v[a+60>>2];z=b;A=b>>31;C=v[a+8>>2];D=v[a+12>>2];while(1){b=e;if(d){m=u[(v[g+12>>2]<<1)+o>>1]<<8;e=m;e=Lka(e,e>>31,z,A);k=mb;h=e;e=Xb(b,-16777216,16776704);n=Lka(x,y,e,e>>31);h=h+n|0;e=mb+k|0;e=h>>>0<n>>>0?e+1|0:e;f=Xb(f,-16777216,16776704);k=Lka(t,w,f,f>>31);h=k+h|0;f=mb+e|0;f=h>>>0<k>>>0?f+1|0:f;e=h+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Xc(e,f,24);e=(f|0)/256|0;j=j+r|0;v[c>>2]=B(e,j>>12)+v[c>>2];i=i+q|0;v[c+4>>2]=v[c+4>>2]+B(i>>12,e);Qb(g+8|0,C,D);e=f-(s&m)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=c;v[a+40>>2]=i;v[a+20>>2]=j>>12;v[a+36>>2]=j;v[a+48>>2]=f;v[a+44>>2]=b;v[a+24>>2]=i>>12;lg(a,l,p);jb=g+16|0}function T8(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=C(0),h=0,i=0;c=jb-32|0;jb=c;a:{d=v[a+20>>2];b:{if(!d){break b}v[d+148>>2]=-1;h=c,i=nb[v[v[a>>2]+40>>2]](a)|0,v[h+16>>2]=i;v[c+8>>2]=1073741822;f=v[Jb(c+16|0,c+8|0)>>2];b=f<<2;if(!b){break b}e=v[a+20>>2];d=0;v[23588]=0;R(285,e+4|0,b+4|0);b=v[23588];v[23588]=0;c:{d:{if((b|0)!=1){b=v[a+20>>2];re(c+8|0,v[b+4>>2],v[b+8>>2]);v[c>>2]=0;v[c+4>>2]=0;e=v[c+12>>2];b=c+16|0;v[b>>2]=v[c+8>>2];v[b+4>>2]=e;e=v[c+4>>2];v[b+8>>2]=v[c>>2];v[b+12>>2]=e;e=jb-16|0;jb=e;v[e+8>>2]=0;jL(b,e+8|0);jb=e+16|0;b=v[v[a>>2]+184>>2];v[23588]=0;R(b|0,a|0,-1);b=v[23588];v[23588]=0;if((b|0)==1){break d}while(1){if((d|0)==(f|0)){d=v[v[a>>2]+188>>2];v[23588]=0;Y(d|0,a|0);d=v[23588];v[23588]=0;if((d|0)!=1){break b}break d}b=v[v[a>>2]+48>>2];v[23588]=0;g=C($a(b|0,a|0,d|0));b=v[23588];v[23588]=0;if((b|0)!=1){z[c+8>>2]=g;d=d+1|0;jL(c+16|0,c+8|0);continue}break}d=V(92948)|0;break c}d=V(92948)|0;break c}d=V(92948)|0}if((O()|0)!=(da(92948)|0)){break a}_(d|0)|0;Kc(v[a+20>>2]+4|0);$()}jb=c+32|0;return}T(d|0);L()}function Sda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0;g=jb-16|0;jb=g;o=v[a+16>>2];l=Sf(1,2);b=mb;p=b;Qb(a,l,b);f=v[a+48>>2];i=v[a+40>>2];j=v[a+36>>2];e=v[a+44>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;q=v[a+32>>2];r=v[a+28>>2];s=v[a+72>>2];b=v[a+68>>2];u=b;w=b>>31;b=v[a+64>>2];x=b;y=b>>31;b=v[a+60>>2];z=b;A=b>>31;C=v[a+8>>2];D=v[a+12>>2];while(1){b=e;if(d){m=t[v[g+12>>2]+o|0]<<16;e=m;e=Lka(e,e>>31,z,A);k=mb;h=e;e=Xb(b,-16777216,16776704);n=Lka(x,y,e,e>>31);h=h+n|0;e=mb+k|0;e=h>>>0<n>>>0?e+1|0:e;f=Xb(f,-16777216,16776704);k=Lka(u,w,f,f>>31);h=k+h|0;f=mb+e|0;f=h>>>0<k>>>0?f+1|0:f;e=h+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Xc(e,f,24);e=(f|0)/256|0;j=j+r|0;v[c>>2]=B(e,j>>12)+v[c>>2];i=i+q|0;v[c+4>>2]=v[c+4>>2]+B(i>>12,e);Qb(g+8|0,C,D);e=f-(s&m)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=c;v[a+40>>2]=i;v[a+20>>2]=j>>12;v[a+36>>2]=j;v[a+48>>2]=f;v[a+44>>2]=b;v[a+24>>2]=i>>12;lg(a,l,p);jb=g+16|0}function zka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=jb-32|0;jb=h;e=b;b=v[a>>2];b=(yo(e,Eb(b))<<1)+b|0;a:{b:{f=v[a+4>>2];if(f>>>0<y[Fb(a)>>2]){if((b|0)!=(f|0)){break b}d=jb-16|0;jb=d;a=_h(d,a,1);Jj(v[a+4>>2],w[c|0]|w[c+1|0]<<8);v[a+4>>2]=v[a+4>>2]+2;kc(a);jb=d+16|0;break a}d=Fb(a);d=Mj(h+8|0,Nj(a,Qc(v[a>>2],f)+1|0),b-v[a>>2]>>1,d);v[23588]=0;R(292,d|0,c|0);c=v[23588];v[23588]=0;if((c|0)!=1){c=v[d+4>>2];f=d+4|0;dq(v[a>>2],b,f);g=v[a+4>>2];e=d+8|0;while(1){if((b|0)!=(g|0)){Jj(v[e>>2],w[b|0]|w[b+1|0]<<8);v[e>>2]=v[e>>2]+2;b=b+2|0;continue}break}pc(a,f);pc(a+4|0,e);pc(Fb(a),Bc(d));v[d>>2]=v[d+4>>2];b=c;Ni(d);break a}a=P()|0;O()|0;Ni(d);T(a|0);L()}i=jb-16|0;jb=i;j=v[a+4>>2];e=(j-(b+2|0)|0)+b|0;k=_h(i,a,f-e>>1);g=v[k+4>>2];d=e;while(1){if(d>>>0>=f>>>0){kc(k);while(1){if((b|0)!=(e|0)){e=e-2|0;j=oV(j-2|0,e);continue}break}jb=i+16|0}else{Jj(g,w[d|0]|w[d+1|0]<<8);g=g+2|0;v[k+4>>2]=g;d=d+2|0;continue}break}a=((b>>>0<=c>>>0&y[a+4>>2]>c>>>0)<<1)+c|0;c=w[a|0];t[b+1|0]=w[a+1|0];t[b|0]=c}Eb(b);jb=h+32|0}function yca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=jb-16|0;jb=e;p=v[a+16>>2];q=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);l=v[a+128>>2];a:{if(!l){k=v[a+8>>2];m=v[a+12>>2];f=v[a>>2];b=v[a+4>>2];h=0;break a}b=v[a+12>>2];m=b;k=v[a+8>>2];n=kg(k,b,l);o=mb;h=v[a+76>>2];f=v[a>>2];b=v[a+4>>2];Pf(f,b,kf(k,m,d),mb);h=h>>>0<mb>>>0?d:0}g=a+112|0;i=v[a+40>>2];j=v[a+36>>2];v[e>>2]=f;v[e+4>>2]=b;b:while(1){if(d){d=d-1|0;v[e+8>>2]=f;v[e+12>>2]=0;h=h-1|0;n=h?n:0;o=h?o:0;f=(b<<1)+p|0;b=l;while(1)if((b|0)<=0){Qb(g,v[a+120>>2],v[a+124>>2]);b=v[a+116>>2];if(b){Rd(g,u[f+(v[e+12>>2]<<1)>>1]/4<<16>>16);Qd(g,b);v[g>>2]=v[g>>2];v[g+4>>2]=0}b=v[a+32>>2];j=v[a+28>>2]+j|0;f=ig(g,q);v[c>>2]=B(j>>12,f)+v[c>>2];i=b+i|0;v[c+4>>2]=v[c+4>>2]+B(f,i>>12);Qb(e,k,m);c=c+8|0;f=v[e>>2];b=v[e+4>>2];continue b}else{Rd(g,u[f+(v[e+12>>2]<<1)>>1]/4<<16>>16);Qd(g,4);Qb(e+8|0,n,o);b=b-1|0;continue}}break}v[a>>2]=f;v[a+4>>2]=b;v[a+40>>2]=i;v[a+20>>2]=j>>12;v[a+36>>2]=j;v[a+24>>2]=i>>12;jb=e+16|0}function dda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=jb-16|0;jb=f;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}l=v[a+16>>2];j=v[a+40>>2];k=v[a+36>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;m=v[a+32>>2];n=v[a+28>>2];while(1){if(d){e=(v[f+12>>2]<<1)+l|0;h=(v[f+8>>2]>>>16&65520)+b|0;e=(((((((B(u[e-4>>1],u[h+2>>1])+B(u[e-6>>1],u[h>>1])|0)+B(u[e-2>>1],u[h+4>>1])|0)+B(u[e>>1],u[h+6>>1])|0)+B(u[e+2>>1],u[h+8>>1])|0)+B(u[e+4>>1],u[h+10>>1])|0)+B(u[e+6>>1],u[h+12>>1])|0)+B(u[e+8>>1],u[h+14>>1])|0)/32768|0;k=k+n|0;v[c>>2]=v[c>>2]+B(e,k>>12);j=j+m|0;v[c+4>>2]=v[c+4>>2]+B(e,j>>12);Qb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;v[a+40>>2]=j;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+24>>2]=j>>12;jb=f+16|0}function xP(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0),m=0,n=0;i=jb-16|0;jb=i;if(vj(v[a+656>>2])){e=w[a+797|0];g=_c(e);f=w[a+799|0];Cb(i+8|0,d+1074312|0,34);d=g?e:f;a:{if(!Bb(v[v[i+8>>2]>>2],v[i+12>>2])){break a}e=d&255;if(!e|e>>>0>120){break a}d=w[Kb(v[a+656>>2]+108|0,e-1|0)|0]}l=C(C(v[a+704>>2])*b);e=v[v[a+656>>2]+44>>2];f=((d&255)+c<<16)-3997696>>16;b:{c:{c=v[a+852>>2]+u[a+772>>1]|0;if(c){h=v[e+36>>2];if(h){break c}}b=qm(e,c+f<<16>>16);break b}k=h+1|0;j=Wx(c,k);d=On(c,k);b=C(1);g=u[e+28>>1];c=f+j<<16>>16;d:{if((g|0)>(c|0)){break d}f=v[e+4>>2];if((c|0)>(uc(f,v[e+8>>2])+g<<16)-65536>>16){break d}if(!d){b=z[Db(f,c-g|0)>>2];break b}e:{f:{g:{switch(x[e>>1]-1|0){case 2:h=v[e+16>>2];if(!uc(h,v[e+20>>2])){break f}b=z[Db(h,d-1|0)>>2];break e;case 0:break g;default:break f}}j=v[e+16>>2];if(!uc(j,v[e+20>>2])){break f}b=z[Db(j,(d+B(h,On(c,x[e+30>>1])<<16>>16)|0)-1|0)>>2];break e}b=te(C(qm(e,(c<<16)+65536>>16)/qm(e,c)),C(C(d|0)/C(k|0)))}b=C(b*z[Db(f,c-g|0)>>2])}}m=a,n=jk(C(C(l*b)*C(16))),v[m+700>>2]=n}jb=i+16|0}function oaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-16|0;jb=d;md(c,0);u[d+14>>1]=w[a+36|0]|w[a+37|0]<<8;u[d+12>>1]=32767;g=c,h=(x[Vc(d+14|0,d+12|0)>>1]<<8>>>0)/32767|0,u[g+28>>1]=h;u[d+10>>1]=w[a+38|0]|w[a+39|0]<<8;u[d+8>>1]=32767;g=c,h=(x[Vc(d+10|0,d+8|0)>>1]<<8>>>0)/32767|0,u[g+30>>1]=h;u[c+32>>1]=64;v[c>>2]=w[a+44|0]|w[a+45|0]<<8|(w[a+46|0]<<16|w[a+47|0]<<24);v[c+4>>2]=w[a+48|0]|w[a+49|0]<<8|(w[a+50|0]<<16|w[a+51|0]<<24);v[c+8>>2]=w[a+52|0]|w[a+53|0]<<8|(w[a+54|0]<<16|w[a+55|0]<<24);v[c+24>>2]=w[a+56|0]|w[a+57|0]<<8|(w[a+58|0]<<16|w[a+59|0]<<24);e=w[b+166|0];if(e>>>0<=4){t[c+38|0]=w[e+42714|0]}e=w[b+167|0]|w[b+168|0]<<8;t[c+39|0]=e;f=(w[b+171|0]|w[b+172|0]<<8)>>>4|0;t[c+41|0]=f;b=(w[b+169|0]|w[b+170|0]<<8)>>>2|0;t[c+40|0]=b;if((b|f)&255){t[c+39|0]=e^-1}b=w[a+40|0]|w[a+41|0]<<8;if(b&4){u[c+34>>1]=x[c+34>>1]|1;b=w[a+40|0]|w[a+41|0]<<8}if(b&8){u[c+34>>1]=x[c+34>>1]|2;b=w[a+40|0]|w[a+41|0]<<8}if(b&16){u[c+34>>1]=x[c+34>>1]|4;b=w[a+40|0]|w[a+41|0]<<8}if(b&32){u[c+34>>1]=x[c+34>>1]|32}jb=d+16|0}function qJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c=jb+-64|0;jb=c;f=v[a>>2];a=v[f>>2];g=v[a+4>>2];v[c+40>>2]=v[a+20>>2];e=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=e;Hf(c+48|0,c+32|0,g);a=v[f+4>>2];f=v[a+8>>2];g=v[a+4>>2];e=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=e;e=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=e;v[c+8>>2]=v[a+8>>2];e=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=e;a:{b:{c:{d:{e=v[c+4>>2];if(g>>>0<=e>>>0){if(g>>>0>y[c+20>>2]){break d}if(f>>>0>y[c+8>>2]){break c}j=v[c+28>>2];if(f>>>0>v[c+24>>2]-j>>>0){break b}k=b+12|0;l=v[c+16>>2];m=v[c>>2];e:while(1){if((f|0)==(h|0)){break a}n=h+j|0;o=B(e,h);a=0;while(1)if((a|0)==(g|0)){h=h+1|0;continue e}else{d=Db(v[b>>2],a);i=d;d=v[(a+o<<2)+m>>2]+(v[d>>2]>>1)|0;p=d;d=ws(k)+d&-4096;v[i>>2]=p-d;i=v[(a<<2)+l>>2]+(n<<1)|0;d=kd(d|2048,12);d=(d|0)<32767?d:32767;u[i>>1]=(d|0)>-32768?d:-32768;a=a+1|0;continue}}}aa(7192,9005,33,8718);L()}aa(7157,9005,34,8718);L()}aa(5900,9005,35,8718);L()}aa(5870,9005,36,8718);L()}jb=c- -64|0}function iJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;c=jb+-64|0;jb=c;f=v[a>>2];a=v[f>>2];g=v[a+4>>2];v[c+40>>2]=v[a+20>>2];e=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=e;Hf(c+48|0,c+32|0,g);a=v[f+4>>2];f=v[a+8>>2];g=v[a+4>>2];e=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=e;e=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=e;v[c+8>>2]=v[a+8>>2];e=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=e;a:{b:{c:{d:{e=v[c+4>>2];if(g>>>0<=e>>>0){i=v[c+20>>2];if(g>>>0>i>>>0){break d}if(f>>>0>y[c+8>>2]){break c}j=v[c+28>>2];if(f>>>0>v[c+24>>2]-j>>>0){break b}k=b+12|0;l=v[c+16>>2];m=v[c>>2];e:while(1){if((f|0)==(h|0)){break a}n=B(e,h);o=B(h+j|0,i);a=0;while(1)if((a|0)==(g|0)){h=h+1|0;continue e}else{d=Db(v[b>>2],a);p=d;d=v[(a+n<<2)+m>>2]+(v[d>>2]>>1)|0;q=d;d=ws(k)+d&-4096;v[p>>2]=q-d;d=kd(d|2048,12);d=(d|0)<32767?d:32767;u[(a+o<<1)+l>>1]=(d|0)>-32768?d:-32768;a=a+1|0;continue}}}aa(7192,9005,33,8718);L()}aa(7157,9005,34,8718);L()}aa(5900,9005,35,8718);L()}aa(5870,9005,36,8718);L()}jb=c- -64|0}function Xia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=jb-16|0;jb=e;d=Gh(b,c);n=e,o=Hb(w[a|0]|w[a+1|0]<<8),u[n+14>>1]=o;u[e+12>>1]=64;Qg(d,x[Vc(e+14|0,e+12|0)>>1]);n=d,o=Hb(w[a+14|0]|w[a+15|0]<<8),t[n+13|0]=o;n=d,o=Hb(w[a+16|0]|w[a+17|0]<<8),t[n+14|0]=o;n=d,o=Hb(w[a+20|0]|w[a+21|0]<<8),t[n+15|0]=o;n=d,o=Hb(w[a+22|0]|w[a+23|0]<<8),t[n+16|0]=o;h=v[d>>2];j=v[d+4>>2];b=w[d+12|0]&-2|oc(h,j)^1;t[d+12|0]=b;b=Hb(w[a+12|0]|w[a+13|0]<<8)>>>3&2|b&-3;t[d+12|0]=b;n=d,o=Hb(w[a+12|0]|w[a+13|0]<<8)>>>3&4|b&251,t[n+12|0]=o;b=4096;a:{b:{switch(c-1|0){case 0:i=-128;b=127;break a;case 1:break b;default:break a}}i=-1616;b=1616}b=b-i|0;l=b;c=b>>>1&32767;b=0;while(1){if(_d(h,j)>>>0<=b>>>0){jb=e+16|0}else{d=Db(h,b);u[d>>1]=k;m=d;g=(b<<2)+a|0;f=pe((w[g+28|0]|w[g+29|0]<<8)<<16>>16)+i|0;d=f>>31;d=d<<6|f>>>26;f=c+(f<<6)|0;d=f>>>0<c>>>0?d+1|0:d;n=m,o=sg(Hc(Mka(f,d,l,0),mb)),t[n+2|0]=o;n=e,o=Hb(w[g+26|0]|w[g+27|0]<<8),u[n+10>>1]=o;u[e+8>>1]=1;b=b+1|0;k=x[ke(e+10|0,e+8|0)>>1]+k|0;continue}break}}function hI(a,b,c,d,e){var f=C(0),g=0,h=C(0),i=0,j=C(0),k=C(0);if(!(a&3)){c=(c<<2)+b|0;d=c+(d<<2)|0;a=a>>2;while(1){if((a|0)>0){b=d-4|0;h=z[b>>2];j=z[c>>2];k=z[d>>2];z[c>>2]=j+k;g=c-4|0;f=z[g>>2];z[g>>2]=f+z[b>>2];j=C(j-k);f=C(f-h);z[d>>2]=C(j*z[e>>2])-C(z[e+4>>2]*f);z[b>>2]=C(f*z[e>>2])+C(j*z[e+4>>2]);b=d-12|0;j=z[b>>2];g=c-8|0;f=z[g>>2];i=g;g=d-8|0;k=z[g>>2];z[i>>2]=f+k;i=c-12|0;h=z[i>>2];z[i>>2]=h+z[b>>2];f=C(f-k);h=C(h-j);z[g>>2]=C(f*z[e+32>>2])-C(z[e+36>>2]*h);z[b>>2]=C(h*z[e+32>>2])+C(f*z[e+36>>2]);b=d-20|0;j=z[b>>2];g=c-16|0;f=z[g>>2];i=g;g=d-16|0;k=z[g>>2];z[i>>2]=f+k;i=c-20|0;h=z[i>>2];z[i>>2]=h+z[b>>2];f=C(f-k);h=C(h-j);z[g>>2]=C(f*z[e+64>>2])-C(z[e+68>>2]*h);z[b>>2]=C(h*z[e+64>>2])+C(f*z[e+68>>2]);b=d-28|0;j=z[b>>2];g=c-24|0;f=z[g>>2];i=g;g=d-24|0;k=z[g>>2];z[i>>2]=f+k;i=c-28|0;h=z[i>>2];z[i>>2]=h+z[b>>2];f=C(f-k);h=C(h-j);z[g>>2]=C(f*z[e+96>>2])-C(z[e+100>>2]*h);z[b>>2]=C(h*z[e+96>>2])+C(f*z[e+100>>2]);a=a-1|0;d=d-32|0;c=c-32|0;e=e+128|0;continue}break}return}aa(15760,13110,2423,9171);L()}function pda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0;h=jb-16|0;jb=h;f=v[a+48>>2];l=v[a+24>>2];m=v[a+20>>2];e=v[a+44>>2];n=v[a+16>>2];b=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=b;o=v[a+72>>2];b=v[a+68>>2];p=b;q=b>>31;b=v[a+64>>2];r=b;s=b>>31;b=v[a+60>>2];t=b;w=b>>31;x=v[a+8>>2];y=v[a+12>>2];while(1){b=e;if(d){e=Xb(b,-16777216,16776704);e=Lka(r,s,e,e>>31);i=mb;z=e;e=(v[h+12>>2]<<1)+n|0;g=v[h+8>>2]>>>21&2040;j=(((B(u[e>>1],u[g+39714>>1])+B(u[e-2>>1],u[g+39712>>1])|0)+B(u[e+2>>1],u[g+39716>>1])|0)+B(u[e+4>>1],u[g+39718>>1])|0)/16384<<8;e=j;k=Lka(e,e>>31,t,w);g=z+k|0;e=mb+i|0;e=g>>>0<k>>>0?e+1|0:e;f=Xb(f,-16777216,16776704);i=Lka(p,q,f,f>>31);g=i+g|0;f=mb+e|0;f=g>>>0<i>>>0?f+1|0:f;e=g+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Xc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(e,m)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(e,l);Qb(h+8|0,x,y);e=f-(o&j)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=c;v[a+48>>2]=f;v[a+44>>2]=b;jb=h+16|0}function F7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=jb-16|0;jb=g;e=jb-160|0;jb=e;d=e+24|0;f=d+56|0;c=Ms(f);v[d>>2]=77956;v[c>>2]=77976;v[d+56>>2]=78016;v[d>>2]=77996;h=f;f=d+4|0;Jn(h,f);v[d>>2]=77956;v[c>>2]=77976;c=Hs(f);v[c>>2]=77440;Lb(c+32|0);v[c+44>>2]=0;v[c+48>>2]=16;c=v[v[d>>2]-12>>2];v[23588]=0;f=ga(62)|0;h=v[23588];v[23588]=0;a:{b:{c:{d:{e:{f:{if((h|0)==1){break f}v[23588]=0;U(63,e+16|0,c+d|0,f|0);c=v[23588];v[23588]=0;if((c|0)==1){break f}$b(e+16|0);c=jb-16|0;jb=c;v[c+8>>2]=17;jb=c+16|0;lm(v[v[d>>2]-12>>2]+d|0,v[c+8>>2]);i=A[b>>3];v[23588]=0;b=ab(64,d|0,+i)|0;c=v[23588];v[23588]=0;if((c|0)==1){break e}v[23588]=0;R(65,e|0,b|0);c=v[23588];v[23588]=0;if((c|0)==1){break d}v[23588]=0;R(61,g|0,e|0);c=v[23588];v[23588]=0;if((c|0)==1){break c}yb(e);yp(b);jb=e+160|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(e)}yp(d);T(a|0);L()}v[23588]=0;R(58,a|0,g|0);a=v[23588];v[23588]=0;if((a|0)!=1){yb(g);jb=g+16|0;return}a=P()|0;O()|0;yb(g);T(a|0);L()}function eda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=jb-16|0;jb=f;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}l=v[a+16>>2];j=v[a+40>>2];k=v[a+36>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;m=v[a+32>>2];n=v[a+28>>2];while(1){if(d){e=v[f+12>>2]+l|0;h=(v[f+8>>2]>>>16&65520)+b|0;e=(((((((B(t[e-2|0],u[h+2>>1])+B(t[e-3|0],u[h>>1])|0)+B(t[e-1|0],u[h+4>>1])|0)+B(t[e|0],u[h+6>>1])|0)+B(t[e+1|0],u[h+8>>1])|0)+B(t[e+2|0],u[h+10>>1])|0)+B(t[e+3|0],u[h+12>>1])|0)+B(t[e+4|0],u[h+14>>1])<<8)/32768|0;k=k+n|0;v[c>>2]=v[c>>2]+B(e,k>>12);j=j+m|0;v[c+4>>2]=v[c+4>>2]+B(e,j>>12);Qb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;v[a+40>>2]=j;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+24>>2]=j>>12;jb=f+16|0}function aK(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=jb-32|0;jb=d;a:{b:{c:{d:{e:{f:{g:{f=a+36|0;e=v[f>>2];c=v[a+40>>2];h:{if(Ob(e,c)){Gc(d+24|0);break h}c=d+8|0;In(c,a);v[23588]=0;c=S(1012,c|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break g}v[d+24>>2]=c;Wf(d+8|0);c=v[a+40>>2];e=v[a+36>>2]}e=(h=f,i=v[d+24>>2],j=Ob(e,c),j?h:i);if((b|0)==-1){f=v[e>>2];g=4194304;c=0;break e}if((b|0)>=0){c=b;f=v[e>>2];if((Qi(f,v[e+4>>2])|0)>(b|0)){break e}}b=ba(8)|0;v[23588]=0;c=Q(55,d+8|0,10887)|0;a=v[23588];v[23588]=0;if((a|0)==1){break f}a=rc(b,c);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break b}a=P()|0;O()|0;yb(c);break d}a=P()|0;O()|0;Wf(d+8|0);break c}a=P()|0;O()|0;ca(b|0);break d}v[a+8>>2]=b;b=v[a+24>>2];v[b+480208>>2]=v[b+480208>>2]&-4194305|g;Fj(b+484360|0,w[lf(f,c)+16|0]);b=lf(v[e>>2],c);c=v[b+8>>2];b=v[b+12>>2];v[23588]=0;+ra(1043,a|0,b|0,c|0);b=v[23588];v[23588]=0;if((b|0)!=1){break a}a=P()|0;O()|0}al(d+24|0)}T(a|0)}L()}v[a+16>>2]=0;v[a+20>>2]=0;al(d+24|0);jb=d+32|0}function Gz(a,b,c){var d=0,e=0;b=b-a>>5;while(1){if((b|0)>0){d=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);e=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[a|0]=e;t[a+1|0]=e>>>8;t[a+2|0]=e>>>16;t[a+3|0]=e>>>24;t[a+4|0]=d;t[a+5|0]=d>>>8;t[a+6|0]=d>>>16;t[a+7|0]=d>>>24;d=w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24);e=w[c+24|0]|w[c+25|0]<<8|(w[c+26|0]<<16|w[c+27|0]<<24);t[a+24|0]=e;t[a+25|0]=e>>>8;t[a+26|0]=e>>>16;t[a+27|0]=e>>>24;t[a+28|0]=d;t[a+29|0]=d>>>8;t[a+30|0]=d>>>16;t[a+31|0]=d>>>24;d=w[c+20|0]|w[c+21|0]<<8|(w[c+22|0]<<16|w[c+23|0]<<24);e=w[c+16|0]|w[c+17|0]<<8|(w[c+18|0]<<16|w[c+19|0]<<24);t[a+16|0]=e;t[a+17|0]=e>>>8;t[a+18|0]=e>>>16;t[a+19|0]=e>>>24;t[a+20|0]=d;t[a+21|0]=d>>>8;t[a+22|0]=d>>>16;t[a+23|0]=d>>>24;d=w[c+12|0]|w[c+13|0]<<8|(w[c+14|0]<<16|w[c+15|0]<<24);e=w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24);t[a+8|0]=e;t[a+9|0]=e>>>8;t[a+10|0]=e>>>16;t[a+11|0]=e>>>24;t[a+12|0]=d;t[a+13|0]=d>>>8;t[a+14|0]=d>>>16;t[a+15|0]=d>>>24;b=b-1|0;a=a+32|0;continue}break}}function Ec(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{c=v[b>>2];e=jb-48|0;jb=e;f=v[b+4>>2];b=w[b+8|0];d=f-(((b|0)==1|(b|0)==4)&(f|0)!=0)|0;f=Lb(a);b:{c:{d:{e:{f:{g:{h:{if((b-1&255)>>>0<=1){t[e+32|0]=0;a=wi(c,c+d|0,e+32|0);v[23588]=0;W(53,f|0,c|0,a|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){break h}a=P()|0;O()|0;break b}if((b-3&255)>>>0>1){break h}v[23588]=0;b=W(53,f|0,c|0,c+d|0)|0;a=v[23588];v[23588]=0;if((a|0)==1){break g}c=he(b);d=yh(b);g=he(b);a=jb-32|0;jb=a;v[a+16>>2]=d;v[a+24>>2]=c;v[a+8>>2]=g;while(1){if(yi(a+24|0,a+16|0)){c=a+8|0;d=a+24|0;g=t[v[d>>2]];t[v[c>>2]]=g?g:32;Ge(d);Ge(c);continue}break}jb=a+32|0;v[23588]=0;c=Q(54,e+16|0,b|0)|0;a=v[23588];v[23588]=0;if((a|0)==1){break f}v[23588]=0;d=Q(55,e|0,17790)|0;a=v[23588];v[23588]=0;if((a|0)==1){break e}v[23588]=0;U(56,e+32|0,c|0,d|0);a=v[23588];v[23588]=0;if((a|0)==1){break d}a=e+32|0;Ac(b,a);yb(a);yb(d);yb(c)}jb=e+48|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;yb(d)}yb(c)}yb(f);T(a|0);L()}}function _$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=jb-32|0;jb=g;v[g+24>>2]=b;a:{b:{if(!(v[d+4>>2]&1)){v[g>>2]=-1;b=nb[v[v[a>>2]+16>>2]](a,b,c,d,e,g)|0;v[g+24>>2]=b;c:{switch(v[g>>2]){case 1:t[f|0]=1;break a;case 0:break b;default:break c}}t[f|0]=1;v[e>>2]=4;break a}fd(g,d);v[23588]=0;b=S(1136,g|0)|0;a=v[23588];v[23588]=0;d:{e:{f:{g:{if((a|0)!=1){$b(g);fd(g,d);v[23588]=0;a=S(1137,g|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break g}$b(g);v[23588]=0;R(1138,g|0,a|0);d=v[23588];v[23588]=0;if((d|0)==1){b=P()|0;O()|0;break d}v[23588]=0;R(1139,g|12,a|0);a=v[23588];v[23588]=0;if((a|0)==1){break f}v[23588]=0;d=g+24|0;a=va(1140,d|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=v[23588];v[23588]=0;if((b|0)==1){break e}t[f|0]=(a|0)==(g|0);b=v[g+24>>2];while(1){d=Fc(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=P()|0;O()|0;$b(g);break d}b=P()|0;O()|0;$b(g);break d}b=P()|0;O()|0;Fc(g);break d}b=P()|0;O()|0;while(1){d=Fc(d-12|0);if((g|0)!=(d|0)){continue}break}}T(b|0);L()}t[f|0]=0}jb=g+32|0;return b|0}function m0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=jb-32|0;jb=g;v[g+24>>2]=b;a:{b:{if(!(v[d+4>>2]&1)){v[g>>2]=-1;b=nb[v[v[a>>2]+16>>2]](a,b,c,d,e,g)|0;v[g+24>>2]=b;c:{switch(v[g>>2]){case 1:t[f|0]=1;break a;case 0:break b;default:break c}}t[f|0]=1;v[e>>2]=4;break a}fd(g,d);v[23588]=0;b=S(19,g|0)|0;a=v[23588];v[23588]=0;d:{e:{f:{g:{if((a|0)!=1){$b(g);fd(g,d);v[23588]=0;a=S(1119,g|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break g}$b(g);v[23588]=0;R(1120,g|0,a|0);d=v[23588];v[23588]=0;if((d|0)==1){b=P()|0;O()|0;break d}v[23588]=0;R(1121,g|12,a|0);a=v[23588];v[23588]=0;if((a|0)==1){break f}v[23588]=0;d=g+24|0;a=va(1122,d|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=v[23588];v[23588]=0;if((b|0)==1){break e}t[f|0]=(a|0)==(g|0);b=v[g+24>>2];while(1){d=yb(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=P()|0;O()|0;$b(g);break d}b=P()|0;O()|0;$b(g);break d}b=P()|0;O()|0;yb(g);break d}b=P()|0;O()|0;while(1){d=yb(d-12|0);if((g|0)!=(d|0)){continue}break}}T(b|0);L()}t[f|0]=0}jb=g+32|0;return b|0}function Cka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=jb-144|0;jb=f;v[23588]=0;l=S(271,a|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){m=c+480192|0;while(1){a:{if((j&65535)>>>0>=l>>>0){Ab(a);jb=f+144|0;return}v[23588]=0;R(290,a|0,f+8|0);e=v[23588];v[23588]=0;if((e|0)!=1){b:{e=Hb(x[f+8>>1]);if(!e|e>>>0>x[m>>1]){break b}e=v[((e<<2)+c|0)+900380>>2];if(!e){break b}e=Gh(e,b);g=w[f+11|0];c:{if(!g){break c}h=w[f+10|0];if(h&1){t[e+12|0]=w[e+12|0]|1}if(h&2){t[e+12|0]=w[e+12|0]|4}if(!(h&4)){break c}t[e+12|0]=w[e+12|0]|2}t[f+4|0]=g;t[f+7|0]=31;h=w[Wb(f+4|0,f+7|0)|0];v[23588]=0;h=h+1&255;R(291,e|0,h|0);g=v[23588];v[23588]=0;if((g|0)==1){break a}t[e+13|0]=w[f+13|0];t[e+14|0]=w[f+14|0];g=w[f+12|0];t[e+15|0]=g;t[e+16|0]=g;g=v[e>>2];e=0;while(1){if((e|0)==(h|0)){break b}i=(f+8|0)+(e<<2)|0;n=Hb(x[i+8>>1]);k=Db(g,e);u[k>>1]=n;i=Hb(x[i+10>>1]);u[f+4>>1]=d?i+128>>>2|0:i;Ef(f+4|0,64);t[k+2|0]=w[f+4|0];e=e+1|0;continue}}j=j+1|0;continue}}break}}b=P()|0;O()|0;Ab(a);T(b|0);L()}function qda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0;g=jb-16|0;jb=g;f=v[a+48>>2];j=v[a+24>>2];k=v[a+20>>2];e=v[a+44>>2];l=v[a+16>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;m=v[a+72>>2];b=v[a+68>>2];n=b;o=b>>31;b=v[a+64>>2];p=b;q=b>>31;b=v[a+60>>2];r=b;s=b>>31;w=v[a+8>>2];x=v[a+12>>2];while(1){b=e;if(d){e=Xb(b,-16777216,16776704);e=Lka(p,q,e,e>>31);h=mb;f=Xb(f,-16777216,16776704);i=Lka(n,o,f,f>>31);e=i+e|0;f=mb+h|0;f=e>>>0<i>>>0?f+1|0:f;y=e;e=v[g+12>>2]+l|0;h=v[g+8>>2]>>>21&2040;h=(((B(t[e|0],u[h+39714>>1])+B(t[e-1|0],u[h+39712>>1])|0)+B(t[e+1|0],u[h+39716>>1])|0)+B(t[e+2|0],u[h+39718>>1])<<8)/16384<<8;e=h;i=Lka(e,e>>31,r,s);e=y+i|0;f=mb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Xc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(e,k)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(e,j);Qb(g+8|0,w,x);e=f-(h&m)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=c;v[a+48>>2]=f;v[a+44>>2]=b;jb=g+16|0}function Ty(a,b,c,d,e){var f=0,g=0,h=0,i=0;g=jb-16|0;jb=g;h=B(c,872)+b|0;a:{if(d){Cb(g+8|0,a+1074312|0,90);if(!Bb(v[v[g+8>>2]>>2],v[g+12>>2])){t[(B(c,872)+b|0)+1427|0]=d}t[(B(c,872)+b|0)+1428|0]=d;break a}d=w[h+1428|0]}f=v[a+480180>>2];if(!e){i=ft(f)}h=h+616|0;b:{c:{if((f|0)!=268435456){if((f|0)!=16777216){break c}f=v[(B(c,872)+b|0)+1272>>2];if(!f|!v[f+44>>2]){break c}a=d&255;if(!(a>>>0<240|e)){tN(b,c,240-a|0);break b}if(!(a>>>0<224|e)){sN(h,224-a|0);break b}rN(h,0-a|0);break b}v[(B(c,872)+b|0)+1324>>2]=65535}e=d&255;d:{if(!(e>>>0>223&i)){break d}e:{f=e&15;if(!f){break e}d=d&240;if((d|0)!=224){if((d|0)!=240){break e}Qy(a,h,f);break b}if(v[a+480180>>2]==524288){break d}Py(a,h,f);break b}if(v[a+480180>>2]!=524288){break b}}f:{if(!(t[(B(c,872)+b|0)+1467|0]&1)){break f}if(v[a+1074416>>2]==1){Cb(g+8|0,a+1074312|0,6);if(Bb(v[v[g+8>>2]>>2],v[g+12>>2])){break f}}d=v[a+480180>>2];if(d&32832){break f}if(!(v[a+480208>>2]&2)|(d|0)!=8){break b}}fk(a,h,(B(c,872)+b|0)+1316|0,0-(e<<2)|0,0)}jb=g+16|0}function mi(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;o(+a);b=j(1)|0;e=j(0)|0;f=b>>>20&2047;a:{if(f-969>>>0>=63){if(f>>>0<=968){return a+1}b:{if(f>>>0<1033){break b}c=0;if(!e&(b|0)==-1048576){break a}if((f|0)==2047){return a+1}if((b|0)>0|(b|0)>=0){return Ir(3105036184601418e216)}if(b>>>0<3230714880){break b}return Ir(12882297539194267e-247)}b=b<<1|e>>>31;e=e<<1;f=(b|0)==-2129002496&(e|0)!=0|b>>>0>2165964800?0:f}c=A[177];g=c+a;a=a-(g-c);c=a*a;h=c*c*(a*A[182]+A[181]);c=c*(a*A[180]+A[179]);a=a*A[178];o(+g);j(1)|0;e=j(0)|0;d=e<<4&2032;a=h+(c+(a+A[d+1464>>3]));d=d+1472|0;i=v[d>>2];b=v[d+4>>2];d=i;i=0;d=d+i|0;b=(e<<13)+b|0;b=d>>>0<i>>>0?b+1|0:b;if(!f){c:{if(!(e&-2147483648)){l(0,d|0);l(1,b+-1048576|0);c=+n();a=c*a+c;a=a+a;break c}e=jb-16|0;l(0,d|0);l(1,b+1071644672|0);c=+n();g=c*a;a=g+c;if(a<1){b=e;v[b+8>>2]=0;v[b+12>>2]=1048576;A[b+8>>3]=A[b+8>>3]*22250738585072014e-324;h=a+1;a=h+(g+(c-a)+(a+(1-h)))+-1;a=a==0?0:a}a=a*22250738585072014e-324}return a}l(0,d|0);l(1,b|0);c=+n();c=c*a+c}return c}function Zj(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=jb-32|0;jb=i;v[i+16>>2]=c;v[i+24>>2]=b;b=i+8|0;fd(b,d);c=0;v[23588]=0;j=S(19,b|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){$b(i+8|0);v[e>>2]=0;a:{while(1){if((g|0)==(h|0)|c){break a}b:{if(cj(i+24|0,i+16|0)){break b}c:{if((wn(j,t[g|0])|0)==37){c=g+1|0;if((h|0)==(c|0)){break b}d:{e:{b=wn(j,t[c|0]);if((b|0)==69){break e}k=0;if((b&255)==48){break e}c=g;break d}if((g+2|0)==(h|0)){break b}k=b;b=wn(j,t[g+2|0])}l=i,m=nb[v[v[a>>2]+36>>2]](a,v[i+24>>2],v[i+16>>2],d,e,f,b,k)|0,v[l+24>>2]=m;g=c+2|0;break c}b=v[j+8>>2];if(uh(b,1,t[g|0])){while(1){f:{g=g+1|0;if((h|0)==(g|0)){g=h;break f}if(uh(b,1,t[g|0])){continue}}break}while(1){if(!op(i+24|0,i+16|0)){break c}b=Yk(v[i+24>>2]);if(!uh(v[j+8>>2],1,b)){break c}em(i+24|0);continue}}if((Bw(j,Yk(v[i+24>>2]))|0)==(Bw(j,t[g|0])|0)){g=g+1|0;em(i+24|0);break c}v[e>>2]=4}c=v[e>>2];continue}break}v[e>>2]=4}if(cj(i+24|0,i+16|0)){v[e>>2]=v[e>>2]|2}jb=i+32|0;return v[i+24>>2]}a=P()|0;O()|0;$b(i+8|0);T(a|0);L()}function YA(a,b,c){var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;t[d+15|0]=c;e=a;a:{b:{c:{switch(b-14|0){case 0:b=14;if(!c){break b}d:{if((c|0)!=15){if((c|0)!=240){break d}t[d+15|0]=239;break b}t[d+15|0]=254;break b}if(c>>>0>=16){t[d+15|0]=c|15;break b}t[d+15|0]=c|240;break b;case 1:t[d+15|0]=c^128;b=15;break b;case 6:case 7:if(c>>>0>=16){t[d+15|0]=c>>>4|240;break b}t[d+15|0]=c|224;break b;case 8:t[d+15|0]=((c^-1)&254)>>>1;b=22;break b;case 9:t[d+15|0]=c&15|128;b=23;break b;case 17:f=d,g=sg(c<<1),t[f+15|0]=g;b=31;break b;case 19:a=32;b=33;e:{f:{switch(c>>>4|0){default:b=0;break b;case 8:a=64;break e;case 10:a=176;break e;case 11:a=224;break e;case 12:case 13:b=c?33:0;break b;case 14:g:{switch(c&15){case 0:t[d+15|0]=119;break b;case 1:t[d+15|0]=119;break b;case 2:t[d+15|0]=121;break b;case 3:break g;default:break b}}t[d+15|0]=123;break b;case 3:break e;case 5:break f;case 0:break b}}a=48}t[d+15|0]=c&15|a;break b;default:break c}}a=0;if(b>>>0>35){break a}}a=w[b+26608|0]}de(e,a,d+15|0);jb=d+16|0}function iH(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;p=a;i=jb-1040|0;jb=i;q=v[116064];a:{b:{a=i+16|0;l=x[((b>>>0>149?0:b)<<1)+91840>>1]+90016|0;c=v[v[116090]+20>>2];if(c){j=v[c+4>>2];c=v[c>>2];e=v[c>>2]+1794895138|0;h=cm(v[c+8>>2],e);f=cm(v[c+12>>2],e);d=cm(v[c+16>>2],e);c:{if(j>>>2>>>0<=h>>>0){break c}k=j-(h<<2)|0;if((d|f)&3|(k>>>0<=f>>>0|d>>>0>=k>>>0)){break c}r=d>>>2|0;s=f>>>2|0;f=0;while(1){k=h>>>1|0;m=k+f|0;n=m<<1;d=c+(n+s<<2)|0;o=cm(v[d>>2],e);d=cm(v[d+4>>2],e);if(d>>>0>=j>>>0|j-d>>>0<=o>>>0|w[c+(d+o|0)|0]){break c}d=vi(l,c+d|0);if(!d){f=c+(r+n<<2)|0;h=cm(v[f>>2],e);e=cm(v[f+4>>2],e);if(e>>>0>=j>>>0|h>>>0>=j-e>>>0){break c}g=w[c+(e+h|0)|0]?0:c+e|0;break c}if((h|0)==1){break c}d=(d|0)<0;h=d?k:h-k|0;f=d?f:m;continue}}}g=g?g:l;c=xg(g);d:{if(c>>>0>=1024){tc(a,g,1023);t[a+1023|0]=0;g=68;break d}tc(a,g,c+1|0);g=0}if(g){if((g|0)!=28){break b}a=21619}break a}xa();L()}if(!w[a|0]){v[i>>2]=b;a=i+16|0;Gw(a,1024,12927,i)}v[116064]=q;Mc(p,a);jb=i+1040|0}function zca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=jb-16|0;jb=e;p=v[a+16>>2];q=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);l=v[a+128>>2];a:{if(!l){k=v[a+8>>2];m=v[a+12>>2];f=v[a>>2];b=v[a+4>>2];h=0;break a}b=v[a+12>>2];m=b;k=v[a+8>>2];n=kg(k,b,l);o=mb;h=v[a+76>>2];f=v[a>>2];b=v[a+4>>2];Pf(f,b,kf(k,m,d),mb);h=h>>>0<mb>>>0?d:0}g=a+112|0;i=v[a+40>>2];j=v[a+36>>2];v[e>>2]=f;v[e+4>>2]=b;b:while(1){if(d){d=d-1|0;v[e+8>>2]=f;v[e+12>>2]=0;h=h-1|0;n=h?n:0;o=h?o:0;f=b+p|0;b=l;while(1)if((b|0)<=0){Qb(g,v[a+120>>2],v[a+124>>2]);b=v[a+116>>2];if(b){Rd(g,t[f+v[e+12>>2]|0]<<6);Qd(g,b);v[g>>2]=v[g>>2];v[g+4>>2]=0}b=v[a+32>>2];j=v[a+28>>2]+j|0;f=ig(g,q);v[c>>2]=B(j>>12,f)+v[c>>2];i=b+i|0;v[c+4>>2]=v[c+4>>2]+B(f,i>>12);Qb(e,k,m);c=c+8|0;f=v[e>>2];b=v[e+4>>2];continue b}else{Rd(g,t[f+v[e+12>>2]|0]<<6);Qd(g,4);Qb(e+8|0,n,o);b=b-1|0;continue}}break}v[a>>2]=f;v[a+4>>2]=b;v[a+40>>2]=i;v[a+20>>2]=j>>12;v[a+36>>2]=j;v[a+24>>2]=i>>12;jb=e+16|0}function Mca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0;e=jb-16|0;jb=e;g=v[a+40>>2];h=v[a+36>>2];i=v[a+16>>2];f=v[a+4>>2];v[e+8>>2]=v[a>>2];v[e+12>>2]=f;j=b+24|0;k=v[a+32>>2];l=v[a+28>>2];m=v[a+8>>2];n=v[a+12>>2];while(1){if(d){f=v[e+8>>2];o=((((v[e+12>>2]&2147483647)<<1|f>>>31)&2147483646)<<1)+i|0;b=(((f>>>16|0)+4&131064)<<1)+j|0;p=u[b+14>>1];q=u[b+12>>1];r=u[b+10>>1];s=u[b+8>>1];t=u[b+6>>1];w=u[b+4>>1];x=u[b+2>>1];y=u[b>>1];f=0;while(1){if((f|0)!=2){b=(f<<1)+o|0;v[(f<<2)+e>>2]=(((((B(u[b+8>>1],r)+B(u[b+4>>1],s)|0)+B(u[b+12>>1],q)|0)+B(u[b+16>>1],p)|0)/2|0)+((((B(u[b-8>>1],x)+B(u[b-12>>1],y)|0)+B(u[b-4>>1],w)|0)+B(u[b>>1],t)|0)/2|0)|0)/16384;f=f+1|0;continue}break}h=h+l|0;v[c>>2]=v[c>>2]+B(v[e>>2],h>>12);g=g+k|0;v[c+4>>2]=v[c+4>>2]+B(v[e+4>>2],g>>12);Qb(e+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}b=v[e+12>>2];v[a>>2]=v[e+8>>2];v[a+4>>2]=b;v[a+40>>2]=g;v[a+20>>2]=h>>12;v[a+36>>2]=h;v[a+24>>2]=g>>12;jb=e+16|0}function Hw(a,b,c,d){var e=0,f=0,g=0,h=0;g=jb-32|0;jb=g;e=d&2147483647;h=e;f=e-1006698496|0;e=e-1140785152|0;a:{if((f|0)==(e|0)&0|e>>>0>f>>>0){e=d<<4|c>>>28;f=c<<4|b>>>28;c=e;b=b&268435455;if((b|0)==134217728&(a|0)!=0|b>>>0>134217728){e=c+1073741824|0;a=f+1|0;e=a?e:e+1|0;f=a;break a}e=c+1073741824|0;if(a|(b|0)!=134217728){break a}b=f&1;a=b+f|0;e=a>>>0<b>>>0?e+1|0:e;f=a;break a}if(!(!c&(h|0)==2147418112?!(a|b):h>>>0<2147418112)){e=c;c=d<<4|e>>>28;f=e<<4|b>>>28;e=c&524287|2146959360;break a}f=0;e=2146435072;if(h>>>0>1140785151){break a}e=0;h=h>>>16|0;if(h>>>0<15249){break a}e=d&65535|65536;Kf(g+16|0,a,b,c,e,h-15233|0);Em(g,a,b,c,e,15361-h|0);e=v[g+4>>2];h=e;a=v[g+8>>2];c=v[g+12>>2]<<4|a>>>28;f=a<<4|e>>>28;e=c;a=h&268435455;b=v[g>>2]|(v[g+16>>2]|v[g+24>>2]|(v[g+20>>2]|v[g+28>>2]))!=0;if((a|0)==134217728&(b|0)!=0|a>>>0>134217728){a=f+1|0;e=a?e:e+1|0;f=a;break a}if(b|(a|0)!=134217728){break a}a=f+(f&1)|0;e=a>>>0<f>>>0?e+1|0:e;f=a}jb=g+32|0;l(0,f|0);l(1,d&-2147483648|e);return+n()}function Uy(a,b,c,d,e){var f=0,g=0,h=0,i=0;g=jb-16|0;jb=g;h=B(c,872)+b|0;a:{if(d){Cb(g+8|0,a+1074312|0,90);if(!Bb(v[v[g+8>>2]>>2],v[g+12>>2])){t[(B(c,872)+b|0)+1428|0]=d}t[(B(c,872)+b|0)+1427|0]=d;break a}d=w[h+1427|0]}f=v[a+480180>>2];if(!e){i=ft(f)}h=h+616|0;b:{c:{if((f|0)!=268435456){if((f|0)!=16777216){break c}f=v[(B(c,872)+b|0)+1272>>2];if(!f|!v[f+44>>2]){break c}a=d&255;if(!(a>>>0<240|e)){tN(b,c,a-240|0);break b}if(!(a>>>0<224|e)){sN(h,a-224|0);break b}rN(h,a);break b}v[(B(c,872)+b|0)+1324>>2]=1}e=d&255;d:{if(!(e>>>0>223&i)){break d}e:{f=e&15;if(!f){break e}d=d&240;if((d|0)!=224){if((d|0)!=240){break e}Ry(a,h,f);break b}if(v[a+480180>>2]==524288){break d}Sy(a,h,f);break b}if(v[a+480180>>2]!=524288){break b}}f:{if(!(t[(B(c,872)+b|0)+1467|0]&1)){break f}if(v[a+1074416>>2]==1){Cb(g+8|0,a+1074312|0,6);if(Bb(v[v[g+8>>2]>>2],v[g+12>>2])){break f}}d=v[a+480180>>2];if(d&32832){break f}if(!(v[a+480208>>2]&2)|(d|0)!=8){break b}}fk(a,h,(B(c,872)+b|0)+1316|0,e<<2,0)}jb=g+16|0}function Kja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;md(b,32);g=b,h=bc(w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24)),v[g>>2]=h;f=bc(w[a+10|0]|w[a+11|0]<<8|(w[a+12|0]<<16|w[a+13|0]<<24));v[b+4>>2]=f;g=b,h=bc(w[a+14|0]|w[a+15|0]<<8|(w[a+16|0]<<16|w[a+17|0]<<24))+f|0,v[g+8>>2]=h;if(!(d?0:c)){c=bc(w[a+46|0]|w[a+47|0]<<8|(w[a+48|0]<<16|w[a+49|0]<<24))}v[b+24>>2]=c;c=w[a+8|0]<<28>>24;a:{if((d|0)!=841887798){break a}d=Hb(w[a+42|0]|w[a+43|0]<<8);if(!d|(d|0)==48){break a}c=(c-(d<<7)|0)+6144|0}Al(b,+(c|0)*.0006510416666666666);t[e+15|0]=w[a+9|0];t[e+14|0]=64;g=b,h=w[Wb(e+15|0,e+14|0)|0]<<2,u[g+30>>1]=h;if(t[a+40|0]&1){u[b+34>>1]=x[b+34>>1]|64;v[b>>2]=v[b>>2]>>>1;v[b+4>>2]=v[b+4>>2]>>>1;v[b+8>>2]=v[b+8>>2]>>>1}b:{if(w[a+41|0]<=8){a=v[b+4>>2];c=v[b+8>>2];break b}u[b+34>>1]=x[b+34>>1]|1;v[b>>2]=v[b>>2]>>>1;a=v[b+4>>2]>>>1|0;v[b+4>>2]=a;c=v[b+8>>2]>>>1|0;v[b+8>>2]=c}c:{if(a+1>>>0<c>>>0){u[b+34>>1]=x[b+34>>1]|2;break c}v[b+4>>2]=0;v[b+8>>2]=0}jb=e+16|0}function Yj(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=jb-32|0;jb=i;v[i+16>>2]=c;v[i+24>>2]=b;c=i+8|0;fd(c,d);b=0;v[23588]=0;j=S(1136,c|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){$b(i+8|0);v[e>>2]=0;a:{while(1){if((g|0)==(h|0)|b){break a}b:{if(_j(i+24|0,i+16|0)){break b}c:{if((un(j,v[g>>2])|0)==37){b=g+4|0;if((h|0)==(b|0)){break b}d:{e:{c=un(j,v[b>>2]);if((c|0)==69){break e}k=0;if((c&255)==48){break e}b=g;break d}if((g+8|0)==(h|0)){break b}k=c;c=un(j,v[g+8>>2])}l=i,m=nb[v[v[a>>2]+36>>2]](a,v[i+24>>2],v[i+16>>2],d,e,f,c,k)|0,v[l+24>>2]=m;g=b+8|0;break c}if(Wk(j,1,v[g>>2])){while(1){f:{g=g+4|0;if((h|0)==(g|0)){g=h;break f}if(Wk(j,1,v[g>>2])){continue}}break}while(1){if(!cs(i+24|0,i+16|0)){break c}if(!Wk(j,1,Xk(v[i+24>>2]))){break c}Bn(i+24|0);continue}}if((Jl(j,Xk(v[i+24>>2]))|0)==(Jl(j,v[g>>2])|0)){g=g+4|0;Bn(i+24|0);break c}v[e>>2]=4}b=v[e>>2];continue}break}v[e>>2]=4}if(_j(i+24|0,i+16|0)){v[e>>2]=v[e>>2]|2}jb=i+32|0;return v[i+24>>2]}a=P()|0;O()|0;$b(i+8|0);T(a|0);L()}function Cha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=eu(c,d);d=b&63;if(e>>>0>d>>>0){c=TS(c,d);d=0;g=jb-16|0;jb=g;t[a+12|0]=0;Kc(a);e=jb-32|0;jb=e;a:{b:{if(Uh(a)>>>0<=14){if(sh(1073741823)>>>0<=14){break b}f=Fb(a);f=Uf(e+8|0,15,uc(v[a>>2],v[a+4>>2]),f);Dd(a,f);Tf(f)}jb=e+32|0;break a}bd();L()}h=0-w[c+1|0]|0;while(1){c:{if((d|0)==15){break c}e=c+(d<<1)|0;f=w[e+1|0];if(!f){break c}t[g+7|0]=64;h=f+(h<<16>>16)|0;f=zl(g+8|0,h&65535,w[Wb(e+2|0,g+7|0)|0]);d:{if(y[a+4>>2]<y[Fb(a)>>2]){OS(a,f);break d}i=jb-32|0;jb=i;e=Fb(a);e=Uf(i+8|0,pg(a,uc(v[a>>2],v[a+4>>2])+1|0),uc(v[a>>2],v[a+4>>2]),e);Hm(v[e+8>>2],x[f>>1]|x[f+2>>1]<<16);v[e+8>>2]=v[e+8>>2]+4;Dd(a,e);Tf(e);jb=i+32|0}d=d+1|0;continue}break}d=w[c+32|0];t[a+14|0]=d>>>4;t[a+13|0]=d&15;c=w[c+31|0];d=c&15;t[a+15|0]=d;t[a+16|0]=d;if(c&16){t[a+12|0]=w[a+12|0]|4}if(c&32){t[a+12|0]=w[a+12|0]|2}jb=g+16|0}e:{if(b<<24>>24>=0){c=w[a+12|0]&-2;a=a+12|0;break e}c=w[a+12|0]&-2|oc(v[a>>2],v[a+4>>2])^1;a=a+12|0}t[a|0]=c}function Vja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=jb-32|0;jb=h;e=b;b=v[a>>2];b=ro(e,Eb(b))+b|0;e=DU(c,d);a:{if((e|0)<=0){break a}f=v[Fb(a)>>2];g=v[a+4>>2];if((f-g|0)>=(e|0)){v[h+8>>2]=d;j=g-b|0;if((j|0)<(e|0)){v[h+8>>2]=c;fB(h+8|0,j);f=v[h+8>>2];l=jb-16|0;jb=l;i=Ok(l,a,e-j|0);k=jb-16|0;jb=k;v[k+8>>2]=f;while(1){if(Ob(f,d)){wd(v[i+4>>2],w[f|0]);f=Ge(k+8|0);v[i+4>>2]=v[i+4>>2]+1;f=v[f>>2];continue}break}jb=k+16|0;kc(i);jb=l+16|0;if((j|0)<=0){break a}}f=jb-16|0;jb=f;j=v[a+4>>2];d=(j-(b+e|0)|0)+b|0;i=Ok(f,a,g-d|0);e=v[i+4>>2];a=d;while(1){if(a>>>0>=g>>>0){kc(i);Aq(b,d,j);jb=f+16|0}else{wd(e,w[a|0]);e=e+1|0;v[i+4>>2]=e;a=a+1|0;continue}break}ph(c,v[h+8>>2],b);break a}f=Fb(a);g=Yl(h+8|0,Wl(a,ed(v[a>>2],g)+e|0),b-v[a>>2]|0,f);e=jb-32|0;jb=e;v[e+24>>2]=c;c=Xv(e+8|0,g+8|0,DU(c,d));d=v[c>>2];while(1){if(v[c+4>>2]!=(d|0)){wd(d,w[v[e+24>>2]]);d=v[c>>2]+1|0;v[c>>2]=d;Ge(e+24|0);continue}break}Td(c);jb=e+32|0;b=CU(a,g,b);Xl(g)}Eb(b);jb=h+32|0}function rp(a,b,c,d,e,f){var g=C(0),h=0,i=C(0),j=0,k=C(0),l=C(0);c=(c<<2)+b|0;d=c+(d<<2)|0;a=a>>2;b=f<<2;while(1){if((a|0)>0){f=d-4|0;i=z[f>>2];k=z[c>>2];l=z[d>>2];z[c>>2]=k+l;h=c-4|0;g=z[h>>2];z[h>>2]=g+z[f>>2];k=C(k-l);g=C(g-i);z[d>>2]=C(k*z[e>>2])-C(z[e+4>>2]*g);z[f>>2]=C(g*z[e>>2])+C(k*z[e+4>>2]);f=d-12|0;k=z[f>>2];h=c-8|0;g=z[h>>2];j=h;h=d-8|0;l=z[h>>2];z[j>>2]=g+l;j=c-12|0;i=z[j>>2];z[j>>2]=i+z[f>>2];g=C(g-l);e=b+e|0;i=C(i-k);z[h>>2]=C(g*z[e>>2])-C(z[e+4>>2]*i);z[f>>2]=C(i*z[e>>2])+C(g*z[e+4>>2]);f=d-20|0;k=z[f>>2];h=c-16|0;g=z[h>>2];j=h;h=d-16|0;l=z[h>>2];z[j>>2]=g+l;j=c-20|0;i=z[j>>2];z[j>>2]=i+z[f>>2];g=C(g-l);e=b+e|0;i=C(i-k);z[h>>2]=C(g*z[e>>2])-C(z[e+4>>2]*i);z[f>>2]=C(i*z[e>>2])+C(g*z[e+4>>2]);f=d-28|0;k=z[f>>2];h=c-24|0;g=z[h>>2];j=h;h=d-24|0;l=z[h>>2];z[j>>2]=g+l;j=c-28|0;i=z[j>>2];z[j>>2]=i+z[f>>2];g=C(g-l);e=b+e|0;i=C(i-k);z[h>>2]=C(g*z[e>>2])-C(z[e+4>>2]*i);z[f>>2]=C(i*z[e>>2])+C(g*z[e+4>>2]);e=b+e|0;a=a-1|0;d=d-32|0;c=c-32|0;continue}break}}function o3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=jb+-64|0;jb=c;f=v[a>>2];a=v[f>>2];g=v[a+4>>2];v[c+40>>2]=v[a+20>>2];d=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=d;Hf(c+48|0,c+32|0,g);a=v[f+4>>2];f=v[a+8>>2];g=v[a+4>>2];d=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=d;d=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=d;v[c+8>>2]=v[a+8>>2];d=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=d;a:{b:{c:{d:{d=v[c+4>>2];if(g>>>0<=d>>>0){if(g>>>0>y[c+20>>2]){break d}if(f>>>0>y[c+8>>2]){break c}h=v[c+28>>2];if(f>>>0>v[c+24>>2]-h>>>0){break b}i=b+12|0;j=v[c+16>>2];k=v[c>>2];b=0;e:while(1){if((b|0)==(f|0)){break a}l=b+h|0;m=B(b,d);a=0;while(1)if((a|0)==(g|0)){b=b+1|0;continue e}else{e=v[(a+m<<2)+k>>2];n=vs(i);o=v[(a<<2)+j>>2]+(l<<1)|0;e=kd((kd(n,21)+e|0)+2048|0,12);e=(e|0)<32767?e:32767;u[o>>1]=(e|0)>-32768?e:-32768;a=a+1|0;continue}}}aa(7192,9005,33,8718);L()}aa(7157,9005,34,8718);L()}aa(5900,9005,35,8718);L()}aa(5870,9005,36,8718);L()}jb=c- -64|0}function Qx(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=C(0);c=jb-48|0;jb=c;a:{b=v[a+20>>2];b:{if(!b){break b}d=v[b+4>>2];b=v[b+8>>2];if(ed(d,b)>>>0<4){break b}re(c+16|0,d,b);b=ee(c+8|0);d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;d=FU(c+24|0,v[c+16>>2],v[c+20>>2],c);v[23588]=0;b=S(157,d|0)|0;f=v[23588];v[23588]=0;c:{if((f|0)!=1){if(b){break c}b=v[v[a>>2]+40>>2];v[23588]=0;f=S(b|0,a|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break a}b=v[a+20>>2];if(ed(v[b+4>>2],v[b+8>>2])-4>>>0<f<<2>>>0){break c}e=v[v[a>>2]+176>>2];b=0;v[23588]=0;R(e|0,a|0,-1);e=v[23588];v[23588]=0;if((e|0)==1){break a}while(1){if((b|0)==(f|0)){b=v[v[a>>2]+180>>2];v[23588]=0;Y(b|0,a|0);a=v[23588];v[23588]=0;if((a|0)!=1){break c}break a}v[23588]=0;g=C(Ba(461,d|0));e=v[23588];v[23588]=0;d:{if((e|0)==1){break d}e=v[v[a>>2]+44>>2];v[23588]=0;Aa(e|0,a|0,b|0,C(pm(g)?g:C(0)));e=v[23588];v[23588]=0;if((e|0)==1){break d}b=b+1|0;continue}break}break a}break a}Ab(d)}jb=c+48|0;return}a=P()|0;O()|0;Ab(d);T(a|0);L()}function bka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=jb-2608|0;jb=f;d=wB(f,a);v[d+1060>>2]=0;v[d+1064>>2]=0;e=d+2604|0;a=d+1068|0;while(1){t[a+4|0]=0;u[a>>1]=0;u[a+2>>1]=0;a=a+6|0;if((e|0)!=(a|0)){continue}break}v[23588]=0;Y(318,d|0);a=v[23588];v[23588]=0;a:{b:{if((a|0)!=1){if((u[d+1068>>1]|u[d+1070>>1])<0){break a}c:{while(1){if((c|0)==(g|0)){break a}v[23588]=0;j=Q(164,d|0,1)|0;a=v[23588];v[23588]=0;if((a|0)==1){break c}a=0;d:{while(1){v[23588]=0;k=Q(164,d|0,1)|0;e=v[23588];v[23588]=0;if((e|0)==1){break d}a=u[(d+B(a,6)|0)+(k?1070:1068)>>1];e:{if((a|0)>255){break e}e=d+B(a,6)|0;h=w[e+1072|0];if(u[e+1068>>1]<0){break e}if(u[e+1070>>1]>=0){continue}}break}h=(j?-1:0)^h;i=(i&255)+(h&255)|0;t[b+g|0]=i;g=g+1|0;continue}break}a=V(30480)|0;break b}a=V(30480)|0;break b}a=V(30480)|0}if((O()|0)==(da(30480)|0)){_(a|0)|0;v[23588]=0;Z(18);a=v[23588];v[23588]=0;if((a|0)!=1){break a}a=P()|0;O()|0}Ab(d);T(a|0);L()}a=Dq(d);Ab(d);jb=f+2608|0;return a|0}function GX(a){a=a|0;var b=0,c=0,d=0,e=0;b=jb+-64|0;jb=b;e=Lb(a);v[23588]=0;a=ga(126)|0;c=v[23588];v[23588]=0;a:{b:{if((c|0)==1){break b}c:{d:{if(!a){break d}v[23588]=0;c=Q(1,b+32|0,8923)|0;a=v[23588];v[23588]=0;if((a|0)==1){break c}v[23588]=0;a=ga(126)|0;d=v[23588];v[23588]=0;e:{f:{g:{h:{if((d|0)==1){break h}v[23588]=0;v[b+12>>2]=a;R(132,b+16|0,b+12|0);a=v[23588];v[23588]=0;if((a|0)==1){break h}v[23588]=0;U(2,b+48|0,c|0,b+16|0);a=v[23588];v[23588]=0;if((a|0)==1){break g}d=b+48|0;a=Ib(e,d);zb(d);zb(b+16|0);zb(c);v[23588]=0;c=ga(128)|0;d=v[23588];v[23588]=0;if((d|0)==1){break b}if(!c){break e}v[23588]=0;Q(133,a|0,17464)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break e}break b}a=P()|0;O()|0;break f}a=P()|0;O()|0;zb(b+16|0)}zb(c);break a}v[23588]=0;c=ga(127)|0;d=v[23588];v[23588]=0;if((d|0)==1){break b}if(!c){break d}v[23588]=0;Q(133,a|0,16766)|0;a=v[23588];v[23588]=0;if((a|0)==1){break b}}jb=b- -64|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0}zb(e);T(a|0);L()}function L1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=jb-32|0;jb=h;f=of(h+16|0,1,0);a:{b:{while(1){j=h+8|0;d=zc(f);m=d;n=Gb(f)+d|0;i=x[b>>1];d=0;c:{if((c|0)==10){Bx(j,m,n,i);break c}e=i;k=B(c,c);l=B(k,c);o=B(k,k);d:{while(1){e=e&65535;g=d|1;if(e>>>0<c>>>0){break d}g=d|2;if(e>>>0<k>>>0){break d}g=d|3;if(e>>>0<l>>>0){break d}if(e>>>0<o>>>0){g=d+4|0}else{d=d+4|0;e=(e>>>0)/(o>>>0)|0;continue}break}}d=g;if((d|0)>(n-m|0)){v[j+4>>2]=61;v[j>>2]=n;break c}l=d+m|0;e=l;while(1){d=i&65535;i=(d|0)/(c|0)|0;e=e-1|0;t[e|0]=w[(d-B(c,i)|0)+4898|0];if(i&65535){continue}break}v[j+4>>2]=0;v[j>>2]=l}if(!v[h+12>>2]){break b}d=ch(Gb(f));v[23588]=0;R(59,f|0,d|0);d=v[23588];v[23588]=0;if((d|0)!=1){continue}break}break a}c=v[h+8>>2];b=zc(f);v[23588]=0;R(60,f|0,c-b|0);b=v[23588];v[23588]=0;e:{if((b|0)!=1){v[23588]=0;R(72,a|0,f|0);a=v[23588];v[23588]=0;if((a|0)!=1){break e}break a}break a}yb(f);jb=h+32|0;return}a=P()|0;O()|0;yb(f);T(a|0);L()}function Nca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0;e=jb-16|0;jb=e;g=v[a+40>>2];h=v[a+36>>2];i=v[a+16>>2];f=v[a+4>>2];v[e+8>>2]=v[a>>2];v[e+12>>2]=f;j=b+24|0;k=v[a+32>>2];l=v[a+28>>2];m=v[a+8>>2];n=v[a+12>>2];while(1){if(d){f=v[e+8>>2];o=(((v[e+12>>2]&2147483647)<<1|f>>>31)&-2)+i|0;b=(((f>>>16|0)+4&131064)<<1)+j|0;p=u[b+14>>1];q=u[b+12>>1];r=u[b+10>>1];s=u[b+8>>1];w=u[b+6>>1];x=u[b+4>>1];y=u[b+2>>1];z=u[b>>1];f=0;while(1){if((f|0)!=2){b=f+o|0;v[(f<<2)+e>>2]=(((((B(t[b+4|0],r)+B(t[b+2|0],s)|0)+B(t[b+6|0],q)|0)+B(t[b+8|0],p)<<8)/2|0)+((((B(t[b-4|0],y)+B(t[b-6|0],z)|0)+B(t[b-2|0],x)|0)+B(t[b|0],w)<<8)/2|0)|0)/16384;f=f+1|0;continue}break}h=h+l|0;v[c>>2]=v[c>>2]+B(v[e>>2],h>>12);g=g+k|0;v[c+4>>2]=v[c+4>>2]+B(v[e+4>>2],g>>12);Qb(e+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}b=v[e+12>>2];v[a>>2]=v[e+8>>2];v[a+4>>2]=b;v[a+40>>2]=g;v[a+20>>2]=h>>12;v[a+36>>2]=h;v[a+24>>2]=g>>12;jb=e+16|0}function f3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c=jb+-64|0;jb=c;e=v[a>>2];a=v[e>>2];f=v[a+4>>2];v[c+40>>2]=v[a+20>>2];d=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=d;Hf(c+48|0,c+32|0,f);a=v[e+4>>2];e=v[a+8>>2];f=v[a+4>>2];d=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=d;d=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=d;v[c+8>>2]=v[a+8>>2];d=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=d;a:{b:{c:{d:{d=v[c+4>>2];if(f>>>0<=d>>>0){h=v[c+20>>2];if(f>>>0>h>>>0){break d}if(e>>>0>y[c+8>>2]){break c}i=v[c+28>>2];if(e>>>0>v[c+24>>2]-i>>>0){break b}j=b+12|0;k=v[c+16>>2];l=v[c>>2];b=0;e:while(1){if((b|0)==(e|0)){break a}m=B(b,d);n=B(b+i|0,h);a=0;while(1)if((a|0)==(f|0)){b=b+1|0;continue e}else{g=kd((v[(a+m<<2)+l>>2]+kd(vs(j),21)|0)+2048|0,12);g=(g|0)<32767?g:32767;u[(a+n<<1)+k>>1]=(g|0)>-32768?g:-32768;a=a+1|0;continue}}}aa(7192,9005,33,8718);L()}aa(7157,9005,34,8718);L()}aa(5900,9005,35,8718);L()}aa(5870,9005,36,8718);L()}jb=c- -64|0}function LF(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;a=jb-16|0;jb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;b=v[a+12>>2];a:{while(1){if(b>>>0>=d>>>0){c=0;break a}c=2;b=v[b>>2];if(b>>>0>1114111|(b&-2048)==55296){break a}b:{c:{if(b>>>0<=127){c=1;f=v[a+8>>2];if((g-f|0)<=0){break a}v[a+8>>2]=f+1;t[f|0]=b;break c}if(b>>>0<=2047){c=v[a+8>>2];if((g-c|0)<2){break b}v[a+8>>2]=c+1;t[c|0]=b>>>6|192;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128;break c}c=v[a+8>>2];f=g-c|0;if(b>>>0<=65535){if((f|0)<3){break b}v[a+8>>2]=c+1;t[c|0]=b>>>12|224;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>6&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128;break c}if((f|0)<4){break b}v[a+8>>2]=c+1;t[c|0]=b>>>18|240;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>12&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>6&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128}b=v[a+12>>2]+4|0;v[a+12>>2]=b;continue}break}c=1}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];jb=a+16|0;return c|0}function ay(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=jb-16|0;jb=d;f=w[a+2|0];if(!(!f|(f|0)==255)){v[d+12>>2]=f+1;v[d+8>>2]=10;Qg(b,v[sd(d+12|0,d+8|0)>>2]);i=w[a+3|0];t[b+15|0]=i;t[b+16|0]=i;j=w[a+4|0];t[b+13|0]=j;l=w[a+5|0];t[b+14|0]=l;f=511;a:{b:{switch(c-1|0){case 1:e=4096;f=128;break a;case 0:break b;default:break a}}e=32768;f=1024}o=f>>>1|e;c=v[b>>2];k=_d(c,v[b+4>>2]);e=0;c:{while(1){if((e|0)==(k|0)){d:{c=w[b+12|0]&-2|t[a|0]&1;t[b+12|0]=c;if(w[a|0]&2){break d}c=c&251;break c}}else{m=Db(c,e);h=(e<<2)+a|0;g=(w[h+6|0]|w[h+7|0]<<8)>>>4|0;u[m>>1]=g;e:{if(e){n=x[Db(c,e-1|0)>>1];if(g>>>0>=n>>>0){break e}g=n+1|0}else{g=0}p=Db(c,e),q=g,u[p>>1]=q}v[d+12>>2]=(((w[h+8|0]|w[h+9|0]<<8)<<16>>16)+o|0)/(f|0);v[d+8>>2]=0;v[d+4>>2]=64;p=m,q=v[Ij(d+12|0,d+8|0,d+4|0)>>2],t[p+2|0]=q;e=e+1|0;continue}break}c=c&-5|(k>>>0>=i>>>0)<<2}t[b+12|0]=c;if(j>>>0<=l>>>0?w[a|0]&4:0){a=c&-3|(k>>>0>=j>>>0)<<1}else{a=c&253}t[b+12|0]=a}jb=d+16|0}function i7(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=jb-32|0;jb=d;v[23588]=0;g=Q(13,d+24|0,a|0)|0;c=v[23588];v[23588]=0;a:{b:{c:{if((c|0)!=1){d:{if(!w[g|0]){break d}c=d+16|0;fd(c,v[v[a>>2]-12>>2]+a|0);v[23588]=0;c=S(68,c|0)|0;e=v[23588];v[23588]=0;e:{f:{if((e|0)!=1){$b(d+16|0);e=Rm(d+8|0,a);f=v[v[a>>2]-12>>2];v[23588]=0;f=a+f|0;h=S(14,f|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break f}e=v[e>>2];v[23588]=0;c=Ua(69,c|0,e|0,f|0,h|0,+b)|0;e=v[23588];v[23588]=0;if((e|0)==1){break f}v[d+16>>2]=c;if(!_u(d+16|0)){break d}c=v[v[a>>2]-12>>2];v[23588]=0;R(16,a+c|0,5);c=v[23588];v[23588]=0;if((c|0)!=1){break d}c=V(0)|0;O()|0;break e}c=V(0)|0;O()|0;$b(d+16|0);break e}c=V(0)|0;O()|0}yk(g);break c}yk(g);break b}c=V(0)|0;O()|0}_(c|0)|0;c=v[v[a>>2]-12>>2];v[23588]=0;Y(17,a+c|0);c=v[23588];v[23588]=0;if((c|0)==1){break a}$()}jb=d+32|0;return a|0}a=P()|0;O()|0;v[23588]=0;Z(18);d=v[23588];v[23588]=0;if((d|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function BJ(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;v[a+4>>2]=b;v[a>>2]=94392;e=(b>>>0)/48|0;d=((0-b|0)!=(B(e,-48)|0))+e|0;v[a+12>>2]=d;e=(b>>>0)/(d>>>0)|0;v[a+8>>2]=e;f=e>>>0<64;c=e&31;if((e&63)>>>0>=32){g=-1<<c}else{g=(1<<c)-1&-1>>>32-c|-1<<c}c=0;v[a+24>>2]=c;f=f?g&65536:0;v[a+28>>2]=f;g=0-c|0;h=Oka(c,f,d,0);c=65536-(f+((c|0)!=0)|0)|0;f=mb;if((c|0)==(f|0)&g>>>0>h>>>0|c>>>0>f>>>0){d=d+1|0;v[a+12>>2]=d;e=(b>>>0)/(d>>>0)|0;v[a+8>>2]=e;f=e>>>0<64;c=e&31;if((e&63)>>>0>=32){c=-1<<c}else{c=(1<<c)-1&-1>>>32-c|-1<<c}v[a+24>>2]=0;v[a+28>>2]=f?c&65536:0}v[a+16>>2]=d-((b>>>0)%(d>>>0)|0);b=e>>>0<63;d=63-e|0;c=d&31;if((d&63)>>>0>=32){d=0;c=-1>>>c|0}else{d=-1>>>c|0;c=d|(1<<c)-1<<32-c}v[a+48>>2]=b?c:-1;v[a+52>>2]=b?d:-1;d=64-e|0;c=d&31;if((d&63)>>>0>=32){d=0;c=-1>>>c|0}else{d=-1>>>c|0;c=d|(1<<c)-1<<32-c}v[a+40>>2]=e?c:0;v[a+44>>2]=e?d:0;c=e+1|0;e=c&31;if((c&63)>>>0>=32){d=-1<<e}else{d=(1<<e)-1&-1>>>32-e|-1<<e}v[a+32>>2]=0;v[a+36>>2]=b?d&65536:0;return a}function Of(a,b,c){t[a+5|0]=c;a:{b:{switch(b|0){case 0:if(!c){break a}t[a+3|0]=1;return;case 1:t[a+3|0]=2;return;case 2:t[a+3|0]=3;return;case 3:t[a+3|0]=4;return;case 4:t[a+3|0]=5;return;case 5:t[a+3|0]=6;return;case 6:t[a+3|0]=7;return;case 7:t[a+3|0]=8;return;case 8:t[a+3|0]=9;return;case 9:t[a+3|0]=10;return;case 10:t[a+3|0]=11;return;case 11:t[a+3|0]=12;return;case 12:t[a+3|0]=13;return;case 13:t[a+3|0]=14;t[a+5|0]=B(c>>>4|0,10)+(c&15);return;case 14:t[a+3|0]=19;return;case 15:if(c>>>0<=31){t[a+3|0]=16;return}t[a+3|0]=17;return;case 16:t[a+3|0]=23;return;case 17:t[a+3|0]=24;return;case 20:t[a+3|0]=25;return;case 21:t[a+3|0]=30;return;case 25:t[a+3|0]=29;return;case 27:t[a+3|0]=15;return;case 29:t[a+3|0]=18;return;case 32:t[a+3|0]=37;return;case 33:t[a+3|0]=28;return;case 34:t[a+3|0]=27;return;case 35:t[a+3|0]=31;return;case 36:t[a+3|0]=32;return;case 37:t[a+3|0]=32;return;case 38:t[a+3|0]=34;return;default:break b}}t[a+3|0]=0}}function Qga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=jb-48|0;jb=f;u[a>>1]=0;u[a+2>>1]=0;u[a+4>>1]=0;c=f+44|0;no(b,c);a:{if(!KP(c)){break a}d=w[f+46|0];g=w[f+47|0];e=w[f+45|0];t[a+4|0]=1;h=e>>>3&3;c=(h|0)!=3;e=(e>>>1^-1)&3;g=g>>>0<192;u[a+2>>1]=x[(B(c,6)+(e<<1)|0)+27368>>1]<<g;i=B(B(w[(e+B(c,3)|0)+27144|0],x[((B(c,90)+B(e,30)|0)+(d>>>3&30)|0)+27152>>1]),1e3);d=d>>>1|0;d=B(((i>>>0)/x[(B(h,6)+(d&6)|0)+27344>>1]|0)+(d&1)|0,e?1:4);u[a>>1]=d;e=w[(g|c<<1)+27380|0];if(e+8>>>0>(d&65535)>>>0){break a}c=jb-32|0;jb=c;v[c+28>>2]=e+4;v[c+8>>2]=36;g=v[b>>2];h=v[b+8>>2];d=v[Jb(c+28|0,c+8|0)>>2];if(!Pb(g,h,d)){d=cf(b)}h=c+8|0;er(h,f);g=gc(c+16|0,v[c+8>>2],d);mc(c,v[b>>2],v[b+8>>2],v[g>>2],v[g+4>>2]);er(h,f);Tb(v[c+8>>2]+d|0,0,36-d|0);Zb(b,v[c+28>>2]);jb=c+32|0;b=2;c=e>>>0>2?e:2;while(1){if((b|0)!=(c|0)){d=b+f|0;b=b+1|0;if(!w[d|0]){continue}break a}break}b=e+f|0;if(Rb(b,9526,4)){b=Rb(b,11048,4)}else{b=0}t[a+5|0]=!b}jb=f+48|0;return a|0}function sx(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=C(0);c=jb+-64|0;jb=c;b=v[a>>2];a=v[b>>2];d=v[a+4>>2];v[c+40>>2]=v[a+20>>2];e=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=e;Hf(c+48|0,c+32|0,d);a=v[b+4>>2];d=v[a+8>>2];e=v[a+4>>2];b=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=b;b=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=b;v[c+8>>2]=v[a+8>>2];b=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=b;a:{b:{c:{d:{f=v[c+4>>2];if(f>>>0>=e>>>0){if(y[c+20>>2]<e>>>0){break d}if(d>>>0>y[c+8>>2]){break c}g=v[c+28>>2];if(d>>>0>v[c+24>>2]-g>>>0){break b}h=v[c+16>>2];i=v[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}j=b+g|0;k=B(b,f);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{l=we(mg(A[(a+k<<3)+i>>3])*134217728);m=v[(a<<2)+h>>2]+(j<<2)|0,n=C(+(Im(l)|0)*7.450580596923828e-9),z[m>>2]=n;a=a+1|0;continue}}}aa(7192,9005,77,8685);L()}aa(7157,9005,78,8685);L()}aa(5900,9005,79,8685);L()}aa(5870,9005,80,8685);L()}jb=c- -64|0}function wq(a){var b=0,c=0,d=0,e=0,f=0;e=jb-16|0;jb=e;a:{b:{c:{d:{e:{f:{g:{h:{b=v[a+480180>>2];switch(b-1|0){case 7:break e;case 0:case 1:case 3:break f;case 2:case 4:case 5:case 6:break g;default:break h}}if((b|0)==16){break b}if((b|0)==32){break f}if((b|0)==64|(b|0)==256|((b|0)==512|(b|0)==2048)|(b|0)==8192){break b}if((b|0)==65536){break d}d=1;if((b|0)==2097152){break a}if((b|0)==4194304){break c}if((b|0)==536870912|(b|0)==67108864|(b|0)==134217728){break a}d=b;if((b|0)==16777216){break a}}d=32;break a}d=b;break a}d=4;if(x[a+480192>>1]){break a}c=Eb(v[a+484344>>2]);v[e+8>>2]=c;a=Eb(v[a+484348>>2]);while(1){if(!Ob(c,a)){d=1;break a}if(!(!Ob(v[c>>2],v[c+4>>2])|v[c+12>>2]==64)){break a}c=v[LM(e+8|0)>>2];continue}}d=16777216;break a}d=32;f=x[a+480188>>1];if(f>>>0>16){break a}while(1){if((c|0)==(f|0)){break b}b=(c<<5)+a|0;if(t[b+480281|0]&1){break a}c=c+1|0;if(x[b+480286>>1]==64){continue}break}break a}d=2}jb=e+16|0;return d}function rx(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=C(0);c=jb+-64|0;jb=c;b=v[a>>2];a=v[b>>2];d=v[a+4>>2];v[c+40>>2]=v[a+20>>2];e=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=e;Hf(c+48|0,c+32|0,d);a=v[b+4>>2];d=v[a+8>>2];e=v[a+4>>2];b=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=b;b=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=b;v[c+8>>2]=v[a+8>>2];b=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=b;a:{b:{c:{d:{f=v[c+4>>2];if(f>>>0>=e>>>0){g=v[c+20>>2];if(g>>>0<e>>>0){break d}if(d>>>0>y[c+8>>2]){break c}h=v[c+28>>2];if(d>>>0>v[c+24>>2]-h>>>0){break b}i=v[c+16>>2];j=v[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}k=B(b,f);l=B(b+h|0,g);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{m=(a+l<<2)+i|0,n=C(+(Im(we(mg(A[(a+k<<3)+j>>3])*134217728))|0)*7.450580596923828e-9),z[m>>2]=n;a=a+1|0;continue}}}aa(7192,9005,77,8685);L()}aa(7157,9005,78,8685);L()}aa(5900,9005,79,8685);L()}aa(5870,9005,80,8685);L()}jb=c- -64|0}function p3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=jb+-64|0;jb=c;b=v[a>>2];a=v[b>>2];d=v[a+4>>2];v[c+40>>2]=v[a+20>>2];e=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=e;Hf(c+48|0,c+32|0,d);a=v[b+4>>2];d=v[a+8>>2];e=v[a+4>>2];b=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=b;b=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=b;v[c+8>>2]=v[a+8>>2];b=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=b;a:{b:{c:{d:{g=v[c+4>>2];if(g>>>0>=e>>>0){if(y[c+20>>2]<e>>>0){break d}if(d>>>0>y[c+8>>2]){break c}h=v[c+28>>2];if(d>>>0>v[c+24>>2]-h>>>0){break b}i=v[c+16>>2];j=v[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}k=b+h|0;l=B(b,g);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{m=v[(a<<2)+i>>2]+(k<<1)|0;f=kd(v[(a+l<<2)+j>>2]+2048|0,12);f=(f|0)<32767?f:32767;u[m>>1]=(f|0)>-32768?f:-32768;a=a+1|0;continue}}}aa(7192,9005,33,8718);L()}aa(7157,9005,34,8718);L()}aa(5900,9005,35,8718);L()}aa(5870,9005,36,8718);L()}jb=c- -64|0}function Cca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=jb-16|0;jb=e;n=v[a+16>>2];o=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);k=v[a+128>>2];a:{if(!k){i=v[a+8>>2];j=v[a+12>>2];g=v[a>>2];b=v[a+4>>2];h=0;break a}i=v[a+8>>2];j=v[a+12>>2];l=kg(i,j,k);m=mb;h=v[a+76>>2];g=v[a>>2];b=v[a+4>>2];Pf(g,b,kf(i,j,d),mb);h=h>>>0<mb>>>0?d:0}f=a+112|0;p=v[a+24>>2];q=v[a+20>>2];v[e>>2]=g;v[e+4>>2]=b;b:while(1){if(d){b=v[e+4>>2];v[e+8>>2]=v[e>>2];v[e+12>>2]=0;h=h-1|0;l=h?l:0;m=h?m:0;d=d-1|0;g=(b<<1)+n|0;b=k;while(1)if((b|0)<=0){Qb(f,v[a+120>>2],v[a+124>>2]);b=v[a+116>>2];if(b){Rd(f,u[(v[e+12>>2]<<1)+g>>1]/4<<16>>16);Qd(f,b);v[f>>2]=v[f>>2];v[f+4>>2]=0}g=v[c>>2];b=ig(f,o);v[c>>2]=g+B(b,q);v[c+4>>2]=v[c+4>>2]+B(b,p);Qb(e,i,j);c=c+8|0;continue b}else{Rd(f,u[(v[e+12>>2]<<1)+g>>1]/4<<16>>16);Qd(f,4);Qb(e+8|0,l,m);b=b-1|0;continue}}break}b=v[e+4>>2];v[a>>2]=v[e>>2];v[a+4>>2]=b;jb=e+16|0}function A9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=v[a>>2];c=Pj(d,v[a+4>>2]);if(c>>>0<b>>>0){g=jb-32|0;jb=g;e=b-c|0;b=v[Fb(a)>>2];c=v[a+4>>2];a:{if(e>>>0<=b-c>>11>>>0){b=jb-16|0;jb=b;v[b>>2]=a;a=v[a+4>>2];v[b+4>>2]=a;v[b+8>>2]=a+(e<<11);a=v[b+4>>2];c=v[b+8>>2];while(1){if((a|0)==(c|0)){kc(b);jb=b+16|0}else{wL(a);a=a+2048|0;v[b+4>>2]=a;continue}break}break a}h=Fb(a);i=g+8|0;b=a;f=Pj(v[a>>2],c)+e|0;c=jb-16|0;jb=c;v[c+12>>2]=f;d=jb-16|0;jb=d;v[d+12>>2]=2097151;v[d+8>>2]=2147483647;a=v[Jb(d+12|0,d+8|0)>>2];jb=d+16|0;b:{if(a>>>0>=f>>>0){d=Sx(b);if(d>>>0<a>>>1>>>0){v[c+8>>2]=d<<1;a=v[Yc(c+8|0,c+12|0)>>2]}jb=c+16|0;break b}bd();L()}d=yL(i,a,Pj(v[b>>2],v[b+4>>2]),h);c=d;a=jb-16|0;jb=a;v[a>>2]=v[c+8>>2];f=v[c+8>>2];v[a+8>>2]=c+8;v[a+4>>2]=f+(e<<11);c=v[a>>2];while(1){if(v[a+4>>2]!=(c|0)){wL(c);c=v[a>>2]+2048|0;v[a>>2]=c;continue}break}Td(a);jb=a+16|0;Dd(b,d);xL(d)}jb=g+32|0;return}if(b>>>0<c>>>0){Nd(a,d+(b<<11)|0)}}function Gda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0;g=jb-16|0;jb=g;f=v[a+48>>2];j=v[a+24>>2];k=v[a+20>>2];e=v[a+44>>2];l=v[a+16>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;m=v[a+72>>2];b=v[a+68>>2];n=b;o=b>>31;b=v[a+64>>2];p=b;q=b>>31;b=v[a+60>>2];r=b;s=b>>31;u=v[a+8>>2];w=v[a+12>>2];while(1){b=e;if(d){e=Xb(b,-16777216,16776704);e=Lka(p,q,e,e>>31);i=mb;f=Xb(f,-16777216,16776704);h=Lka(n,o,f,f>>31);e=h+e|0;f=mb+i|0;f=e>>>0<h>>>0?f+1|0:f;i=e;h=v[g+12>>2]+l|0;e=t[h|0];x=i;i=((B(t[h+1|0]-e|0,v[g+8>>2]>>>10&4194048)|0)/16384|0)+(e<<8)<<8;e=i;h=Lka(e,e>>31,r,s);e=x+h|0;f=mb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Xc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(e,k)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(e,j);Qb(g+8|0,u,w);e=f-(i&m)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=c;v[a+48>>2]=f;v[a+44>>2]=b;jb=g+16|0}function g3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=jb+-64|0;jb=c;b=v[a>>2];a=v[b>>2];d=v[a+4>>2];v[c+40>>2]=v[a+20>>2];e=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=e;Hf(c+48|0,c+32|0,d);a=v[b+4>>2];d=v[a+8>>2];e=v[a+4>>2];b=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=b;b=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=b;v[c+8>>2]=v[a+8>>2];b=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=b;a:{b:{c:{d:{g=v[c+4>>2];if(g>>>0>=e>>>0){h=v[c+20>>2];if(h>>>0<e>>>0){break d}if(d>>>0>y[c+8>>2]){break c}i=v[c+28>>2];if(d>>>0>v[c+24>>2]-i>>>0){break b}j=v[c+16>>2];k=v[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}l=B(b,g);m=B(b+i|0,h);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{f=kd(v[(a+l<<2)+k>>2]+2048|0,12);f=(f|0)<32767?f:32767;u[(a+m<<1)+j>>1]=(f|0)>-32768?f:-32768;a=a+1|0;continue}}}aa(7192,9005,33,8718);L()}aa(7157,9005,34,8718);L()}aa(5900,9005,35,8718);L()}aa(5870,9005,36,8718);L()}jb=c- -64|0}function I6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=jb-80|0;jb=e;v[e+72>>2]=c;a=dg(a,e+72|0);c=Gc(a+4|0);g=Gc(a+24|0);h=Gc(a+32|0);i=Sb(a+36|0);v[a+56>>2]=3;j=Sb(a+68|0);v[23588]=0;R(947,a|0,d|0);f=v[23588];v[23588]=0;a:{b:{c:{d:{if((f|0)!=1){f=v[b>>2];k=v[b+4>>2];l=v[b+12>>2];v[e+40>>2]=v[b+8>>2];v[e+44>>2]=l;v[e+32>>2]=f;v[e+36>>2]=k;b=ee(e+24|0);f=v[e+44>>2];v[e+16>>2]=v[e+40>>2];v[e+20>>2]=f;v[23588]=0;f=v[e+36>>2];v[e+8>>2]=v[e+32>>2];v[e+12>>2]=f;f=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=f;U(936,e+48|0,e+8|0,e|0);b=v[23588];v[23588]=0;if((b|0)==1){break d}v[23588]=0;U(948,a|0,e+48|0,d|0);b=v[23588];v[23588]=0;if((b|0)==1){break c}Ab(e+48|0);v[23588]=0;Y(949,a|0);b=v[23588];v[23588]=0;if((b|0)==1){break b}De(e+72|0);jb=e+80|0;return a|0}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=P()|0;O()|0;Ab(e+48|0);break a}d=P()|0;O()|0}We(j);Wf(i);As(h);jj(g);ij(c);De(a);De(e+72|0);T(d|0);L()}function Es(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0;o(+a);e=j(1)|0;c=j(0)|0;a:{b:{d=e>>>20&2047;if(d-969>>>0<63){k=d;break b}if(d>>>0<=968){return a+1}if(d>>>0<1033){break b}b=0;if(!c&(e|0)==-1048576){break a}if((d|0)==2047){return a+1}if((e|0)<0){return Ir(12882297539194267e-247)}return Ir(3105036184601418e216)}b=A[170];f=A[169]*a+b;b=f-b;b=b*A[172]+(b*A[171]+a);a=b*b;g=a*a*(b*A[176]+A[175]);a=a*(b*A[174]+A[173]);o(+f);j(1)|0;h=j(0)|0;c=h<<4&2032;b=g+(a+(A[c+1464>>3]+b));d=c+1472|0;c=h<<13;e=0;i=v[d>>2]+e|0;c=c+v[d+4>>2]|0;c=e>>>0>i>>>0?c+1|0:c;d=i;if(!k){c:{if(!(h&-2147483648)){l(0,d|0);l(1,c-1058013184|0);a=+n();a=(a*b+a)*5486124068793689e288;break c}e=jb-16|0;l(0,d|0);l(1,c+1071644672|0);g=+n();f=g*b;a=f+g;if(a<1){v[e+8>>2]=0;v[e+12>>2]=1048576;A[e+8>>3]=A[e+8>>3]*22250738585072014e-324;b=a+1;a=b+(f+(g-a)+(a+(1-b)))+-1;a=a==0?0:a}a=a*22250738585072014e-324}return a}l(0,d|0);l(1,c|0);a=+n();b=a*b+a}return b}function XP(a,b,c,d){var e=0,f=0;e=jb-16|0;jb=e;t[e+15|0]=c;f=b&15;b=w[f+27072|0];a:{b:{switch(f|0){case 0:b=c?d>>>0<51?0:b:0;break a;case 5:c:{d:{f=c&15;e:{if(!((f|0)!=2&(c&240)!=32)){c=159;t[e+15|0]=159;b=20;break e}if((f|0)==12){break d}}if(d>>>0<51){break a}if((c&240)==192){break c}break a}if(d>>>0<51){break a}}t[e+15|0]=0;b=25;break a;case 7:b=d>>>0<52?0:b;break a;case 10:c=c&240;if(!c){break a}t[e+15|0]=c;break a;case 11:t[e+15|0]=B(c&15,17);break a;case 12:t[e+15|0]=c>>>2;break a;case 13:t[e+15|0]=B(c>>>4|0,10)+(c&15);break a;case 14:f:{switch((c>>>4|0)-1|0){case 0:t[e+15|0]=c|240;b=2;break a;case 1:t[e+15|0]=c|240;b=3;break a;case 7:if(d>>>0<52){break a}t[e+15|0]=c&15|96;case 11:case 12:b=20;break a;case 8:b=15;t[e+15|0]=c&15;break a;case 9:t[e+15|0]=c<<4|15;b=11;break a;case 10:break f;default:break a}}t[e+15|0]=c|240;b=11;break a;case 15:break b;default:break a}}b=c>>>0>47?17:b}de(a,b,e+15|0);jb=e+16|0}function hja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;md(b,32);to(b);f=b,g=Hb(w[a+40|0]|w[a+41|0]<<8)>>>2|0,u[f+32>>1]=g;c=x[b+34>>1];if((pe((w[a+38|0]|w[a+39|0]<<8)<<16>>16)|0)>0){c=c|32;u[b+34>>1]=c;d=pe((w[a+38|0]|w[a+39|0]<<8)<<16>>16);e=(d<<8&-256)+2047|0;d=d>>>24|0;f=b,g=Dc(Oka(e,e>>>0<2047?d+1|0:d,4095,0),mb),u[f+28>>1]=g}f=b,g=bc(w[a+58|0]|w[a+59|0]<<8|(w[a+60|0]<<16|w[a+61|0]<<24)),v[f>>2]=g;f=b,g=bc(w[a+62|0]|w[a+63|0]<<8|(w[a+64|0]<<16|w[a+65|0]<<24)),v[f+4>>2]=g;f=b,g=bc(w[a+62|0]|w[a+63|0]<<8|(w[a+64|0]<<16|w[a+65|0]<<24))+bc(w[a+66|0]|w[a+67|0]<<8|(w[a+68|0]<<16|w[a+69|0]<<24))|0,v[f+8>>2]=g;c=c&-3|((Hb(w[a+44|0]|w[a+45|0]<<8)|0)!=0)<<1;u[b+34>>1]=c;f=b,g=c&65531|Hb(w[a+44|0]|w[a+45|0]<<8)<<1&4,u[f+34>>1]=g;f=b,g=bc(w[a+54|0]|w[a+55|0]<<8|(w[a+56|0]<<16|w[a+57|0]<<24))<<1,v[f+24>>2]=g;c=pe((w[a+42|0]|w[a+43|0]<<8)<<16>>16);if(c){Al(b,+(c|0)/96);c=pe((w[a+42|0]|w[a+43|0]<<8)<<16>>16)}t[b+37|0]=c<<4}function Fda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0;g=jb-16|0;jb=g;f=v[a+48>>2];j=v[a+24>>2];k=v[a+20>>2];e=v[a+44>>2];l=v[a+16>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;m=v[a+72>>2];b=v[a+68>>2];n=b;o=b>>31;b=v[a+64>>2];p=b;q=b>>31;b=v[a+60>>2];r=b;s=b>>31;t=v[a+8>>2];w=v[a+12>>2];while(1){b=e;if(d){e=Xb(b,-16777216,16776704);e=Lka(p,q,e,e>>31);i=mb;f=Xb(f,-16777216,16776704);h=Lka(n,o,f,f>>31);e=h+e|0;f=mb+i|0;f=e>>>0<h>>>0?f+1|0:f;i=e;h=(v[g+12>>2]<<1)+l|0;e=u[h>>1];x=i;i=e+((B(u[h+2>>1]-e|0,v[g+8>>2]>>>18|0)|0)/16384|0)<<8;e=i;h=Lka(e,e>>31,r,s);e=x+h|0;f=mb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Xc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(e,k)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(e,j);Qb(g+8|0,t,w);e=f-(i&m)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=c;v[a+48>>2]=f;v[a+44>>2]=b;jb=g+16|0}function U7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=C(0),o=0,p=0,q=0,r=0,s=0,t=C(0),u=C(0),x=C(0),y=C(0),A=0,B=0,E=0,F=0,G=0,H=C(0);g=jb-16|0;jb=g;m=v[a+4240>>2];a:{if(!m){break a}if(!$h(a+44|0)){break a}n=z[a+4220>>2];e=v[a+44>>2];F=g,G=Jc(e,0),v[F+8>>2]=G;F=g,G=Jc(e,1),v[F+12>>2]=G;e=v[a+56>>2];o=Jc(e,0);v[g>>2]=o;p=Jc(e,1);v[g+4>>2]=p;y=C(C(1)-n);q=v[a+4208>>2];A=w[a+4264|0];e=d;b:while(1){if(e){k=v[a+4244>>2];B=k<<1;f=0;l=0;while(1)if((f|0)==2){f=k+1|0;v[a+4244>>2]=(f|0)==(m|0)?0:f;e=e-1|0;continue b}else{h=(A?1-l|0:f)&255;j=v[((h<<2)+a|0)+4248>>2];E=v[a+4240>>2];r=f<<2;s=r+(g+8|0)|0;i=v[s>>2];v[s>>2]=i+4;j=k-j|0;t=z[Db(q,h+((j>>31&E)+j<<1)|0)>>2];u=z[i>>2];x=C(C(t*z[a+4224>>2])+C(u*z[a+4260>>2]));F=Db(q,f+B|0),H=C(D(x))<C(10000000195414814e-40)?C(0):x,z[F>>2]=H;h=g+r|0;i=v[h>>2];v[h>>2]=i+4;z[i>>2]=C(u*y)+C(n*t);l=l+1|0;f=f+1|0;continue}}break}ri(a,b,c,o,p,d)}jb=g+16|0}function RW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;j=jb-32|0;jb=j;d=$m(j+8|0,a);c=jb-48|0;jb=c;k=-1;a:{if(!lD(d,c+8|0)){break a}k=0;if(!qD(c+8|0)){break a}l=xg(13017);if(l){o=v[d+12>>2];b:{if(!wl(d,w[c+24|0]|w[c+25|0]<<8|(w[c+26|0]<<16|w[c+27|0]<<24))){break b}while(1){c:{if((w[c+20|0]|w[c+21|0]<<8|(w[c+22|0]<<16|w[c+23|0]<<24))>>>0>n>>>0){if(eg(d,5)){break c}}g=m&1;break b}g=0;h=1;d:{if((w[c+12|0]|w[c+13|0]<<8)>>>0>=64){f=Nq(d);a=f&63;e:{if(!(f&64)){break e}e=6;while(1){i=Nq(d);a=(i&127)<<e|a;if(!(i&128)){break e}i=e>>>0<25;e=e+7|0;if(i){continue}break}}e=f>>>7|0;f=e?-2147483648:a;if(((e?(a|0)>=0?0-a|0:f:f)|0)<=0){break d}}while(1){e=Nq(d);if(e){f=g>>>0>=l>>>0;a=f&h;if(!((h^1)&1|f)){a=(Pp(e<<24>>24)&255)==w[g+13017|0]}h=a;g=g+1|0;continue}break}hd(d,4);m=(g|0)==(l|0)?h&1?1:m:m}n=n+1|0;continue}}wl(d,o)}if(!g){break a}k=Ae(d,b,pD(c+8|0),0)}jb=c+48|0;jb=j+32|0;return k|0}function yw(a,b,c,d,e,f,g,h,i,j,k,l){var m=0;m=jb-16|0;jb=m;t[m+15|0]=a;a:{b:{if((a|0)==(f|0)){if(!w[b|0]){break b}a=0;t[b|0]=0;b=v[e>>2];v[e>>2]=b+1;t[b|0]=46;if(!Gb(h)){break a}b=v[j>>2];if((b-i|0)>159){break a}c=v[k>>2];v[j>>2]=b+4;v[b>>2]=c;break a}c:{if((a|0)!=(g|0)){break c}if(!Gb(h)){break c}if(!w[b|0]){break b}a=0;b=v[j>>2];if((b-i|0)>159){break a}a=v[k>>2];v[j>>2]=b+4;v[b>>2]=a;a=0;v[k>>2]=0;break a}a=-1;f=wi(l,l+32|0,m+15|0)-l|0;if((f|0)>31){break a}g=w[f+82976|0];d:{e:{switch((f&-2)-22|0){case 2:b=v[e>>2];if((b|0)!=(d|0)&(w[b-1|0]&95)!=(w[c|0]&127)){break a}v[e>>2]=b+1;t[b|0]=g;a=0;break a;case 0:t[c|0]=80;break d;default:break e}}a=g&95;if((a|0)!=w[c|0]){break d}t[c|0]=a|128;if(!w[b|0]){break d}t[b|0]=0;if(!Gb(h)){break d}a=v[j>>2];if((a-i|0)>159){break d}b=v[k>>2];v[j>>2]=a+4;v[a>>2]=b}a=v[e>>2];v[e>>2]=a+1;t[a|0]=g;a=0;if((f|0)>21){break a}v[k>>2]=v[k>>2]+1;break a}a=-1}jb=m+16|0;return a}function Vda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0;g=jb-16|0;jb=g;m=v[a+16>>2];j=Sf(1,2);b=mb;n=b;Qb(a,j,b);f=v[a+48>>2];o=v[a+24>>2];p=v[a+20>>2];e=v[a+44>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;q=v[a+72>>2];b=v[a+68>>2];r=b;s=b>>31;b=v[a+64>>2];t=b;w=b>>31;b=v[a+60>>2];x=b;y=b>>31;z=v[a+8>>2];A=v[a+12>>2];while(1){b=e;if(d){k=u[(v[g+12>>2]<<1)+m>>1]<<8;e=k;e=Lka(e,e>>31,x,y);i=mb;h=e;e=Xb(b,-16777216,16776704);l=Lka(t,w,e,e>>31);h=h+l|0;e=mb+i|0;e=h>>>0<l>>>0?e+1|0:e;f=Xb(f,-16777216,16776704);i=Lka(r,s,f,f>>31);h=i+h|0;f=mb+e|0;f=h>>>0<i>>>0?f+1|0:f;e=h+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Xc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(e,p)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(e,o);Qb(g+8|0,z,A);e=f-(q&k)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=c;v[a+48>>2]=f;v[a+44>>2]=b;lg(a,j,n);jb=g+16|0}function Uha(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;e=jb-32|0;jb=e;b=jb-32|0;jb=b;v[b+16>>2]=1073741824;u[b+22>>1]=12;c=sc(64);v[23588]=0;d=S(835,c|0)|0;f=v[23588];v[23588]=0;a:{b:{c:{if((f|0)!=1){c=Lf(b+8|0,d);d=v[c>>2];v[23588]=0;R(836,d|0,a|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}a=v[c>>2];v[23588]=0;a=W(837,a|0,b+22|0,b+16|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break c}d:{if(!a){Gc(b+24|0);break d}a=v[c>>2];v[23588]=0;R(838,a|0,15);a=v[23588];v[23588]=0;if((a|0)==1){break c}dg(b+24|0,c)}rg(c);jb=b+32|0;b=v[b+24>>2];break a}a=P()|0;O()|0;Mb(c);break b}a=P()|0;O()|0;rg(c)}T(a|0);L()}v[e+24>>2]=b;a=0;e:{f:{g:{while(1){if((a|0)==12){break e}v[23588]=0;c=Q(1,e+8|0,(a<<2)+32176|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){v[23588]=0;U(486,b|0,a|0,c|0);d=v[23588];v[23588]=0;if((d|0)==1){break g}zb(c);a=a+1|0;continue}break}a=P()|0;O()|0;break f}a=P()|0;O()|0;zb(c)}rg(e+24|0);T(a|0);L()}jb=e+32|0;return b|0}function Ep(a){a=a|0;var b=0,c=0,d=C(0),e=C(0),f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=C(0),n=0,o=C(0);b=v[a+36>>2];if(!b){Kc(a+16|0);return}a:{b:{switch(x[a>>1]){case 3:c=a+16|0;if(b>>>0>=1001){Kc(c);return}ck(c,b);b=u[a+28>>1];d=C(qm(a,(b<<16)+65536>>16)/qm(a,b));c=v[a+36>>2]+1|0;d=te(d,C(C(1)/C(c>>>0)));a=v[a+16>>2];b=1;while(1){if((b|0)==(c|0)){break a}e=te(d,C(b>>>0));n=Db(a,b-1|0),o=e,z[n>>2]=o;b=b+1|0;continue};case 1:c=a+16|0;f=x[a+30>>1];if(f>>>0>1e3/(b>>>0)>>>0){Kc(c);return}ck(c,B(b,f));h=x[a+30>>1];j=On(u[a+28>>1],h);i=v[a+36>>2];d=C(C(1)/C(i+1>>>0));c=0;c:while(1){if((c&65535)>>>0>=f>>>0){break a}b=On(c+j<<16>>16,h)<<16;e=qm(a,b+65536>>16);b=b>>16;e=te(C(e/qm(a,b)),d);k=B(b,v[a+36>>2]);l=v[a+16>>2];b=1;while(1){g=b&65535;if(i>>>0<g>>>0){c=c+1|0;continue c}else{m=te(e,C(g>>>0));n=Db(l,(g+k|0)-1|0),o=m,z[n>>2]=o;b=b+1|0;continue}}};case 0:Kc(a+16|0);return;default:break b}}Kc(a+16|0);v[a+36>>2]=0}}function Wda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0,A=0;g=jb-16|0;jb=g;m=v[a+16>>2];j=Sf(1,2);b=mb;n=b;Qb(a,j,b);f=v[a+48>>2];o=v[a+24>>2];p=v[a+20>>2];e=v[a+44>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;q=v[a+72>>2];b=v[a+68>>2];r=b;s=b>>31;b=v[a+64>>2];u=b;w=b>>31;b=v[a+60>>2];x=b;y=b>>31;z=v[a+8>>2];A=v[a+12>>2];while(1){b=e;if(d){k=t[v[g+12>>2]+m|0]<<16;e=k;e=Lka(e,e>>31,x,y);i=mb;h=e;e=Xb(b,-16777216,16776704);l=Lka(u,w,e,e>>31);h=h+l|0;e=mb+i|0;e=h>>>0<l>>>0?e+1|0:e;f=Xb(f,-16777216,16776704);i=Lka(r,s,f,f>>31);h=i+h|0;f=mb+e|0;f=h>>>0<i>>>0?f+1|0:f;e=h+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Xc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(e,p)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(e,o);Qb(g+8|0,z,A);e=f-(q&k)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=c;v[a+48>>2]=f;v[a+44>>2]=b;lg(a,j,n);jb=g+16|0}function hda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=jb-16|0;jb=f;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;while(1){if(d){e=(v[f+12>>2]<<1)+j|0;h=(v[f+8>>2]>>>16&65520)+b|0;e=(((((((B(u[e-4>>1],u[h+2>>1])+B(u[e-6>>1],u[h>>1])|0)+B(u[e-2>>1],u[h+4>>1])|0)+B(u[e>>1],u[h+6>>1])|0)+B(u[e+2>>1],u[h+8>>1])|0)+B(u[e+4>>1],u[h+10>>1])|0)+B(u[e+6>>1],u[h+12>>1])|0)+B(u[e+8>>1],u[h+14>>1])|0)/32768|0;v[c>>2]=v[c>>2]+B(e,l);v[c+4>>2]=v[c+4>>2]+B(e,k);Qb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;jb=f+16|0}function Uga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=jb-16|0;jb=e;u[e+12>>1]=0;v[e+8>>2]=0;j=8;n=B(c,d)<<1;a:while(1){if((d|0)!=(l|0)){i=(l<<1)+b|0;o=n+i|0;while(1){b:{c:{if(i>>>0<o>>>0){u[e+6>>1]=0;pS(a,e+15|0,e+12|0,j,e+6|0);g=x[e+6>>1];f=x[e+12>>1];c=j;while(1){if(c&255){h=f<<1;f=h&254;d:{if(f){h=(h&65534)>>>0>255;break d}if(!nf(a,e+5|0)){break c}f=w[e+5|0];h=f>>>7|0;f=f<<1&254|1}c=c-1|0;g=g<<1|h;continue}break}u[e+12>>1]=f;break b}l=l+1|0;continue a}u[e+12>>1]=0}c=1;h=g&65535;e:{if(h>>>0<4){break e}f=15;while(1){c=f;m=f&255;if(h>>>m&1){break e}f=c-1|0;if(m>>>0>1){continue}break}}f=g&1;t[e+15|0]=f;g=f-1^(g&65534)>>>1;f=g+x[e+8>>1]|0;u[e+6>>1]=f;u[i>>1]=f;v[e+8>>2]=((g>>1)-(k<<16>>16)|0)+(f<<16>>16<<1);i=(d<<1)+i|0;j=(c+j&254)>>>1|0;c=-32768;k=v[e+8>>2];f:{if((k|0)>=-32768){c=32767;if((k|0)<32768){break f}}v[e+8>>2]=c}k=f;continue}}break}jb=e+16|0}function v9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=C(0),j=0,k=0,l=0,m=0,n=C(0),o=C(0),p=C(0),q=C(0),r=0,s=0,t=0,u=C(0),w=C(0),x=C(0),y=C(0),A=0,B=0,E=0,F=C(0);r=v[a+4220>>2];if(r){f=v[a+44>>2];k=Jc(f,0);l=Jc(f,1);g=v[a+56>>2];s=Jc(g,0);j=v[a+4208>>2];A=v[a+4228>>2];f=d;t=Jc(g,1);m=t;g=s;while(1){if(f){h=v[a+4224>>2];e=h-A|0;e=(v[a+4220>>2]&e>>31)+e<<1;B=Db(j,e);n=z[Db(j,e|1)>>2];u=z[a+4244>>2];o=z[B>>2];w=z[a+4252>>2];p=z[l>>2];x=z[a+4248>>2];q=z[k>>2];y=z[a+4256>>2];i=C(C(n*u)+C(C(o*w)+C(C(p*x)+C(q*y))));e=h<<1;E=Db(j,e),F=C(D(i))<C(10000000195414814e-40)?C(0):i,z[E>>2]=F;i=C(C(o*u)+C(C(n*w)+C(C(q*x)+C(p*y))));E=Db(j,e|1),F=C(D(i))<C(10000000195414814e-40)?C(0):i,z[E>>2]=F;h=h+1|0;v[a+4224>>2]=(h|0)==(r|0)?0:h;z[g>>2]=C(q*z[a+4240>>2])+C(o*z[a+4236>>2]);z[m>>2]=C(p*z[a+4240>>2])+C(n*z[a+4236>>2]);f=f-1|0;m=m+4|0;g=g+4|0;l=l+4|0;k=k+4|0;continue}else{ri(a,b,c,s,t,d)}break}}}function XG(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=jb-32|0;jb=c;a:{if(w[a+52|0]){d=v[a+48>>2];if(!b){break a}t[a+52|0]=0;v[a+48>>2]=-1;break a}v[c+24>>2]=1;e=v[Oe(c+24|0,a+44|0)>>2];h=(e|0)>0?e:0;while(1){if((f|0)!=(h|0)){d=-1;g=ru(v[a+32>>2]);if((g|0)==-1){break a}t[(c+24|0)+f|0]=g;f=f+1|0;continue}break}b:{c:{if(w[a+53|0]){t[c+23|0]=w[c+24|0];break c}h=c+24|0;while(1){d:{d=v[a+40>>2];g=v[d>>2];j=v[d+4>>2];i=c+24|0;f=i+e|0;e:{switch(lH(v[a+36>>2],d,i,f,c+16|0,c+23|0,h,c+12|0)-1|0){case 0:break e;case 1:break b;case 2:break d;default:break c}}d=v[a+40>>2];v[d>>2]=g;v[d+4>>2]=j;if((e|0)==8){break b}d=ru(v[a+32>>2]);if((d|0)==-1){break b}t[f|0]=d;e=e+1|0;continue}break}t[c+23|0]=w[c+24|0]}f:{if(!b){while(1){if((e|0)<=0){break f}d=-1;e=e-1|0;if((Zr(yf(t[e+(c+24|0)|0]),v[a+32>>2])|0)!=-1){continue}break a}}d=yf(t[c+23|0]);v[a+48>>2]=d;break a}d=yf(t[c+23|0]);break a}d=-1}jb=c+32|0;return d}function Dca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=jb-16|0;jb=e;n=v[a+16>>2];o=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);k=v[a+128>>2];a:{if(!k){i=v[a+8>>2];j=v[a+12>>2];g=v[a>>2];b=v[a+4>>2];h=0;break a}i=v[a+8>>2];j=v[a+12>>2];l=kg(i,j,k);m=mb;h=v[a+76>>2];g=v[a>>2];b=v[a+4>>2];Pf(g,b,kf(i,j,d),mb);h=h>>>0<mb>>>0?d:0}f=a+112|0;p=v[a+24>>2];q=v[a+20>>2];v[e>>2]=g;v[e+4>>2]=b;b:while(1){if(d){b=v[e+4>>2];v[e+8>>2]=v[e>>2];v[e+12>>2]=0;h=h-1|0;l=h?l:0;m=h?m:0;d=d-1|0;g=b+n|0;b=k;while(1)if((b|0)<=0){Qb(f,v[a+120>>2],v[a+124>>2]);b=v[a+116>>2];if(b){Rd(f,t[v[e+12>>2]+g|0]<<6);Qd(f,b);v[f>>2]=v[f>>2];v[f+4>>2]=0}g=v[c>>2];b=ig(f,o);v[c>>2]=g+B(b,q);v[c+4>>2]=v[c+4>>2]+B(b,p);Qb(e,i,j);c=c+8|0;continue b}else{Rd(f,t[v[e+12>>2]+g|0]<<6);Qd(f,4);Qb(e+8|0,l,m);b=b-1|0;continue}}break}b=v[e+4>>2];v[a>>2]=v[e>>2];v[a+4>>2]=b;jb=e+16|0}function Vu(a){var b=0,c=0,d=0,e=0;c=jb-16|0;jb=c;a:{if(w[a+3|0]!=19){break a}t[a+3|0]=20;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{b=w[a+5|0];switch(b>>>4|0){case 4:break j;case 3:break k;case 2:break l;case 1:break m;case 0:break n;case 13:break b;case 12:break c;case 11:break d;case 10:break e;case 9:break f;case 7:break g;case 6:break h;case 5:break i;default:break a}}t[a+3|0]=0;break a}t[a+3|0]=2;t[a+5|0]=b|240;break a}t[a+3|0]=3;t[a+5|0]=b|240;break a}t[a+5|0]=b&15|16;break a}t[a+5|0]=b&3|48;break a}t[a+5|0]=b&15|32;break a}t[a+5|0]=b&15|176;break a}t[a+5|0]=b&3|64;break a}t[a+3|0]=15;t[a+5|0]=b&15;break a}if(b&15){t[a+3|0]=11;t[a+5|0]=b<<4|15;break a}t[a+3|0]=0;break a}b=b&15;if(b){t[a+3|0]=11;v[c+12>>2]=b;v[c+8>>2]=14;d=a,e=w[sd(c+12|0,c+8|0)|0]|240,t[d+5|0]=e;break a}t[a+3|0]=0;break a}if((b|0)!=192){break a}t[a|0]=254;t[a+3|0]=0;break a}if((b|0)!=208){break a}t[a+3|0]=0}jb=c+16|0}function GF(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;b=0;a=c;while(1){a:{if(a>>>0>=d>>>0|b>>>0>=e>>>0){break a}g=1;f=t[a|0];b:{if((f|0)>=0){break b}if(f>>>0<4294967234){break a}if(f>>>0<=4294967263){if((d-a|0)<2){break a}g=2;if((w[a+1|0]&192)==128){break b}break a}g=f&255;c:{d:{if(f>>>0<=4294967279){if((d-a|0)<3){break a}h=w[a+2|0];f=w[a+1|0];if((g|0)==237){break d}if((g|0)==224){if((f&224)==160){break c}break a}if((f&192)!=128){break a}break c}if((d-a|0)<4|f>>>0>4294967284|e-b>>>0<2){break a}h=w[a+3|0];i=w[a+2|0];f=w[a+1|0];e:{f:{switch(g-240|0){case 0:if((f+112&255)>>>0<48){break e}break a;case 4:if((f&240)==128){break e}break a;default:break f}}if((f&192)!=128){break a}}if((i&192)!=128|(h&192)!=128|(g<<18&1835008|(f&48)<<12)>>>0>1114111){break a}b=b+1|0;g=4;break b}if((f&224)!=128){break a}}g=3;if((h&192)!=128){break a}}b=b+1|0;a=a+g|0;continue}break}return a-c|0}function ZG(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=jb-32|0;jb=c;a:{if(w[a+52|0]){d=v[a+48>>2];if(!b){break a}t[a+52|0]=0;v[a+48>>2]=-1;break a}v[c+24>>2]=1;e=v[Oe(c+24|0,a+44|0)>>2];h=(e|0)>0?e:0;while(1){if((f|0)!=(h|0)){d=-1;g=ru(v[a+32>>2]);if((g|0)==-1){break a}t[(c+24|0)+f|0]=g;f=f+1|0;continue}break}b:{c:{if(w[a+53|0]){v[c+20>>2]=t[c+24|0];break c}h=c+24|0;while(1){d:{d=v[a+40>>2];g=v[d>>2];j=v[d+4>>2];i=c+24|0;f=i+e|0;e:{switch(lH(v[a+36>>2],d,i,f,c+16|0,c+20|0,h,c+12|0)-1|0){case 0:break e;case 1:break b;case 2:break d;default:break c}}d=v[a+40>>2];v[d>>2]=g;v[d+4>>2]=j;if((e|0)==8){break b}d=ru(v[a+32>>2]);if((d|0)==-1){break b}t[f|0]=d;e=e+1|0;continue}break}v[c+20>>2]=t[c+24|0]}f:{if(!b){while(1){if((e|0)<=0){break f}d=-1;e=e-1|0;if((Zr(t[e+(c+24|0)|0],v[a+32>>2])|0)!=-1){continue}break a}}d=v[c+20>>2];v[a+48>>2]=d;break a}d=v[c+20>>2];break a}d=-1}jb=c+32|0;return d}function ida(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=jb-16|0;jb=f;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;while(1){if(d){e=v[f+12>>2]+j|0;h=(v[f+8>>2]>>>16&65520)+b|0;e=(((((((B(t[e-2|0],u[h+2>>1])+B(t[e-3|0],u[h>>1])|0)+B(t[e-1|0],u[h+4>>1])|0)+B(t[e|0],u[h+6>>1])|0)+B(t[e+1|0],u[h+8>>1])|0)+B(t[e+2|0],u[h+10>>1])|0)+B(t[e+3|0],u[h+12>>1])|0)+B(t[e+4|0],u[h+14>>1])<<8)/32768|0;v[c>>2]=v[c>>2]+B(e,l);v[c+4>>2]=v[c+4>>2]+B(e,k);Qb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;jb=f+16|0}function ts(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=jb+-64|0;jb=c;b=v[a>>2];a=v[b>>2];d=v[a+4>>2];v[c+40>>2]=v[a+20>>2];e=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=e;Hf(c+48|0,c+32|0,d);a=v[b+4>>2];d=v[a+8>>2];e=v[a+4>>2];b=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=b;b=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=b;v[c+8>>2]=v[a+8>>2];b=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=b;a:{b:{c:{d:{f=v[c+4>>2];if(f>>>0>=e>>>0){g=v[c+20>>2];if(g>>>0<e>>>0){break d}if(d>>>0>y[c+8>>2]){break c}h=v[c+28>>2];if(d>>>0>v[c+24>>2]-h>>>0){break b}i=v[c+16>>2];j=v[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}k=B(b,f);l=B(b+h|0,g);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{z[(a+l<<2)+i>>2]=C(v[(a+k<<2)+j>>2])*C(7.450580596923828e-9);a=a+1|0;continue}}}aa(7192,9005,33,8718);L()}aa(7157,9005,34,8718);L()}aa(5900,9005,35,8718);L()}aa(5870,9005,36,8718);L()}jb=c- -64|0}function qfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=jb-144|0;jb=g;Co(a);a:{b:{if(!eg(a,64)){break b}c:{d:{if(!wl(a,60)){break d}if(!_Q(a,14094)){break d}c=15;d=450;break c}Co(a);if(!eg(a,128)){break b}b=0;if(!wl(a,124)){break a}if(!_Q(a,15357)){break a}c=31;d=930}Co(a);b=0;e:{while(1){if((b&65535)>>>0>=c>>>0){break e}b=b+1|0;if(YQ(a)>>>0<=131072){continue}break}b=0;break a}hd(a,4);if(!eg(a,2)){break b}b=0;e=jb-16|0;jb=e;c=jb-16|0;jb=c;Wm(c+8|0,e+8|0);f=v[c+12>>2];ld(c,a,v[c+8>>2],v[c+12>>2]);h=v[c+4>>2];if((f|0)==(h|0)){hd(a,v[c+12>>2])}jb=c+16|0;if((f|0)==(h|0)){i=Hb(x[e+8>>1])}jb=e+16|0;if(i>>>0<178){break a}b=-1;if(!eg(a,d)){break a}hd(a,d);d=jb-16|0;jb=d;e=g+8|0;ZR(d+8|0,e);c=v[d+12>>2];ld(d,a,v[d+8>>2],v[d+12>>2]);f=v[d+4>>2];if((f|0)==(c|0)){hd(a,v[d+12>>2])}jb=d+16|0;a=(c|0)==(f|0);if(!a){eA(e)}if(!a){break a}b=ZQ(w[g+8|0]);break a}b=-1}jb=g+144|0;return b|0}function JF(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=c;while(1){a:{if(e>>>0<=i>>>0|a>>>0>=d>>>0){break a}f=1;b=t[a|0];b:{if((b|0)>=0){break b}if(b>>>0<4294967234){break a}if(b>>>0<=4294967263){if((d-a|0)<2){break a}f=2;if((w[a+1|0]&192)==128){break b}break a}g=b&255;c:{d:{if(b>>>0<=4294967279){if((d-a|0)<3){break a}h=w[a+2|0];b=w[a+1|0];if((g|0)==237){break d}if((g|0)==224){if((b&224)==160){break c}break a}if((b&192)!=128){break a}break c}if((d-a|0)<4|b>>>0>4294967284){break a}f=w[a+3|0];h=w[a+2|0];b=w[a+1|0];e:{f:{switch(g-240|0){case 0:if((b+112&255)>>>0<48){break e}break a;case 4:if((b&240)==128){break e}break a;default:break f}}if((b&192)!=128){break a}}if((h&192)!=128|(f&192)!=128){break a}f=4;if((g<<18&1835008|(b&48)<<12)>>>0>1114111){break a}break b}if((b&224)!=128){break a}}f=3;if((h&192)!=128){break a}}i=i+1|0;a=a+f|0;continue}break}return a-c|0}function Pu(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=jb-560|0;jb=f;u[f+558>>1]=b;a:{if((b-256&65535)>>>0<65281){break a}e=((b<<2)+a|0)+900380|0;b=v[e>>2];b:{if(b){c=vP(f,c);d=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=d;d=w[c+11|0]|w[c+12|0]<<8|(w[c+13|0]<<16|w[c+14|0]<<24);e=w[c+7|0]|w[c+8|0]<<8|(w[c+9|0]<<16|w[c+10|0]<<24);t[b+7|0]=e;t[b+8|0]=e>>>8;t[b+9|0]=e>>>16;t[b+10|0]=e>>>24;t[b+11|0]=d;t[b+12|0]=d>>>8;t[b+13|0]=d>>>16;t[b+14|0]=d>>>24;t[b+15|0]=w[c+15|0];d=v[c+44>>2];v[b+40>>2]=v[c+40>>2];v[b+44>>2]=d;d=v[c+36>>2];v[b+32>>2]=v[c+32>>2];v[b+36>>2]=d;d=v[c+28>>2];v[b+24>>2]=v[c+24>>2];v[b+28>>2]=d;d=v[c+20>>2];v[b+16>>2]=v[c+16>>2];v[b+20>>2]=d;sy(b+48|0,c+48|0);sy(b+68|0,c+68|0);sy(b+88|0,c+88|0);tc(b+108|0,c+108|0,448);d=b;cu(c);break b}b=$s(556);if(!b){v[e>>2]=0;break a}d=vP(b,c);v[e>>2]=d}g=a,h=x[ke(a+480192|0,f+558|0)>>1],u[g+480192>>1]=h}jb=f+560|0;return d|0}function J8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{g=b;c=jb-16|0;jb=c;d=Lb(a);while(1){b:{c:{d:{if(Gb(g)>>>0>f>>>0){b=v[zi(g,f)>>2];if(b>>>0>=2097152){v[23588]=0;R(919,d|0,63);a=v[23588];v[23588]=0;if((a|0)!=1){break c}break b}a=0;while(1){if((a|0)==6){b=7;a=6;break d}e=b&63;t[(c+10|0)+a|0]=e;if(b>>>0>=64){a=a+1|0;b=b>>>6|0;continue}break}if(a){b=a+1|0;if((b|0)!=2){break d}a=1;b=2;if((e|0)!=1){break d}a=w[c+10|0]|64}else{a=w[c+10|0]}v[23588]=0;R(919,d|0,a<<24>>24);a=v[23588];v[23588]=0;if((a|0)!=1){break c}break b}jb=c+16|0;break a}i=(-1<<b^-1)<<7-a;e=b-1|0;j=e+(c+10|0)|0;a=b;while(1){if(!a){break c}e:{if((a|0)==(b|0)){a=w[j|0];v[23588]=0;R(919,d|0,(a|i)<<24>>24);h=v[23588];v[23588]=0;a=e;break e}v[23588]=0;a=a-1|0;R(919,d|0,t[a+(c+10|0)|0]|-128);h=v[23588];v[23588]=0}if((h|0)!=1){continue}break}break b}f=f+1|0;continue}break}a=P()|0;O()|0;zb(d);T(a|0);L()}}function us(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=jb+-64|0;jb=c;b=v[a>>2];a=v[b>>2];d=v[a+4>>2];v[c+40>>2]=v[a+20>>2];e=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=e;Hf(c+48|0,c+32|0,d);a=v[b+4>>2];d=v[a+8>>2];e=v[a+4>>2];b=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=b;b=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=b;v[c+8>>2]=v[a+8>>2];b=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=b;a:{b:{c:{d:{f=v[c+4>>2];if(f>>>0>=e>>>0){if(y[c+20>>2]<e>>>0){break d}if(d>>>0>y[c+8>>2]){break c}g=v[c+28>>2];if(d>>>0>v[c+24>>2]-g>>>0){break b}h=v[c+16>>2];i=v[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}j=b+g|0;k=B(b,f);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{z[v[(a<<2)+h>>2]+(j<<2)>>2]=C(v[(a+k<<2)+i>>2])*C(7.450580596923828e-9);a=a+1|0;continue}}}aa(7192,9005,33,8718);L()}aa(7157,9005,34,8718);L()}aa(5900,9005,35,8718);L()}aa(5870,9005,36,8718);L()}jb=c- -64|0}function Hea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;g=jb-16|0;jb=g;d=v[b>>2];e=lk(d,v[b+4>>2]);a:{if(e>>>0<c>>>0){i=jb-32|0;jb=i;f=c-e|0;e=v[Fb(b)>>2];d=v[b+4>>2];b:{if(f>>>0<=e-d>>4>>>0){h=jb-16|0;jb=h;d=Et(h,b,f);e=v[d+4>>2];f=v[d+8>>2];while(1){if((e|0)==(f|0)){kc(d);jb=h+16|0}else{Du(e);e=e+16|0;v[d+4>>2]=e;continue}break}break b}e=Fb(b);e=fQ(i+8|0,gQ(b,lk(v[b>>2],d)+f|0),lk(v[b>>2],v[b+4>>2]),e);d=jb-16|0;jb=d;v[d>>2]=v[e+8>>2];h=v[e+8>>2];v[d+8>>2]=e+8;v[d+4>>2]=h+(f<<4);f=v[d>>2];while(1){if(v[d+4>>2]!=(f|0)){Du(f);f=v[d>>2]+16|0;v[d>>2]=f;continue}break}Td(d);jb=d+16|0;Dd(b,e);d=v[e+4>>2];f=v[e+8>>2];while(1){if((d|0)!=(f|0)){f=f-16|0;v[e+8>>2]=f;continue}break}d=v[e>>2];if(d){_o(e);Mb(d)}}jb=i+32|0;break a}if(c>>>0<e>>>0){Nd(b,d+(c<<4)|0)}}if(Pb(v[a>>2],v[a+8>>2],c<<4)){c=v[b>>2];fc(g+8|0,c,lk(c,v[b+4>>2])<<4);td(g,a,v[g+8>>2],v[g+12>>2])}jb=g+16|0}function Nba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;l=jb-16|0;jb=l;d=v[ec(l+8|0,Eb(v[a+4>>2]))>>2];i=jb-32|0;jb=i;e=d;d=v[a>>2];h=(yo(e,Eb(d))<<1)+d|0;g=fz(b,c);a:{if((g|0)<=0){break a}e=v[Fb(a)>>2];d=v[a+4>>2];if((g|0)<=e-d>>1){f=d-h|0;j=f>>1;b:{if((j|0)>=(g|0)){e=c;break b}v[i+8>>2]=b;v[i+8>>2]=v[i+8>>2]+(j<<1);e=v[i+8>>2];eP(a,e,c,g-j|0);if((f|0)<=0){break a}}m=jb-16|0;jb=m;j=v[a+4>>2];f=(j-((g<<1)+h|0)|0)+h|0;g=_h(m,a,d-f>>1);k=v[g+4>>2];c=f;while(1){if(c>>>0>=d>>>0){kc(g);Aq(h,f,j);jb=m+16|0}else{Mi(k,x[c>>1]);k=k+2|0;v[g+4>>2]=k;c=c+2|0;continue}break}_n(b,e,h);break a}f=Fb(a);f=Mj(i+8|0,Nj(a,Qc(v[a>>2],d)+g|0),h-v[a>>2]>>1,f);d=jb-16|0;jb=d;e=No(d,f+8|0,fz(b,c));c=v[e>>2];while(1){if(v[e+4>>2]!=(c|0)){Mi(c,x[b>>1]);c=v[e>>2]+2|0;v[e>>2]=c;b=b+2|0;continue}break}Td(e);jb=d+16|0;h=jP(a,f,h);Ni(f)}Eb(h);jb=i+32|0;jb=l+16|0;return a|0}function LW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-96|0;jb=d;yc(b);Wo(a);a:{if(!wv(b,d+56|0)){break a}if(!kD(d+56|0)){break a}b:{if(!c){break b}if(!Pb(v[b>>2],v[b+8>>2],bc(v[d+60>>2])-28|0)){break a}Mv(a);g=d,h=Lv(),v[g+32>>2]=h;e=d+32|0;Kv(Tj(v[a+4>>2])+32|0,e);rr(e);c=v[Tj(v[a+4>>2])+32>>2];v[23588]=0;R(191,e|0,b|0);b=v[23588];v[23588]=0;c:{if((b|0)==1){break c}b=v[d+32>>2];e=v[d+60>>2];f=v[d+68>>2];v[23588]=0;b=fa(192,b|0,bc(e)-28|0,c|0,bc(f)|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break c}e=0;if(!b){break a}re(d+16|0,v[c>>2],v[c+4>>2]);_g(d+24|0,v[d+16>>2],v[d+20>>2]);b=ee(d+8|0);c=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=c;b=pr(d+32|0,v[d+24>>2],v[d+28>>2],d);gd(Tj(v[a+4>>2])+12|0,b);Ab(b);break b}a=Da(92948,26056)|0;b=O()|0;d:{if((da(92948)|0)==(b|0)){break d}if((da(26056)|0)==(b|0)){break d}T(a|0);L()}_(a|0)|0;$();e=0;break a}e=1}jb=d+96|0;return e|0}function jca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=jb-16|0;jb=e;v[e+12>>2]=1;a:{if(ko(a)){c=v[a>>2];j=qg(c,v[a+4>>2]);v[e+8>>2]=j;k=v[Jb(e+12|0,e+8|0)>>2];while(1){if(k){k=k-1|0;if((b|0)!=(c|0)){f=Eb(v[b>>2]);g=Eb(v[b+4>>2]);d=jb-16|0;jb=d;h=HB(f,g);b:{if(h>>>0<=Xm(c)>>>0){v[d+8>>2]=g;l=v[c>>2];i=Qc(l,v[c+4>>2]);m=i>>>0>=h>>>0;if(m){i=g}else{v[d+8>>2]=f;lP(d+8|0,i);i=v[d+8>>2]}f=Pi(f,i,l);if(!m){nP(c,v[d+8>>2],g,h-Qc(v[c>>2],v[c+4>>2])|0);break b}Nd(c,f);break b}mP(c);hq(c,Nj(c,h));nP(c,f,g,h)}jb=d+16|0;Yo(c+12|0,b+12|0);u[c+28>>1]=x[b+28>>1]}c=c+32|0;continue}break}if(!j){yz(a,1-j|0,b);break a}fP(a,v[a>>2]+32|0);break a}if(v[a>>2]){hP(a);c=v[a>>2];ko(a);Mb(c);n=Fb(a),o=0,v[n>>2]=o;v[a>>2]=0;v[a+4>>2]=0}c=cq(a,1);if(sh(134217727)>>>0<c>>>0){bd();L()}d=$P(c);v[a>>2]=d;v[a+4>>2]=d;n=Fb(a),o=d+(c<<5)|0,v[n>>2]=o;yz(a,1,b)}jb=e+16|0}function oF(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;g=jb-32|0;jb=g;f=d&2147483647;e=f-1065418752|0;h=f-1082064896|0;a:{if((e|0)==(h|0)&0|e>>>0<h>>>0){f=(d&33554431)<<7|c>>>25;e=0;i=e;h=c&33554431;if(!(!e&(h|0)==16777216?!(a|b):!e&h>>>0<16777216)){e=f+1073741825|0;break a}e=f+1073741824|0;if(h^16777216|a|(b|i)){break a}e=(f&1)+e|0;break a}if(!(!c&(f|0)==2147418112?!(a|b):f>>>0<2147418112)){e=((d&33554431)<<7|c>>>25)&4194303|2143289344;break a}e=2139095040;if(f>>>0>1082064895){break a}e=0;f=f>>>16|0;if(f>>>0<16145){break a}e=d&65535|65536;Kf(g+16|0,a,b,c,e,f-16129|0);Em(g,a,b,c,e,16257-f|0);b=v[g+8>>2];e=(v[g+12>>2]&33554431)<<7|b>>>25;h=v[g>>2]|(v[g+16>>2]|v[g+24>>2]|(v[g+20>>2]|v[g+28>>2]))!=0;f=v[g+4>>2];a=0;b=b&33554431;if(!(!a&(b|0)==16777216?!(h|f):!a&b>>>0<16777216)){e=e+1|0;break a}if(b^16777216|h|(a|f)){break a}e=(e&1)+e|0}jb=g+32|0;return l(2,d&-2147483648|e),q()}function am(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;v[a+4>>2]=0;if(Pd(w[fm(d+8|0,a,1)|0])){a:{b:{c:{if((b|0)==2147483647){while(1){b=v[(v[v[a>>2]-12>>2]+a|0)+24>>2];v[23588]=0;b=S(104,b|0)|0;c=v[23588];v[23588]=0;d:{if((c|0)!=1){if(!oc(b,-1)){break d}break b}break c}v[a+4>>2]=v[a+4>>2]+1;continue}}if(v[a+4>>2]>=(b|0)){break a}e:{while(1){c=v[(v[v[a>>2]-12>>2]+a|0)+24>>2];v[23588]=0;c=S(104,c|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break e}if(oc(c,-1)){break b}c=v[a+4>>2]+1|0;v[a+4>>2]=c;if((b|0)>(c|0)){continue}break}c=0;break a}}b=V(0)|0;O()|0;_(b|0)|0;c=1;dm(v[v[a>>2]-12>>2]+a|0,1);f:{g:{if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[23588]=0;Z(105);a=v[23588];v[23588]=0;if((a|0)!=1){break f}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)==1){break g}T(a|0);L()}$();break a}V(0)|0;O()|0;Ub()}L()}c=2}Ki(v[v[a>>2]-12>>2]+a|0,c)}jb=d+16|0;return a|0}function _9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=v[a>>2];d=xk(e,v[a+4>>2]);if(d>>>0<b>>>0){h=jb-32|0;jb=h;a:{b:{e=b-d|0;b=v[Fb(a)>>2];f=v[a+4>>2];c:{if(e>>>0<=(b-f|0)/52>>>0){Zx(a,e,c);break c}d=Fb(a);f=SL(a,xk(v[a>>2],f)+e|0);g=xk(v[a>>2],v[a+4>>2]);b=h+8|0;og(b+12|0,d);if(f){d=RL(f)}else{d=0}v[b>>2]=d;g=d+B(g,52)|0;v[b+8>>2]=g;v[b+4>>2]=g;i=Bc(b),j=d+B(f,52)|0,v[i>>2]=j;v[23588]=0;U(879,b|0,e|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break b}f=v[a>>2];c=v[a+4>>2];e=b+4|0;while(1){if((c|0)!=(f|0)){c=c-52|0;d=vl(v[e>>2]-52|0,c);v[d+20>>2]=v[c+20>>2];g=v[c+16>>2];v[d+12>>2]=v[c+12>>2];v[d+16>>2]=g;BQ(d+24|0,c+24|0);$c(d+36|0,c+36|0);v[d+48>>2]=v[c+48>>2];v[e>>2]=v[e>>2]-52;continue}break}pc(a,e);pc(a+4|0,b+8|0);pc(Fb(a),Bc(b));v[b>>2]=v[b+4>>2];QL(b)}jb=h+32|0;break a}a=P()|0;O()|0;QL(b);T(a|0);L()}return}if(b>>>0<d>>>0){TL(a,e+B(b,52)|0)}}function Rga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=jb-16|0;jb=e;u[e+12>>1]=0;v[e+8>>2]=0;n=B(c,d);k=4;a:while(1){if((d|0)!=(l|0)){i=b+l|0;o=n+i|0;while(1){b:{c:{if(i>>>0<o>>>0){t[e+7|0]=0;oS(a,e+15|0,e+12|0,e+7|0);g=w[e+7|0];f=x[e+12>>1];c=k;while(1){if(c&255){h=f<<1;f=h&254;d:{if(f){h=(h&65534)>>>0>255;break d}if(!nf(a,e+6|0)){break c}f=w[e+6|0];h=f>>>7|0;f=f<<1&254|1}c=c-1|0;g=g<<1|h;continue}break}u[e+12>>1]=f;break b}l=l+1|0;continue a}u[e+12>>1]=0}c=1;h=g&255;e:{if(h>>>0<4){break e}f=7;while(1){c=f;m=f&255;if(h>>>m&1){break e}f=c-1|0;if(m>>>0>1){continue}break}}f=g&1;t[e+15|0]=f;g=f-1^(g&254)>>>1;f=g+w[e+8|0]|0;t[e+7|0]=f;t[i|0]=f;v[e+8>>2]=((g>>1)-(j<<24>>24)|0)+(f<<24>>24<<1);i=d+i|0;k=(c+k&254)>>>1|0;c=-128;j=v[e+8>>2];f:{if((j|0)>=-128){c=127;if((j|0)<128){break f}}v[e+8>>2]=c}j=f;continue}}break}jb=e+16|0}function Qca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0;e=jb-16|0;jb=e;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];f=v[a+4>>2];v[e+8>>2]=v[a>>2];v[e+12>>2]=f;j=b+24|0;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){f=v[e+8>>2];m=((((v[e+12>>2]&2147483647)<<1|f>>>31)&2147483646)<<1)+i|0;b=(((f>>>16|0)+4&131064)<<1)+j|0;n=u[b+14>>1];o=u[b+12>>1];p=u[b+10>>1];q=u[b+8>>1];r=u[b+6>>1];s=u[b+4>>1];t=u[b+2>>1];w=u[b>>1];f=0;while(1){if((f|0)!=2){b=(f<<1)+m|0;v[(f<<2)+e>>2]=(((((B(u[b+8>>1],p)+B(u[b+4>>1],q)|0)+B(u[b+12>>1],o)|0)+B(u[b+16>>1],n)|0)/2|0)+((((B(u[b-8>>1],t)+B(u[b-12>>1],w)|0)+B(u[b-4>>1],s)|0)+B(u[b>>1],r)|0)/2|0)|0)/16384;f=f+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[e>>2],h);v[c+4>>2]=v[c+4>>2]+B(v[e+4>>2],g);Qb(e+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}b=v[e+12>>2];v[a>>2]=v[e+8>>2];v[a+4>>2]=b;jb=e+16|0}function NN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{g=b;c=jb-16|0;jb=c;d=Lb(a);while(1){b:{c:{d:{if(Gb(g)>>>0>f>>>0){b=v[zi(g,f)>>2];if(b>>>0>=2097152){v[23588]=0;R(51,d|0,63);a=v[23588];v[23588]=0;if((a|0)!=1){break c}break b}a=0;while(1){if((a|0)==6){b=7;a=6;break d}e=b&63;t[(c+10|0)+a|0]=e;if(b>>>0>=64){a=a+1|0;b=b>>>6|0;continue}break}if(a){b=a+1|0;if((b|0)!=2){break d}a=1;b=2;if((e|0)!=1){break d}a=w[c+10|0]|64}else{a=w[c+10|0]}v[23588]=0;R(51,d|0,a&255);a=v[23588];v[23588]=0;if((a|0)!=1){break c}break b}jb=c+16|0;break a}i=(-1<<b^-1)<<7-a;e=b-1|0;j=e+(c+10|0)|0;a=b;while(1){if(!a){break c}e:{if((a|0)==(b|0)){a=w[j|0];v[23588]=0;R(51,d|0,a|i&255);h=v[23588];v[23588]=0;a=e;break e}v[23588]=0;a=a-1|0;R(51,d|0,w[a+(c+10|0)|0]|128);h=v[23588];v[23588]=0}if((h|0)!=1){continue}break}break b}f=f+1|0;continue}break}a=P()|0;O()|0;zb(d);T(a|0);L()}}function j7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0),m=0,n=0,o=C(0),p=C(0),q=C(0),r=C(0),s=C(0),t=C(0),u=C(0),w=C(0),x=C(0);h=jb-16|0;jb=h;if($h(a+44|0)){f=v[a+44>>2];g=Jc(f,0);v[h+8>>2]=g;f=Jc(f,1);v[h+12>>2]=f;j=v[a+56>>2];m=Jc(j,0);v[h>>2]=m;j=Jc(j,1);v[h+4>>2]=j;a:{if(z[Db(a+4208|0,2)>>2]!=C(.5)){f=d;b:while(1){g=0;if(!f){break a}while(1)if((g|0)==2){f=f-1|0;continue b}else{k=g<<2;e=k+(h+8|0)|0;i=v[e>>2];v[e>>2]=i+4;e=a+k|0;n=e+4248|0;q=z[n>>2];l=z[i>>2];r=z[a+4236>>2];s=z[a+4232>>2];t=z[a+4228>>2];u=z[a+4220>>2];w=z[a+4224>>2];i=e+4240|0;o=z[i>>2];z[n>>2]=o;z[i>>2]=l;i=e+4264|0;x=z[i>>2];e=e+4256|0;p=z[e>>2];z[i>>2]=p;l=C(C(C(C(t*q)+C(C(u*l)+C(w*o)))-C(s*p))-C(r*x));z[e>>2]=l;k=h+k|0;e=v[k>>2];v[k>>2]=e+4;z[e>>2]=l;g=g+1|0;continue}}}e=g;g=d<<2;tc(m,e,g);tc(j,f,g);f=v[a+56>>2];m=Jc(f,0);j=Jc(f,1)}ri(a,b,c,m,j,d)}jb=h+16|0}function gfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=v[a>>2];c=xd(d,v[a+4>>2]);if(c>>>0<b>>>0){f=jb-32|0;jb=f;c=b-c|0;b=v[Fb(a)>>2];d=v[a+4>>2];a:{if(c>>>0<=(b-d|0)/12>>>0){d=jb-16|0;jb=d;b=Pt(d,a,c);a=v[b+4>>2];c=v[b+8>>2];while(1){if((a|0)==(c|0)){kc(b);jb=d+16|0}else{DQ(a);a=a+12|0;v[b+4>>2]=a;continue}break}break a}b=Fb(a);b=Hk(f+8|0,jn(a,xd(v[a>>2],d)+c|0),xd(v[a>>2],v[a+4>>2]),b);e=jb-16|0;jb=e;d=CQ(e,b+8|0,c);c=v[d>>2];while(1){if(v[d+4>>2]!=(c|0)){DQ(c);c=v[d>>2]+12|0;v[d>>2]=c;continue}break}Td(d);jb=e+16|0;e=v[a>>2];c=v[a+4>>2];d=b+4|0;while(1){if((c|0)!=(e|0)){c=c-12|0;BQ(v[d>>2]-12|0,c);v[d>>2]=v[d>>2]-12;continue}break}pc(a,d);pc(a+4|0,b+8|0);pc(Fb(a),Bc(b));v[b>>2]=v[b+4>>2];a=v[b+4>>2];while(1){c=v[b+8>>2];if((c|0)!=(a|0)){c=c-12|0;v[b+8>>2]=c;EQ(c);continue}break}a=v[b>>2];if(a){_o(b);Mb(a)}}jb=f+32|0;return}if(b>>>0<c>>>0){FQ(a,d+B(b,12)|0)}}function rba(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=jb-16|0;jb=f;b=v[a+4>>2];if(Pd(w[b+223884|0])){cO(b+223860|0);b=v[a+4>>2]}v[a+24>>2]=0;v[a+28>>2]=0;v[b>>2]=0;c=v[a>>2];v[b+40>>2]=v[c+480196>>2];v[b+44>>2]=v[c+480204>>2];v[b+80>>2]=v[c+480200>>2];c=x[c+480188>>1];v[f+8>>2]=0;v[f+12>>2]=0;d=f+8|0;u[d+4>>1]=65280;v[d>>2]=0;e=jb-16|0;jb=e;v[e+12>>2]=c;b=a+8|0;a:{if(gn(b)>>>0>=c>>>0){g=v[b>>2];h=Ug(g,v[b+4>>2]);v[e+8>>2]=h;i=v[Jb(e+12|0,e+8|0)>>2];while(1){if(i){v[g>>2]=v[d>>2];u[g+4>>1]=x[d+4>>1];i=i-1|0;g=g+8|0;continue}break}if(c>>>0>h>>>0){mN(b,c-h|0,d);break a}Nd(b,v[b>>2]+(c<<3)|0);break a}vO(b);mz(b,nr(b,c));mN(b,c,d)}jb=e+16|0;b=0;while(1){c=v[a>>2];if(x[c+480188>>1]<=b>>>0){jb=f+16|0}else{d=B(b,872);eo((d+v[a+4>>2]|0)+616|0,c,b&65535,134217728);c=d+v[a+4>>2]|0;u[c+1432>>1]=0;t[c+1418|0]=0;t[c+1415|0]=0;t[c+1413|0]=0;b=b+1|0;continue}break}}function uw(a,b,c,d,e,f,g,h,i,j,k,l){a:{b:{if((a|0)==(f|0)){if(!w[b|0]){break a}f=0;t[b|0]=0;a=v[e>>2];v[e>>2]=a+1;t[a|0]=46;if(!Gb(h)){break b}a=v[j>>2];if((a-i|0)>159){break b}b=v[k>>2];v[j>>2]=a+4;v[a>>2]=b;return 0}c:{if((a|0)!=(g|0)){break c}if(!Gb(h)){break c}if(!w[b|0]){break a}f=0;a=v[j>>2];if((a-i|0)>159){break b}b=v[k>>2];v[j>>2]=a+4;v[a>>2]=b;v[k>>2]=0;return 0}f=-1;a=ww(l,l+128|0,a)-l|0;if((a|0)>124){break b}g=w[(a>>2)+82976|0];d:{e:{f=a&-5;if((f|0)!=88){if((f|0)!=96){break e}a=v[e>>2];if((a|0)!=(d|0)){f=-1;if((w[a-1|0]&95)!=(w[c|0]&127)){break b}}v[e>>2]=a+1;t[a|0]=g;return 0}t[c|0]=80;break d}d=g&95;if((d|0)!=w[c|0]){break d}t[c|0]=d|128;if(!w[b|0]){break d}t[b|0]=0;if(!Gb(h)){break d}b=v[j>>2];if((b-i|0)>159){break d}c=v[k>>2];v[j>>2]=b+4;v[b>>2]=c}b=v[e>>2];v[e>>2]=b+1;t[b|0]=g;f=0;if((a|0)>84){break b}v[k>>2]=v[k>>2]+1}return f}return-1}function c3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=jb+-64|0;jb=c;b=v[a>>2];a=v[b>>2];d=v[a+4>>2];v[c+40>>2]=v[a+20>>2];e=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=e;Hf(c+48|0,c+32|0,d);a=v[b+4>>2];d=v[a+8>>2];e=v[a+4>>2];b=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=b;b=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=b;v[c+8>>2]=v[a+8>>2];b=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=b;a:{b:{c:{d:{f=v[c+4>>2];if(f>>>0>=e>>>0){g=v[c+20>>2];if(g>>>0<e>>>0){break d}if(d>>>0>y[c+8>>2]){break c}h=v[c+28>>2];if(d>>>0>v[c+24>>2]-h>>>0){break b}i=v[c+16>>2];j=v[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}k=B(b,f);l=B(b+h|0,g);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{z[(a+l<<2)+i>>2]=A[(a+k<<3)+j>>3];a=a+1|0;continue}}}aa(7192,9005,77,8685);L()}aa(7157,9005,78,8685);L()}aa(5900,9005,79,8685);L()}aa(5870,9005,80,8685);L()}jb=c- -64|0}function CP(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=jb-16|0;jb=g;b=v[a>>2];ec(g+8|0,b);a:{b:{c:{d:{e:{if(Ed(v[b+16>>2])){while(1){if(c>>>0>31){break e}v[23588]=0;d=ga(43)|0;e=v[23588];v[23588]=0;if((e|0)!=1){f=d|f;c=c+32|0;continue}break}c=V(93532)|0;if((O()|0)!=(da(93532)|0)){break c}_(c|0)|0;t[b+20|0]=0;v[23588]=0;Y(31,b|0);c=v[23588];v[23588]=0;if((c|0)==1){break d}$();break e}t[b+20|0]=0}if(!w[b+20|0]){d=v[b+24>>2];b=0;c=1;while(1){if(c){c=0;b=v[d+2496>>2];e=d+(b<<2)|0;i=v[d+((b+397>>>0)%624<<2)>>2];h=(b+1>>>0)%624|0;b=v[d+(h<<2)>>2];b=i^(b&2147483647|v[e>>2]&-2147483648)>>>1^0-(b&1)&-1727483681;v[e>>2]=b;v[d+2496>>2]=h;b=b^b>>>11;b=b<<7&-1658038656^b;b=b<<15&-272236544^b;b=b>>>18^b;continue}break}f=b^f}jb=g+16|0;break a}c=P()|0;O()|0;v[23588]=0;Z(18);a=v[23588];v[23588]=0;if((a|0)==1){break b}}T(c|0);L()}V(0)|0;O()|0;Ub();L()}return v[a+28>>2]&f}function jA(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;i=jb-32|0;jb=i;$R(a,b);h=jb-16|0;jb=h;md(c,1);g=Hb(w[b+22|0]|w[b+23|0]<<8)<<1;v[c>>2]=g;t[c+37|0]=w[b+24|0]<<4;t[h+15|0]=w[b+25|0];t[h+14|0]=64;l=c,m=w[Wb(h+15|0,h+14|0)|0]<<2,u[l+30>>1]=m;f=Hb(w[b+26|0]|w[b+27|0]<<8);a=f<<1;k=Hb(w[b+28|0]|w[b+29|0]<<8);j=k<<1;a=k>>>0>=2?a+j>>>0<=g>>>0?a:f+j>>>0>g>>>0?a:f:a;a:{b:{switch(g|0){case 2:v[c>>2]=0;break a;case 0:break a;default:break b}}v[c+4>>2]=a;f=a+j|0;v[c+8>>2]=f;if(a>>>0>=g>>>0){a=g-1|0;v[c+4>>2]=a}if(!(!(f>>>0<4|a>>>0>f>>>0)&f-a>>>0>3)){v[c+4>>2]=0;v[c+8>>2]=0;f=0;a=0}if(!(f>>>0>8|a|(!e|f>>>0>=g>>>0))){v[c+8>>2]=0;break a}if(a>>>0>=f>>>0){break a}u[c+34>>1]=x[c+34>>1]|2}jb=h+16|0;Hl(i,3,b);a=i+16|0;Ec(a,i);c=Cc(d,a);yb(a);a=0;while(1){if((a|0)!=32){d=a+c|0;if((w[d|0]-1&255)>>>0<=30){t[d|0]=32}a=a+1|0;continue}break}a=mA(b);jb=i+32|0;return a}function XE(a,b,c,d,e,f,g,h){var i=0,j=0,k=C(0);i=jb-96|0;jb=i;qy(v[a+24>>2]);t[v[a+24>>2]+1298420|0]=v[a+52>>2]!=0;v[i+92>>2]=f;v[i+88>>2]=e;v[i+84>>2]=d;v[i+80>>2]=c;a:{d=i+80|0;c=0;while(1){b:{if((c|0)!=4){if(v[(c<<2)+d>>2]){break b}}else{c=4}break a}c=c+1|0;continue}}v[i+40>>2]=b;v[i+36>>2]=c;v[i+32>>2]=d;e=v[a+32>>2];k=z[a+48>>2];v[i+8>>2]=b;c=v[i+36>>2];v[i>>2]=v[i+32>>2];v[i+4>>2]=c;d=jb-16|0;jb=d;v[d+8>>2]=v[i+8>>2];c=v[i+4>>2];v[d>>2]=v[i>>2];v[d+4>>2]=c;c=vJ(i+48|0);v[c+8>>2]=e;v[c+4>>2]=0;v[c>>2]=h;e=v[d+4>>2];v[c+12>>2]=v[d>>2];v[c+16>>2]=e;v[c+20>>2]=v[d+8>>2];z[c+24>>2]=k;v[c>>2]=g;jb=d+16|0;while(1){if(b){d=v[a+24>>2];v[i+24>>2]=b;v[i+28>>2]=0;v[i+16>>2]=134217727;v[i+20>>2]=0;d=yJ(d,v[Yq(i+24|0,i+16|0)>>2],c);j=d+j|0;b=b-d|0;if(d){continue}}break}if(!(v[a+52>>2]!=1|j)){a=v[a+24>>2];v[a+480208>>2]=v[a+480208>>2]&-513}jb=i+96|0;return j}function QX(){var a=0,b=0,c=0,d=0;c=jb-32|0;jb=c;a:{a=Mc(c+16|0,15351);if(!Gb(a)){break a}b:{if((Dg(a,14600)|0)!=-1){b=Dg(a,14600);v[23588]=0;X(130,c|0,a|0,b+1|0,-1);b=v[23588];v[23588]=0;if((b|0)==1){break b}Ac(a,c);yb(c)}if((Dg(a,16764)|0)!=-1){b=Dg(a,16764);v[23588]=0;X(130,c|0,a|0,b+1|0,-1);b=v[23588];v[23588]=0;if((b|0)==1){break b}Ac(a,c);yb(c)}if((Dg(a,13813)|0)!=-1){b=Dg(a,13813);v[23588]=0;X(130,c|0,a|0,0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break b}Ac(a,c);yb(c)}if((Dg(a,13662)|0)!=-1){b=Dg(a,13662);v[23588]=0;X(130,c|0,a|0,0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break b}Ac(a,c);yb(c)}if((Dg(a,13705)|0)!=-1){b=Dg(a,13705);v[23588]=0;X(130,c|0,a|0,0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break b}Ac(a,c);yb(c)}v[23588]=0;b=S(131,a|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){break a}}c=P()|0;O()|0;yb(a);T(c|0);L()}yb(a);jb=c+32|0;return b|0}function l3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=jb+-64|0;jb=c;b=v[a>>2];a=v[b>>2];d=v[a+4>>2];v[c+40>>2]=v[a+20>>2];e=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=e;Hf(c+48|0,c+32|0,d);a=v[b+4>>2];d=v[a+8>>2];e=v[a+4>>2];b=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=b;b=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=b;v[c+8>>2]=v[a+8>>2];b=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=b;a:{b:{c:{d:{f=v[c+4>>2];if(f>>>0>=e>>>0){if(y[c+20>>2]<e>>>0){break d}if(d>>>0>y[c+8>>2]){break c}g=v[c+28>>2];if(d>>>0>v[c+24>>2]-g>>>0){break b}h=v[c+16>>2];i=v[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}j=b+g|0;k=B(b,f);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{z[v[(a<<2)+h>>2]+(j<<2)>>2]=A[(a+k<<3)+i>>3];a=a+1|0;continue}}}aa(7192,9005,77,8685);L()}aa(7157,9005,78,8685);L()}aa(5900,9005,79,8685);L()}aa(5870,9005,80,8685);L()}jb=c- -64|0}function hm(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;$k(a);a:{b:{c:{f=v[b+32>>2];d:{if(!f){e=v[b+2084>>2];if(e){break d}break b}c=v[b+4>>2];if((c|0)<9){break c}e=v[b+2084>>2];if(!e){break c}}h=v[a+1392>>2];j=gm(h);d=v[b+2092>>2];c=0;while(1){if((d|0)>=2){f=d>>>1|0;i=f+c|0;g=y[(i<<2)+e>>2]>j>>>0;d=g?f:d-f|0;c=g?c:i;continue}break}d=v[a+1396>>2];c=w[b+23|0]?c:v[v[b+2088>>2]+(c<<2)>>2];b=w[c+v[b+8>>2]|0];e:{if((d|0)<(b|0)){c=-1;b=0;break e}v[a+1392>>2]=h>>>b;b=d-b|0}v[a+1396>>2]=b;return c}if(w[b+23|0]){break a}e=(c|0)>0?c:0;while(1){if((d|0)!=(e|0)){f:{c=w[v[b+8>>2]+d|0];if((c|0)==255){break f}g=v[a+1392>>2];if(v[f+(d<<2)>>2]!=(g&(-1<<c^-1))){break f}e=v[a+1396>>2];if((e|0)>=(c|0)){v[a+1392>>2]=g>>>c;v[a+1396>>2]=e-w[v[b+8>>2]+d|0];return d}v[a+1396>>2]=0;break b}d=d+1|0;continue}break}dc(a,21);v[a+1396>>2]=0}return-1}aa(11298,13110,1705,5448);L()}function Fw(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=a;a:{if(b&3){while(1){c=w[b|0];if(!c|(c|0)==61){break a}b=b+1|0;if(b&3){continue}break}}c=v[b>>2];b:{if((c^-1)&c-16843009&-2139062144){break b}while(1){if((c^1027423549)-16843009&(c^-1)&-2139062144){break b}c=v[b+4>>2];b=b+4|0;if(!(c-16843009&(c^-1)&-2139062144)){continue}break}}while(1){c=b;e=w[b|0];if((e|0)!=61){b=c+1|0;if(e){continue}}break}b=c}if((a|0)==(b|0)){return 0}g=b-a|0;c:{if(w[g+a|0]){break c}f=v[117002];if(!f){break c}b=v[f>>2];if(!b){break c}while(1){d:{c=a;e=b;i=0;h=g;d=0;e:{if(!g){break e}d=w[c|0];f:{if(!d){break f}while(1){g:{j=w[e|0];if(!j){break g}h=h-1|0;if(!h|(d|0)!=(j|0)){break g}e=e+1|0;d=w[c+1|0];c=c+1|0;if(d){continue}break f}break}i=d}d=(i&255)-w[e|0]|0}if(!d){b=b+g|0;if(w[b|0]==61){break d}}b=v[f+4>>2];f=f+4|0;if(b){continue}break c}break}k=b+1|0}return k}function Rca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0;e=jb-16|0;jb=e;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];f=v[a+4>>2];v[e+8>>2]=v[a>>2];v[e+12>>2]=f;j=b+24|0;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){f=v[e+8>>2];m=(((v[e+12>>2]&2147483647)<<1|f>>>31)&-2)+i|0;b=(((f>>>16|0)+4&131064)<<1)+j|0;n=u[b+14>>1];o=u[b+12>>1];p=u[b+10>>1];q=u[b+8>>1];r=u[b+6>>1];s=u[b+4>>1];w=u[b+2>>1];x=u[b>>1];f=0;while(1){if((f|0)!=2){b=f+m|0;v[(f<<2)+e>>2]=(((((B(t[b+4|0],p)+B(t[b+2|0],q)|0)+B(t[b+6|0],o)|0)+B(t[b+8|0],n)<<8)/2|0)+((((B(t[b-4|0],w)+B(t[b-6|0],x)|0)+B(t[b-2|0],s)|0)+B(t[b|0],r)<<8)/2|0)|0)/16384;f=f+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[e>>2],h);v[c+4>>2]=v[c+4>>2]+B(v[e+4>>2],g);Qb(e+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}b=v[e+12>>2];v[a>>2]=v[e+8>>2];v[a+4>>2]=b;jb=e+16|0}function qea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=jb-32|0;jb=g;d=jb-16|0;jb=d;c=a+33|0;v[b>>2]=w[c+206|0]|w[c+207|0]<<8;dM(c,b+48|0,w[c+192|0],w[c+200|0],w[c+194|0],w[c+195|0],w[c+196|0],0);dM(c,b+68|0,w[c+193|0],w[c+201|0],w[c+197|0],w[c+198|0],w[c+199|0],1);f=b+236|0;while(1){if((e|0)==96){if(w[c+208|0]){t[b+31|0]=w[c+209|0]+1;f=w[b+31|0];a:{b:{if(!f){e=1;break b}e=16;if(f>>>0<17){break a}}t[b+31|0]=e}u[d+14>>1]=w[c+210|0]|w[c+211|0]<<8;u[d+12>>1]=127;i=b,j=w[Vc(d+14|0,d+12|0)|0]+1|0,t[i+30|0]=j}t[b+33|0]=w[c+212|0];jb=d+16|0}else{i=cc(f,e+12|0),j=w[c+e|0],u[i>>1]=j;e=e+1|0;continue}break}e=b+236|0;while(1){if((h|0)!=96){f=cc(e,h+12|0);d=w[c+h|0];u[f>>1]=d>>>0<(w[a+27|0]|w[a+28|0]<<8)>>>0?d:0;h=h+1|0;continue}break}Hl(g,3,a+4|0);c=g+16|0;Ec(c,g);Cc(b+492|0,c);yb(c);if(!w[a+241|0]){t[b+30|0]=w[a+26|0]}jb=g+32|0}function pQ(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0;f=jb-16|0;jb=f;n=v[a+20>>2];g=x[a+34>>1]&65;v[f+8>>2]=g;v[f>>2]=g^65;g=b;i=a+24|0;o=d+1298224|0;e=d+1074992|0;j=nj(d);p=a+4|0;q=a+12|0;r=a+8|0;s=a+16|0;t=d+480180|0;while(1){if((e|0)!=(o|0)){if(v[e+104>>2]==(a|0)){if(v[e+16>>2]){v[e+16>>2]=g}if(y[e+4>>2]>c>>>0){v[e>>2]=0;v[e+4>>2]=0}b=a;if(v[e+76>>2]){wc(e+76|0,c);b=v[e+104>>2]}d=v[e+88>>2];b=gD(d,b);h=v[(b?q:p)>>2];v[e+84>>2]=v[(b?s:r)>>2];v[e+80>>2]=h;b=d|v[f+8>>2];v[e+88>>2]=b;v[e+88>>2]=b&(v[f>>2]^-1);b=e+704|0;h=v[a+24>>2];a:{if(!v[e+704>>2]|!h){break a}if(Jm(v[t>>2])){break a}d=v[(j?b:i)>>2];k=Lka(v[(j?i:b)>>2],0,v[e+700>>2],0);l=k+(d>>>1|0)|0;m=mb;u=e,w=Dc(Oka(l,k>>>0>l>>>0?m+1|0:m,d,0),mb),v[u+700>>2]=w}v[b>>2]=h}e=e+872|0;continue}break}v[a>>2]=c;v[a+20>>2]=g;Cz(n);jb=f+16|0}function aD(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=jb-32|0;jb=c;v[23588]=0;e=Q(13,c+24|0,467480)|0;d=v[23588];v[23588]=0;a:{b:{c:{if((d|0)!=1){d:{e:{if(!w[e|0]){break e}f=Rm(c+8|0,467480);d=v[v[116870]-12>>2]+467480|0;g=v[d+4>>2];v[23588]=0;h=S(14,d|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break d}f=v[f>>2];v[23588]=0;b=a+b|0;a=ka(15,f|0,a|0,((g&176)==32?b:a)|0,b|0,d|0,h|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break d}v[c+16>>2]=a;if(!_u(c+16|0)){break e}a=v[v[116870]-12>>2];v[23588]=0;R(16,a+467480|0,5);a=v[23588];v[23588]=0;if((a|0)!=1){break e}break d}yk(e);break b}a=V(0)|0;O()|0;yk(e);break c}a=V(0)|0;O()|0}_(a|0)|0;a=v[v[116870]-12>>2];v[23588]=0;Y(17,a+467480|0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$()}jb=c+32|0;return}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)==1){V(0)|0;O()|0;Ub();L()}T(a|0);L()}function TB(a){var b=0,c=0,d=0,e=0,f=0,g=0;if((w[a|0]-16&255)>>>0>=241){e=a+1954|0;c=a+1698|0;a:{b:{while(1){if((c|0)==(e|0)){c=0;e=0;while(1){b=32;if((c|0)==32){break a}d=B(c,13)+a|0;if(w[d+14|0]){break b}b=(c<<4)+a|0;if(w[b+418|0]|w[b+419|0]<<8|(w[b+420|0]<<16|w[b+421|0]<<24)){break b}f=w[b+422|0]|w[b+423|0]<<8|(w[b+424|0]<<16|w[b+425|0]<<24);if(w[d+942|0]|f>>>0>1048575){break b}d=B(c,11)+a|0;g=d+1346|0;if(w[g|0]>15|w[d+1351|0]>3|w[d+1356|0]>3){break b}c:{d:{if(f){d=w[b+430|0]|w[b+431|0]<<8|(w[b+432|0]<<16|w[b+433|0]<<24);if(d>>>0<=1048574&(d>>>0<(w[b+426|0]|w[b+427|0]<<8|(w[b+428|0]<<16|w[b+429|0]<<24))>>>0|d>>>0>f>>>0)){break b}b=1;if(e){break c}break d}b=1;if(e){break c}if(Rb(g,26253,11)){break d}b=0;break c}b=1}e=b;c=c+1|0;continue}}b=t[c|0];c=c+1|0;if((b|0)>=-1){continue}break}return 0}b=c}a=b>>>0>31&e}else{a=0}return a}function Kaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-32|0;jb=d;e=Lb(d+16|0);a:{b:{c:{if(c>>>0<64){break c}v[23588]=0;c=S(189,b|0)|0;f=v[23588];v[23588]=0;d:{if((f|0)!=1){v[d+12>>2]=c;if((c|0)>0){break d}v[23588]=0;Q(55,a|0,21619)|0;a=v[23588];v[23588]=0;if((a|0)!=1){break b}}break a}v[23588]=0;c=S(202,b|0)|0;f=v[23588];v[23588]=0;if((f|0)!=1){g=d,h=Ei(c),v[g+8>>2]=h;c=v[sd(d+12|0,d+8|0)>>2];v[23588]=0;R(46,e|0,c|0);c=v[23588];v[23588]=0;if((c|0)!=1){break c}}break a}e:{while(1){f:{v[23588]=0;c=S(206,b|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break f}if(!c){break e}v[23588]=0;W(847,e|0,1,((c-65&255)>>>0<26?c+32|0:c)<<24>>24)|0;c=v[23588];v[23588]=0;if((c|0)!=1){continue}}break}break a}v[23588]=0;Q(188,b|0,4)|0;b=v[23588];v[23588]=0;if((b|0)==1){break a}$c(a,e)}yb(e);jb=d+32|0;return}a=P()|0;O()|0;yb(e);T(a|0);L()}function Mp(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;c=jb-16|0;jb=c;a:{b:{switch(w[a+480224|0]-1|0){default:b=v[a+24620>>2];d=b>>31;v[c+8>>2]=1;v[c>>2]=v[a+1074420>>2]<<1;f=Lka(b,d,5e4,0);e=mb;b=v[Yc(c+8|0,c)>>2];b=Hc(Mka(f,e,b,b>>31),mb);v[a+1074404>>2]=b;break a;case 1:b=v[a+24620>>2];v[c+8>>2]=1;v[c+12>>2]=0;g=c,h=Lka(v[a+1074420>>2],0,Lka(v[a+1074408>>2],0,v[a+1074416>>2],0),mb),v[g>>2]=h;v[c+4>>2]=mb;b=Lka(b,0,6e5,0);d=c+8|0;e=b;f=mb;b=mv(v[d>>2],v[d+4>>2],v[c>>2],v[c+4>>2])?c:d;b=Oka(e,f,v[b>>2],v[b+4>>2]);v[a+1074404>>2]=b;break a;case 0:break b}}b=v[a+24620>>2];d=b>>31;v[c+8>>2]=1;v[c>>2]=v[a+1074420>>2];f=Lka(b,d,1e4,0);e=mb;b=v[Yc(c+8|0,c)>>2];b=Hc(Mka(f,e,b,b>>31),mb);v[a+1074404>>2]=b}e=a+1074404|0;a=v[a+480244>>2];b=Lka(a,a>>31,b,b>>31)+32768|0;a=mb;a=Hc(Mka(b,b>>>0<32768?a+1|0:a,65536,0),mb);v[e>>2]=a?a:1;jb=c+16|0}function lK(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0;o(+a);b=j(1)|0;c=j(0)|0;a:{b:{c:{d:{if((b|0)>0|(b|0)>=0){e=b;if(b>>>0>1048575){break d}}if(!(b&2147483647|c)){return-1/(a*a)}if((b|0)>0|(b|0)>=0){break c}return(a-a)/0}if(e>>>0>2146435071){break a}b=1072693248;k=-1023;if((e|0)!=1072693248){b=e;break b}if(c){break b}return 0}o(+(a*0x40000000000000));b=j(1)|0;c=j(0)|0;k=-1077}l(0,c|0);c=b+614242|0;l(1,(c&1048575)+1072079006|0);d=+n()+-1;f=d*(d*.5);g=d/(d+2);h=g*g;a=h*h;o(+(d-f));b=j(1)|0;j(0)|0;l(0,0);l(1,b|0);i=+n();m=i*1.4426950407214463;p=+((c>>>20|0)+k|0);q=m+p;a=g*(f+(a*(a*(a*.15313837699209373+.22222198432149784)+.3999999999940942)+h*(a*(a*(a*.14798198605116586+.1818357216161805)+.2857142874366239)+.6666666666666735)))+(d-i-f);a=q+(m+(p-q)+((a+i)*1.6751713164886512e-10+a*1.4426950407214463))}return a}function CK(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=C(0),k=0,l=C(0),m=0,n=0,o=0,p=C(0);d=a+4208|0;j=C(C(z[Db(d,2)>>2]*C(2999.9990234375))+C(.0010000000474974513));l=C(z[Db(d,3)>>2]*C(.9980000257492065));f=-3e3/+C(j*C(y[v[a+16>>2]+24620>>2]));h=a+4272|0;c=ak(10,f*+y[Db(h,4)>>2]);d=a+4232|0;o=Db(d,0),p=C(c),z[o>>2]=p;c=ak(10,f*+y[Db(h,5)>>2]);o=Db(d,1),p=C(c),z[o>>2]=p;m=f*(1/+C(l+C(.0010000000474974513))+-1);c=0;while(1){if((e|0)==4){e=a+4208|0;f=ak(10,+AK(z[Db(e,0)>>2])*.05);b=4/K(c)*f;c=ak(10,+AK(z[Db(e,1)>>2])*.1);z[a+4228>>2]=b*K(c);z[a+4224>>2]=f*K(1-c)}else{g=Db(h,e);k=e>>>1|0;n=v[Db(h,k+4|0)>>2];g=v[g>>2];i=ak(10,m*+(n+g>>>0));b=ak(10,f*+(g>>>0));j=z[Db(d,k)>>2];g=e<<1;i=(1-i)*.5;o=Db(d,g+2|0),p=C(b*(1-i)),z[o>>2]=p;o=Db(d,g+3|0),p=C(b*i),z[o>>2]=p;b=b*+j;b=b*(b*(b*(b+1)+1)+1)+1;c=b*b+c;e=e+1|0;continue}break}}function nn(a,b,c,d){var e=0,f=0;f=jb-16|0;jb=f;v[23588]=0;Y(952,a|0);e=v[23588];v[23588]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((e|0)!=1){e=v[a+24>>2];v[23588]=0;R(d|0,f|0,e|0);d=v[23588];v[23588]=0;if((d|0)==1){break i}d=v[f>>2];e=xd(d,v[f+4>>2]);if(e>>>0<2147483647){break h}d=ba(8)|0;v[23588]=0;b=Q(1007,d|0,7389)|0;e=v[23588];v[23588]=0;if((e|0)==1){break g}v[23588]=0;U(119,b|0,93308,168);b=v[23588];v[23588]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}j:{if(!((b|0)<(e|0)&(b|0)>=0)){b=fg(21619);break j}b=fg(Lc(Md(d,b)))}We(f);break d}b=V(0)|0;O()|0;ca(d|0)}We(f)}_(b|0)|0;b=0;v[23588]=0;X(939,c|0,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break c}$()}jb=f+16|0;return b}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Ub()}L()}T(a|0);L()}function v6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-32|0;jb=e;v[23588]=0;Y(952,a|0);d=v[23588];v[23588]=0;a:{b:{c:{d:{e:{f:{g:{if((d|0)==1){break g}v[23588]=0;Y(953,b|0);d=v[23588];v[23588]=0;if((d|0)==1){break g}v[23588]=0;Y(953,c|0);d=v[23588];v[23588]=0;if((d|0)==1){break g}f=v[a+24>>2];v[23588]=0;d=Q(55,e+16|0,b|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break g}v[23588]=0;c=Q(55,e|0,c|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break f}v[23588]=0;X(968,f|0,d|0,c|0,1);b=v[23588];v[23588]=0;if((b|0)==1){break e}yb(c);yb(d);b=1;break b}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;break d}b=V(0)|0;O()|0;yb(c)}yb(d)}_(b|0)|0;b=0;v[23588]=0;X(939,6412,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$()}jb=e+32|0;return b|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function qI(a,b,c,d){var e=0,f=C(0),g=0,h=C(0),i=0,j=0,k=0,l=C(0),m=C(0),n=C(0),o=0;e=jb-96|0;jb=e;o=(d|0)>0?d:0;while(1){if((j|0)!=(o|0)){z[e+48>>2]=-z[a>>2];z[e>>2]=z[a+68>>2];d=0;while(1){if((d|0)!=4){i=(e+48|0)+(d<<3)|0;g=(d<<4)+a|0;h=z[g+4>>2];f=z[g+8>>2];z[i+4>>2]=h+f;k=d<<1;z[(8-k<<2)+e>>2]=h-f;h=z[g+16>>2];f=z[g+12>>2];z[(7-k<<2)+e>>2]=h-f;z[i+8>>2]=-C(h+f);d=d+1|0;continue}break}pI(e+48|0);pI(e);z[e+4>>2]=-z[e+4>>2];z[e+12>>2]=-z[e+12>>2];z[e+20>>2]=-z[e+20>>2];z[e+28>>2]=-z[e+28>>2];g=0;while(1){if((g|0)!=9){d=g<<2;i=d+b|0;h=z[i>>2];f=z[d+(e+48|0)>>2];l=z[d+71168>>2];m=z[d+71204>>2];n=z[d+e>>2];z[i>>2]=C(f*l)-C(m*n);i=a+d|0;d=c+d|0;f=C(C(f*m)+C(n*l));z[i>>2]=C(h*z[d>>2])-C(z[d+36>>2]*f);z[(17-g<<2)+a>>2]=C(h*z[d+36>>2])+C(f*z[d>>2]);g=g+1|0;continue}break}b=b+36|0;a=a+72|0;j=j+1|0;continue}break}jb=e+96|0}function bU(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;while(1){a:{g=c;if(!c){g=0;break a}c=g-1|0;if(!w[c+b|0]){continue}}break}b:{if((d|0)!=4){break b}c=0;while(1){if((c|0)==(g|0)){if((e|0)==(f|0)){d=2;if((e|0)==(h|0)){break b}}if(e){d=0;if(!f){break b}}d=e?3:f?1:3}else{c:{d:{e:{d=b+c|0;i=w[d|0];switch(i-10|0){case 0:break d;case 3:break e;default:break c}}e=e+1|0;break c}f=f+1|0}h=c?(w[d-1|0]==13&(i|0)==10)+h|0:h;c=c+1|0;continue}break}}e=0;f=(d|0)==2;c=0;while(1){if(c>>>0<g>>>0){c=((f&w[b+c|0]==13)+c|0)+1|0;e=e+1|0;continue}break}_f(a);xt(a,e);f=(d|0)==1?32:13;h=d&-3?13:32;d=(d|0)==2;c=0;while(1){if(c>>>0<g>>>0){f:{g:{h:{i:{e=t[b+c|0];switch(e-10|0){case 1:case 2:break f;case 0:break g;case 3:break h;default:break i}}if(e){break f}e=32;break f}c=c+d|0;e=f;break f}e=h}Xp(a,e);c=c+1|0;continue}break}}function OV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;md(b,0);v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=Rq(a+4|0,a);d=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[b+4>>2]=d;c=Rq(a+8|0,a);f=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[b+8>>2]=f;c=(w[a+15|0]|w[a+16|0]<<8)<<1;v[b+24>>2]=c;c=w[a+15|0]|w[a+16|0]<<8?c:16726;v[b+24>>2]=c;g=b,h=(B(Xu(t[a+17|0],w[a+14|0]<<28>>24),c)>>>0)/8363|0,v[g+24>>2]=h;t[e+15|0]=w[a+18|0];t[e+14|0]=127;g=b,h=(((w[Wb(e+15|0,e+14|0)|0]<<8|64)&65344)>>>0)/127|0,u[g+30>>1]=h;c=w[a+14|0];if(c>>>0>=16){u[b+34>>1]=32;u[b+28>>1]=c&240}c=w[a+19|0];if(c&4){u[b+34>>1]=x[b+34>>1]|1;c=w[a+19|0]}a:{if(!(c&8)|d>>>0>=f>>>0){break a}f=x[b+34>>1];d=f|2;u[b+34>>1]=d;c=w[a+19|0];if(c&16){d=f|6;u[b+34>>1]=d;c=w[a+19|0]}if(!(c&64)){break a}u[b+34>>1]=d|128}jb=e+16|0}function g4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=jb+-64|0;jb=e;a:{b:{if((b|0)>=0){d=v[a+24>>2];if(sj(Vb(v[d+484360>>2],w[d+484376|0]))>>>0>b>>>0){break b}}a=a+16|0;break a}d=0;c:{f=v[a+24>>2];g=v[f+484344>>2];i=v[f+484348>>2];h=x[cc(v[Vb(v[f+484360>>2],w[f+484376|0])>>2],b)>>1];if(!Qm(g,i,h)){break c}if((c|0)>=0){d=c;if((d|0)<v[Yb(g,h)+12>>2]){break c}}a=a+16|0;break a}u[f+1074448>>1]=b;c=f;f=b&65535;DM(c,f);c=v[a+24>>2];v[c+1074392>>2]=-2;v[c+1074428>>2]=d;g=w[a+64|0];b=e+24|0;u[b+4>>1]=0;t[b+6|0]=255;v[b+16>>2]=2;v[b>>2]=0;u[b+12>>1]=f;v[b+8>>2]=d;d=v[b+20>>2];v[e+16>>2]=v[b+16>>2];v[e+20>>2]=d;d=v[b+12>>2];v[e+8>>2]=v[b+8>>2];v[e+12>>2]=d;d=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=d;b=e+48|0;Zt(b,c,g?7:1,e);j=a,k=A[wM(v[e+52>>2])>>3],A[j+16>>3]=k;Di(b);a=a+16|0}jb=e- -64|0;return+A[a>>3]}function dM(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;k=jb-16|0;jb=k;t[k+15|0]=c;t[k+14|0]=12;Qg(b,w[Wb(k+15|0,k+14|0)|0]);c=0;l=v[b>>2];m=v[b+4>>2];p=_d(l,m);while(1){if((c|0)==(p|0)){c=0;t[b+12|0]=0;a:{if(!(d&1)){break a}if(oc(l,m)){break a}c=1;t[b+12|0]=1}if(e>>>0<=11){if(d&2){c=c|4;t[b+12|0]=c}t[b+15|0]=e;t[b+16|0]=e}if(!(g>>>0>11|f>>>0>g>>>0)){if(d&4){t[b+12|0]=c|2}t[b+14|0]=g;t[b+13|0]=f}jb=k+16|0}else{b:{c:{d:{switch(h|0){case 0:j=Db(l,c);i=(c<<2)+a|0;u[j>>1]=w[i+96|0]|w[i+97|0]<<8;i=i+98|0;break c;case 1:break d;default:break b}}j=Db(l,c);i=(c<<2)+a|0;u[j>>1]=w[i+144|0]|w[i+145|0]<<8;i=i+146|0}t[j+2|0]=w[i|0]}e:{if(!c){break e}i=Db(l,c);j=x[i>>1];n=Db(l,c-1|0);o=x[n>>1];if(j>>>0>255|j>>>0>=o>>>0){break e}j=j|o&65280;u[i>>1]=j;if(j>>>0>=x[n>>1]){break e}u[i>>1]=j+256}c=c+1|0;continue}break}}function CN(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=jb-16|0;jb=e;h=-1;a:{if(!my(a,b,2)){break a}f=v[b+656>>2];g=a+1074312|0;Cb(e+8|0,g,31);b:{if(Bb(v[v[e+8>>2]>>2],v[e+12>>2])){d=v[b+740>>2];if(d){break b}break a}d=v[b+740>>2]}Cb(e+8|0,g,31);g=d-Bb(v[v[e+8>>2]>>2],v[e+12>>2])|0;i=v[a+480180>>2];d=(i|0)==4096;j=f+88|0;f=d?64:(i|0)==16384?192:512;d=$p(j,g,f,d?255:64)-(f>>>1|0)|0;if(w[b+746|0]&16){h=Vp(a,b,!(v[b+88>>2]&32768),d);break a}if(vj(v[b+656>>2])){if((d|0)==u[b+772>>1]){break a}k=b,l=dd(d),u[k+772>>1]=l;t[b+851|0]=w[b+851|0]|64;break a}a=nj(a);v[e+8>>2]=d;c:{if((d|0)<0){v[e+8>>2]=0-d;ai(e+8|0,255);a=(v[e+8>>2]<<2)+(a?38160:37136)|0;break c}ai(e+8|0,255);a=(v[e+8>>2]<<2)+(a?37136:38160)|0}a=v[a>>2];b=a;d=a>>31;a=v[c>>2];k=c,l=Hc(Mka(Lka(b,d,a,a>>31),mb,65536,0),mb),v[k>>2]=l}jb=e+16|0;return h}function saa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;md(c,0);u[c+28>>1]=w[a+36|0]<<2;d=w[a+37|0];u[c+32>>1]=64;u[c+30>>1]=d<<2;v[c>>2]=w[a+40|0]|w[a+41|0]<<8|(w[a+42|0]<<16|w[a+43|0]<<24);v[c+4>>2]=w[a+44|0]|w[a+45|0]<<8|(w[a+46|0]<<16|w[a+47|0]<<24);v[c+8>>2]=w[a+48|0]|w[a+49|0]<<8|(w[a+50|0]<<16|w[a+51|0]<<24);v[c+24>>2]=w[a+52|0]|w[a+53|0]<<8|(w[a+54|0]<<16|w[a+55|0]<<24);d=w[b+151|0];if(d>>>0<=4){t[c+38|0]=w[d+42714|0]}d=w[b+152|0]|w[b+153|0]<<8;t[c+39|0]=d;e=(w[b+156|0]|w[b+157|0]<<8)>>>4|0;t[c+41|0]=e;b=(w[b+154|0]|w[b+155|0]<<8)>>>2|0;t[c+40|0]=b;if((b|e)&255){t[c+39|0]=d^-1}b=w[a+38|0]|w[a+39|0]<<8;if(b&4){u[c+34>>1]=x[c+34>>1]|1;b=w[a+38|0]|w[a+39|0]<<8}if(b&8){u[c+34>>1]=x[c+34>>1]|2;b=w[a+38|0]|w[a+39|0]<<8}if(b&16){u[c+34>>1]=x[c+34>>1]|4;b=w[a+38|0]|w[a+39|0]<<8}if(b&32){u[c+34>>1]=x[c+34>>1]|32}}function rda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=jb-16|0;jb=b;g=v[a+40>>2];h=v[a+36>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+32>>2];k=v[a+28>>2];l=v[a+8>>2];m=v[a+12>>2];while(1){if(d){f=v[b+8>>2];n=((((v[b+12>>2]&2147483647)<<1|f>>>31)&2147483646)<<1)+i|0;e=f>>>21&2040;o=u[e+39718>>1];p=u[e+39716>>1];q=u[e+39714>>1];r=u[e+39712>>1];e=0;while(1){if((e|0)!=2){f=(e<<1)+n|0;v[(e<<2)+b>>2]=(((B(u[f>>1],q)+B(u[f-4>>1],r)|0)+B(u[f+4>>1],p)|0)+B(u[f+8>>1],o)|0)/16384;e=e+1|0;continue}break}h=h+k|0;v[c>>2]=v[c>>2]+B(v[b>>2],h>>12);g=g+j|0;v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],g>>12);Qb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=g;v[a+20>>2]=h>>12;v[a+36>>2]=h;v[a+24>>2]=g>>12;jb=b+16|0}function eba(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=jb-880|0;jb=b;c=Tb(a,0,76);v[c+84>>2]=0;v[c+88>>2]=0;v[c+80>>2]=256;u[c+76>>1]=65535;v[c+92>>2]=0;v[c+96>>2]=0;t[c+100|0]=1;d=c+223848|0;e=c+616|0;a=e;while(1){a=iQ(a)+872|0;if((d|0)!=(a|0)){continue}break}d=Sb(d);g=Ly(c+223860|0);f=b+8|0;Tb(f,0,108);Nz(b+120|0,48e3);Tb(b+664|0,0,72);t[b+754|0]=0;u[b+752>>1]=65535;t[b+746|0]=0;u[b+744>>1]=65535;t[b+738|0]=0;u[b+736>>1]=65535;v[b+748>>2]=0;v[b+740>>2]=0;Tb(b+756|0,0,103);v[b+868>>2]=0;v[b+872>>2]=0;t[b+875|0]=0;t[b+876|0]=0;t[b+877|0]=0;t[b+878|0]=0;v[b+860>>2]=0;v[b+864>>2]=0;t[b+859|0]=w[b+859|0]&128;a=((e+223232|0)-e|0)/872|0;while(1){if((a|0)>0){a=a-1|0;e=Rp(e,f)+872|0;continue}break}v[23588]=0;R(538,d|0,32);a=v[23588];v[23588]=0;if((a|0)!=1){jb=b+880|0;return c|0}a=P()|0;O()|0;Sp(g);hc(d);T(a|0);L()}function Hy(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=x[a+480188>>1];h=d>>>0>256?d:256;f=v[a+1298300>>2];c=d;a:{while(1){if((c|0)!=(h|0)){e=B(c,872)+a|0;if(!v[e+1075068>>2]){if(!pj(v[e+1075648>>2])|w[e+1075081|0]&24){break a}}if(w[e+1075081|0]&2){if(!Ed(f)){break a}if(!jN(f,c&65535)){break a}}c=c+1|0;continue}break}e=0;f=65535;g=8388608;if(b>>>0<=255){b=B(b,872)+a|0;if(!v[b+1075688>>2]){c=65535;if(v[b+1075068>>2]){break a}}g=v[b+1075680>>2]|v[b+1075672>>2]<<9}while(1){if((d|0)==(h|0)){c=f;break a}b=B(d,872)+a|0;if(!(v[b+1075688>>2]?0:v[b+1075068>>2])){c=(v[b+1075680>>2]|v[b+1075672>>2]<<9)>>>(v[b+1075080>>2]>>>1&1)|0;b:{c:{if(c>>>0<g>>>0){b=v[(B(d,872)+a|0)+1075716>>2];break c}if((c|0)!=(g|0)){break b}b=v[(B(d,872)+a|0)+1075716>>2];if(e>>>0>=b>>>0){break b}}g=c;f=d;e=b}d=d+1|0;continue}break}c=d}return c&65535}function lI(a){var b=0,c=0,d=0,e=0,f=0,g=0;c=v[a+32>>2];a:{b:{b=v[a+1380>>2];if((b|0)==-1){d=1;b=-1;break b}e=v[a+1116>>2];d=(b|0)>(e|0)?b:e;while(1){c:{if((b|0)!=(d|0)){f=w[(a+b|0)+1120|0];c=f+c|0;if((f|0)==255){break c}d=b}if(y[a+40>>2]<c>>>0){dc(a,1);break a}b=(d|0)==(e|0)?-1:d;d=0;break b}b=b+1|0;continue}}while(1){if((b|0)!=-1){return 1}e=v[a+40>>2];if(e>>>0<=c+26>>>0){dc(a,1);break a}if(Rb(c,93872,4)){dc(a,21);break a}if(w[c+4|0]){dc(a,21);break a}d:{if(d){if(!v[a+992>>2]|!(t[c+5|0]&1)){break d}dc(a,21);break a}if(t[c+5|0]&1){break d}dc(a,21);break a}b=0;f=c+27|0;d=w[c+26|0];c=f+d|0;if(e>>>0<c>>>0){dc(a,1);break a}while(1){e:{if((b|0)==(d|0)){b=d;break e}g=w[b+f|0];c=g+c|0;if((g|0)!=255){break e}b=b+1|0;continue}break}b=(b|0)==(d|0)?-1:b;d=0;if(c>>>0<=e>>>0){continue}break}dc(a,1)}return 0}function Z2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-96|0;jb=d;v[23588]=0;e=v[b+12>>2];v[d+40>>2]=v[b+8>>2];v[d+44>>2]=e;e=v[b+4>>2];v[d+32>>2]=v[b>>2];v[d+36>>2]=e;e=S(1079,d+32|0)|0;f=v[23588];v[23588]=0;if((f|0)!=1){a:{b:{if(e){v[23588]=0;R(1080,d+72|0,b|0);b=v[23588];v[23588]=0;if((b|0)!=1){b=d+80|0;Cv(b,v[d+72>>2],v[d+76>>2]);e=Cg(d+88|0,b);f=Cg(d- -64|0,c);g=v[e+4>>2];v[d+8>>2]=v[e>>2];v[d+12>>2]=g;e=v[f+4>>2];v[d>>2]=v[f>>2];v[d+4>>2]=e;Dv(a,d+8|0,d);break b}break a}v[23588]=0;R(1081,d+72|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break a}b=d+80|0;Cv(b,v[d+72>>2],v[d+76>>2]);e=Cg(d+56|0,b);f=Cg(d+48|0,c);g=v[e+4>>2];v[d+24>>2]=v[e>>2];v[d+28>>2]=g;e=v[f+4>>2];v[d+16>>2]=v[f>>2];v[d+20>>2]=e;Dv(a,d+24|0,d+16|0)}le(b);le(d+72|0);le(c);jb=d+96|0;return}}a=P()|0;O()|0;le(c);T(a|0);L()}function y7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;b=si(a,b,c,d);v[b+4260>>2]=0;v[b>>2]=46748;c=b+4960|0;e=b+4504|0;d=e;while(1){d=Sb(d)+24|0;if((d|0)!=(c|0)){continue}break}t[b+5046|0]=1;u[b+5044>>1]=0;a=b+4208|0;f=Db(a,0),g=1063675494,v[f>>2]=g;f=Db(a,1),g=1065185444,v[f>>2]=g;f=Db(a,2),g=0,v[f>>2]=g;f=Db(a,3),g=1032805417,v[f>>2]=g;f=Db(a,4),g=1053079357,v[f>>2]=g;f=Db(a,5),g=1059859440,v[f>>2]=g;f=Db(a,6),g=1047457519,v[f>>2]=g;f=Db(a,7),g=1062836634,v[f>>2]=g;f=Db(a,8),g=1038174126,v[f>>2]=g;f=Db(a,9),g=1065353216,v[f>>2]=g;f=Db(a,10),g=1065353216,v[f>>2]=g;f=Db(a,11),g=1048525618,v[f>>2]=g;f=Db(a,12),g=1059760811,v[f>>2]=g;v[23588]=0;R(897,b+44|0,2);a=v[23588];v[23588]=0;if((a|0)==1){a=P()|0;O()|0;while(1){c=vc(c-24|0);if((e|0)!=(c|0)){continue}break}If(b);T(a|0);L()}return b|0}function eF(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=jb-48|0;jb=d;v[23588]=0;Y(952,a|0);e=v[23588];v[23588]=0;a:{b:{c:{if((e|0)!=1){e=Lb(d+32|0);v[23588]=0;Y(c|0,d+16|0);c=v[23588];v[23588]=0;d:{e:{if((c|0)!=1){h=d,i=Eb(v[d+16>>2]),v[h+8>>2]=i;f=1;while(1){g=Eb(v[d+20>>2]);c=v[d+8>>2];if(!Ob(c,g)){c=fg(Lc(e));We(d+16|0);yb(e);break b}if(!f){v[23588]=0;Q(941,e|0,14575)|0;c=v[23588];v[23588]=0;if((c|0)==1){break e}c=v[d+8>>2]}v[23588]=0;Q(800,e|0,c|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break e}lq(d+8|0);f=0;continue}}c=V(0)|0;O()|0;break d}c=V(0)|0;O()|0;We(d+16|0)}yb(e);break c}c=V(0)|0;O()|0}_(c|0)|0;c=0;v[23588]=0;X(939,b|0,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$()}jb=d+48|0;return c}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)==1){V(0)|0;O()|0;Ub();L()}T(a|0);L()}function rG(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=jb-32|0;jb=h;a:{b:{c:{if((b|0)!=(c|0)){j=v[116064];v[116064]=0;g=jb-16|0;jb=g;Gd();e=jb-16|0;jb=e;f=jb-16|0;jb=f;Ew(f,b,h+28|0,2);k=v[f>>2];i=v[f+4>>2];b=v[f+12>>2];v[e+8>>2]=v[f+8>>2];v[e+12>>2]=b;v[e>>2]=k;v[e+4>>2]=i;jb=f+16|0;i=v[e>>2];f=v[e+4>>2];b=v[e+12>>2];v[g+8>>2]=v[e+8>>2];v[g+12>>2]=b;v[g>>2]=i;v[g+4>>2]=f;jb=e+16|0;f=v[g>>2];e=v[g+4>>2];b=v[g+12>>2];v[h+16>>2]=v[g+8>>2];v[h+20>>2]=b;v[h+8>>2]=f;v[h+12>>2]=e;jb=g+16|0;i=v[h+16>>2];f=v[h+20>>2];g=v[h+8>>2];e=v[h+12>>2];b=v[116064];if(!b){break c}if(v[h+28>>2]!=(c|0)){break b}l=g;m=e;n=i;o=f;if((b|0)!=68){break a}break b}v[d>>2]=4;break a}v[116064]=j;if(v[h+28>>2]==(c|0)){break a}}v[d>>2]=4;g=l;e=m;i=n;f=o}v[a>>2]=g;v[a+4>>2]=e;v[a+8>>2]=i;v[a+12>>2]=f;jb=h+32|0}function bia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=jb-16|0;jb=e;c=qf(a,c);me(e,v[a+36>>2]);h=a;a:{if(!c){Rc(e,a+32|0,5);d=0;if(Bb(v[v[e>>2]>>2],v[e+4>>2])){break a}}d=jb-32|0;jb=d;f=v[a+36>>2];Vf(f,d+30|0);b:{c:{d:{e:{a=x[d+30>>1];if(a>>>0>=4001){i=v[b+12>>2];a=jb-16|0;jb=a;g=xc(a,15896);$c(d,g);zb(g);jb=a+16|0;v[23588]=0;U(478,d+16|0,d|0,d+30|0);a=v[23588];v[23588]=0;if((a|0)==1){break e}a=v[i+1298464>>2];v[23588]=0;U(376,a|0,2,d+16|0);a=v[23588];v[23588]=0;if((a|0)==1){break d}zb(d+16|0);ac(d);a=4e3}ug(xj(v[b>>2],0),a);b=xj(v[b>>2],0);j=d,k=Eb(v[b>>2]),v[j+16>>2]=k;b=Eb(v[b+4>>2]);break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;zb(d+16|0)}ac(d);T(b|0);L()}while(1){a=v[d+16>>2];if(Ob(a,b)){Vf(f,d);u[a>>1]=x[d>>1];Re(d+16|0);continue}break}jb=d+32|0;d=c}Xe(h,d);jb=e+16|0}function R9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=jb-16|0;jb=f;j=qf(a,c);me(f,v[a+36>>2]);k=a;a:{if(!j){Rc(f,a+32|0,5);c=0;if(Bb(v[v[f>>2]>>2],v[f+4>>2])){break a}}e=jb-48|0;jb=e;h=v[a+36>>2];Jk(h,e+40|0);c=v[e+44>>2];if(!c&y[e+40>>2]>=257|c){v[e+40>>2]=256;v[e+44>>2]=0}l=v[e+40>>2];m=v[e+44>>2];c=0;b:{c:{d:{e:{while(1){if(!m&c>>>0>=l>>>0){break b}Vf(h,e+38|0);g=Lb(e+24|0);v[23588]=0;Q(485,h|0,g|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){v[23588]=0;U(11,e+8|0,d|0,g|0);a=v[23588];v[23588]=0;if((a|0)==1){break e}v[23588]=0;a=Q(888,b|0,e+38|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break d}i=a;a=e+8|0;Ib(i,a);zb(a);yb(g);c=c+1|0;continue}break}c=P()|0;O()|0;break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;zb(e+8|0)}yb(g);T(c|0);L()}jb=e+48|0;c=j}Xe(k,c);jb=f+16|0}function sda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=jb-16|0;jb=b;g=v[a+40>>2];h=v[a+36>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+32>>2];k=v[a+28>>2];l=v[a+8>>2];m=v[a+12>>2];while(1){if(d){f=v[b+8>>2];n=(((v[b+12>>2]&2147483647)<<1|f>>>31)&-2)+i|0;e=f>>>21&2040;o=u[e+39718>>1];p=u[e+39716>>1];q=u[e+39714>>1];r=u[e+39712>>1];e=0;while(1){if((e|0)!=2){f=e+n|0;v[(e<<2)+b>>2]=(((B(t[f|0],q)+B(t[f-2|0],r)|0)+B(t[f+2|0],p)|0)+B(t[f+4|0],o)<<8)/16384;e=e+1|0;continue}break}h=h+k|0;v[c>>2]=v[c>>2]+B(v[b>>2],h>>12);g=g+j|0;v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],g>>12);Qb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=g;v[a+20>>2]=h>>12;v[a+36>>2]=h;v[a+24>>2]=g>>12;jb=b+16|0}function rha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=jb-432|0;jb=d;yc(b);xA(b,d+376|0,d+296|0,d+8|0);k=d,l=sg((m=w[d+427|0]+1|0,n=1,o=bc(v[d+408>>2]),o?m:n)),t[k+4|0]=l;i=w[Wb(26800,d+4|0)|0];t[d+7|0]=i;u[d+4>>1]=4;a:{b:{while(1){if((h&255)>>>0>=i>>>0){break b}e=Hb(x[d+8>>1])<<16>>16;if(!((e|0)<0|w[d+291|0]>63)){e=e&65535;f=0;while(1){if((f|0)==(e|0)){c:{e=g;g=bc(v[d+296>>2]);if(e>>>0<g>>>0){if(cd(b,g)){break c}}t[d+7|0]=h+1;break b}}else{d:{if(!cd(b,bc(v[d+392>>2])+(f<<2)|0)){break d}if(!cd(b,Bo(b))){break d}e:{if(!c){j=Le(b);break e}j=Gj(b)}u[d+2>>1]=j;k=d,l=x[ke(d+4|0,d+2|0)>>1],u[k+4>>1]=l}f=f+1|0;continue}break}g=bc(v[d+296>>2]);xA(b,d+376|0,d+296|0,d+8|0);h=h+1|0;continue}break}qv(a);break a}u[a>>1]=x[d+4>>1];t[a+2|0]=w[d+7|0]}jb=d+432|0}
function pv(a,b,c,d){var e=0,f=0,g=0,h=0;g=jb-16|0;jb=g;a:{if(!c){break a}if(d){b=gc(g+8|0,a,b);a=jb-16|0;jb=a;v[a+12>>2]=c;d=v[b+4>>2];b:{if(!d){d=v[b>>2];break b}e=32-d|0;v[a+8>>2]=e;c=v[b>>2];h=e;e=v[Jb(a+8|0,a+12|0)>>2];v[c>>2]=-1<<d&-1>>>h-e|v[c>>2];f=v[a+12>>2];d=c+4|0;v[b>>2]=d;c=f-e|0}e=d;d=c>>>5<<2;Tb(e,255,d);e=c&31;v[a+12>>2]=e;if((c&-32)!=(c|0)){c=b;b=d+v[b>>2]|0;v[c>>2]=b;v[b>>2]=v[b>>2]|-1>>>32-e}jb=a+16|0;break a}b=gc(g,a,b);a=jb-16|0;jb=a;v[a+12>>2]=c;d=v[b+4>>2];c:{if(!d){d=v[b>>2];break c}e=32-d|0;v[a+8>>2]=e;c=v[b>>2];f=v[c>>2];h=e;e=v[Jb(a+8|0,a+12|0)>>2];v[c>>2]=(-1<<d&-1>>>h-e^-1)&f;f=v[a+12>>2];d=c+4|0;v[b>>2]=d;c=f-e|0}e=d;d=c>>>5<<2;Tb(e,0,d);e=c&31;v[a+12>>2]=e;if((c&-32)!=(c|0)){c=b;b=d+v[b>>2]|0;v[c>>2]=b;v[b>>2]=v[b>>2]&(-1>>>32-e^-1)}jb=a+16|0}jb=g+16|0}function vka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=jb-48|0;jb=g;h=a+8|0;c=v[a+8>>2];j=Bc(a);a:{if((c|0)!=v[j>>2]){break a}i=a+4|0;e=v[a+4>>2];d=v[a>>2];if(e>>>0>d>>>0){a=e;d=((a-d>>1)+1|0)/-2<<1;e=a+d|0;while(1){if((a|0)!=(c|0)){e=oV(e,a)+2|0;a=a+2|0;continue}break}c=e;v[h>>2]=c;v[i>>2]=d+v[i>>2];break a}v[g+24>>2]=c-d;v[g+44>>2]=1;e=g+24|0;c=v[Yc(e,g+44|0)>>2];c=Mj(e,c,c>>>2|0,v[a+16>>2]);d=ec(g+16|0,v[a+4>>2]);f=v[ec(g+8|0,v[a+8>>2])>>2];e=jb-32|0;jb=e;d=v[d>>2];v[e+24>>2]=d;d=No(e+8|0,c+8|0,HB(d,f));f=v[d>>2];while(1){if(v[d+4>>2]!=(f|0)){k=f;f=v[e+24>>2];Jj(k,w[f|0]|w[f+1|0]<<8);f=v[d>>2]+2|0;v[d>>2]=f;Re(e+24|0);continue}break}Td(d);jb=e+32|0;pc(a,c);pc(i,c+4|0);pc(h,c+8|0);pc(j,Bc(c));Ni(c);c=v[a+8>>2]}Jj(c,w[b|0]|w[b+1|0]<<8);v[h>>2]=v[h>>2]+2;jb=g+48|0}function Gd(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0;if(w[468292]){return v[117072]}c=jb-32|0;jb=c;a:{b:{while(1){e=(c+8|0)+(a<<2)|0;d=1<<a&2147483647;if(d|1){d=NG(a,d?14249:21619)}else{d=v[a<<2>>2]}v[e>>2]=d;if((d|0)==-1){break b}a=a+1|0;if((a|0)!=6){continue}break}if(!MG(0)){b=89968;if(!Rb(c+8|0,89968,24)){break a}b=89992;if(!Rb(c+8|0,89992,24)){break a}a=0;if(!w[468064]){while(1){f=(a<<2)+468016|0,g=NG(a,21619),v[f>>2]=g;a=a+1|0;if((a|0)!=6){continue}break}t[468064]=1;v[117010]=v[117004]}b=468016;if(!Rb(c+8|0,468016,24)){break a}b=468040;if(!Rb(c+8|0,468040,24)){break a}b=Od(24);if(!b){break b}}a=v[c+12>>2];v[b>>2]=v[c+8>>2];v[b+4>>2]=a;a=v[c+28>>2];v[b+16>>2]=v[c+24>>2];v[b+20>>2]=a;a=v[c+20>>2];v[b+8>>2]=v[c+16>>2];v[b+12>>2]=a;break a}b=0}jb=c+32|0;t[468292]=1;v[117072]=b;return b}function Oca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=jb-16|0;jb=f;g=v[a+40>>2];h=v[a+36>>2];i=v[a+16>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;j=b+24|0;k=v[a+32>>2];l=v[a+28>>2];m=v[a+8>>2];n=v[a+12>>2];while(1){if(d){b=(v[f+12>>2]<<1)+i|0;e=(((v[f+8>>2]>>>16|0)+4&131064)<<1)+j|0;b=(((((B(u[b+4>>1],u[e+10>>1])+B(u[b+2>>1],u[e+8>>1])|0)+B(u[b+6>>1],u[e+12>>1])|0)+B(u[b+8>>1],u[e+14>>1])|0)/2|0)+((((B(u[b-4>>1],u[e+2>>1])+B(u[b-6>>1],u[e>>1])|0)+B(u[b-2>>1],u[e+4>>1])|0)+B(u[b>>1],u[e+6>>1])|0)/2|0)|0)/16384|0;h=h+l|0;v[c>>2]=v[c>>2]+B(b,h>>12);g=g+k|0;v[c+4>>2]=v[c+4>>2]+B(b,g>>12);Qb(f+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;v[a+40>>2]=g;v[a+20>>2]=h>>12;v[a+36>>2]=h;v[a+24>>2]=g>>12;jb=f+16|0}function vq(a,b){var c=0;c=jb-16|0;jb=c;a=hr(a);a:{b:{c:{switch(b-1|0){default:if((b|0)!=16777216){break b}Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(a,7,1),9,1),10,1),13,1),15,1),16,1),17,1),18,1),20,1),21,1),24,1),25,1),26,1),28,1),30,1),31,1),33,1),34,1),39,1),41,1),44,1),46,1),45,1),47,1),48,1),50,1),99,1),102,1),104,1),105,1),115,1);break a;case 1:vy(c,2);b=v[c+12>>2];v[a+8>>2]=v[c+8>>2];v[a+12>>2]=b;b=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=b;Zf(a,107);break a;case 3:vy(c,4);b=v[c+12>>2];v[a+8>>2]=v[c+8>>2];v[a+12>>2]=b;b=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=b;Zf(a,4);break a;case 2:break b;case 0:break c}}Nb(a,88,1);break a}vy(c,b);b=v[c+12>>2];v[a+8>>2]=v[c+8>>2];v[a+12>>2]=b;b=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=b}jb=c+16|0}function tK(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=jb-48|0;jb=j;k=v[a+4>>2];l=v[a>>2];a=v[a+8>>2];v[j+32>>2]=b;v[j+44>>2]=a;v[j+36>>2]=l;v[j+40>>2]=k;v[23588]=0;a=Q(932,(d?d:933)|0,e|0)|0;b=v[23588];v[23588]=0;a:{b:{c:{d:{if((b|0)!=1){v[j+16>>2]=a;a=v[dg(j+24|0,j+16|0)>>2];b=v[j+44>>2];v[j+8>>2]=v[j+40>>2];v[j+12>>2]=b;v[23588]=0;b=v[j+36>>2];v[j>>2]=v[j+32>>2];v[j+4>>2]=b;c=+za(934,j|0,+c,a|0);a=v[23588];v[23588]=0;if((a|0)==1){break d}De(j+16|0);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;De(j+16|0)}_(a|0)|0;v[23588]=0;ia(935,15018,d|0,e|0,f|0,g|0,h|0,i|0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();c=0}jb=j+48|0;return+c}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function N8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;a:{c=jb-16|0;jb=c;e=Lb(a);g=c,h=Oi(b),v[g+8>>2]=h;g=c,h=gr(b),v[g>>2]=h;a=0;b:{while(1){c:{if(!yi(c+8|0,c)){if(!a){break c}v[23588]=0;R(49,e|0,65533);a=v[23588];v[23588]=0;if((a|0)!=1){break c}break b}b=w[v[c+8>>2]];d:{e:{if(!a){if(!(b&128)){a=0;v[23588]=0;R(49,e|0,b|0);b=v[23588];v[23588]=0;if((b|0)!=1){break d}break b}if((b&224)==192){d=b&31;a=1;break d}if((b&240)==224){d=b&15;a=2;break d}d=65533;if((b&248)!=240){break e}d=b&7;a=3;break d}if((b&192)!=128){d=0;v[23588]=0;R(49,e|0,65533);f=v[23588];v[23588]=0;a=0;if((f|0)==1){break b}}d=b&63|d<<6;a=a-1|0;if(a){break d}}a=0;v[23588]=0;R(49,e|0,d|0);b=v[23588];v[23588]=0;d=0;if((b|0)==1){break b}}Ge(c+8|0);continue}break}jb=c+16|0;break a}a=P()|0;O()|0;Fc(e);T(a|0);L()}}function B9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{b:{if((Pj(v[a>>2],v[a+4>>2])|0)==2){if((Pj(v[a+12>>2],v[a+16>>2])|0)==(b|0)){break b}}v[23588]=0;R(899,a|0,2);c=v[23588];v[23588]=0;c:{if((c|0)==1){break c}v[23588]=0;R(899,a+12|0,b|0);c=v[23588];v[23588]=0;if((c|0)==1){break c}v[23588]=0;R(900,a+24|0,2);c=v[23588];v[23588]=0;if((c|0)==1){break c}v[23588]=0;R(900,a+36|0,b|0);c=v[23588];v[23588]=0;if((c|0)==1){break c}c=a;while(1)if((d|0)==2){a=0;while(1){if((a|0)==(b|0)){break b}d=dr(v[c+12>>2],a);f=Db(v[c+36>>2],a),g=d,v[f>>2]=g;a=a+1|0;continue}}else{e=dr(v[a>>2],d);f=Db(v[a+24>>2],d),g=e,v[f>>2]=g;d=d+1|0;continue}}b=V(92948)|0;if((O()|0)!=(da(92948)|0)){break a}_(b|0)|0;Kc(a);AL(a);b=a+12|0;Kc(b);AL(b);b=a+24|0;Kc(b);zL(b);a=a+36|0;Kc(a);zL(a);$()}return}T(b|0);L()}function S8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=C(0);c=jb-4112|0;jb=c;h=nb[v[v[a>>2]+120>>2]](a)|0;if(!h){nb[v[v[a>>2]+124>>2]](a)}v[c+12>>2]=0;f=jb-16|0;jb=f;while(1){d=v[a+44>>2];if(Pj(d,v[a+48>>2])>>>0<=e>>>0){jb=f+16|0}else{v[f+12>>2]=0;d=dr(d,e);g=(d+2048|0)-d>>2;while(1){if((g|0)>0){z[d>>2]=z[f+12>>2];g=g-1|0;d=d+4|0;continue}break}e=e+1|0;continue}break}f=c+2064|0;a:while(1){if(b){v[c+8>>2]=b;wc(c+8|0,512);e=c+16|0;zy(e);d=v[c+8>>2];nb[v[v[a>>2]+60>>2]](a,e,f,d);e=0;while(1)if((e|0)==(d|0)){b=b-d|0;continue a}else{g=(c+16|0)+(e<<2)|0;z[c+4>>2]=D(z[g>>2]);i=c,j=z[Jx(c+12|0,c+4|0)>>2],z[i+12>>2]=j;z[c+4>>2]=D(z[g+2048>>2]);i=c,j=z[Jx(c+12|0,c+4|0)>>2],z[i+12>>2]=j;e=e+1|0;continue}}break}if(!h){nb[v[v[a>>2]+128>>2]](a)}jb=c+4112|0;return C(z[c+12>>2])}function H3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=jb-32|0;jb=d;j=d,k=UJ(),v[j+24>>2]=k;g=a+24|0;c=d+24|0;SJ(g,be(c));jj(c);u[a+28>>1]=0;PP();f=jb-16|0;jb=f;e=sc(144);v[23588]=0;h=Q(1063,e|0,4)|0;i=v[23588];v[23588]=0;a:{if((i|0)!=1){e=v[Lf(f+8|0,h)>>2];jb=f+16|0;break a}a=P()|0;O()|0;Mb(e);T(a|0);L()}v[d+24>>2]=e;RJ(a+32|0,be(c));As(c);j=d,k=TJ(v[a>>2]),v[j+24>>2]=k;QJ(a+4|0,be(c));ij(c);Hn(v[g>>2],v[a+4>>2]);t[a+64|0]=1;v[a+60>>2]=0;v[a+48>>2]=1065353216;v[a+52>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;j=d,k=Fi(v[b>>2]),v[j+24>>2]=k;e=wf(b);b:{while(1){b=v[d+24>>2];if(!Hg(b,e)){break b}c=vd(b);b=xh(d+8|0,c);v[23588]=0;X(968,a|0,b|0,c+12|0,0);c=v[23588];v[23588]=0;if((c|0)!=1){yb(b);Kg(d+24|0);continue}break}a=P()|0;O()|0;yb(b);T(a|0);L()}jb=d+32|0}function BL(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=jb-16|0;jb=e;a:{if(uc(v[a>>2],v[a+4>>2])>>>0>511){break a}if(!Yg(v[v[b>>2]-12>>2]+b|0)){break a}d=jb-16|0;jb=d;f=sc(64);v[23588]=0;g=S(835,f|0)|0;h=v[23588];v[23588]=0;b:{c:{if((h|0)!=1){f=Lf(d,g);g=v[f>>2];v[23588]=0;g=W(894,g|0,b|0,c|0)|0;h=v[23588];v[23588]=0;d:{e:{if((h|0)!=1){if((g|0)==1){break e}Gc(d+8|0);break d}a=P()|0;O()|0;rg(f);break c}dg(d+8|0,f)}rg(f);jb=d+16|0;d=v[d+8>>2];break b}a=P()|0;O()|0;Mb(f)}T(a|0);L()}v[e+8>>2]=d;f:{g:{if(!Ed(d)){v[23588]=0;b=Q(893,b|0,c|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break g}v[e>>2]=b;qT(e+8|0,be(e));rg(e);d=v[e+8>>2]}if(!Ed(d)){break f}v[23588]=0;R(487,a|0,e+8|0);a=v[23588];v[23588]=0;i=d;if((a|0)!=1){break f}}a=P()|0;O()|0;rg(e+8|0);T(a|0);L()}rg(e+8|0)}jb=e+16|0;return i}function rd(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=v[a+112>>2];d=v[a+116>>2];e=!!(b|d);c=b;a:{i=e;f=v[a+4>>2];e=v[a+44>>2];b=f-e|0;h=b;g=b+v[a+120>>2]|0;b=v[a+124>>2]+(b>>31)|0;b=g>>>0<h>>>0?b+1|0:b;if(!(i&(c>>>0<=g>>>0&(b|0)>=(d|0)|(b|0)>(d|0)))){h=Lw(a);if((h|0)>=0){break a}f=v[a+4>>2];e=v[a+44>>2]}v[a+112>>2]=-1;v[a+116>>2]=-1;v[a+104>>2]=f;c=e-f|0;d=c+g|0;b=(c>>31)+b|0;v[a+120>>2]=d;v[a+124>>2]=d>>>0<c>>>0?b+1|0:b;return-1}d=g+1|0;b=d?b:b+1|0;f=v[a+4>>2];e=v[a+8>>2];c=v[a+112>>2];g=v[a+116>>2];b:{if(!(c|g)){break b}i=c-d|0;c=g-(b+(d>>>0>c>>>0)|0)|0;j=e-f|0;g=j>>31;if((c|0)>=(g|0)&i>>>0>=j>>>0|(c|0)>(g|0)){break b}e=f+i|0}v[a+104>>2]=e;c=v[a+44>>2];e=c-f|0;d=e+d|0;b=(e>>31)+b|0;v[a+120>>2]=d;v[a+124>>2]=d>>>0<e>>>0?b+1|0:b;if(c>>>0>=f>>>0){t[f-1|0]=h}return h}function Pca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=jb-16|0;jb=f;g=v[a+40>>2];h=v[a+36>>2];i=v[a+16>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;j=b+24|0;k=v[a+32>>2];l=v[a+28>>2];m=v[a+8>>2];n=v[a+12>>2];while(1){if(d){b=v[f+12>>2]+i|0;e=(((v[f+8>>2]>>>16|0)+4&131064)<<1)+j|0;b=(((((B(t[b+2|0],u[e+10>>1])+B(t[b+1|0],u[e+8>>1])|0)+B(t[b+3|0],u[e+12>>1])|0)+B(t[b+4|0],u[e+14>>1])<<8)/2|0)+((((B(t[b-2|0],u[e+2>>1])+B(t[b-3|0],u[e>>1])|0)+B(t[b-1|0],u[e+4>>1])|0)+B(t[b|0],u[e+6>>1])<<8)/2|0)|0)/16384|0;h=h+l|0;v[c>>2]=v[c>>2]+B(b,h>>12);g=g+k|0;v[c+4>>2]=v[c+4>>2]+B(b,g>>12);Qb(f+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;v[a+40>>2]=g;v[a+20>>2]=h>>12;v[a+36>>2]=h;v[a+24>>2]=g>>12;jb=f+16|0}function AV(a,b,c){var d=0,e=0;e=jb-16|0;jb=e;t[e+15|0]=c;a:{if(b>>>0>35){break a}b:{c:{d:{e:{f:{d=w[b+26288|0];switch(d-17|0){case 1:case 3:case 4:case 5:break a;case 0:break c;case 2:break d;case 6:break e;default:break f}}g:{if(d-6>>>0<2){break g}if((d|0)==31){break b}if((d|0)==11){break g}if((d|0)!=1){break a}d=(c|0)!=0;break a}b=c&240;if(!b|(b|0)==240|(c&15)==15){break a}t[e+15|0]=b;break a}if(c>>>0<=64){t[e+15|0]=c<<1;d=23;break a}t[e+15|0]=128;d=23;break a}d=19;h:{switch((c&240)-48>>>4|0){case 0:t[e+15|0]=159;d=20;break a;case 1:t[e+15|0]=192;d=20;break a;case 2:if(c&14){break a}t[e+15|0]=((c|0)!=80)<<6;d=21;break a;case 4:break h;default:break a}}t[e+15|0]=c&15|160;d=20;break a}d=c>>>0<32?16:17;break a}t[e+15|0]=(b<<5|c>>>3)^128;d=31}de(a,d,e+15|0);jb=e+16|0}function Un(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=v[b+88>>2];d=c|2048;v[b+88>>2]=d;f=v[b+656>>2];if(!(!f|t[b+730|0]&1)){d=c|6144;v[b+88>>2]=d}a:{if(!v[b+76>>2]){break a}b:{if(!(d&8)|c&2048){break b}c=v[b+104>>2];if(!c){break b}e=x[c+34>>1];if(e&2){d=(e&4?d|4:d&-135)|2;v[b+88>>2]=d;e=v[c>>2];v[b+76>>2]=e;g=v[c+4>>2];v[b+80>>2]=g;c=v[c+8>>2];v[b+84>>2]=c;if(c>>>0<e>>>0){v[b+76>>2]=c;h=c}else{h=e}e=v[b+4>>2];if(h>>>0>=e>>>0){break b}v[b>>2]=0;v[b+4>>2]=((e-g>>>0)%(c-g>>>0)|0)+g;break b}d=d&-135;v[b+88>>2]=d;v[b+76>>2]=v[c>>2]}if(!f){break a}if(!(!(v[a+480180>>2]&1064964?1:w[f+60|0]&2)|!v[f>>2])){v[b+88>>2]=d|4096}if(w[f+65|0]==255|x[b+728>>1]!=65535){break a}i=b,j=dd($p(f+48|0,v[b+724>>2],256,64)),u[i+728>>1]=j;i=b,j=x[Db(v[f+48>>2],w[f+65|0])>>1],v[i+724>>2]=j}}function PW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;g=jb-16|0;jb=g;cd(b,w[c+32|0]|w[c+33|0]<<8|(w[c+34|0]<<16|w[c+35|0]<<24));h=Sb(a);a=w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24);v[23588]=0;R(184,h|0,a|0);a=v[23588];v[23588]=0;if((a|0)!=1){a:{a=0;while(1){b:{if((w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24))>>>0<=a>>>0){break b}e=v[b+8>>2];f=v[b>>2];v[23588]=0;e=W(156,f|0,e|0,4)|0;f=v[23588];v[23588]=0;if((f|0)==1){break a}if(!e){break b}e=w[c+4|0]|w[c+5|0]<<8;v[23588]=0;e=Q(185,b|0,e|0)|0;f=v[23588];v[23588]=0;c:{if((f|0)!=1){v[g+12>>2]=e;if(xd(v[d>>2],v[d+4>>2])>>>0<=e>>>0){break c}v[23588]=0;R(186,h|0,g+12|0);e=v[23588];v[23588]=0;if((e|0)!=1){break c}}break a}a=a+1|0;continue}break}jb=g+16|0;return}}a=P()|0;O()|0;vc(h);T(a|0);L()}function $7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=C(0),o=C(0),p=0,q=0,r=0,s=0;h=jb-16|0;jb=h;if($h(a+44|0)){g=v[a+44>>2];r=h,s=Jc(g,0),v[r+8>>2]=s;r=h,s=Jc(g,1),v[r+12>>2]=s;g=v[a+56>>2];l=Jc(g,0);v[h>>2]=l;m=Jc(g,1);v[h+4>>2]=m;p=w[a+4273|0];q=w[a+4272|0];g=d;while(1){k=0;if(g){while(1){if((k|0)!=2){j=k<<2;i=j+(h+8|0)|0;e=v[i>>2];v[i>>2]=e+4;f=C(z[e>>2]*z[a+4240>>2]);e=a+j|0;i=e+4228|0;f=C(f+C(z[i>>2]*z[a+4236>>2]));z[i>>2]=f;f=SK(C(f*C(1073741824)),q,p);i=e+4244|0;e=e+4252|0;n=z[e>>2];o=z[a+4264>>2];f=C(C(C(f*z[a+4260>>2])-C(z[a+4268>>2]*z[i>>2]))-C(n*o));z[e>>2]=f;z[i>>2]=n+C(f*o);e=h+j|0;j=v[e>>2];v[e>>2]=j+4;z[j>>2]=f*C(9.313225746154785e-10);k=k+1|0;continue}break}g=g-1|0;continue}else{ri(a,b,c,l,m,d)}break}}jb=h+16|0}function Bp(a){var b=C(0),c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;e=(p(a),j(2));d=e&2147483647;a:{if(d>>>0<=1061752794){b=C(1);if(d>>>0<964689920){break a}b=fi(+a);break a}if(d>>>0<=1081824209){if(d>>>0>=1075235812){b=C(-fi(((e|0)<0?3.141592653589793:-3.141592653589793)+ +a));break a}f=+a;if((e|0)<0){b=gi(f+1.5707963267948966);break a}b=gi(1.5707963267948966-f);break a}if(d>>>0<=1088565717){if(d>>>0>=1085271520){b=fi(((e|0)<0?6.283185307179586:-6.283185307179586)+ +a);break a}if((e|0)<0){b=gi(-4.71238898038469-+a);break a}b=gi(+a+-4.71238898038469);break a}b=C(a-a);if(d>>>0>=2139095040){break a}b:{switch(ax(a,c+8|0)&3){case 0:b=fi(A[c+8>>3]);break a;case 1:b=gi(-A[c+8>>3]);break a;case 2:b=C(-fi(A[c+8>>3]));break a;default:break b}}b=gi(A[c+8>>3])}a=b;jb=c+16|0;return a}function p1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=jb-32|0;jb=c;v[c+28>>2]=0;if(Pd(w[fm(c+24|0,a,0)|0])){d=c+16|0;fd(d,v[v[a>>2]-12>>2]+a|0);v[23588]=0;d=S(1097,d|0)|0;e=v[23588];v[23588]=0;a:{b:{if((e|0)!=1){e=Rm(c+8|0,a);f=Gc(c);g=v[v[a>>2]-12>>2];f=v[f>>2];e=v[e>>2];v[23588]=0;ma(1100,d|0,e|0,f|0,a+g|0,c+28|0,c+20|0);d=v[23588];v[23588]=0;if((d|0)!=1){break b}}b=V(0)|0;O()|0;$b(c+16|0);_(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;dm(v[v[a>>2]-12>>2]+a|0,b);c:{d:{if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[23588]=0;Z(105);a=v[23588];v[23588]=0;if((a|0)!=1){break c}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)==1){break d}T(a|0);L()}$();break a}V(0)|0;O()|0;Ub()}L()}$b(c+16|0);v[b>>2]=v[c+20>>2]}Ki(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}jb=c+32|0;return a|0}function zea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=jb-80|0;jb=c;a:{d=v[a+4>>2];b:{if(d>>>0<b>>>0){f=ee(c+72|0);e=b-d|0;g=Ct(a);c:{if(!(e>>>0>g>>>0|d>>>0>g-e>>>0)){Cm(c+56|0,v[a>>2],d);gc(f,v[c+56>>2],v[c+60>>2]);v[a+4>>2]=v[a+4>>2]+e;break c}d=go(c+56|0);v[23588]=0;b=Q(728,a|0,b|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break a}v[23588]=0;R(729,d|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break a}v[d+4>>2]=v[a+4>>2]+e;ul(c+40|0,v[a>>2]);Cm(c+32|0,v[a>>2],v[a+4>>2]);ul(c+24|0,v[d>>2]);b=v[c+44>>2];v[c+8>>2]=v[c+40>>2];v[c+12>>2]=b;nR(c+48|0,c+8|0,v[c+32>>2],v[c+36>>2],v[c+24>>2],v[c+28>>2]);gc(f,v[c+48>>2],v[c+52>>2]);Lt(a,d);Ve(d)}a=gc(c+16|0,v[f>>2],v[f+4>>2]);pv(v[a>>2],v[a+4>>2],e,0);break b}v[a+4>>2]=b}jb=c+80|0;return}a=P()|0;O()|0;Ve(d);T(a|0);L()}function nL(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=jb-16|0;jb=c;e=v[b+4220>>2];f=v[b+4224>>2];g=v[b+4228>>2];h=v[b+4232>>2];i=v[b+4240>>2];j=v[b+4236>>2];l=w[b+4244|0];k=b+4208|0;Ri(k,33);d=v[k>>2];t[d+32|0]=l;t[d+24|0]=j;t[d+25|0]=j>>>8;t[d+26|0]=j>>>16;t[d+27|0]=j>>>24;t[d+28|0]=i;t[d+29|0]=i>>>8;t[d+30|0]=i>>>16;t[d+31|0]=i>>>24;t[d+16|0]=g;t[d+17|0]=g>>>8;t[d+18|0]=g>>>16;t[d+19|0]=g>>>24;t[d+20|0]=h;t[d+21|0]=h>>>8;t[d+22|0]=h>>>16;t[d+23|0]=h>>>24;t[d+8|0]=e;t[d+9|0]=e>>>8;t[d+10|0]=e>>>16;t[d+11|0]=e>>>24;t[d+12|0]=f;t[d+13|0]=f>>>8;t[d+14|0]=f>>>16;t[d+15|0]=f>>>24;t[d|0]=76;t[d+1|0]=70;t[d+2|0]=79;t[d+3|0]=32;t[d+4|0]=0;t[d+5|0]=0;t[d+6|0]=0;t[d+7|0]=0;re(c+8|0,v[k>>2],v[b+4212>>2]);gc(a,v[c+8>>2],v[c+12>>2]);jb=c+16|0}function VK(a){var b=0,c=0,d=0,e=0;b=jb-16|0;jb=b;e=(p(a),j(2));c=e&2147483647;a:{if(c>>>0<=1061752794){if(c>>>0<964689920){break a}a=gi(+a);break a}if(c>>>0<=1081824209){d=+a;if(c>>>0<=1075235811){if((e|0)<0){a=C(-fi(d+1.5707963267948966));break a}a=fi(d+-1.5707963267948966);break a}a=gi(-(((e|0)>=0?-3.141592653589793:3.141592653589793)+d));break a}if(c>>>0<=1088565717){if(c>>>0<=1085271519){d=+a;if((e|0)<0){a=fi(d+4.71238898038469);break a}a=C(-fi(d+-4.71238898038469));break a}a=gi(((e|0)<0?6.283185307179586:-6.283185307179586)+ +a);break a}if(c>>>0>=2139095040){a=C(a-a);break a}b:{switch(ax(a,b+8|0)&3){case 0:a=gi(A[b+8>>3]);break a;case 1:a=fi(A[b+8>>3]);break a;case 2:a=gi(-A[b+8>>3]);break a;default:break b}}a=C(-fi(A[b+8>>3]))}jb=b+16|0;return a}function pI(a){var b=C(0),c=C(0),d=C(0),e=C(0),f=C(0),g=C(0),h=C(0),i=C(0),j=C(0),k=C(0),l=C(0),m=C(0),n=C(0),o=C(0);f=z[a>>2];i=z[a+24>>2];c=C(f-i);d=z[a+16>>2];b=z[a+32>>2];g=z[a+8>>2];e=C(d+C(b-g));z[a+16>>2]=c+e;j=C(c-C(e*C(.5)));c=z[a+4>>2];e=z[a+20>>2];h=z[a+28>>2];k=C(C(C(c-e)-h)*C(.8660253882408142));z[a+4>>2]=j+k;l=C(C(d-b)*C(.1736481785774231));f=C(f+C(i*C(.5)));i=C(C(g+b)*C(.7660444378852844));m=C(l+C(f-i));n=C(C(c+e)*C(.9848077297210693));b=C(z[a+12>>2]*C(.8660253882408142));c=C(C(c+h)*C(.6427876353263855));o=C(C(n-b)-c);z[a+12>>2]=m+o;z[a+20>>2]=m-o;z[a+28>>2]=j-k;d=C(C(g+d)*C(.9396926164627075));g=C(C(f+d)-l);e=C(C(e-h)*C(.3420201539993286));h=C(C(e-b)-n);z[a+32>>2]=g+h;d=C(C(f-d)+i);b=C(C(b+e)-c);z[a+24>>2]=d+b;z[a+8>>2]=d-b;z[a>>2]=g-h}function wN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{f=jb-16|0;jb=f;e=Lb(a);d=Oi(b);v[f+8>>2]=d;g=gr(b);a=0;b:{while(1){c:{if(!Ob(d,g)){if(!a){break c}v[23588]=0;R(49,e|0,65533);a=v[23588];v[23588]=0;if((a|0)!=1){break c}break b}b=w[d|0];d:{e:{if(!a){if(!(b&128)){a=0;v[23588]=0;R(49,e|0,b|0);b=v[23588];v[23588]=0;if((b|0)!=1){break d}break b}if((b&224)==192){c=b&31;a=1;break d}if((b&240)==224){c=b&15;a=2;break d}c=65533;if((b&248)!=240){break e}c=b&7;a=3;break d}if((b&192)!=128){c=0;v[23588]=0;R(49,e|0,65533);d=v[23588];v[23588]=0;a=0;if((d|0)==1){break b}}c=b&63|c<<6;a=a-1|0;if(a){break d}}a=0;v[23588]=0;R(49,e|0,c|0);b=v[23588];v[23588]=0;c=0;if((b|0)==1){break b}}d=v[Ge(f+8|0)>>2];continue}break}jb=f+16|0;break a}a=P()|0;O()|0;Fc(e);T(a|0);L()}}function Tga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=jb-16|0;jb=e;t[e+15|0]=0;u[e+12>>1]=0;j=8;n=B(c,d)<<1;a:while(1){if((d|0)!=(k|0)){h=(k<<1)+b|0;o=n+h|0;while(1){b:{c:{if(h>>>0<o>>>0){u[e+10>>1]=0;pS(a,e+15|0,e+12|0,j,e+10|0);i=x[e+10>>1];f=x[e+12>>1];c=j;while(1){if(c&255){g=f<<1;f=g&254;d:{if(f){g=(g&65534)>>>0>255;break d}if(!nf(a,e+9|0)){break c}f=w[e+9|0];g=f>>>7|0;f=f<<1&254|1}c=c-1|0;i=i<<1|g;continue}break}u[e+12>>1]=f;break b}k=k+1|0;continue a}u[e+12>>1]=0}c=1;g=i&65535;e:{if(g>>>0<4){break e}f=15;while(1){c=f;m=f&255;if(g>>>m&1){break e}f=c-1|0;if(m>>>0>1){continue}break}}f=i&1;t[e+15|0]=f;l=(f-1^(i&65534)>>>1)+l|0;u[e+10>>1]=l;u[h>>1]=l;h=(d<<1)+h|0;j=(c+j&254)>>>1|0;continue}}break}jb=e+16|0}function S_(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=jb-16|0;jb=k;a:{if(a){a=ZF(c);b:{if(b){Rk(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Qk(k,a);break b}Lr(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Nh(k,a)}Vi(i,k);Fc(k);l=e,m=$i(a),v[l>>2]=m;l=f,m=aj(a),v[l>>2]=m;bh(k,a);Ac(g,k);yb(k);Oh(k,a);Vi(h,k);Fc(k);a=Pk(a);break a}a=YF(c);c:{if(b){Rk(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Qk(k,a);break c}Lr(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Nh(k,a)}Vi(i,k);Fc(k);l=e,m=$i(a),v[l>>2]=m;l=f,m=aj(a),v[l>>2]=m;bh(k,a);Ac(g,k);yb(k);Oh(k,a);Vi(h,k);Fc(k);a=Pk(a)}v[j>>2]=a;jb=k+16|0}function SX(a){a=a|0;var b=0,c=0,d=0,e=0;c=jb-192|0;jb=c;b=c+16|0;oi(b,a);v[23588]=0;R(88,c+32|0,b|0);a=v[23588];v[23588]=0;a:{b:{c:{d:{e:{if((a|0)!=1){v[23588]=0;a=Q(89,c+48|0,c+32|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break e}yb(c+32|0);yb(c+16|0);b=v[v[a>>2]-12>>2];v[23588]=0;d=ga(62)|0;e=v[23588];v[23588]=0;if((e|0)==1){break c}v[23588]=0;U(63,c+8|0,a+b|0,d|0);b=v[23588];v[23588]=0;if((b|0)==1){break c}$b(c+8|0);b=a+v[v[a>>2]-12>>2]|0;v[b+4>>2]=v[b+4>>2]&-75;v[b+4>>2]=v[b+4>>2]|8;v[23588]=0;b=Q(95,a|0,c+32|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break c}a=Zk(v[(b+v[v[b>>2]-12>>2]|0)+16>>2]);d=v[c+32>>2];rf(b);jb=c+192|0;a=a?0:d;break a}b=P()|0;O()|0;break d}b=P()|0;O()|0;yb(c+32|0)}yb(c+16|0);break b}b=P()|0;O()|0;rf(a)}T(b|0);L()}return a|0}function F6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=jb+-64|0;jb=f;v[f+56>>2]=d;d=dg(a,f+56|0);g=Gc(d+4|0);h=Gc(d+24|0);i=Gc(d+32|0);j=Sb(d+36|0);v[d+56>>2]=3;k=Sb(d+68|0);v[23588]=0;R(947,d|0,e|0);a=v[23588];v[23588]=0;a:{b:{c:{d:{if((a|0)!=1){fc(f+24|0,b,c);a=ee(f+16|0);v[23588]=0;b=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=b;Ha(951,f+32|0,v[f+24>>2],v[f+28>>2],f+8|0);a=v[23588];v[23588]=0;if((a|0)==1){break d}v[23588]=0;U(948,d|0,f+32|0,e|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}Ab(f+32|0);v[23588]=0;Y(949,d|0);a=v[23588];v[23588]=0;if((a|0)!=1){break a}}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;Ab(f+32|0)}We(k);Wf(j);As(i);jj(h);ij(g);De(d);De(f+56|0);T(e|0);L()}De(f+56|0);jb=f- -64|0;return d|0}function mL(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=C(0);c=jb-80|0;jb=c;d=v[b>>2];b=v[b+4>>2];e=ee(c+48|0);f=v[e+4>>2];v[c>>2]=v[e>>2];v[c+4>>2]=f;b=pr(c+56|0,d,b,c);v[23588]=0;d=S(202,b|0)|0;e=v[23588];v[23588]=0;a:{if((e|0)==1){break a}v[23588]=0;d=W(905,b|0,c+8|0,d|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break a}b:{if(!d){break b}if(Rb(c+8|0,17588,4)|v[c+12>>2]){break b}g=a,h=Xd(z[c+16>>2],C(0)),z[g+4220>>2]=h;g=a,h=Xd(z[c+20>>2],C(0)),z[g+4224>>2]=h;g=a,h=Xd(z[c+24>>2],C(0)),z[g+4228>>2]=h;d=v[c+28>>2];if(d>>>0<=5){v[a+4232>>2]=d}v[a+4236>>2]=v[c+32>>2];t[a+4240|0]=w[c+36|0]!=0;t[a+4241|0]=w[c+37|0]!=0;t[a+4242|0]=w[c+38|0]!=0;t[a+4243|0]=w[c+39|0]!=0;t[a+4244|0]=w[c+40|0]!=0;Ss(a)}Ab(b);jb=c+80|0;return}a=P()|0;O()|0;Ab(b);T(a|0);L()}function W_(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=jb-16|0;jb=k;a:{if(a){a=aG(c);b:{if(b){Rk(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Qk(k,a);break b}Lr(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Nh(k,a)}Ac(i,k);yb(k);l=e,m=$i(a),t[l|0]=m;l=f,m=aj(a),t[l|0]=m;bh(k,a);Ac(g,k);yb(k);Oh(k,a);Ac(h,k);yb(k);a=Pk(a);break a}a=$F(c);c:{if(b){Rk(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Qk(k,a);break c}Lr(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Nh(k,a)}Ac(i,k);yb(k);l=e,m=$i(a),t[l|0]=m;l=f,m=aj(a),t[l|0]=m;bh(k,a);Ac(g,k);yb(k);Oh(k,a);Ac(h,k);yb(k);a=Pk(a)}v[j>>2]=a;jb=k+16|0}function cp(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=jb-32|0;jb=d;v[d+28>>2]=0;a:{b:{c:{if(Pd(w[fm(d+24|0,a,0)|0])){f=d+16|0;fd(f,v[v[a>>2]-12>>2]+a|0);v[23588]=0;f=S(1097,f|0)|0;e=v[23588];v[23588]=0;d:{e:{if((e|0)==1){break e}e=Rm(d+8|0,a);g=Gc(d);h=v[v[a>>2]-12>>2];g=v[g>>2];e=v[e>>2];v[23588]=0;ma(c|0,f|0,e|0,g|0,a+h|0,d+28|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break e}$b(d+16|0);break d}b=V(0)|0;O()|0;$b(d+16|0);_(b|0)|0;b=v[d+28>>2]|1;v[d+28>>2]=b;dm(v[v[a>>2]-12>>2]+a|0,b);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[23588]=0;Z(105);a=v[23588];v[23588]=0;if((a|0)!=1){break b}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)==1){break c}T(a|0);L()}$()}Ki(v[v[a>>2]-12>>2]+a|0,v[d+28>>2])}jb=d+32|0;break a}V(0)|0;O()|0;Ub()}L()}return a}function YR(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;while(1){if((c|0)!=20){g=b;b=t[a+c|0];b=g+((b&255)!=0&(b|0)<32)|0;c=c+1|0;continue}break}d=b;a:{if(b>>>0>5){break a}while(1){if((h|0)!=15){e=B(h,30)+a|0;f=e+20|0;c=0;b=0;while(1){if((c|0)!=22){g=b;b=t[c+f|0];b=g+((b&255)!=0&(b|0)<32)|0;c=c+1|0;continue}break}d=b+d|0;if(d>>>0>48){break a}c=w[e+45|0];if(w[e+44|0]|c>>>0>64){break a}b=Hb(w[e+42|0]|w[e+43|0]<<8);if(b>>>0>32768){break a}h=h+1|0;i=c|i;j=b+j|0;continue}break}if(!j|!(i&255)){break a}d=w[a+470|0];if(d>>>0>128){break a}b=w[a+471|0];if(b>>>0>220){break a}a=a+472|0;f=dA(a);b:{if((a|0)==(f|0)){break b}c=a;while(1){c=c+1|0;if((f|0)==(c|0)){break b}a=Kr(w[a|0],w[c|0])?c:a;continue}}a=w[a|0];if(a>>>0>63){break a}k=(b|(a|d))!=0}return k}function L6(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;f=jb-16|0;jb=f;if(a){a=qc(f+8|0,a);e=v[a+4>>2];c=v[a>>2];a=jb-16|0;jb=a;v[a>>2]=c;v[a+4>>2]=e;v[a+8>>2]=c;v[a+12>>2]=e;b=jb+-64|0;jb=b;e=a;c=0;a:{if(!v[a+4>>2]){break a}g=v[e>>2];h=v[e+4>>2];a=32224;while(1){if((a|0)==32624){c=32624;while(1){a=c;if((a|0)!=32672){v[b+40>>2]=g;v[b+44>>2]=h;c=qc(b+32|0,v[a+8>>2]);d=v[b+44>>2];v[b+8>>2]=v[b+40>>2];v[b+12>>2]=d;d=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=d;c=a+12|0;if(!lM(b+8|0,b)){continue}}break}c=(a|0)!=32672;break a}v[b+56>>2]=g;v[b+60>>2]=h;c=qc(b+48|0,v[a+4>>2]);d=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=d;d=v[c+4>>2];v[b+16>>2]=v[c>>2];v[b+20>>2]=d;a=a+8|0;if(!lM(b+24|0,b+16|0)){continue}break}c=1}jb=b- -64|0;jb=e+16|0}jb=f+16|0;return c|0}function Iv(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb+-64|0;jb=e;v[e+60>>2]=d;a:{f=v[b>>2];b:{if(!(nb[v[v[f>>2]+36>>2]](f,c,d)|0)){Ih(a);break b}Pl(e+40|0,v[b>>2],v[b+4>>2]);b=v[b>>2];d=v[v[b>>2]+24>>2];v[23588]=0;b=S(d|0,b|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break a}v[e+36>>2]=b-c;g=v[Jb(e+60|0,e+36|0)>>2];b=v[e+44>>2];v[e+16>>2]=v[e+40>>2];v[e+20>>2]=b;b=jb-16|0;jb=b;d=e+16|0;f=Pl(b+8|0,v[d>>2],v[d+4>>2]);v[23588]=0;h=v[f+4>>2];v[b>>2]=v[f>>2];v[b+4>>2]=h;X(172,e+48|0,b|0,c|0,g|0);c=v[23588];v[23588]=0;c:{if((c|0)!=1){le(d);jb=b+16|0;break c}a=P()|0;O()|0;le(d);T(a|0);L()}b=ee(e+24|0);c=v[e+52>>2];v[e+8>>2]=v[e+48>>2];v[e+12>>2]=c;c=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=c;Dv(a,e+8|0,e)}jb=e- -64|0;return}a=P()|0;O()|0;le(e+40|0);T(a|0);L()}function Ey(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;a:{if(!d){break a}if(c){t[b+815|0]=c;break a}c=w[b+815|0]}f=v[a+480180>>2];d=f&1048580;c=d?(c&240?-16:15)&c:c;b:{c:{d:{if(!d){d=c&240;e:{f:{g:{h:{c=c&15;if((c|0)==15){a=v[a+480208>>2]&4096;if(!d){break h}if(!a){break b}a=0-(d>>>2|0)|0;break d}a=v[a+480208>>2]&4096;if(!c|(d|0)!=240){break g}if(!a){break b}c=c<<2;break c}d=0;if(!a){break f}break b}if(a){break b}if(!c){break e}}c=c<<2;if(!(f&16777248)|!d){break c}break b}a=0-(d>>>2|0)|0;break d}if(w[a+480209|0]&16){break b}Cb(e+8|0,a+1074312|0,56);a=c&240;a=a?a>>>2|0:0-(c<<2&60)|0;if(!Bb(v[v[e+8>>2]>>2],v[e+12>>2])){break d}a=(a|0)/4<<24>>24}c=a;if(!c){break b}}a=v[b+692>>2];u[b+784>>1]=0;g=b,h=Xb(a+c|0,0,256),v[g+692>>2]=h}jb=e+16|0}function $p(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=jb-16|0;jb=h;f=v[a>>2];e=v[a+4>>2];i=_d(f,e)-1|0;while(1){a:{b:{if(_d(f,e)-1>>>0<=g>>>0){g=i;break b}if(x[Oc(f,e,g)>>1]<(b|0)){break a}e=v[a+4>>2];f=v[a>>2]}i=x[Oc(f,e,g)>>1];f=0;v[h+12>>2]=0;c:{if((b|0)>=(i|0)){j=h,k=(w[Oc(v[a>>2],v[a+4>>2],g)+2|0]<<16)/(d|0)|0,v[j+12>>2]=k;break c}e=0;if(g){e=g-1|0;f=(w[Oc(v[a>>2],v[a+4>>2],e)+2|0]<<16)/(d|0)|0;v[h+12>>2]=f;e=x[Oc(v[a>>2],v[a+4>>2],e)>>1]}if((b|0)<=(e|0)|e>>>0>=i>>>0){break c}a=((w[Oc(v[a>>2],v[a+4>>2],g)+2|0]<<16)/(d|0)|0)-f|0;d=a;g=a>>31;a=b-e|0;b=Lka(d,g,a,a>>31);a=i-e|0;j=h,k=Hc(Mka(b,mb,a,a>>31),mb)+f|0,v[j+12>>2]=k}oe(h+12|0,0,65536);jb=h+16|0;return(B(v[h+12>>2],c)+32768|0)/65536|0}g=g+1|0;e=v[a+4>>2];f=v[a>>2];continue}}function Naa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=jb-48|0;jb=e;g=Lc(b);d=Gb(b);i=Lc(c);h=Gb(c);d=d+g|0;f=-1;a:{while(1){if((d|0)==(g|0)){break a}d=d-1|0;if(Cp(i,h,w[d|0])){continue}break}f=d-g|0}b:{c:{if((f|0)!=-1){k=e,l=he(b),v[k+16>>2]=l;k=e,l=Fp(e+16|0,f),v[k+24>>2]=l;k=e,l=Fp(e+24|0,1),v[k+32>>2]=l;c=lj(e+40|0,e+32|0);k=e,l=yh(b),v[k>>2]=l;d=lj(e+8|0,e);NL(b,v[c>>2],v[d>>2]);break c}if(!Gb(b)){break c}g=Lc(b);d=Gb(b);i=Lc(c);h=Gb(c);if(!d|!h){c=-1}else{c=g;f=d+c|0;h=h+i|0;while(1){d:{d=i;e:{if((c|0)!=(f|0)){while(1){if((d|0)==(h|0)){break e}j=t[d|0];d=d+1|0;if(!oc(t[c|0],j)){continue}break}}else{c=f}break d}c=c+1|0;continue}break}c=(c|0)==(f|0)?-1:c-g|0}if(c){break c}Lb(a);break b}$c(a,b)}jb=e+48|0}function zp(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0;o(+a);b=j(1)|0;d=j(0)|0;a:{b:{c:{d:{if((b|0)>0|(b|0)>=0){f=b;if(b>>>0>1048575){break d}}if(!(b&2147483647|d)){return-1/(a*a)}if((b|0)>0|(b|0)>=0){break c}return(a-a)/0}if(f>>>0>2146435071){break a}b=1072693248;g=-1023;if((f|0)!=1072693248){b=f;break b}if(d){break b}return 0}o(+(a*0x40000000000000));b=j(1)|0;d=j(0)|0;g=-1077}b=b+614242|0;h=+((b>>>20|0)+g|0);e=h*.6931471803691238;l(0,d|0);l(1,(b&1048575)+1072079006|0);a=+n()+-1;c=a/(a+2);i=e;k=a;m=c;e=a*(a*.5);c=c*c;a=c*c;a=i+(k+(m*(e+(a*(a*(a*.15313837699209373+.22222198432149784)+.3999999999940942)+c*(a*(a*(a*.14798198605116586+.1818357216161805)+.2857142874366239)+.6666666666666735)))+h*1.9082149292705877e-10-e))}return a}function yC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;g=jb-16|0;jb=g;e=v[b>>2];d=Qc(e,v[b+4>>2]);a:{if(d>>>0<c>>>0){i=jb-32|0;jb=i;d=c-d|0;f=v[Fb(b)>>2];e=v[b+4>>2];b:{if(d>>>0<=f-e>>1>>>0){f=jb-16|0;jb=f;e=_h(f,b,d);d=v[e+4>>2];h=v[e+8>>2];while(1){if((d|0)==(h|0)){kc(e);jb=f+16|0}else{Fo(d);d=d+2|0;v[e+4>>2]=d;continue}break}break b}f=Fb(b);e=Mj(i+8|0,Nj(b,Qc(v[b>>2],e)+d|0),Qc(v[b>>2],v[b+4>>2]),f);h=jb-16|0;jb=h;d=No(h,e+8|0,d);f=v[d>>2];while(1){if(v[d+4>>2]!=(f|0)){Fo(f);f=v[d>>2]+2|0;v[d>>2]=f;continue}break}Td(d);jb=h+16|0;Dd(b,e);Ni(e)}jb=i+32|0;break a}if(c>>>0<d>>>0){Nd(b,e+(c<<1)|0)}}c=Pb(v[a>>2],v[a+8>>2],c<<1);if(c){d=v[b>>2];fc(g+8|0,d,Qc(d,v[b+4>>2])<<1);td(g,a,v[g+8>>2],v[g+12>>2])}jb=g+16|0;return c|0}function dl(a,b,c){var d=0,e=0,f=0,g=0;e=jb-48|0;jb=e;d=v[a+24>>2];g=v[d+24620>>2];a:{if(!((g|0)==(b|0)&v[d+24624>>2]==(c|0))){f=e+8|0;tc(f,d+24604|0,40);v[e+28>>2]=c;v[e+24>>2]=b;c=v[e+44>>2];Bs(f,v[e+40>>2]);bo(f,c);ry(d,f);if((b|0)==(g|0)){break a}c=v[a+24>>2]+906300|0;d=ek(c);while(1){if((c|0)!=(d|0)){b=v[c>>2];b:{if(!b){break b}if(!(nb[v[v[b>>2]+120>>2]](b)|0)){break b}nb[v[v[b>>2]+112>>2]](b,0);nb[v[v[b>>2]+100>>2]](b);nb[v[v[b>>2]+128>>2]](b)}c=c+160|0;continue}break}c=v[a+24>>2]+906300|0;d=ek(c);while(1){if((c|0)!=(d|0)){b=v[c>>2];c:{if(!b){break c}if(nb[v[v[b>>2]+120>>2]](b)|0){break c}nb[v[v[b>>2]+112>>2]](b,1);nb[v[v[b>>2]+124>>2]](b)}c=c+160|0;continue}break}break a}if(w[a+29|0]){break a}uM(d,1)}t[a+29|0]=1;jb=e+48|0}function z3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-80|0;jb=d;a=v[a+4>>2];Wv(d+16|0,b);v[23588]=0;b=Q(1,d|0,17734)|0;e=v[23588];v[23588]=0;a:{b:{c:{d:{e:{f:{g:{h:{if((e|0)!=1){v[23588]=0;U(2,d+32|0,d+16|0,b|0);e=v[23588];v[23588]=0;if((e|0)==1){break h}v[23588]=0;U(477,d+48|0,d+32|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break g}v[23588]=0;R(1015,d- -64|0,d+48|0);c=v[23588];v[23588]=0;if((c|0)==1){break f}c=v[v[a>>2]+8>>2];v[23588]=0;R(c|0,a|0,d- -64|0);a=v[23588];v[23588]=0;if((a|0)==1){break e}yb(d- -64|0);zb(d+48|0);zb(d+32|0);zb(b);zb(d+16|0);jb=d+80|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;yb(d- -64|0)}zb(d+48|0)}zb(d+32|0)}zb(b)}zb(d+16|0);T(a|0);L()}function mca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=jb-48|0;jb=g;h=a+8|0;c=v[a+8>>2];j=Bc(a);a:{if((c|0)!=v[j>>2]){break a}i=a+4|0;d=v[a+4>>2];e=v[a>>2];if(d>>>0>e>>>0){a=((d-e>>2)+1|0)/-2<<2;c=Pi(d,c,a+d|0);v[h>>2]=c;v[i>>2]=a+v[i>>2];break a}v[g+24>>2]=c-e>>1;v[g+44>>2]=1;d=g+24|0;c=v[Yc(d,g+44|0)>>2];c=Uf(d,c,c>>>2|0,v[a+16>>2]);e=ec(g+16|0,v[a+4>>2]);f=v[ec(g+8|0,v[a+8>>2])>>2];d=jb-32|0;jb=d;e=v[e>>2];v[d+24>>2]=e;e=Vm(d+8|0,c+8|0,bu(f,e));f=v[e>>2];while(1){if(v[e+4>>2]!=(f|0)){k=f;f=v[d+24>>2];Hm(k,x[f>>1]|x[f+2>>1]<<16);f=v[e>>2]+4|0;v[e>>2]=f;Ke(d+24|0);continue}break}Td(e);jb=d+32|0;pc(a,c);pc(i,c+4|0);pc(h,c+8|0);pc(j,Bc(c));Tf(c);c=v[a+8>>2]}Hm(c,x[b>>1]|x[b+2>>1]<<16);v[h>>2]=v[h>>2]+4;jb=g+48|0}function Sga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=jb-16|0;jb=e;t[e+15|0]=0;u[e+12>>1]=0;n=B(c,d);j=4;a:while(1){if((d|0)!=(k|0)){h=b+k|0;o=n+h|0;while(1){b:{c:{if(h>>>0<o>>>0){t[e+11|0]=0;oS(a,e+15|0,e+12|0,e+11|0);i=w[e+11|0];f=x[e+12>>1];c=j;while(1){if(c&255){g=f<<1;f=g&254;d:{if(f){g=(g&65534)>>>0>255;break d}if(!nf(a,e+10|0)){break c}f=w[e+10|0];g=f>>>7|0;f=f<<1&254|1}c=c-1|0;i=i<<1|g;continue}break}u[e+12>>1]=f;break b}k=k+1|0;continue a}u[e+12>>1]=0}c=1;g=i&255;e:{if(g>>>0<4){break e}f=7;while(1){c=f;m=f&255;if(g>>>m&1){break e}f=c-1|0;if(m>>>0>1){continue}break}}f=i&1;t[e+15|0]=f;l=(f-1^(i&254)>>>1)+l|0;t[e+11|0]=l;t[h|0]=l;h=d+h|0;j=(c+j&254)>>>1|0;continue}}break}jb=e+16|0}function yE(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=jb-32|0;jb=h;f=of(h+16|0,1,0);a:{b:{while(1){j=h+8|0;e=zc(f);g=e;i=Gb(f)+e|0;e=w[b|0];c:{if((c|0)==10){bK(j,g,i,e);break c}k=c>>>0>e>>>0?1:B(c,c)>>>0>e>>>0?2:3;if((k|0)>(i-g|0)){v[j+4>>2]=61;v[j>>2]=i;break c}i=g+k|0;g=i;while(1){k=e&255;e=(k|0)/(c|0)|0;g=g-1|0;t[g|0]=w[(k-B(c,e)|0)+4898|0];if(e&255){continue}break}v[j+4>>2]=0;v[j>>2]=i}if(!v[h+12>>2]){break b}e=ch(Gb(f));v[23588]=0;R(59,f|0,e|0);e=v[23588];v[23588]=0;if((e|0)!=1){continue}break}break a}b=v[h+8>>2];c=zc(f);v[23588]=0;R(60,f|0,b-c|0);b=v[23588];v[23588]=0;d:{if((b|0)!=1){v[23588]=0;R(d|0,a|0,f|0);a=v[23588];v[23588]=0;if((a|0)!=1){break d}break a}break a}yb(f);jb=h+32|0;return}a=P()|0;O()|0;yb(f);T(a|0);L()}function KM(a,b){var c=C(0),d=C(0),e=C(0);a:{b:{c:{switch(b|0){case 0:Ip(a,C(1));dk(a,C(3.725290298461914e-9));Hp(a,C(268435456));Gp(a,0);break b;case 1:Ip(a,C(32));dk(a,C(4.656612873077393e-10));Hp(a,C(2147483648));Gp(a,0);break b;case 2:Ip(a,C(2));dk(a,C(7.450580596923828e-9));Hp(a,C(134217728));Gp(a,1);break b;default:Ip(a,C(1));dk(a,C(7.450580596923828e-9));Hp(a,C(134217728));Gp(a,1);jy(a,0);iy(a,1);hy(a,1);d=C(256);c=C(128);e=C(128);b=0;break a;case 4:case 5:break c}}Ip(a,C(.75));dk(a,C(7.450580596923828e-9));Hp(a,C(134217728));Gp(a,1);jy(a,0);b=(b|0)==4;iy(a,b?2:3);hy(a,1);d=C(256);c=b?C(256):C(192);e=c;b=1;break a}jy(a,1);iy(a,0);hy(a,0);d=C(128);e=C(100);c=C(256);b=4}z[a+16>>2]=c;z[a+20>>2]=e;z[a+24>>2]=d;v[a+28>>2]=b}function dS(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;o=v[b>>2];while(1){if((i|0)==128){ug(b,c);c=v[a+8>>2];d=c+d|0;i=x[e>>1];a:{b:{c:{if(!f){break c}j=f;f=h&65535;if((c+(j+(f<<11)|0)|0)!=(Vg(v[a>>2])&-2)){break c}cd(a,c+(f<<10)|0);if(!iA(a,16,1)){break b}u[e>>1]=8;break b}if((h&65535)==(k&65535)){h=k;break a}f=k<<8&16776960;if(!g){if((Vg(v[a>>2])|0)!=(d+B(f,i)|0)){break a}}cd(a,c+B(f,x[e>>1])|0);h=iA(a,64,1)?h:k}cd(a,c)}c=l&65535;d:{if(c>>>0>(h&65535)>>>0){if((d+(B(c,x[e>>1])<<8)|0)==(Vg(v[a>>2])|0)){break d}}if(c>>>0>=255){hA(b,254,65534);hA(b,255,65535)}l=h}a=l&65535}else{j=x[cc(o,i)>>1];m=j+1|0;n=(h&65535)>>>0>j>>>0|j>>>0>127;k=n?k:c>>>0>i>>>0?m:k;l=(l&65535)>>>0>j>>>0?l:m;h=n?h:m;i=i+1|0;continue}break}return a}function Vn(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;g=jb-16|0;jb=g;if(e){v[e>>2]=0}a:{h=v[a+484344>>2];if(!xe(h,v[a+484348>>2],b)){break a}i=Yb(h,b);k=v[i+48>>2];b=id(v[i>>2],v[k+12>>2],c,d);f=w[b+5|0];b:{c:{d:{e:{j=w[b+3|0];switch(j-10|0){case 1:case 3:case 5:case 6:break a;case 0:break c;case 2:case 4:case 7:break d;default:break e}}if(j-35>>>0>=2){break a}}v[g+12>>2]=1;h=0;if((j|0)!=17){break b}h=v[a+480180>>2]==4;break b}v[g+12>>2]=2;h=0}v[g+8>>2]=v[i+12>>2]+(c^-1);d=0;c=v[Jb(g+8|0,g+12|0)>>2];a=c;while(1){f:{if(a){b=B(Pg(v[k+12>>2]),6)+b|0;if(w[b+3|0]==34){break f}c=d}f=(j-37&255)>>>0<254?f:c?f:f<<8;if(!e){break a}v[e>>2]=c;break a}i=f<<8;f=w[b+5|0]|(h?f>>>0<256?i+-8192|0:i:i);d=d+1|0;a=a-1|0;continue}}jb=g+16|0;return f}function NH(a,b,c,d){a:{switch(b-9|0){case 0:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=v[b>>2];return;case 6:b=v[c>>2];v[c>>2]=b+4;b=u[b>>1];v[a>>2]=b;v[a+4>>2]=b>>31;return;case 7:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=x[b>>1];v[a+4>>2]=0;return;case 8:b=v[c>>2];v[c>>2]=b+4;b=t[b|0];v[a>>2]=b;v[a+4>>2]=b>>31;return;case 9:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=w[b|0];v[a+4>>2]=0;return;case 16:b=v[c>>2]+7&-8;v[c>>2]=b+8;A[a>>3]=A[b>>3];return;case 17:nb[d|0](a,c);default:return;case 1:case 4:case 14:b=v[c>>2];v[c>>2]=b+4;b=v[b>>2];v[a>>2]=b;v[a+4>>2]=b>>31;return;case 2:case 5:case 11:case 15:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=v[b>>2];v[a+4>>2]=0;return;case 3:case 10:case 12:case 13:break a}}b=v[c>>2]+7&-8;v[c>>2]=b+8;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c}function Kea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;g=jb-16|0;jb=g;e=v[b>>2];d=qg(e,v[b+4>>2]);a:{if(d>>>0<c>>>0){i=jb-32|0;jb=i;d=c-d|0;f=v[Fb(b)>>2];e=v[b+4>>2];b:{if(d>>>0<=f-e>>5>>>0){f=jb-16|0;jb=f;e=Lz(f,b,d);d=v[e+4>>2];h=v[e+8>>2];while(1){if((d|0)==(h|0)){kc(e);jb=f+16|0}else{aQ(d);d=d+32|0;v[e+4>>2]=d;continue}break}break b}f=Fb(b);e=Dt(i+8|0,cq(b,qg(v[b>>2],e)+d|0),qg(v[b>>2],v[b+4>>2]),f);h=jb-16|0;jb=h;d=bQ(h,e+8|0,d);f=v[d>>2];while(1){if(v[d+4>>2]!=(f|0)){aQ(f);f=v[d>>2]+32|0;v[d>>2]=f;continue}break}Td(d);jb=h+16|0;Dd(b,e);cQ(e)}jb=i+32|0;break a}if(c>>>0<d>>>0){Nd(b,e+(c<<5)|0)}}if(Pb(v[a>>2],v[a+8>>2],c<<5)){c=v[b>>2];fc(g+8|0,c,qg(c,v[b+4>>2])<<5);td(g,a,v[g+8>>2],v[g+12>>2])}jb=g+16|0}function RX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;h=jb-16|0;jb=h;f=od(b);d=yd(v[b+4>>2],w[b+11|0]);i=od(c);g=yd(v[c+4>>2],w[c+11|0]);d=d+f|0;e=-1;a:{while(1){if((d|0)==(f|0)){break a}d=d-1|0;if(nu(i,g,w[d|0])){continue}break}e=d-f|0}b:{c:{if((e|0)!=-1){c=ec(h+8|0,Qf(Qf(Oi(b),e),1));d=ec(h,gr(b));oD(b,v[c>>2],v[d>>2]);break c}if(!Fk(v[b+4>>2],w[b+11|0])){break c}f=od(b);d=yd(v[b+4>>2],w[b+11|0]);i=od(c);g=yd(v[c+4>>2],w[c+11|0]);if(!d|!g){c=-1}else{c=f;e=d+c|0;g=g+i|0;while(1){d:{d=i;e:{if((c|0)!=(e|0)){while(1){if((d|0)==(g|0)){break e}j=w[d|0];d=d+1|0;if(!oc(w[c|0],j)){continue}break}}else{c=e}break d}c=c+1|0;continue}break}c=(c|0)==(e|0)?-1:c-f|0}if(c){break c}Lb(a);break b}$c(a,b)}jb=h+16|0}function O6(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0;b=jb-48|0;jb=b;c=Lb(b+32|0);v[23588]=0;Y(940,b+16|0);a=v[23588];v[23588]=0;a:{b:{c:{d:{if((a|0)!=1){f=b,g=Eb(v[b+16>>2]),v[f+8>>2]=g;d=1;while(1){e=Eb(v[b+20>>2]);a=v[b+8>>2];if(!Ob(a,e)){a=fg(Lc(c));We(b+16|0);yb(c);break b}if(!d){v[23588]=0;Q(941,c|0,14575)|0;a=v[23588];v[23588]=0;if((a|0)==1){break d}a=v[b+8>>2]}v[23588]=0;Q(800,c|0,a|0)|0;a=v[23588];v[23588]=0;if((a|0)==1){break d}lq(b+8|0);d=0;continue}}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;We(b+16|0)}yb(c);_(a|0)|0;a=0;v[23588]=0;X(939,6988,0,0,0);c=v[23588];v[23588]=0;if((c|0)==1){break a}$()}jb=b+48|0;return a|0}b=P()|0;O()|0;v[23588]=0;Z(18);a=v[23588];v[23588]=0;if((a|0)==1){V(0)|0;O()|0;Ub();L()}T(b|0);L()}function iaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=jb-32|0;jb=f;c=Pg(v[v[a+48>>2]+12>>2]);a:{if(!b){break a}c=B(b,c);b:{if(v[a+12>>2]!=(b|0)){break b}if((pk(v[a>>2],v[a+4>>2])|0)!=(c|0)){break b}b=jb-16|0;jb=b;d=Eb(v[a>>2]);a=Eb(v[a+4>>2]);Ej(b+8|0);e=Ys(a,d);c=jb-16|0;jb=c;v[c+8>>2]=d;while(1){if((e|0)>0){a=v[c+8>>2];d=w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24);t[a|0]=d;t[a+1|0]=d>>>8;t[a+2|0]=d>>>16;t[a+3|0]=d>>>24;d=w[b+12|0]|w[b+13|0]<<8;t[a+4|0]=d;t[a+5|0]=d>>>8;e=e-1|0;Bk(c+8|0);continue}break}jb=c+16|0;jb=b+16|0;break a}e=f+8|0;Ej(e);c=xT(f+16|0,c,e);WL(a);v[a>>2]=v[c>>2];v[a+4>>2]=v[c+4>>2];e=Fb(c);g=Fb(a),h=v[e>>2],v[g>>2]=h;v[e>>2]=0;v[c>>2]=0;v[c+4>>2]=0;uk(c);v[a+12>>2]=b}jb=f+32|0}function UG(a,b,c,d,e,f){var g=0;g=jb-80|0;jb=g;a:{if((f|0)>=16384){Id(g+32|0,b,c,d,e,0,0,0,2147352576);d=v[g+40>>2];e=v[g+44>>2];b=v[g+32>>2];c=v[g+36>>2];if(f>>>0<32767){f=f-16383|0;break a}Id(g+16|0,b,c,d,e,0,0,0,2147352576);f=((f|0)<49149?f:49149)-32766|0;d=v[g+24>>2];e=v[g+28>>2];b=v[g+16>>2];c=v[g+20>>2];break a}if((f|0)>-16383){break a}Id(g- -64|0,b,c,d,e,0,0,0,7471104);d=v[g+72>>2];e=v[g+76>>2];b=v[g+64>>2];c=v[g+68>>2];if(f>>>0>4294934644){f=f+16269|0;break a}Id(g+48|0,b,c,d,e,0,0,0,7471104);f=((f|0)>-48920?f:-48920)+32538|0;d=v[g+56>>2];e=v[g+60>>2];b=v[g+48>>2];c=v[g+52>>2]}Id(g,b,c,d,e,0,0,0,f+16383<<16);b=v[g+12>>2];v[a+8>>2]=v[g+8>>2];v[a+12>>2]=b;b=v[g+4>>2];v[a>>2]=v[g>>2];v[a+4>>2]=b;jb=g+80|0}function si(a,b,c,d){var e=0,f=0,g=0;v[a+20>>2]=d;v[a+16>>2]=c;v[a+12>>2]=b;v[a+4>>2]=0;v[a+8>>2]=0;v[a>>2]=44312;c=a+24|0;v[c>>2]=0;v[c+4>>2]=0;v[c+16>>2]=0;v[c+8>>2]=0;v[c+12>>2]=0;b=Sb(a+44|0);g=Sb(b+12|0);e=Sb(b+24|0);f=Sb(b+36|0);v[23588]=0;R(897,b|0,0);d=v[23588];v[23588]=0;if((d|0)==1){a=P()|0;O()|0;vc(f);vc(e);Qs(g);Qs(b);T(a|0);L()}u[a+4204>>1]=0;v[a+4196>>2]=1065353216;v[a+4200>>2]=0;d=v[a+16>>2];v[d+946300>>2]=v[d+946300>>2]+1;v[v[a+20>>2]>>2]=a;v[23588]=0;e=S(898,a+92|0)|0;d=v[23588];v[23588]=0;a:{if((d|0)!=1){f=a+4200|0;v[c>>2]=e;c=v[a+16>>2]+906300|0;d=w[a+4200|0];b=v[a+20>>2];while(1){if((Ld(c,d)|0)==(b|0)|d>>>0>248){break a}d=d+1|0;t[f|0]=d;continue}}a=P()|0;O()|0;kL(b);T(a|0);L()}return a}function ax(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=jb-16|0;jb=e;g=(p(a),j(2));c=g&2147483647;a:{if(c>>>0<=1305022426){h=+a;f=h*.6366197723675814+6755399441055744+-6755399441055744;d=h+f*-1.5707963109016418+f*-1.5893254773528196e-8;A[b>>3]=d;g=d<-.7853981852531433;if(D(f)<2147483648){c=~~f}else{c=-2147483648}if(g){d=f+-1;A[b>>3]=h+d*-1.5707963109016418+d*-1.5893254773528196e-8;c=c-1|0;break a}if(!(d>.7853981852531433)){break a}d=f+1;A[b>>3]=h+d*-1.5707963109016418+d*-1.5893254773528196e-8;c=c+1|0;break a}if(c>>>0>=2139095040){A[b>>3]=C(a-a);c=0;break a}i=c;c=(c>>>23|0)-150|0;A[e+8>>3]=(l(2,i-(c<<23)|0),q());c=SH(e+8|0,e,c,1,0);d=A[e>>3];if((g|0)<0){A[b>>3]=-d;c=0-c|0;break a}A[b>>3]=d}jb=e+16|0;return c}function Hda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=jb-16|0;jb=b;f=v[a+40>>2];g=v[a+36>>2];j=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;k=v[a+32>>2];l=v[a+28>>2];m=v[a+8>>2];n=v[a+12>>2];while(1){if(d){e=v[b+8>>2];o=e>>>18|0;p=((((v[b+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+j|0;e=0;while(1){if((e|0)!=2){h=(e<<1)+p|0;i=u[h>>1];v[(e<<2)+b>>2]=i+((B(u[h+4>>1]-i|0,o)|0)/16384|0);e=e+1|0;continue}break}g=g+l|0;v[c>>2]=v[c>>2]+B(v[b>>2],g>>12);f=f+k|0;v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],f>>12);Qb(b+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=f;v[a+20>>2]=g>>12;v[a+36>>2]=g;v[a+24>>2]=f>>12;jb=b+16|0}function X0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=v[b+44>>2];i=v[b+24>>2];if(h>>>0<i>>>0){v[b+44>>2]=i;h=i}l=-1;m=-1;n=f&24;a:{if(!n|(e|0)==1&(n|0)==24){break a}if(h){g=h-zc(b+32|0)|0;o=g;g=g>>31}b:{c:{switch(e|0){case 1:if(f&8){e=v[b+12>>2]-v[b+8>>2]|0;j=e;k=e>>31;break b}e=i-v[b+20>>2]|0;j=e;k=e>>31;break b;case 0:break b;case 2:break c;default:break a}}j=o;k=g}d=d+k|0;c=c+j|0;d=j>>>0>c>>>0?d+1|0:d;e=c;c=d;if((g|0)<=(d|0)&e>>>0>o>>>0|(d|0)>(g|0)|(d|0)<0){break a}d=f&8;d:{if(!(c|e)){break d}if(v[b+12>>2]?0:d){break a}if(!(f&16)){break d}if(!i){break a}}if(d){d=v[b+8>>2];An(b,d,d+e|0,h)}if(f&16){Pw(b,v[b+20>>2],v[b+28>>2]);bs(b,e)}l=e;m=c}Xg(a,l,m)}function WE(a,b,c,d,e,f){var g=0,h=0,i=C(0),j=0;g=jb-80|0;jb=g;qy(v[a+24>>2]);t[v[a+24>>2]+1298420|0]=v[a+52>>2]!=0;v[g+40>>2]=b;v[g+36>>2]=c;v[g+32>>2]=d;i=z[a+48>>2];j=v[a+32>>2];v[g+8>>2]=b;c=v[g+36>>2];v[g>>2]=v[g+32>>2];v[g+4>>2]=c;d=jb-16|0;jb=d;v[d+8>>2]=v[g+8>>2];c=v[g+4>>2];v[d>>2]=v[g>>2];v[d+4>>2]=c;c=vJ(g+48|0);v[c+8>>2]=j;v[c+4>>2]=0;v[c>>2]=f;f=v[d+4>>2];v[c+12>>2]=v[d>>2];v[c+16>>2]=f;v[c+20>>2]=v[d+8>>2];z[c+24>>2]=i;v[c>>2]=e;jb=d+16|0;while(1){if(b){d=v[a+24>>2];v[g+24>>2]=b;v[g+28>>2]=0;v[g+16>>2]=134217727;v[g+20>>2]=0;d=yJ(d,v[Yq(g+24|0,g+16|0)>>2],c);h=d+h|0;b=b-d|0;if(d){continue}}break}if(!(v[a+52>>2]!=1|h)){a=v[a+24>>2];v[a+480208>>2]=v[a+480208>>2]&-513}jb=g+80|0;return h}function VR(a,b){var c=0,d=0,e=0;c=jb-32|0;jb=c;a:{if(!Pb(v[a>>2],v[a+8>>2],1024)){v[c+24>>2]=0;v[c+28>>2]=0;v[c+16>>2]=0;v[c+20>>2]=0;a=64;while(1){if(a){d=w[c+20|0]|w[c+21|0]<<8|(w[c+22|0]<<16|w[c+23|0]<<24);e=w[c+16|0]|w[c+17|0]<<8|(w[c+18|0]<<16|w[c+19|0]<<24);t[b|0]=e;t[b+1|0]=e>>>8;t[b+2|0]=e>>>16;t[b+3|0]=e>>>24;t[b+4|0]=d;t[b+5|0]=d>>>8;t[b+6|0]=d>>>16;t[b+7|0]=d>>>24;d=w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24);e=w[c+24|0]|w[c+25|0]<<8|(w[c+26|0]<<16|w[c+27|0]<<24);t[b+8|0]=e;t[b+9|0]=e>>>8;t[b+10|0]=e>>>16;t[b+11|0]=e>>>24;t[b+12|0]=d;t[b+13|0]=d>>>8;t[b+14|0]=d>>>16;t[b+15|0]=d>>>24;a=a-1|0;b=b+16|0;continue}break}break a}fA(c+8|0,b);td(c+16|0,a,v[c+8>>2],v[c+12>>2])}jb=c+32|0}function yn(a,b,c,d,e,f,g,h,i,j){var k=0,l=0,m=0,n=0;l=jb-16|0;jb=l;t[l+15|0]=a;a:{b:{c:{k=v[d>>2];if((k|0)!=(c|0)){break c}m=43;n=a&255;if((n|0)!=w[j+24|0]){m=45;if(w[j+25|0]!=(n|0)){break c}}v[d>>2]=c+1;t[c|0]=m;break b}if(!(!Gb(g)|(a|0)!=(f|0))){a=0;b=v[i>>2];if((b-h|0)>159){break a}a=v[e>>2];v[i>>2]=b+4;v[b>>2]=a;break b}a=-1;f=wi(j,j+26|0,l+15|0)-j|0;if((f|0)>23){break a}d:{e:{switch(b-8|0){case 0:case 2:if((b|0)>(f|0)){break d}break a;case 1:break d;default:break e}}if((b|0)!=16|(f|0)<22){break d}if((c|0)==(k|0)|(k-c|0)>2|w[k-1|0]!=48){break a}a=0;v[e>>2]=0;v[d>>2]=k+1;t[k|0]=w[f+82976|0];break a}v[d>>2]=k+1;t[k|0]=w[f+82976|0];v[e>>2]=v[e>>2]+1;a=0;break a}a=0;v[e>>2]=0}jb=l+16|0;return a}function II(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=jb-16|0;jb=f;a:{b:{c:{d:{e:{if((b|0)>=0){g=a;a=v[a+32>>2];if((Pg(a)|0)>(b|0)){break e}}a=ba(8)|0;v[23588]=0;b=Q(55,f|0,10656)|0;c=v[23588];v[23588]=0;if((c|0)==1){break d}a=rc(a,b);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break b}c=P()|0;O()|0;yb(b);break c}d=(a+(b<<5)|0)+480280|0;c=c?134218752:0;v[d>>2]=c|v[d>>2]&-134218753;d=(a+B(b,872)|0)+1075080|0;v[d>>2]=c|v[d>>2]&-134218753;a=x[a+480188>>1];d=a>>>0>256?a:256;b=b+1|0;g=v[g+32>>2];while(1){if((a|0)==(d|0)){break a}e=g+B(a,872)|0;if((b|0)==x[e+1075778>>1]){e=e+1075080|0;v[e>>2]=c|v[e>>2]&-134218753}a=a+1|0;continue}}c=P()|0;O()|0;ca(a|0)}T(c|0)}L()}jb=f+16|0}function Ida(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=jb-16|0;jb=b;f=v[a+40>>2];g=v[a+36>>2];j=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;k=v[a+32>>2];l=v[a+28>>2];m=v[a+8>>2];n=v[a+12>>2];while(1){if(d){e=v[b+8>>2];o=e>>>10&4194048;p=(((v[b+12>>2]&2147483647)<<1|e>>>31)&-2)+j|0;e=0;while(1){if((e|0)!=2){h=e+p|0;i=t[h|0];v[(e<<2)+b>>2]=((B(t[h+2|0]-i|0,o)|0)/16384|0)+(i<<8);e=e+1|0;continue}break}g=g+l|0;v[c>>2]=v[c>>2]+B(v[b>>2],g>>12);f=f+k|0;v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],f>>12);Qb(b+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=f;v[a+20>>2]=g>>12;v[a+36>>2]=g;v[a+24>>2]=f>>12;jb=b+16|0}function fca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=jb-16|0;jb=e;h=qf(a,c);me(e,v[a+36>>2]);i=a;a:{if(!h){Rc(e,a+32|0,5);c=0;if(Bb(v[v[e>>2]>>2],v[e+4>>2])){break a}}f=v[a+36>>2];a=jb-16|0;jb=a;v[a+12>>2]=0;yG(f,a+12|0,1);c=v[a+12>>2];d=c>>>2&3;t[a+11|0]=d;if(d){t[a+4|0]=3;d=w[Wb(a+4|0,a+11|0)|0];t[a+4|0]=0;t[a|0]=0;t[a+10|0]=0;b:{if(!d){break b}hi(f,a+4|0);if((d|0)==1){break b}hi(f,a);if(d>>>0<3){break b}hi(f,a+10|0);g=w[a+10|0]<<24}c=c&255|w[a+4|0]<<8|w[a|0]<<16|g;v[a+12>>2]=c}d=c>>>4|0;v[a+4>>2]=d;v[a>>2]=1e6;Ix(b,v[Jb(a+4|0,a)>>2]);c=0;while(1){g=Gb(b);if(g>>>0<=c>>>0){if((d|0)!=(g|0)){am(f,d-g|0)}jb=a+16|0}else{Uk(f,Sc(b,c),1);c=c+1|0;continue}break}c=h}Xe(i,c);jb=e+16|0}function wh(a,b){var c=C(0),d=C(0),e=C(0),f=C(0),g=C(0),h=0;f=FK(a);h=a+4208|0;c=C(C(z[Db(h,4)>>2]*C(1.899999976158142))+C(.10000000149011612));g=z[a+4268>>2];d=te(C(10),C(C(C(C(C(v[((b<<2)+a|0)+4292>>2])/g)*C(-60))/C(C(z[Db(h,3)>>2]*C(19.899999618530273))+C(.10000000149011612)))/C(20)));c=C(C(te(d,C(C(2)-C(C(2)/c)))+C(-1))/C(C(1)-Bp(c>C(1)?C(3.1415927410125732):C(f*C(C(6.2831854820251465)/g)))));a:{if(c==C(0)){break a}if(!pm(c)){break a}g=C(c+c);f=C(C(-2)-g);c=C(C(f*f)+C(C(c*c)*C(-4)));if(c>C(0)){e=C(K(c))}c=C(C(e-f)/g);if(C(D(c))>C(1)){c=C(C(C(-f)-e)/g)}e=Jf(c)}b=(b<<3)+a|0;z[b+4404>>2]=e;z[b+4400>>2]=d;c=z[a+4272>>2];c=C(c*c);e=C(C(1)-c);d=C(d*d);return C(C(C(e*C(d/C(C(1)-C(c*d))))*e)+c)}function vda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=jb-16|0;jb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+8>>2];k=v[a+12>>2];while(1){if(d){f=v[b+8>>2];l=((((v[b+12>>2]&2147483647)<<1|f>>>31)&2147483646)<<1)+i|0;e=f>>>21&2040;m=u[e+39718>>1];n=u[e+39716>>1];o=u[e+39714>>1];p=u[e+39712>>1];e=0;while(1){if((e|0)!=2){f=(e<<1)+l|0;v[(e<<2)+b>>2]=(((B(u[f>>1],o)+B(u[f-4>>1],p)|0)+B(u[f+4>>1],n)|0)+B(u[f+8>>1],m)|0)/16384;e=e+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[b>>2],h);v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],g);Qb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;jb=b+16|0}function Efa(a){a=a|0;var b=0,c=0,d=0,e=0;c=jb-192|0;jb=c;b=c+16|0;oi(b,a);v[23588]=0;R(88,c+32|0,b|0);a=v[23588];v[23588]=0;a:{b:{c:{d:{e:{if((a|0)!=1){v[23588]=0;a=Q(89,c+48|0,c+32|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break e}yb(c+32|0);yb(c+16|0);b=v[v[a>>2]-12>>2];v[23588]=0;d=ga(62)|0;e=v[23588];v[23588]=0;if((e|0)==1){break c}v[23588]=0;U(63,c+8|0,a+b|0,d|0);b=v[23588];v[23588]=0;if((b|0)==1){break c}$b(c+8|0);v[23588]=0;b=Q(90,a|0,c+32|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break c}a=Zk(v[(b+v[v[b>>2]-12>>2]|0)+16>>2]);d=x[c+32>>1];rf(b);jb=c+192|0;a=(a?0:d)&65535;break a}b=P()|0;O()|0;break d}b=P()|0;O()|0;yb(c+32|0)}yb(c+16|0);break b}b=P()|0;O()|0;rf(a)}T(b|0);L()}return a|0}function wfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=jb-32|0;jb=d;md(c,2);t[d+16|0]=w[b+13|0];t[d|0]=64;e=d+16|0;i=c,j=w[Wb(e,d)|0]<<2,u[i+30>>1]=j;v[c+24>>2]=(w[b+14|0]|w[b+15|0]<<8)<<1;tk(d,2,b+1|0);Ec(e,d);Be(c+43|0,e);yb(e);e=Zc(a,8,1,0,2);a:{if((w[b|0]&3)!=1){break a}g=w[b+22|0]|w[b+23|0]<<8|(w[b+24|0]<<16|w[b+25|0]<<24);v[c>>2]=g;f=w[b+26|0]|w[b+27|0]<<8|(w[b+28|0]<<16|w[b+29|0]<<24);v[c+4>>2]=f;a=w[b+30|0]|w[b+31|0]<<8|(w[b+32|0]<<16|w[b+33|0]<<24);h=a-(a>>>0>f>>>0)|0;v[c+8>>2]=h;a=w[b|0];if(a&4){u[c+34>>1]=x[c+34>>1]|2;a=w[b|0]}if(a&8){u[c+34>>1]=x[c+34>>1]|4;a=w[b|0]}if(!(a&16)){break a}wd(e,16);cg(e,9);v[c+8>>2]=h>>>1;v[c+4>>2]=f>>>1;v[c>>2]=g>>>1}jb=d+32|0}function oA(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=jb-16|0;jb=e;d=w[a|0];if(d&1){t[b+12|0]=w[b+12|0]|1;d=w[a|0]}if(d&2){t[b+12|0]=w[b+12|0]|4;d=w[a|0]}if(d&4){t[b+12|0]=w[b+12|0]|2;d=w[a|0]}if(d&16){t[b+12|0]=w[b+12|0]|16;d=w[a|0]}if(d&32){t[b+12|0]=w[b+12|0]|8}t[e+15|0]=w[a+1|0];t[e+14|0]=25;Qg(b,w[Wb(e+15|0,e+14|0)|0]);t[b+15|0]=w[a+2|0];t[b+16|0]=w[a+3|0];t[b+13|0]=w[a+4|0];t[b+14|0]=w[a+5|0];g=v[b>>2];i=_d(g,v[b+4>>2]);b=0;while(1){if((b|0)!=(i|0)){h=Db(g,b);f=(b<<2)+a|0;d=w[f+6|0]|w[f+7|0]<<8;u[h>>1]=d;a:{if(!b){break a}j=d;d=x[Db(g,b-1|0)>>1];if(j>>>0>=d>>>0){break a}u[h>>1]=d+1}k=h,l=Xb((w[f+8|0]|w[f+9|0]<<8)<<16>>16>>c,0,64),t[k+2|0]=l;b=b+1|0;continue}break}jb=e+16|0}function NG(a,b){var c=0,d=0,e=0;a:{if(w[b|0]){break a}b=Fw(13815);if(w[b|0]?b:0){break a}b=Fw(B(a,12)+79584|0);if(w[b|0]?b:0){break a}b=Fw(14099);if(w[b|0]?b:0){break a}b=14715}b:{while(1){d=w[b+c|0];if(!(!d|(d|0)==47)){d=23;c=c+1|0;if((c|0)!=23){continue}break b}break}d=c}e=14715;c:{d:{c=w[b|0];e:{f:{if(!(w[b+d|0]|(c|0)==46)){e=b;if((c|0)!=67){break f}}if(!w[e+1|0]){break e}}if(!vi(e,14715)){break e}if(vi(e,13432)){break d}}if(!a){c=79656;if(w[e+1|0]==46){break c}}return 0}c=v[117003];if(c){while(1){if(!vi(e,c+8|0)){break c}c=v[c+32>>2];if(c){continue}break}}c=Od(36);if(c){v[c+4>>2]=20;v[c>>2]=79552;b=c+8|0;tc(b,e,d);t[b+d|0]=0;v[c+32>>2]=v[117003];v[117003]=c}c=a|c?c:79656}return c}function r6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-32|0;jb=d;v[23588]=0;Y(952,a|0);e=v[23588];v[23588]=0;a:{b:{c:{if((e|0)==1){break c}v[23588]=0;Y(953,b|0);e=v[23588];v[23588]=0;if((e|0)==1){break c}v[23588]=0;Y(953,c|0);f=v[23588];v[23588]=0;e=1;if((f|0)==1){break c}f=v[a+24>>2];b=qc(d+24|0,b);c=qc(d+16|0,c);g=v[c>>2];c=v[c+4>>2];v[23588]=0;h=v[b+4>>2];v[d+8>>2]=v[b>>2];v[d+12>>2]=h;lF(974,f,d+8|0,g,c);b=v[23588];v[23588]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,5510,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();e=0}jb=d+32|0;return e|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function Aga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;b=jb-528|0;jb=b;e=-1;a:{if(!eg(a,1468)){break a}wl(a,1464);c=b+524|0;lS(a,c);if(!ne(c,26889)){e=0;if(!ne(b+524|0,15497)){break a}}wl(a,20);c=1;while(1){if((c&65535)>>>0<=31){if(iS(a,b)){c=c+1|0;d=mA(b)+d|0;continue}else{e=-1;break a}}break}e=0;if(d>>>0>40){break a}d=b+520|0;c=jb-16|0;jb=c;b:{if(!eg(a,2)){t[c|0]=0;qC(d,c);break b}Wm(c+8|0,d);lA(c,a,v[c+8>>2],v[c+12>>2])}jb=c+16|0;if(w[b+520|0]>128){break a}d=Nc(b+520|0);c=jb-16|0;jb=c;c:{if(!eg(a,512)){UR(b);break c}Lu(c+8|0,b);lA(c,a,v[c+8>>2],v[c+12>>2])}jb=c+16|0;c=0;e=1;a=w[d|0];while(1){if((c|0)==512){break a}d=b+c|0;c=c+1|0;if(a>>>0>=w[d|0]){continue}break}e=0}jb=b+528|0;return e|0}function Xj(a,b){var c=0,d=0,e=0,f=0;c=jb+-64|0;jb=c;d=v[v[a>>2]-12>>2]+a|0;e=v[d+16>>2]&-3;Sl(d,e);a:{b:{if(Pd(w[fm(c+56|0,a,1)|0])){d=v[(v[v[a>>2]-12>>2]+a|0)+24>>2];v[23588]=0;f=v[b+12>>2];v[c+16>>2]=v[b+8>>2];v[c+20>>2]=f;f=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=f;U(108,c+40|0,d|0,c+8|0);b=v[23588];v[23588]=0;c:{if((b|0)!=1){b=iE(c+40|0,Xg(c+24|0,-1,-1))?e|4:e;break c}b=V(0)|0;O()|0;_(b|0)|0;b=e|1;dm(v[v[a>>2]-12>>2]+a|0,b);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[23588]=0;Z(105);a=v[23588];v[23588]=0;if((a|0)!=1){break a}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)==1){break b}T(a|0);L()}$()}Ki(v[v[a>>2]-12>>2]+a|0,b)}jb=c- -64|0;return a}V(0)|0;O()|0;Ub()}L()}function Xda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=jb-16|0;jb=b;i=v[a+16>>2];h=Sf(1,2);e=mb;j=e;Qb(a,h,e);f=v[a+40>>2];g=v[a+36>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;k=v[a+32>>2];l=v[a+28>>2];m=v[a+8>>2];n=v[a+12>>2];while(1){if(d){d=d-1|0;o=((((v[b+12>>2]&2147483647)<<1|v[b+8>>2]>>>31)&2147483646)<<1)+i|0;e=0;while(1){if((e|0)!=2){v[(e<<2)+b>>2]=u[(e<<1)+o>>1];e=e+1|0;continue}break}g=g+l|0;v[c>>2]=v[c>>2]+B(v[b>>2],g>>12);f=f+k|0;v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],f>>12);Qb(b+8|0,m,n);c=c+8|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=f;v[a+20>>2]=g>>12;v[a+36>>2]=g;v[a+24>>2]=f>>12;lg(a,h,j);jb=b+16|0}function OX(a){a=a|0;var b=0,c=0,d=0,e=0;c=jb-192|0;jb=c;b=c+16|0;oi(b,a);v[23588]=0;R(88,c+32|0,b|0);a=v[23588];v[23588]=0;a:{b:{c:{d:{e:{if((a|0)!=1){v[23588]=0;a=Q(89,c+48|0,c+32|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break e}yb(c+32|0);yb(c+16|0);b=v[v[a>>2]-12>>2];v[23588]=0;d=ga(62)|0;e=v[23588];v[23588]=0;if((e|0)==1){break c}v[23588]=0;U(63,c+8|0,a+b|0,d|0);b=v[23588];v[23588]=0;if((b|0)==1){break c}$b(c+8|0);v[23588]=0;b=Q(93,a|0,c+32|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break c}a=Zk(v[(b+v[v[b>>2]-12>>2]|0)+16>>2]);d=v[c+32>>2];rf(b);jb=c+192|0;a=a?0:d;break a}b=P()|0;O()|0;break d}b=P()|0;O()|0;yb(c+32|0)}yb(c+16|0);break b}b=P()|0;O()|0;rf(a)}T(b|0);L()}return a|0}function ZV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;md(b,0);v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=Rq(a+4|0,a);f=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[b+4>>2]=f;c=Rq(a+8|0,a);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[b+8>>2]=c;t[e+15|0]=127;t[e+14|0]=w[a+15|0];g=b,h=(((w[Wb(e+15|0,e+14|0)|0]<<8|64)&65344)>>>0)/127|0,u[g+30>>1]=h;d=w[a+12|0];if(d>>>0>=16){u[b+34>>1]=32;u[b+28>>1]=d&240}d=(w[a+13|0]|w[a+14|0]<<8)<<1;v[b+24>>2]=d;d=w[a+13|0]|w[a+14|0]<<8?d:16726;v[b+24>>2]=d;g=b,h=(B(Xu(0,w[a+12|0]<<28>>24),d)>>>0)/8363|0,v[g+24>>2]=h;if(c>>>0>f>>>0){u[b+34>>1]=x[b+34>>1]|2}if(w[a+16|0]&132){u[b+34>>1]=x[b+34>>1]|1}jb=e+16|0}function rH(a){a=a|0;var b=0,c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b:{if(!v[(v[v[a>>2]-12>>2]+a|0)+24>>2]){break b}v[23588]=0;c=Q(1104,d+8|0,a|0)|0;b=v[23588];v[23588]=0;c:{if((b|0)!=1){d:{if(!Pd(w[c|0])){break d}b=v[(v[v[a>>2]-12>>2]+a|0)+24>>2];v[23588]=0;b=S(1105,b|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){if((b|0)!=-1){break d}b=v[v[a>>2]-12>>2];v[23588]=0;Y(1106,a+b|0);b=v[23588];v[23588]=0;if((b|0)!=1){break d}}b=V(0)|0;O()|0;qH(c);break c}qH(c);break b}b=V(0)|0;O()|0}_(b|0)|0;c=v[v[a>>2]-12>>2];v[23588]=0;Y(17,a+c|0);c=v[23588];v[23588]=0;if((c|0)==1){break a}$()}jb=d+16|0;return a|0}a=P()|0;O()|0;v[23588]=0;Z(18);c=v[23588];v[23588]=0;if((c|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function V4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-32|0;jb=d;e=Sb(a);a=0;c=v[b+24>>2];c=tt(v[c+484344>>2],v[c+484348>>2]);v[23588]=0;R(181,e|0,c|0);c=v[23588];v[23588]=0;a:{if((c|0)!=1){b:{c:{d:{e:{while(1){c=v[b+24>>2];f=v[c+484344>>2];if(tt(f,v[c+484348>>2])>>>0<=a>>>0){break b}v[23588]=0;R(1022,d|0,Yb(f,a)|0);c=v[23588];v[23588]=0;if((c|0)!=1){c=v[b+24>>2];v[23588]=0;U(1009,d+16|0,c|0,d|0);c=v[23588];v[23588]=0;if((c|0)==1){break e}v[23588]=0;R(183,e|0,d+16|0);c=v[23588];v[23588]=0;if((c|0)==1){break d}a=a+1|0;yb(d+16|0);yb(d);continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;yb(d+16|0)}yb(d);break a}jb=d+32|0;return}a=P()|0;O()|0}We(e);T(a|0);L()}function Ky(a,b,c){var d=0,e=0,f=0,g=0;d=jb+-64|0;jb=d;e=v[a>>2];f=v[e-4>>2];g=v[e-8>>2];v[d+28>>2]=0;v[d+32>>2]=0;v[d+36>>2]=0;v[d+40>>2]=0;v[d+44>>2]=0;v[d+48>>2]=0;v[d+52>>2]=0;v[d+56>>2]=0;e=0;t[d+59|0]=0;t[d+60|0]=0;t[d+61|0]=0;t[d+62|0]=0;v[d+20>>2]=0;v[d+24>>2]=0;v[d+16>>2]=b;v[d+12>>2]=a;v[d+8>>2]=c;a=a+g|0;a:{if(Zg(f,c,0)){v[d+56>>2]=1;nb[v[v[f>>2]+20>>2]](f,d+8|0,a,a,1,0);e=v[d+32>>2]==1?a:0;break a}nb[v[v[f>>2]+24>>2]](f,d+8|0,a,1,0);b:{switch(v[d+44>>2]){case 0:e=v[d+48>>2]==1?v[d+36>>2]==1?v[d+40>>2]==1?v[d+28>>2]:0:0:0;break a;case 1:break b;default:break a}}if(v[d+32>>2]!=1){if(v[d+48>>2]|v[d+36>>2]!=1|v[d+40>>2]!=1){break a}}e=v[d+24>>2]}jb=d- -64|0;return e}function oh(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=jb+-64|0;jb=f;a:{b:{if((b|0)==65535|c-1025>>>0<4294966272){break b}d=v[a>>2];e=v[a+4>>2];if(xe(d,e,b)){break b}c:{d:{if(xk(d,e)>>>0<=b>>>0){d=_x(f+8|0,a);v[23588]=0;U(201,a|0,b+1|0,d|0);e=v[23588];v[23588]=0;if((e|0)==1){break d}gl(d);d=v[a>>2]}v[23588]=0;R(211,ag(d,b)|0,c|0);c=v[23588];v[23588]=0;e:{if((c|0)!=1){c=ag(v[a>>2],b);v[c+16>>2]=0;v[c+20>>2]=0;c=v[a>>2];v[23588]=0;Y(212,ag(c,b)|0);c=v[23588];v[23588]=0;if((c|0)!=1){break e}}b=V(92948)|0;a=O()|0;break c}a=ag(v[a>>2],b);g=Ob(v[a>>2],v[a+4>>2]);break b}b=V(92948)|0;a=O()|0;gl(d)}if((da(92948)|0)!=(a|0)){break a}_(b|0)|0;$()}jb=f- -64|0;return g|0}T(b|0);L()}function Xfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=jb+-64|0;jb=c;i=c,j=cf(a)>>>5|0,u[i+32>>1]=j;u[c+16>>1]=3999;h=b+480190|0;d=x[Vc(c+32|0,c+16|0)>>1];u[h>>1]=d;g=1;while(1){f=g&65535;if(f>>>0<=d>>>0){d=Gi(b,f);e=c+32|0;Xt(a,e);md(d,0);Cj(c,2,e);e=c+16|0;Ec(e,c);Cc(((f<<5)+b|0)+946304|0,e);yb(e);v[d+24>>2]=8287;i=c,j=Hb(x[c+60>>1]),u[i+16>>1]=j;u[c>>1]=64;i=d,j=x[Vc(e,c)>>1]<<2,u[i+30>>1]=j;i=d,j=bc(v[c+52>>2])&-2,v[i>>2]=j;e=Hb(x[c+62>>1]);i=Db(d+68|0,0),j=e,v[i>>2]=j;e=Hb(x[c+56>>1]);f=Hb(x[c+58>>1]);a:{if(f>>>0<2){break a}f=e+f<<1;if(f>>>0>y[d>>2]){break a}v[d+16>>2]=f;v[d+12>>2]=e<<1;u[d+34>>1]=x[d+34>>1]|8}g=g+1|0;d=x[h>>1];continue}break}jb=c- -64|0}function wda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=jb-16|0;jb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+8>>2];k=v[a+12>>2];while(1){if(d){f=v[b+8>>2];l=(((v[b+12>>2]&2147483647)<<1|f>>>31)&-2)+i|0;e=f>>>21&2040;m=u[e+39718>>1];n=u[e+39716>>1];o=u[e+39714>>1];p=u[e+39712>>1];e=0;while(1){if((e|0)!=2){f=e+l|0;v[(e<<2)+b>>2]=(((B(t[f|0],o)+B(t[f-2|0],p)|0)+B(t[f+2|0],n)|0)+B(t[f+4|0],m)<<8)/16384;e=e+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[b>>2],h);v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],g);Qb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;jb=b+16|0}function $q(a){a=a|0;var b=0,c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b:{if(!v[(v[v[a>>2]-12>>2]+a|0)+24>>2]){break b}v[23588]=0;c=Q(13,d+8|0,a|0)|0;b=v[23588];v[23588]=0;c:{if((b|0)!=1){d:{if(!w[c|0]){break d}b=v[(v[v[a>>2]-12>>2]+a|0)+24>>2];v[23588]=0;b=S(22,b|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){if((b|0)!=-1){break d}b=v[v[a>>2]-12>>2];v[23588]=0;R(16,a+b|0,1);b=v[23588];v[23588]=0;if((b|0)!=1){break d}}b=V(0)|0;O()|0;yk(c);break c}yk(c);break b}b=V(0)|0;O()|0}_(b|0)|0;c=v[v[a>>2]-12>>2];v[23588]=0;Y(17,a+c|0);c=v[23588];v[23588]=0;if((c|0)==1){break a}$()}jb=d+16|0;return a|0}a=P()|0;O()|0;v[23588]=0;Z(18);c=v[23588];v[23588]=0;if((c|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function jea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;g=jb-16|0;jb=g;md(b,4);u[b+30>>1]=w[a+12|0]<<2;Ef(b+30|0,256);e=w[a+15|0];u[b+34>>1]=32;u[b+28>>1]=e;t[b+37|0]=w[a+13|0];t[b+36|0]=w[a+16|0];f=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);v[b>>2]=f;c=w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24);v[b+4>>2]=c;d=(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))+c|0;v[b+8>>2]=d;e=w[a+14|0];if(e&16){d=d>>>1|0;v[b+8>>2]=d;c=c>>>1|0;v[b+4>>2]=c;f=f>>>1|0;v[b>>2]=f;e=w[a+14|0]}if(e&32){d=d>>>1|0;v[b+8>>2]=d;c=c>>>1|0;v[b+4>>2]=c;v[b>>2]=f>>>1;e=w[a+14|0]}if(!(!(e&3)|c>>>0>=d>>>0)){u[b+34>>1]=34;u[b+34>>1]=w[a+14|0]&2?38:34}a=Mc(g,21619);Be(b+43|0,a);yb(a);jb=g+16|0}function iF(a,b,c,d){var e=0,f=0,g=0;f=jb-32|0;jb=f;v[23588]=0;Y(952,a|0);e=v[23588];v[23588]=0;a:{b:{c:{d:{e:{f:{if((e|0)==1){break f}v[23588]=0;Y(953,b|0);e=v[23588];v[23588]=0;if((e|0)==1){break f}g=v[a+24>>2];v[23588]=0;e=Q(55,f|0,b|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break e}v[23588]=0;U(d|0,f+16|0,g|0,e|0);b=v[23588];v[23588]=0;if((b|0)==1){break d}a=f+16|0;b=fg(Lc(a));yb(a);yb(e);break b}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;yb(e)}_(b|0)|0;b=0;v[23588]=0;X(939,c|0,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$()}jb=f+32|0;return b}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function E1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=jb-32|0;jb=d;e=v[a+28>>2];v[d+16>>2]=e;f=v[a+20>>2];v[d+28>>2]=c;v[d+24>>2]=b;b=f-e|0;v[d+20>>2]=b;f=b+c|0;i=2;b=d+16|0;a:{while(1){b:{c:{d:{if(!bx(hb(v[a+60>>2],b|0,i|0,d+12|0)|0)){g=v[d+12>>2];if((g|0)==(f|0)){break d}if((g|0)>=0){break c}break b}if((f|0)!=-1){break b}}b=v[a+44>>2];v[a+28>>2]=b;v[a+20>>2]=b;v[a+16>>2]=b+v[a+48>>2];a=c;break a}h=v[b+4>>2];j=h>>>0<g>>>0;e=(j<<3)+b|0;h=g-(j?h:0)|0;v[e>>2]=h+v[e>>2];b=(j?12:4)+b|0;v[b>>2]=v[b>>2]-h;f=f-g|0;i=i-j|0;b=e;continue}break}v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a>>2]=v[a>>2]|32;a=0;if((i|0)==2){break a}a=c-v[b+4>>2]|0}jb=d+32|0;return a|0}function LL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=C(0),j=C(0),k=0,l=C(0);g=jb-16|0;jb=g;e=u[d>>1];f=u[d+2>>1];if(!(!x[b>>1]|(e|0)>(f|0)|(!(z[c>>2]>C(0))|(f-e|0)>32766))){u[a>>1]=3;f=a+4|0;Kc(f);u[a+28>>1]=65472;v[g+12>>2]=1065353216;PL(f,g+12|0);v[a+32>>2]=0;u[a+30>>1]=0;Kc(a+16|0);h=u[d>>1];u[a+28>>1]=h;e=jb-16|0;jb=e;u[e+14>>1]=x[b>>1];u[e+12>>1]=32767;b=u[Vc(e+14|0,e+12|0)>>1];jb=e+16|0;u[a+30>>1]=b;i=C(D(z[c>>2]));z[a+32>>2]=i;i=te(i,C(C(1)/C(b|0)));ck(f,(u[d+2>>1]-h|0)+1|0);b=v[a+4>>2];c=u[a+28>>1];e=u[d+2>>1];d=u[d>>1];while(1){if((d|0)>(e|0)){Ep(a)}else{j=te(i,C(d|0));k=Db(b,d-c|0),l=j,z[k>>2]=l;d=d+1|0;continue}break}h=1}jb=g+16|0;return h|0}function rX(){var a=0,b=0,c=0,d=0;a=_C(v[v[116870]-12>>2]+467480|0,10);c=jb-16|0;jb=c;v[23588]=0;b=Q(13,c+8|0,467480)|0;d=v[23588];v[23588]=0;a:{b:{c:{d:{if((d|0)!=1){e:{if(!w[b|0]){break e}d=Rm(c,467480);v[23588]=0;a=Q(21,d|0,a|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){if(!_u(a)){break e}a=v[v[116870]-12>>2];v[23588]=0;R(16,a+467480|0,1);a=v[23588];v[23588]=0;if((a|0)!=1){break e}}a=V(0)|0;O()|0;yk(b);break d}yk(b);break c}a=V(0)|0;O()|0}_(a|0)|0;b=v[v[116870]-12>>2];v[23588]=0;Y(17,b+467480|0);b=v[23588];v[23588]=0;if((b|0)==1){break b}$()}jb=c+16|0;break a}c=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(c|0);L()}V(0)|0;O()|0;Ub();L()}$q(467480)}function Yn(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;a:{if(c){t[b+809|0]=c;break a}c=w[b+809|0]}e=v[a+480180>>2];d=e&202376205?(c&240?-16:15)&c:c;c=v[b+688>>2];b:{if(e&69206029){break b}g=d&240;f=d&15;if((f|0)==15){if(g){Xn(a,b,(d&240)>>>4|0,0);return}if(!(t[b+851|0]&1)){break b}c=w[a+480208|0]&2?c:c-60|0;break b}if((g|0)!=240){break b}if(f){Wn(a,b,f,0);return}if(!(t[b+851|0]&1)){break b}c=w[a+480208|0]&2?c:c+60|0}c:{if(!(!(t[b+851|0]&1)|w[a+480208|0]&2)&(v[a+1074416>>2]!=1|(e|0)!=524288)){break c}a=d&255;d=d&15;d:{if(d){if(a&240?e&16777248:0){break c}c=c-(d<<2)|0;break d}c=(a>>>2&60)+c|0}if((e|0)!=1){break c}v[b+88>>2]=v[b+88>>2]|2097152}h=b,i=Xb(c,0,256),v[h+688>>2]=i}function Yda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=jb-16|0;jb=b;i=v[a+16>>2];h=Sf(1,2);e=mb;j=e;Qb(a,h,e);f=v[a+40>>2];g=v[a+36>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;k=v[a+32>>2];l=v[a+28>>2];m=v[a+8>>2];n=v[a+12>>2];while(1){if(d){d=d-1|0;o=(((v[b+12>>2]&2147483647)<<1|v[b+8>>2]>>>31)&-2)+i|0;e=0;while(1){if((e|0)!=2){v[(e<<2)+b>>2]=t[e+o|0]<<8;e=e+1|0;continue}break}g=g+l|0;v[c>>2]=v[c>>2]+B(v[b>>2],g>>12);f=f+k|0;v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],f>>12);Qb(b+8|0,m,n);c=c+8|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=f;v[a+20>>2]=g>>12;v[a+36>>2]=g;v[a+24>>2]=f>>12;lg(a,h,j);jb=b+16|0}function Sca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=jb-16|0;jb=f;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;j=b+24|0;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){b=(v[f+12>>2]<<1)+i|0;e=(((v[f+8>>2]>>>16|0)+4&131064)<<1)+j|0;b=(((((B(u[b+4>>1],u[e+10>>1])+B(u[b+2>>1],u[e+8>>1])|0)+B(u[b+6>>1],u[e+12>>1])|0)+B(u[b+8>>1],u[e+14>>1])|0)/2|0)+((((B(u[b-4>>1],u[e+2>>1])+B(u[b-6>>1],u[e>>1])|0)+B(u[b-2>>1],u[e+4>>1])|0)+B(u[b>>1],u[e+6>>1])|0)/2|0)|0)/16384|0;v[c>>2]=v[c>>2]+B(b,h);v[c+4>>2]=v[c+4>>2]+B(b,g);Qb(f+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;jb=f+16|0}function uH(a){var b=0,c=0,d=0,e=0,f=0;c=jb-192|0;jb=c;b=c+16|0;oi(b,a);v[23588]=0;R(88,c+32|0,b|0);a=v[23588];v[23588]=0;a:{b:{c:{d:{if((a|0)!=1){v[23588]=0;a=Q(89,c+48|0,c+32|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break d}yb(c+32|0);yb(c+16|0);b=v[v[a>>2]-12>>2];v[23588]=0;d=ga(62)|0;e=v[23588];v[23588]=0;if((e|0)==1){break b}v[23588]=0;U(63,c+8|0,a+b|0,d|0);b=v[23588];v[23588]=0;if((b|0)==1){break b}$b(c+8|0);v[23588]=0;b=Q(94,a|0,c+32|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break b}a=Zk(v[(b+v[v[b>>2]-12>>2]|0)+16>>2]);f=A[c+32>>3];rf(b);jb=c+192|0;return a?0:f}b=P()|0;O()|0;break c}b=P()|0;O()|0;yb(c+32|0)}yb(c+16|0);break a}b=P()|0;O()|0;rf(a)}T(b|0);L()}function Rea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=jb-16|0;jb=e;i=e,j=zj(b),v[i>>2]=j;d=jb-16|0;jb=d;g=a;c=Sd(a);a:{if(c){f=ic(g);while(1){a=c;c=a+13|0;if(It(b,c)){f=a;c=v[a>>2];if(c){continue}break a}if(!It(c,b)){break a}f=a+4|0;c=v[a+4>>2];if(c){continue}break}break a}a=ic(g);f=a}v[d+12>>2]=a;b=v[f>>2];if(!b){c=jb-16|0;jb=c;a=ic(g);h=lh(d,sc(20),mh(c+8|0,a));b=v[h>>2];a=v[e>>2];a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);t[b+17|0]=0;t[b+13|0]=a;t[b+14|0]=a>>>8;t[b+15|0]=a>>>16;t[b+16|0]=a>>>24;i=ic(h),j=1,t[i+4|0]=j;jb=c+16|0;Jg(g,v[d+12>>2],f,v[d>>2]);b=be(d);qk(d);h=1}Ig(e+8|0,v[ec(d,b)>>2],h);jb=d+16|0;jb=e+16|0;return v[e+8>>2]+17|0}function uz(a,b,c){var d=0,e=0,f=0,g=0;d=Lb(a);a=Gb(b);v[23588]=0;R(46,d|0,a|0);a=v[23588];v[23588]=0;if((a|0)!=1){a:{while(1){if(Gb(b)>>>0>e>>>0){f=v[zi(b,e)>>2];g=f&-32;a=32;b:{while(1){c:{if((a|0)==256){a=0;break c}if((g|0)==128|v[(a<<2)+c>>2]!=(f|0)){a=a+1|0;continue}else{v[23588]=0;R(47,d|0,a<<24>>24);a=v[23588];v[23588]=0;if((a|0)!=1){break b}break a}}break}d:{while(1){if((a|0)==32){break d}if(v[(a<<2)+c>>2]!=(f|0)){a=a+1|0;continue}break}v[23588]=0;R(47,d|0,a<<24>>24);a=v[23588];v[23588]=0;if((a|0)!=1){break b}break a}v[23588]=0;R(47,d|0,63);a=v[23588];v[23588]=0;if((a|0)!=1){break b}break a}e=e+1|0;continue}break}return}}a=P()|0;O()|0;yb(d);T(a|0);L()}function Xha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=jb-32|0;jb=d;v[d+28>>2]=0;ok(a,d+28|0);a:{b:{i=v[d+28>>2];c:{if(i>>>0>500){break c}d:{e:{while(1){if((f|0)==(i|0)){break c}g=Lb(d+16|0);v[23588]=0;u[d+14>>1]=0;e=W(483,a|0,g|0,255)|0;h=v[23588];v[23588]=0;if((h|0)==1){break b}if(!e){break d}v[23588]=0;R(472,a|0,d+14|0);e=v[23588];v[23588]=0;if((e|0)==1){break b}v[23588]=0;U(11,d|0,c|0,g|0);e=v[23588];v[23588]=0;if((e|0)!=1){v[23588]=0;e=Q(484,b|0,d+14|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break e}Ib(e,d);zb(d);yb(g);f=f+1|0;continue}break}f=P()|0;O()|0;break a}f=P()|0;O()|0;zb(d);break a}yb(g)}jb=d+32|0;return}f=P()|0;O()|0}yb(g);T(f|0);L()}function Dja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=jb-32|0;jb=e;v[e+24>>2]=b;j=e,k=he(a),v[j+8>>2]=k;f=Nn(e+24|0,e+8|0);a:{b:{h=Rh(c,d);if(!h){break b}if(!Zs(a,c)){b=Gb(a);g=ad(a);c:{if(g-b>>>0>=h>>>0){g=zc(a);if((b|0)==(f|0)){break c}i=f+g|0;Wh(i+h|0,i,b-f|0);break c}rm(a,g,(b+h|0)-g|0,b,f,0,h);g=v[a>>2]}b=b+h|0;Qh(a,b);t[e+8|0]=0;ie(b+g|0,e+8|0);b=f+g|0;while(1){if((c|0)==(d|0)){break b}ie(b,c);c=c+1|0;b=b+1|0;continue}}d=Th(e+8|0,c,d);c=Lc(d);f=Gb(d);v[23588]=0;c=fa(356,a|0,b|0,c|0,c+f|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){yb(d);break a}a=P()|0;O()|0;yb(d);T(a|0);L()}j=e,k=he(a),v[j+8>>2]=k;c=Fp(e+8|0,f)}jb=e+32|0;return c|0}function Wha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=jb-32|0;jb=d;u[d+30>>1]=0;Vf(a,d+30|0);a:{b:{i=x[d+30>>1];c:{if(i>>>0>500){break c}d:{e:{while(1){if((f|0)==(i|0)){break c}g=Lb(d+16|0);v[23588]=0;u[d+14>>1]=0;e=Q(485,a|0,g|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break b}if(!e){break d}v[23588]=0;R(472,a|0,d+14|0);e=v[23588];v[23588]=0;if((e|0)==1){break b}v[23588]=0;U(11,d|0,c|0,g|0);e=v[23588];v[23588]=0;if((e|0)!=1){v[23588]=0;e=Q(484,b|0,d+14|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break e}Ib(e,d);zb(d);yb(g);f=f+1|0;continue}break}f=P()|0;O()|0;break a}f=P()|0;O()|0;zb(d);break a}yb(g)}jb=d+32|0;return}f=P()|0;O()|0}yb(g);T(f|0);L()}function WN(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;g=jb-112|0;jb=g;v[g+108>>2]=0;e=Vn(a,e&65535,d,c,g+108|0);f=w[b+790|0];if(!v[g+108>>2]){d=(f|0)==15;c=d&!w[b+792|0];e=e<<8;a:{if(e){v[b+664>>2]=e;break a}e=0;if(d){break a}e=v[b+664>>2]}h=c?0:w[b+836|0]<<16}if((f|0)==15){c=w[b+792|0];b:{if(!c){c=v[b+76>>2];v[g>>2]=1;f=v[Yc(g,g+108|0)>>2]<<3;d=Lka(c,0,e,0);e=(256<<f>>>1|0)+d|0;c=mb;c=d>>>0>e>>>0?c+1|0:c;d=f+8|0;f=d&31;if((d&63)>>>0>=32){d=0;c=c>>>f|0}else{d=c>>>f|0;c=((1<<f)-1&c)<<32-f|e>>>f}e=Dc(c,d);break b}cB(g);if(c>>>0>9){break b}c=v[b+104>>2];if(!c){break b}e=v[Db(c+68|0,w[b+792|0]-1|0)>>2]+e|0}v[b+664>>2]=e}Zn(a,b,e+h|0);jb=g+112|0}function FL(a,b,c){var d=0,e=0,f=0,g=0,h=0;a:{e=jb-48|0;jb=e;d=Lb(e+32|0);v[23588]=0;R(889,b|0,e+24|0);f=v[23588];v[23588]=0;if((f|0)!=1){b:{g=v[e+28>>2];f=v[e+24>>2];_f(d);v[23588]=0;f=!g&f>>>0<255?f:255;R(60,d|0,f|0);g=v[23588];v[23588]=0;if((g|0)==1){break b}c:{while(1){if((f|0)==(h|0)){b=qV(Lc(d),Gb(d));if((b|0)==-1){break c}v[23588]=0;R(60,d|0,b|0);b=v[23588];v[23588]=0;if((b|0)!=1){break c}break b}g=Sc(d,h);v[23588]=0;Q(890,b|0,g|0)|0;g=v[23588];v[23588]=0;if((g|0)!=1){h=h+1|0;continue}break}break b}v[23588]=0;U(11,e+8|0,a|0,d|0);a=v[23588];v[23588]=0;if((a|0)==1){break b}a=e+8|0;Ib(c,a);zb(a);yb(d);jb=e+48|0;break a}}a=P()|0;O()|0;yb(d);T(a|0);L()}}function uy(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=jb-16|0;jb=e;b=v[a>>2];if(!oc(b,v[a+4>>2])){b=Eb(b);v[e+8>>2]=b;c=Eb(v[a+4>>2]);while(1){if(Ob(b,c)){Po(b,4194304,67108864);g=v[b>>2];f=g+f|0;b=d;b=f>>>0<g>>>0?b+1|0:b;d=b;b=v[Ke(e+8|0)>>2];continue}else{c=v[a>>2];b=uc(c,v[a+4>>2]);l=e,m=Eb(c),v[l>>2]=m;d=Oka(f,d,b,0);h=d;g=((mb&1)<<31|d>>>1)&2147483647;f=b<<24;d=0;i=Eb(v[a+4>>2]);while(1){b=v[e>>2];if(Ob(b,i)){j=b;c=v[b>>2];b=c>>>8|0;c=g+(c<<24)|0;b=b+k|0;b=Dc(Oka(c,c>>>0<g>>>0?b+1|0:b,h,k),mb);v[j>>2]=b;c=f;f=c-b|0;d=d-(b>>>0>c>>>0)|0;Ke(e);continue}else{d=v[a>>2];if(!uc(d,v[a+4>>2])){fv();L()}v[d>>2]=f+v[d>>2]}break}}break}}jb=e+16|0}function Gt(a,b){var c=0,d=0,e=0;c=jb-48|0;jb=c;d=c+24|0;jQ(d,a+8|0,a+10|0,a+12|0,a+16|0,a+14|0);jQ(c,b+8|0,b+10|0,b+12|0,b+16|0,b+14|0);a=v[d>>2];b=w[a|0]|w[a+1|0]<<8;a=v[c>>2];b=Ft(b,w[a|0]|w[a+1|0]<<8);a:{if(!wj(b)){break a}a=v[d+4>>2];b=w[a|0]|w[a+1|0]<<8;a=v[c+4>>2];b=Ft(b,w[a|0]|w[a+1|0]<<8);if(!wj(b)){break a}a=v[d+8>>2];b=w[a|0]|w[a+1|0]<<8;a=v[c+8>>2];b=Ft(b,w[a|0]|w[a+1|0]<<8);if(!wj(b)){break a}a=v[c+12>>2];e=(w[a|0]|w[a+1|0]<<8)<<16>>16;a=v[d+12>>2];b=pe((w[a|0]|w[a+1|0]<<8)<<16>>16);a=pe(e);b=(a|0)==(b|0)?0:(b|0)<(a|0)?-1:1;if(!wj(b)){break a}a=v[d+16>>2];b=w[a|0]|w[a+1|0]<<8;a=v[c+16>>2];b=Ft(b,w[a|0]|w[a+1|0]<<8)}a=ff(b);jb=c+48|0;return a}function Tca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=jb-16|0;jb=f;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;j=b+24|0;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){b=v[f+12>>2]+i|0;e=(((v[f+8>>2]>>>16|0)+4&131064)<<1)+j|0;b=(((((B(t[b+2|0],u[e+10>>1])+B(t[b+1|0],u[e+8>>1])|0)+B(t[b+3|0],u[e+12>>1])|0)+B(t[b+4|0],u[e+14>>1])<<8)/2|0)+((((B(t[b-2|0],u[e+2>>1])+B(t[b-3|0],u[e>>1])|0)+B(t[b-1|0],u[e+4>>1])|0)+B(t[b|0],u[e+6>>1])<<8)/2|0)|0)/16384|0;v[c>>2]=v[c>>2]+B(b,h);v[c+4>>2]=v[c+4>>2]+B(b,g);Qb(f+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;jb=f+16|0}function KI(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;d=jb-16|0;jb=d;a:{b:{c:{d:{if((b|0)>=0){a=v[a+32>>2];if((Pg(a)|0)>(b|0)){break d}}a=ba(8)|0;v[23588]=0;d=Q(55,d|0,10656)|0;b=v[23588];v[23588]=0;if((b|0)==1){break c}a=rc(a,d);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}b=P()|0;O()|0;yb(d);break b}if(c<0|c>1){a=ba(8)|0;v[23588]=0;d=Q(55,d|0,11672)|0;b=v[23588];v[23588]=0;if((b|0)!=1){a=rc(a,d);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}b=P()|0;O()|0;yb(d);break b}b=P()|0;O()|0;ca(a|0);break b}e=(a+B(b,872)|0)+1075740|0,f=yl(c*64),v[e>>2]=f;jb=d+16|0;return}b=P()|0;O()|0;ca(a|0)}T(b|0)}L()}function j5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=jb-32|0;jb=e;f=Sb(a);a=b;b=x[v[b+24>>2]+480192>>1];v[23588]=0;R(181,f|0,b|0);c=v[23588];v[23588]=0;b=1;a:{if((c|0)!=1){b:{c:{d:{e:{while(1){d=b&65535;c=v[a+24>>2];if(d>>>0>x[c+480192>>1]){break b}c=AM(c,d);v[23588]=0;c=Q(55,e|0,c|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){d=v[a+24>>2];v[23588]=0;U(1009,e+16|0,d|0,c|0);d=v[23588];v[23588]=0;if((d|0)==1){break e}v[23588]=0;R(183,f|0,e+16|0);d=v[23588];v[23588]=0;if((d|0)==1){break d}yb(e+16|0);yb(c);b=b+1|0;continue}break}b=P()|0;O()|0;break a}b=P()|0;O()|0;break c}b=P()|0;O()|0;yb(e+16|0)}yb(c);break a}jb=e+32|0;return}b=P()|0;O()|0}We(f);T(b|0);L()}function tda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=jb-16|0;jb=b;f=v[a+40>>2];g=v[a+36>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+32>>2];k=v[a+28>>2];l=v[a+8>>2];m=v[a+12>>2];while(1){if(d){e=(v[b+12>>2]<<1)+i|0;h=v[b+8>>2]>>>21&2040;e=(((B(u[e>>1],u[h+39714>>1])+B(u[e-2>>1],u[h+39712>>1])|0)+B(u[e+2>>1],u[h+39716>>1])|0)+B(u[e+4>>1],u[h+39718>>1])|0)/16384|0;g=g+k|0;v[c>>2]=v[c>>2]+B(e,g>>12);f=f+j|0;v[c+4>>2]=v[c+4>>2]+B(e,f>>12);Qb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=f;v[a+20>>2]=g>>12;v[a+36>>2]=g;v[a+24>>2]=f>>12;jb=b+16|0}function zia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=b;c=jb-48|0;jb=c;d=a;a:{if(gu(v[d>>2],v[d+8>>2])){v[g>>2]=0;break a}cT(c+16|0,c+32|0);mc(c+24|0,v[d>>2],v[d+8>>2],v[c+16>>2],v[c+20>>2]);h=v[c+28>>2];i=w[c+32|0];f=i&127;v[g>>2]=f;a=f;b=0;while(1){if(a){b=b+1|0;a=a>>>1|0;continue}break}a=b;e=1;while(1){b=(B(h,7)+a|0)+B(e,-7)|0;b:{while(1){if(i<<24>>24>=0|e>>>0>=h>>>0){break b}i=w[(c+32|0)+e|0];f=i&127|f<<7;v[g>>2]=f;a=a+7|0;e=e+1|0;if((h|0)!=(e|0)){continue}break}Zb(d,h);cT(c+8|0,c+32|0);mc(c+24|0,v[d>>2],v[d+8>>2],v[c+8>>2],v[c+12>>2]);h=v[c+28>>2];f=v[g>>2];e=0;a=b;continue}break}Zb(d,e);if(a>>>0<33){break a}v[g>>2]=-1}jb=c+48|0}function xn(a,b,c,d,e,f,g,h,i,j){var k=0,l=0;a:{b:{k=v[d>>2];if((k|0)!=(c|0)){break b}l=43;if(v[j+96>>2]!=(a|0)){l=45;if(v[j+100>>2]!=(a|0)){break b}}v[d>>2]=c+1;t[c|0]=l;break a}c:{if(!(!Gb(g)|(a|0)!=(f|0))){g=0;a=v[i>>2];if((a-h|0)>159){break c}b=v[e>>2];v[i>>2]=a+4;v[a>>2]=b;break a}g=-1;f=ww(j,j+104|0,a)-j|0;if((f|0)>92){break c}a=f>>2;d:{e:{switch(b-8|0){case 0:case 2:if((a|0)<(b|0)){break d}break c;case 1:break d;default:break e}}if((b|0)!=16|(f|0)<88){break d}if((c|0)==(k|0)|(k-c|0)>2|w[k-1|0]!=48){break c}v[e>>2]=0;v[d>>2]=k+1;t[k|0]=w[a+82976|0];return 0}v[d>>2]=k+1;t[k|0]=w[a+82976|0];v[e>>2]=v[e>>2]+1;g=0}return g}v[e>>2]=0;return 0}function DN(a,b,c,d,e){var f=0,g=0,h=0,i=0;a:{b:{c:{if(t[b+851|0]&1){f=w[b+848|0];g=c&240;if(g){f=f&15|g;t[b+848|0]=f}c=c&15;if(c){f=c|f&-16;t[b+848|0]=f}t[b+849|0]=(f&240)>>>4;if(v[a+480180>>2]!=32768){break a}break c}if(v[a+480180>>2]==32768){break c}c=w[b+849|0]-1|0;t[b+849|0]=c;if(c&255){break a}f=w[b+848|0];break b}f=w[b+848|0];if((f&240)==16){break b}if(!(w[a+480209|0]&16)){break a}}t[b+849|0]=(f&240)>>>4;c=f&15;c=d?c:0-c|0;d=v[b+656>>2];d:{if(vj(d)){v[b+852>>2]=v[b+852>>2]+B(c,v[v[d+44>>2]+36>>2]);break d}h=b,i=eh(a,gt(a,v[b+700>>2],u[b+772>>1],v[b+704>>2])+c|0,u[b+772>>1],v[b+704>>2]),v[h+700>>2]=i}if(!e){break a}v[b>>2]=0;v[b+4>>2]=0}}function N4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=jb-32|0;jb=e;f=Sb(a);a=b;b=x[v[b+24>>2]+480190>>1];v[23588]=0;R(181,f|0,b|0);d=v[23588];v[23588]=0;b=1;a:{if((d|0)!=1){b:{c:{d:{e:{while(1){c=b&65535;d=v[a+24>>2];if(c>>>0>x[d+480190>>1]){break b}v[23588]=0;d=Q(55,e|0,BM(d,c)|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){c=v[a+24>>2];v[23588]=0;U(1009,e+16|0,c|0,d|0);c=v[23588];v[23588]=0;if((c|0)==1){break e}v[23588]=0;R(183,f|0,e+16|0);c=v[23588];v[23588]=0;if((c|0)==1){break d}yb(e+16|0);yb(d);b=b+1|0;continue}break}b=P()|0;O()|0;break a}b=P()|0;O()|0;break c}b=P()|0;O()|0;yb(e+16|0)}yb(d);break a}jb=e+32|0;return}b=P()|0;O()|0}We(f);T(b|0);L()}function um(a,b,c,d){var e=0,f=0;e=jb-16|0;jb=e;f=a+1074312|0;Cb(e+8|0,f,84);a:{if(Bb(v[v[e+8>>2]>>2],v[e+12>>2])){break a}b:{if(v[a+480208>>2]&16384){break b}if((d|0)!=8){Cb(e+8|0,f,10);if(!Bb(v[v[e+8>>2]>>2],v[e+12>>2])){break b}}v[b+88>>2]=v[b+88>>2]&-257}c:{d:{e:{switch(d-4|0){case 0:c=((c<<8|8)>>>0)/15|0;break d;case 2:c=(c>>>0<64?c:64)<<2;break d;default:break e}}if(!(v[a+480180>>2]&2107410)){break d}if(c>>>0<=128){c=c<<1;break d}if((c|0)!=164){break c}v[b+88>>2]=v[b+88>>2]|256;c=128}v[b+692>>2]=c}u[b+784>>1]=0;v[b+88>>2]=v[b+88>>2]|2097152;Cb(e+8|0,f,10);if(!Bb(v[v[e+8>>2]>>2],v[e+12>>2])){break a}t[b+831|0]=0;u[b+778>>1]=0}jb=e+16|0}function rz(a,b,c,d,e){var f=0,g=0,h=0,i=0;g=jb-16|0;jb=g;i=ol(a,b);a:{if((i|0)==255){break a}if(ik(v[a>>2])){break a}b:{if(c>>>0>6208431){f=7;c=1023;break b}f=7;c:{if(c>>>0>3104215){break c}f=6;if(c>>>0>1552107){break c}f=5;if(c>>>0>776053){break c}f=4;if(c>>>0>388026){break c}f=3;if(c>>>0>194013){break c}f=2;if(c>>>0>97006){break c}f=c>>>0>48503}c=Lka(1<<20-f,0,c,0)+24858e3|0;h=mb;c=Dc(Oka(c,c>>>0<24858e3?h+1|0:h,49716e3,0),mb)}if(e){u[g+14>>1]=(b&3)+c;u[g+12>>1]=1023;c=x[Vc(g+14|0,g+12|0)>>1]}h=yt(i);e=Kb(a+8|0,i);t[e|0]=(f<<10|c)>>>8|(d?0:32);gh(v[a>>2],v[a+4>>2],b,h|160,c&255);gh(v[a>>2],v[a+4>>2],b,h|176,w[e|0]);t[a+534|0]=1}jb=g+16|0}function Y0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=jb-16|0;jb=g;a:{b:{if(!oc(b,-1)){i=v[a+8>>2];j=v[a+12>>2];d=v[a+24>>2];if((d|0)==v[a+28>>2]){e=-1;if(!(w[a+48|0]&16)){break a}h=v[a+20>>2];k=v[a+44>>2];v[23588]=0;c=a+32|0;R(47,c|0,0);f=v[23588];v[23588]=0;if((f|0)==1){break b}f=ad(c);v[23588]=0;R(60,c|0,f|0);f=v[23588];v[23588]=0;if((f|0)==1){break b}e=zc(c);Pw(a,e,Gb(c)+e|0);bs(a,d-h|0);v[a+44>>2]=v[a+20>>2]+(k-h|0);d=v[a+24>>2]}v[g+12>>2]=d+1;d=v[Yc(g+12|0,a+44|0)>>2];v[a+44>>2]=d;if(w[a+48|0]&8){c=zc(a+32|0);An(a,c,c+(j-i|0)|0,d)}e=xH(a,pp(b));break a}e=Ow(b);break a}a=V(0)|0;O()|0;_(a|0)|0;$()}jb=g+16|0;return e|0}function Bba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-80|0;jb=d;e=zf(d+48|0);v[23588]=0;g=Q(797,b|0,e|0)|0;f=v[23588];v[23588]=0;a:{b:{c:{if((f|0)!=1){if(g){break c}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[23588]=0;S(798,a|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){break b}}break a}g=v[e+4>>2];v[23588]=0;U(190,d|0,b|0,g|0);f=v[23588];v[23588]=0;if((f|0)==1){break a}f=jc(d+24|0,d);gd(e+8|0,f);Ab(f);Ab(d);d:{if(c>>>0<2){break d}c=g&1;if(!c){break d}v[23588]=0;Q(188,b|0,2-c|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break d}break a}wk(a,e)}zd(e);jb=d+80|0;return}a=P()|0;O()|0;zd(e);T(a|0);L()}function y1(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=jb-32|0;jb=e;if(_H(1,e+16|0)){is(v[116064],12631);L()}c=hs(e+8|0,v[e+16>>2]);g=hs(e,v[e+20>>2]);d=jb-32|0;jb=d;b=jb-16|0;jb=b;a=jb-16|0;jb=a;h=a,i=Lka(v[c>>2],v[c+4>>2],1e9,0),v[h>>2]=i;v[a+4>>2]=mb;c=rl(a+8|0,a);f=v[c+4>>2];c=v[c>>2];jb=a+16|0;v[b+8>>2]=c;v[b+12>>2]=f;a=v[b+12>>2];v[d+8>>2]=v[b+8>>2];v[d+12>>2]=a;jb=b+16|0;f=v[d+8>>2];c=v[d+12>>2];a=v[g+4>>2];v[d>>2]=v[g>>2];v[d+4>>2]=a;a=d;c=v[a+4>>2]+c|0;b=v[a>>2];f=f+b|0;v[a+16>>2]=f;v[a+20>>2]=b>>>0>f>>>0?c+1|0:c;a=rl(a+24|0,a+16|0);b=v[a+4>>2];a=v[a>>2];jb=d+32|0;a=Yr(e+24|0,a,b);b=v[a+4>>2];a=v[a>>2];jb=e+32|0;mb=b;return a|0}function uda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=jb-16|0;jb=b;f=v[a+40>>2];g=v[a+36>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+32>>2];k=v[a+28>>2];l=v[a+8>>2];m=v[a+12>>2];while(1){if(d){e=v[b+12>>2]+i|0;h=v[b+8>>2]>>>21&2040;e=(((B(t[e|0],u[h+39714>>1])+B(t[e-1|0],u[h+39712>>1])|0)+B(t[e+1|0],u[h+39716>>1])|0)+B(t[e+2|0],u[h+39718>>1])<<8)/16384|0;g=g+k|0;v[c>>2]=v[c>>2]+B(e,g>>12);f=f+j|0;v[c+4>>2]=v[c+4>>2]+B(e,f>>12);Qb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=f;v[a+20>>2]=g>>12;v[a+36>>2]=g;v[a+24>>2]=f>>12;jb=b+16|0}function pl(a,b,c){var d=0,e=0,f=0;d=Lb(a);a=Gb(b);v[23588]=0;R(46,d|0,a|0);a=v[23588];v[23588]=0;if((a|0)!=1){a:{while(1){if(Gb(b)>>>0>e>>>0){f=v[zi(b,e)>>2];a=32;b:{while(1){c:{if((a|0)==256){a=0;break c}if(v[(a<<2)+c>>2]==(f|0)){v[23588]=0;R(47,d|0,a<<24>>24);a=v[23588];v[23588]=0;if((a|0)!=1){break b}break a}else{a=a+1|0;continue}}break}d:{while(1){if((a|0)==32){break d}if(v[(a<<2)+c>>2]!=(f|0)){a=a+1|0;continue}break}v[23588]=0;R(47,d|0,a<<24>>24);a=v[23588];v[23588]=0;if((a|0)!=1){break b}break a}v[23588]=0;R(47,d|0,63);a=v[23588];v[23588]=0;if((a|0)!=1){break b}break a}e=e+1|0;continue}break}return}}a=P()|0;O()|0;yb(d);T(a|0);L()}function NX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=jb-32|0;jb=c;a:{b:{c:{d:{if(h=rh(v[b+4>>2],w[b+11|0]),i=1,j=v[b+12>>2],j?h:i){Lb(a);break d}e=Lb(c+16|0);d=yd(v[b+4>>2],w[b+11|0]);f=or(14270);g=od(b);v[23588]=0;X(102,e|0,g|0,d|0,d+f|0);d=v[23588];v[23588]=0;e:{if((d|0)!=1){v[23588]=0;W(103,e|0,14270,f|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){break e}}a=P()|0;O()|0;zb(e);T(a|0);L()}v[23588]=0;R(132,c|0,b+12|0);b=v[23588];v[23588]=0;if((b|0)==1){break c}v[23588]=0;U(2,a|0,c+16|0,c|0);a=v[23588];v[23588]=0;if((a|0)==1){break b}zb(c);zb(c+16|0)}jb=c+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;zb(c)}zb(c+16|0);T(b|0);L()}function B2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=jb-32|0;jb=e;h=Lb(a);f=Lb(e+16|0);a=1;a:{b:{c:{while(1){d=a&65535;c=v[b+24>>2];if(d>>>0>x[c+480192>>1]){if(!(i&1)){break c}v[23588]=0;R(247,h|0,f|0);a=v[23588];v[23588]=0;if((a|0)!=1){break c}a=P()|0;O()|0;break a}c=AM(c,d);v[23588]=0;c=Q(55,e|0,c|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break b}d=Qe(c);v[23588]=0;g=Q(800,f|0,c|0)|0;j=v[23588];v[23588]=0;d:{if((j|0)==1){break d}v[23588]=0;Q(941,g|0,21589)|0;g=v[23588];v[23588]=0;if((g|0)==1){break d}i=d^1|i;yb(c);a=a+1|0;continue}break}a=P()|0;O()|0;yb(c);break a}yb(f);jb=e+32|0;return}a=P()|0;O()|0}yb(f);yb(h);T(a|0);L()}function A2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=jb-32|0;jb=e;h=Lb(a);f=Lb(e+16|0);a=1;a:{b:{c:{while(1){d=a&65535;c=v[b+24>>2];if(d>>>0>x[c+480190>>1]){if(!(i&1)){break c}v[23588]=0;R(247,h|0,f|0);a=v[23588];v[23588]=0;if((a|0)!=1){break c}a=P()|0;O()|0;break a}v[23588]=0;c=Q(55,e|0,BM(c,d)|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break b}d=Qe(c);v[23588]=0;g=Q(800,f|0,c|0)|0;j=v[23588];v[23588]=0;d:{if((j|0)==1){break d}v[23588]=0;Q(941,g|0,21589)|0;g=v[23588];v[23588]=0;if((g|0)==1){break d}i=d^1|i;yb(c);a=a+1|0;continue}break}a=P()|0;O()|0;yb(c);break a}yb(f);jb=e+32|0;return}a=P()|0;O()|0}yb(f);yb(h);T(a|0);L()}function Wr(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;h=jb-16|0;jb=h;f=d?d:468004;d=v[f>>2];a:{b:{c:{if(!b){if(d){break c}break a}e=-2;if(!c){break a}i=a?a:h+12|0;d:{if(d){a=c;break d}a=w[b|0];d=a<<24>>24;if((d|0)>=0){v[i>>2]=a;e=(d|0)!=0;break a}if(!v[v[116090]>>2]){v[i>>2]=d&57343;e=1;break a}a=a-194|0;if(a>>>0>50){break c}d=v[(a<<2)+82768>>2];a=c-1|0;if(!a){break b}b=b+1|0}g=w[b|0];j=g>>>3|0;if((j-16|(d>>26)+j)>>>0>7){break c}while(1){a=a-1|0;d=g-128|d<<6;if((d|0)>=0){v[f>>2]=0;v[i>>2]=d;e=c-a|0;break a}if(!a){break b}b=b+1|0;g=w[b|0];if((g&192)==128){continue}break}}v[f>>2]=0;v[116064]=25;e=-1;break a}v[f>>2]=d}jb=h+16|0;return e}function BY(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;if(Zg(a,v[b+8>>2],f)){ow(b,c,d,e);return}g=w[b+53|0];j=v[a+12>>2];t[b+53|0]=0;h=w[b+52|0];t[b+52|0]=0;m=a+16|0;kw(v[m>>2],v[a+20>>2],b,c,d,e,f);k=w[b+53|0];g=g|k;l=w[b+52|0];h=h|l;i=a+24|0;j=(j<<3)+m|0;a:{if(i>>>0>=j>>>0){break a}while(1){h=h&1;g=g&1;if(w[b+54|0]){break a}b:{if(l){if(v[b+24>>2]==1){break a}if(w[a+8|0]&2){break b}break a}if(!k){break b}if(!(t[a+8|0]&1)){break a}}u[b+52>>1]=0;kw(v[i>>2],v[i+4>>2],b,c,d,e,f);k=w[b+53|0];g=k|g;l=w[b+52|0];h=l|h;i=i+8|0;if(j>>>0>i>>>0){continue}break}}t[b+53|0]=(g&255)!=0;t[b+52|0]=(h&255)!=0}function yba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=jb-48|0;jb=d;f=Lc(b);e=Gb(b);h=Lc(c);i=Gb(c);g=-1;a:{if(!e){break a}j=e+f|0;e=f;while(1){if((e|0)==(j|0)){break a}if(Cp(h,i,w[e|0])){e=e+1|0;continue}break}g=e-f|0}b:{c:{if((g|0)!=-1){k=d,l=he(b),v[k+32>>2]=l;f=lj(d+40|0,d+32|0);k=d,l=he(b),v[k+8>>2]=l;k=d,l=Fp(d+8|0,g),v[k+16>>2]=l;c=lj(d+24|0,d+16|0);NL(b,v[f>>2],v[c>>2]);break c}i=Gb(b);if(!i){break c}h=Lc(b);j=Gb(b);e=Lc(c);g=-1;f=Gb(c);if(f){c=h+j|0;d:{while(1){if((c|0)==(h|0)){break d}c=c-1|0;if(!Cp(e,f,w[c|0])){continue}break}g=c-h|0}}if((i-1|0)!=(g|0)){break c}Lb(a);break b}$c(a,b)}jb=d+48|0}function Dba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-80|0;jb=d;e=zf(d+48|0);v[23588]=0;c=Q(793,b|0,e|0)|0;f=v[23588];v[23588]=0;a:{b:{c:{if((f|0)!=1){if(c){break c}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[23588]=0;S(794,a|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){break b}}break a}c=v[e+4>>2];v[23588]=0;c=bc(c);c=c?c:-1;U(190,d|0,b|0,c|0);f=v[23588];v[23588]=0;if((f|0)==1){break a}f=jc(d+24|0,d);gd(e+8|0,f);Ab(f);Ab(d);d:{c=c&1;if(!c){break d}v[23588]=0;Q(188,b|0,2-c|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break d}break a}wk(a,e)}zd(e);jb=d+80|0;return}a=P()|0;O()|0;zd(e);T(a|0);L()}function zX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=jb-16|0;jb=g;e=od(b);d=yd(v[b+4>>2],w[b+11|0]);i=od(c);j=yd(v[c+4>>2],w[c+11|0]);f=-1;a:{if(!d){break a}h=d+e|0;d=e;while(1){if((d|0)==(h|0)){break a}if(nu(i,j,w[d|0])){d=d+1|0;continue}break}f=d-e|0}b:{c:{if((f|0)!=-1){c=ec(g+8|0,Oi(b));d=ec(g,Qf(Oi(b),f));oD(b,v[c>>2],v[d>>2]);break c}f=Fk(v[b+4>>2],w[b+11|0]);if(!f){break c}e=od(b);i=yd(v[b+4>>2],w[b+11|0]);j=od(c);d=-1;h=yd(v[c+4>>2],w[c+11|0]);if(h){c=e+i|0;d:{while(1){if((c|0)==(e|0)){break d}c=c-1|0;if(!nu(j,h,w[c|0])){continue}break}d=c-e|0}}if((f-1|0)!=(d|0)){break c}Lb(a);break b}$c(a,b)}jb=g+16|0}function Nga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=C(0),g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c=jb-16|0;jb=c;a:{b:{d=v[b+8>>2];if((d|0)==v[a+8>>2]){e=v[b+4>>2];if((e|0)!=v[a+4>>2]){break b}v[c+12>>2]=d;v[c+8>>2]=d;d=v[Jb(c+12|0,c+8|0)>>2];v[c+12>>2]=e;v[c+8>>2]=e;h=v[Jb(c+12|0,c+8|0)>>2];i=v[a>>2];j=v[b>>2];b=0;c:while(1){if((b|0)==(d|0)){break a}k=B(b,e);a=0;while(1)if((a|0)==(h|0)){b=b+1|0;continue c}else{l=(a+k<<1)+i|0;f=Vh(C(Xd(z[v[(a<<2)+j>>2]+(b<<2)>>2],C(-1))*C(32768)));d:{if(C(D(f))<C(2147483648)){g=~~f;break d}g=-2147483648}m=l,n=dd(g),u[m>>1]=n;a=a+1|0;continue}}}aa(17301,8943,27,9470);L()}aa(17251,8943,28,9470);L()}jb=c+16|0}function Eia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=v[a>>2];d=Eq(c,v[a+4>>2]);if(d>>>0<b>>>0){f=jb-32|0;jb=f;c=b-d|0;b=v[Fb(a)>>2];e=v[a+4>>2];a:{if(c>>>0<=(b-e|0)/40>>>0){d=jb-16|0;jb=d;b=UU(d,a,c);a=v[b+4>>2];c=v[b+8>>2];while(1){if((a|0)==(c|0)){kc(b);jb=d+16|0}else{ZS(a);a=a+40|0;v[b+4>>2]=a;continue}break}break a}b=Fb(a);d=RU(f+8|0,SU(a,Eq(v[a>>2],e)+c|0),Eq(v[a>>2],v[a+4>>2]),b);b=jb-16|0;jb=b;v[b>>2]=v[d+8>>2];e=v[d+8>>2];v[b+8>>2]=d+8;v[b+4>>2]=B(c,40)+e;c=v[b>>2];while(1){if(v[b+4>>2]!=(c|0)){ZS(c);c=v[b>>2]+40|0;v[b>>2]=c;continue}break}Td(b);jb=b+16|0;QU(a,d);PU(d)}jb=f+32|0;return}if(b>>>0<d>>>0){Nd(a,c+B(b,40)|0)}}function EN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=jb-16|0;jb=d;v[d+12>>2]=b;if(b>>>0<4294967280){a:{if(xl(a)>>>0>=b>>>0){break a}i=d,j=yd(v[a+4>>2],w[a+11|0]),v[i+8>>2]=j;e=Mg(v[Yc(d+12|0,d+8|0)>>2]);if((e|0)==(xl(a)|0)){break a}f=yd(v[a+4>>2],w[a+11|0]);b:{c:{if((e|0)==10){g=v[a>>2];h=1;b=a;c=f;break c}b=e+1|0;d:{if(xl(a)>>>0<e>>>0){b=sc(b);break d}v[23588]=0;b=S(52,b|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break d}a=V(0)|0;O()|0;_(a|0)|0;$();break b}c=w[a+11|0];h=ff(c);g=od(a);c=yd(v[a+4>>2],c)}b=ve(b,g,c+1|0);if(h){Mb(g)}if((e|0)!=10){bf(a,e+1|0);Fd(a,f);ud(a,b);break b}ce(a,f)}}jb=d+16|0;return}hf();L()}function Mga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=C(0),g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c=jb-16|0;jb=c;a:{b:{d=v[b+8>>2];if((d|0)==v[a+8>>2]){e=v[b+4>>2];if((e|0)!=v[a+4>>2]){break b}v[c+12>>2]=d;v[c+8>>2]=d;d=v[Jb(c+12|0,c+8|0)>>2];v[c+12>>2]=e;v[c+8>>2]=e;h=v[Jb(c+12|0,c+8|0)>>2];i=v[a>>2];j=v[b>>2];b=0;c:while(1){if((b|0)==(d|0)){break a}k=B(b,e);a=0;while(1)if((a|0)==(h|0)){b=b+1|0;continue c}else{l=(a+k|0)+i|0;f=Vh(C(Xd(z[v[(a<<2)+j>>2]+(b<<2)>>2],C(-1))*C(128)));d:{if(C(D(f))<C(2147483648)){g=~~f;break d}g=-2147483648}m=l,n=nS(g),t[m|0]=n;a=a+1|0;continue}}}aa(17301,8943,27,9470);L()}aa(17251,8943,28,9470);L()}jb=c+16|0}function naa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-80|0;jb=d;e=zf(d+48|0);v[23588]=0;g=Q(868,b|0,e|0)|0;f=v[23588];v[23588]=0;a:{b:{c:{if((f|0)!=1){if(g){break c}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[23588]=0;S(869,a|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){break b}}break a}g=v[e+4>>2];v[23588]=0;U(190,d|0,b|0,g|0);f=v[23588];v[23588]=0;if((f|0)==1){break a}f=jc(d+24|0,d);gd(e+8|0,f);Ab(f);Ab(d);d:{if(!(g&1)|c>>>0<2){break d}v[23588]=0;Q(188,b|0,1)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break d}break a}wk(a,e)}zd(e);jb=d+80|0;return}a=P()|0;O()|0;zd(e);T(a|0);L()}function _6(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0;d=jb-96|0;jb=d;v[d+88>>2]=c;c=v[a>>2];e=v[a+4>>2];f=v[a+12>>2];v[d+56>>2]=v[a+8>>2];v[d+60>>2]=f;v[d+48>>2]=c;v[d+52>>2]=e;a=ee(d+40|0);c=v[d+60>>2];v[d+24>>2]=v[d+56>>2];v[d+28>>2]=c;v[23588]=0;c=v[d+52>>2];v[d+16>>2]=v[d+48>>2];v[d+20>>2]=c;c=v[a+4>>2];v[d+8>>2]=v[a>>2];v[d+12>>2]=c;U(936,d- -64|0,d+16|0,d+8|0);a=v[23588];v[23588]=0;a:{b:{if((a|0)!=1){a=v[dg(d+32|0,d+88|0)>>2];v[23588]=0;b=+za(937,d- -64|0,+b,a|0);a=v[23588];v[23588]=0;if((a|0)==1){break b}Ab(d- -64|0);De(d+88|0);jb=d+96|0;return+b}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ab(d- -64|0)}De(d+88|0);T(a|0);L()}function rv(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=jb-16|0;jb=f;t[f+15|0]=d;t[b+12|0]=w[b+12|0]&240|w[a|0]&15;i=a+1|0;e=f+15|0;Qg(b,w[Wb(i,e)|0]);g=w[Wb(a+2|0,e)|0];t[b+13|0]=g;k=b,l=Cd(w[a+3|0],g,d),t[k+14|0]=l;e=w[Wb(a+4|0,e)|0];t[b+15|0]=e;k=b,l=Cd(w[a+5|0],e,d),t[k+16|0]=l;g=v[b>>2];b=0;while(1){t[f+14|0]=25;if(b>>>0<w[Wb(f+14|0,i)|0]){e=B(b,3)+a|0;h=Xb(w[e+6|0]+c<<24>>24,0,64);d=Db(g,b);t[d+2|0]=h;e=w[e+7|0]|w[e+8|0]<<8;u[d>>1]=e;a:{if(!b){break a}h=Db(g,b-1|0);j=x[h>>1];if(e>>>0>255|e>>>0>=j>>>0){break a}e=e|j&65280;u[d>>1]=e;if(x[h>>1]<=(e&65535)>>>0){break a}u[d>>1]=e+256}b=b+1|0;continue}break}jb=f+16|0}function qD(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{if(Rb(a,3878,4)){break a}b=w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24);if(b>>>0<36){break a}c=w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24);if(c>>>0<36){break a}d=w[a+32|0]|w[a+33|0]<<8|(w[a+34|0]<<16|w[a+35|0]<<24);if(d>>>0<36){break a}e=w[a+12|0]|w[a+13|0]<<8|(w[a+14|0]<<16|w[a+15|0]<<24);if(e-1>>>0>858993458){break a}f=w[a+20|0]|w[a+21|0]<<8|(w[a+22|0]<<16|w[a+23|0]<<24);if(f-1>>>0>536870910){break a}a=w[a+28|0]|w[a+29|0]<<8|(w[a+30|0]<<16|w[a+31|0]<<24);if(B(e,-5)-1>>>0<b>>>0|a-1>>>0>1073741822|(f<<3^-1)>>>0<c>>>0){break a}g=(a<<2^-1)>>>0>=d>>>0}return g}function YU(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a:{if(!d){break a}i=w[e|0];if(!i){break a}g=d-6|0;j=(g&255)>>>0<6&35>>>g;l=d-2|0;m=0-c|0;while(1){if(!b){break a}k=(l&255)>>>0>2;h=B(m,6);c=a;a=h+c|0;f=w[a+3|0];b:{if(!(k|(f-2&255)>>>0>2)){g=1;if(w[(c+h|0)+5|0]<224){break b}break a}g=(d|0)==(f|0);if(!(1<<f&2240)|(!j|f>>>0>11)){break b}g=1}c:{if(k){break c}f=c+h|0;if((w[f+2|0]-11&255)>>>0>2){break c}if(w[f+4|0]){break a}}d:{if(!j){break d}f=c+h|0;if((w[f+2|0]-3&255)>>>0>3){break d}if(w[f+4|0]){break a}}b=b-1|0;if(!g){continue}c=w[(c+h|0)+5|0];if(c?(c|0)!=(i|0):0){break a}if((c|0)!=(i|0)){continue}break}t[e|0]=0}}function Fba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-80|0;jb=d;e=zf(d+48|0);v[23588]=0;c=Q(789,b|0,e|0)|0;f=v[23588];v[23588]=0;a:{b:{c:{if((f|0)!=1){if(c){break c}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[23588]=0;S(790,a|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){break b}}break a}c=v[e+4>>2];v[23588]=0;c=bc(c);U(190,d|0,b|0,c|0);f=v[23588];v[23588]=0;if((f|0)==1){break a}f=jc(d+24|0,d);gd(e+8|0,f);Ab(f);Ab(d);d:{c=c&1;if(!c){break d}v[23588]=0;Q(188,b|0,2-c|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break d}break a}wk(a,e)}zd(e);jb=d+80|0;return}a=P()|0;O()|0;zd(e);T(a|0);L()}function JS(a){var b=0,c=0,d=0,e=0,f=0;b=jb-32|0;jb=b;e=b,f=bc(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))+788|0,v[e>>2]=f;v[b+4>>2]=0;e=b,f=bc(w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24)),v[e+8>>2]=f;v[b+12>>2]=0;c=bc(w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24));v[b+16>>2]=c?c:52;v[b+20>>2]=0;e=b,f=bc(w[a+32|0]|w[a+33|0]<<8|(w[a+34|0]<<16|w[a+35|0]<<24))+80|0,v[e+24>>2]=f;v[b+28>>2]=0;a=b;d=af(a,4);a:{if((a|0)==(d|0)){break a}c=a;while(1){c=c+8|0;if((d|0)==(c|0)){break a}a=mv(v[a>>2],v[a+4>>2],v[c>>2],v[c+4>>2])?c:a;continue}}jb=b+32|0;c=v[a>>2];b=c-52|0;mb=v[a+4>>2]-(c>>>0<52)|0;return b}function QH(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=jb-208|0;jb=f;v[f+204>>2]=c;c=f+160|0;Tb(c,0,40);v[f+200>>2]=v[f+204>>2];a:{if((PH(0,b,f+200|0,f+80|0,c,d,e)|0)<0){e=-1;break a}i=v[a+76>>2]>=0;g=v[a>>2];if(v[a+72>>2]<=0){v[a>>2]=g&-33}b:{c:{d:{if(!v[a+48>>2]){v[a+48>>2]=80;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;h=v[a+44>>2];v[a+44>>2]=f;break d}if(v[a+16>>2]){break c}}c=-1;if(oC(a)){break b}}c=PH(a,b,f+200|0,f+80|0,f+160|0,d,e)}if(h){nb[v[a+36>>2]](a,0,0)|0;v[a+48>>2]=0;v[a+44>>2]=h;v[a+28>>2]=0;b=v[a+20>>2];v[a+16>>2]=0;v[a+20>>2]=0;c=b?c:-1}b=a;a=v[a>>2];v[b>>2]=a|g&32;e=a&32?-1:c;if(!i){break a}}jb=f+208|0;return e}function Maa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=jb-16|0;jb=h;f=c;e=jb-16|0;jb=e;g=b;d=Sd(b);a:{if(d){c=ic(g);while(1){b=d;d=b+16|0;if(jM(f,d)){c=b;d=v[b>>2];if(d){continue}break a}if(!jM(d,f)){break a}c=b+4|0;d=v[b+4>>2];if(d){continue}break}break a}b=ic(g);c=b}v[e+12>>2]=b;b=v[c>>2];if(!b){b=jb-16|0;jb=b;d=ic(g);d=lh(e,sc(28),mh(b+8|0,d));i=v[d>>2];v[23588]=0;R(846,i+16|0,f|0);f=v[23588];v[23588]=0;b:{if((f|0)!=1){j=ic(d),k=1,t[j+4|0]=k;jb=b+16|0;break b}a=P()|0;O()|0;iM(d);T(a|0);L()}Jg(g,v[e+12>>2],c,v[e>>2]);b=be(e);iM(e);i=1}c=h+8|0;Ig(c,v[ec(e,b)>>2],i);jb=e+16|0;tP(a,c);jb=h+16|0}function J6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=jb-16|0;jb=e;i=e,j=zj(b),v[i>>2]=j;c=jb-16|0;jb=c;g=a;d=Sd(a);a:{if(d){f=ic(g);while(1){a=d;d=a+16|0;if(ot(b,d)){f=a;d=v[a>>2];if(d){continue}break a}if(!ot(d,b)){break a}f=a+4|0;d=v[a+4>>2];if(d){continue}break}break a}a=ic(g);f=a}v[c+12>>2]=a;b=v[f>>2];if(!b){a=jb-16|0;jb=a;b=ic(g);b=lh(c,sc(40),mh(a+8|0,b));Lb($c(v[b>>2]+16|0,v[e>>2])+12|0);i=ic(b),j=1,t[i+4|0]=j;jb=a+16|0;Jg(g,v[c+12>>2],f,v[c>>2]);b=be(c);a=v[c>>2];v[c>>2]=0;if(a){if(w[ic(c)+4|0]){wm(a+16|0)}Mb(a)}h=1}Ig(e+8|0,v[ec(c,b)>>2],h);jb=c+16|0;a=vd(v[e+8>>2]);jb=e+16|0;return a+12|0}function wP(a,b,c){a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{b=b&15;switch(b-3|0){case 2:break j;case 1:break k;case 0:break l;case 10:case 11:break b;case 9:break c;case 8:break d;case 7:break e;case 6:break f;case 5:break g;case 4:break h;case 3:break i;default:break a}}t[a+798|0]=0;return}t[a+798|0]=1;return}t[a+798|0]=2;return}t[a+798|0]=3;return}t[a+730|0]=w[a+730|0]&254;return}t[a+730|0]=w[a+730|0]|1;return}t[a+738|0]=w[a+738|0]&254;return}t[a+738|0]=w[a+738|0]|1;return}t[a+746|0]=w[a+746|0]&254;return}t[a+746|0]=w[a+746|0]|1;return}if((c|0)!=16777216){break a}c=a;a=w[a+746|0];t[c+746|0]=(b|0)==13?a&238|1:a|17}}function XA(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=jb-16|0;jb=e;d=(c<<3)+a|0;f=w[d+356|0];t[b+12|0]=w[b+12|0]&248|f&1|f<<1&4|f>>>1&2;Qg(b,Cd(w[d+352|0],2,16));t[b+13|0]=w[d+354|0];t[b+14|0]=w[d+355|0];d=w[d+353|0];t[b+15|0]=d;t[b+16|0]=d;d=0;u[e+14>>1]=0;f=((c|0)!=0)<<1;h=v[b>>2];j=_d(h,v[b+4>>2]);k=(c<<6)+a|0;c=((c|0)==2?-1:0)&255;while(1){if((d|0)==(j|0)){WA(b,32);jb=e+16|0}else{a=k+(d<<2)|0;u[e+12>>1]=w[a+160|0]|w[a+161|0]<<8;g=ke(e+14|0,e+12|0);i=Db(h,d);g=x[g>>1];u[i>>1]=g;u[e+14>>1]=g+1;t[e+11|0]=(c^w[a+162|0])>>>f;t[e+10|0]=64;l=i,m=w[Wb(e+11|0,e+10|0)|0],t[l+2|0]=m;d=d+1|0;continue}break}}function R$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=jb-48|0;jb=f;v[f+40>>2]=b;a:{if(!(v[c+4>>2]&1)){c=nb[v[v[a>>2]+24>>2]](a,b,c,d,e)|0;break a}a=f+24|0;fd(a,c);v[23588]=0;a=S(1119,a|0)|0;b=v[23588];v[23588]=0;b:{if((b|0)!=1){$b(f+24|0);c:{if(e){Oh(f+24|0,a);break c}Nh(f+24|0,a)}g=f,h=he(f+24|0),v[g+16>>2]=h;while(1){g=f,h=yh(f+24|0),v[g+8>>2]=h;if(!yi(f+16|0,f+8|0)){c=v[f+40>>2];yb(f+24|0);break a}a=t[v[f+16>>2]];v[23588]=0;Q(21,f+40|0,a|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){Ge(f+16|0);continue}break}c=P()|0;O()|0;yb(f+24|0);break b}c=P()|0;O()|0;$b(f+24|0)}T(c|0);L()}jb=f+48|0;return c|0}function QV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-208|0;jb=d;XB(c,a);WB(c,d+16|0,B(w[a+4|0],3));a:{if(w[a+4|0]<2){break a}c=jb-16|0;jb=c;v[c+12>>2]=64;v[c+8>>2]=255;e=w[Jb(c+12|0,c+8|0)|0];jb=c+16|0;t[d+12|0]=e;Qg(b,w[Wb(a+4|0,d+12|0)|0]);t[b+13|0]=w[a+2|0];t[b+14|0]=w[a+3|0];a=w[a+1|0];t[b+15|0]=a;t[b+16|0]=a;e=v[b>>2];f=_d(e,v[b+4>>2]);a=0;while(1){if((a|0)==(f|0)){break a}b:{if(!a){b=w[d+18|0];c=Db(e,0);break b}g=x[Db(e,a-1|0)>>1];v[d+12>>2]=1;b=(d+16|0)+B(a,3)|0;v[d+8>>2]=(t[b+1|0]&1)<<8|w[b|0];h=Oe(d+12|0,d+8|0);c=Db(e,a);u[c>>1]=x[h>>1]+g;b=w[b+2|0]}t[c+2|0]=b;a=a+1|0;continue}}jb=d+208|0}function G3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=jb+-64|0;jb=d;f=d+16|0;h=jb-16|0;jb=h;i=EP(h+8|0);while(1){if((j|0)==12){jb=h+16|0}else{g=jb+-64|0;jb=g;c=v[i+4>>2];e=v[i>>2];a:{if((c|0)==(e|0)){break a}c=(c-e|0)+1|0;if(!c){c=zJ(BJ(g+8|0,32));break a}e=E(c);e=BJ(g+8|0,(c<<e+1?32:31)-e|0);while(1){k=zJ(e);if(c>>>0<=k>>>0){continue}break}c=v[i>>2]+k|0}jb=g- -64|0;l=Db(f,j),m=c,v[l>>2]=m;j=j+1|0;continue}break}f=HP(d,f,JP(f));FP(a,f);Fm(f);jb=d- -64|0;d=wx(a+120|0,a,b);t[d+20|0]=1;v[23588]=0;R(1068,a|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){a=P()|0;O()|0;Gn(d);T(a|0);L()}return a|0}function cba(a){a=a|0;var b=0,c=0,d=0;c=a+1298224|0;b=a+1074992|0;while(1){if((b|0)==(c|0)){dt(a+484344|0);_f(a+1298308|0);nA(a+1298320|0);_f(a+1298332|0);Kc(a+1298408|0);b=a+900380|0;c=a+484380|0;while(1){if((b|0)==(c|0)){a:{c=a+901404|0;while(1){if((b|0)==(c|0)){b=a+906300|0;c=ek(b);while(1){if((b|0)==(c|0)){break a}xV(b);b=b+160|0;continue}}d=v[b>>2];if(d){Mb(cu(d))}v[b>>2]=0;b=b+4|0;continue}}}else{Dm(c);c=c+104|0;continue}break}v[a+480180>>2]=0;v[a+480184>>2]=0;a=a+480186|0;u[a>>1]=0;u[a+2>>1]=0;u[a+4>>1]=0;u[a+6>>1]=0}else{v[b+104>>2]=0;v[b+656>>2]=0;v[b+76>>2]=0;v[b+16>>2]=0;b=b+872|0;continue}break}}function $L(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=jb-16|0;jb=h;t[h+15|0]=b;t[h+14|0]=10;Qg(g,w[Wb(h+15|0,h+14|0)|0]);t[g+15|0]=c;t[g+16|0]=c;t[g+14|0]=e;t[g+13|0]=d;j=v[g>>2];k=_d(j,v[g+4>>2]);b=0;a:{while(1){if((b|0)==(k|0)){b:{b=w[g+12|0]&-2|a&1;if(a&2){break b}b=b&251;break a}}else{m=Db(j,b);l=B(b,3)+f|0;i=(w[l|0]|w[l+1|0]<<8)>>>4|0;u[m>>1]=i;c:{if(b){n=x[Db(j,b-1|0)>>1];if(i>>>0>=n>>>0){break c}i=n+1|0}else{i=0}o=Db(j,b),p=i,u[o>>1]=p}o=m,p=Cd(w[l+2|0],0,64),t[o+2|0]=p;b=b+1|0;continue}break}b=b&-5|(c>>>0<=k>>>0)<<2}t[g+12|0]=(d>>>0<=e>>>0?a&4:0)?b&-3|(d>>>0<=k>>>0)<<1:b&253;jb=h+16|0}function wU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a:{e=jb-16|0;jb=e;f=jb-32|0;jb=f;c=of(f+16|0,1,0);b:{c:{d:{while(1){d=zc(c);Gx(f+8|0,d,Gb(c)+d|0,v[b>>2]);if(!v[f+12>>2]){break d}d=ch(Gb(c));v[23588]=0;R(59,c|0,d|0);d=v[23588];v[23588]=0;if((d|0)!=1){continue}break}break c}b=v[f+8>>2];d=zc(c);v[23588]=0;R(60,c|0,b-d|0);b=v[23588];v[23588]=0;e:{if((b|0)!=1){v[23588]=0;R(72,e|0,c|0);b=v[23588];v[23588]=0;if((b|0)!=1){break e}break c}break c}yb(c);jb=f+32|0;break b}a=P()|0;O()|0;yb(c);T(a|0);L()}v[23588]=0;R(71,a|0,e|0);a=v[23588];v[23588]=0;if((a|0)!=1){zb(e);jb=e+16|0;break a}a=P()|0;O()|0;zb(e);T(a|0);L()}}function Zo(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a:{e=jb-16|0;jb=e;f=jb-32|0;jb=f;c=of(f+16|0,1,0);b:{c:{d:{while(1){d=zc(c);Kx(f+8|0,d,Gb(c)+d|0,v[b>>2]);if(!v[f+12>>2]){break d}d=ch(Gb(c));v[23588]=0;R(59,c|0,d|0);d=v[23588];v[23588]=0;if((d|0)!=1){continue}break}break c}b=v[f+8>>2];d=zc(c);v[23588]=0;R(60,c|0,b-d|0);b=v[23588];v[23588]=0;e:{if((b|0)!=1){v[23588]=0;R(72,e|0,c|0);b=v[23588];v[23588]=0;if((b|0)!=1){break e}break c}break c}yb(c);jb=f+32|0;break b}a=P()|0;O()|0;yb(c);T(a|0);L()}v[23588]=0;R(71,a|0,e|0);a=v[23588];v[23588]=0;if((a|0)!=1){zb(e);jb=e+16|0;break a}a=P()|0;O()|0;zb(e);T(a|0);L()}}function FD(a,b){var c=0,d=0,e=0,f=0;c=v[a>>2];d=Ug(c,v[a+4>>2]);if(d>>>0<b>>>0){f=jb-32|0;jb=f;c=b-d|0;b=v[Fb(a)>>2];e=v[a+4>>2];a:{if(c>>>0<=b-e>>3>>>0){d=jb-16|0;jb=d;b=kr(d,a,c);a=v[b+4>>2];c=v[b+8>>2];while(1){if((a|0)==(c|0)){kc(b);jb=d+16|0}else{Sj(a);a=a+8|0;v[b+4>>2]=a;continue}break}break a}b=Fb(a);d=mr(f+8|0,nr(a,Ug(v[a>>2],e)+c|0),Ug(v[a>>2],v[a+4>>2]),b);b=jb-16|0;jb=b;v[b>>2]=v[d+8>>2];e=v[d+8>>2];v[b+8>>2]=d+8;v[b+4>>2]=(c<<3)+e;c=v[b>>2];while(1){if(v[b+4>>2]!=(c|0)){Sj(c);c=v[b>>2]+8|0;v[b>>2]=c;continue}break}Td(b);jb=b+16|0;Dd(a,d);lr(d)}jb=f+32|0;return}if(b>>>0<d>>>0){Nd(a,c+(b<<3)|0)}}function rY(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=jb-32|0;jb=k;m=v[c>>2];l=v[c+8>>2];c=v[c+4>>2];v[k+8>>2]=c;v[k+12>>2]=l;v[k+24>>2]=c;v[k+28>>2]=l;v[k+20>>2]=m;v[k+16>>2]=d;v[23588]=0;c=v[k+20>>2];v[k>>2]=v[k+16>>2];v[k+4>>2]=c;a=La(1049,a|0,b|0,k|0)|0;b=v[23588];v[23588]=0;a:{b:{if((b|0)==1){a=V(0)|0;O()|0;_(a|0)|0;v[23588]=0;ia(935,10365,e|0,f|0,g|0,h|0,i|0,j|0);a=v[23588];v[23588]=0;if((a|0)==1){break b}$();a=-255}jb=k+32|0;break a}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}return a|0}function Ap(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=jb-16|0;jb=e;f=jb-32|0;jb=f;c=of(f+16|0,1,0);a:{b:{c:{while(1){d=zc(c);Kx(f+8|0,d,Gb(c)+d|0,v[b>>2]);if(!v[f+12>>2]){break c}d=ch(Gb(c));v[23588]=0;R(59,c|0,d|0);d=v[23588];v[23588]=0;if((d|0)!=1){continue}break}break b}b=v[f+8>>2];d=zc(c);v[23588]=0;R(60,c|0,b-d|0);b=v[23588];v[23588]=0;d:{if((b|0)!=1){v[23588]=0;R(61,e|0,c|0);b=v[23588];v[23588]=0;if((b|0)!=1){break d}break b}break b}yb(c);jb=f+32|0;break a}a=P()|0;O()|0;yb(c);T(a|0);L()}v[23588]=0;R(58,a|0,e|0);a=v[23588];v[23588]=0;if((a|0)!=1){yb(e);jb=e+16|0;return}a=P()|0;O()|0;yb(e);T(a|0);L()}function l9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=jb-16|0;jb=e;f=jb-32|0;jb=f;c=of(f+16|0,1,0);a:{b:{c:{while(1){d=zc(c);Kx(f+8|0,d,Gb(c)+d|0,w[b|0]);if(!v[f+12>>2]){break c}d=ch(Gb(c));v[23588]=0;R(59,c|0,d|0);d=v[23588];v[23588]=0;if((d|0)!=1){continue}break}break b}b=v[f+8>>2];d=zc(c);v[23588]=0;R(60,c|0,b-d|0);b=v[23588];v[23588]=0;d:{if((b|0)!=1){v[23588]=0;R(61,e|0,c|0);b=v[23588];v[23588]=0;if((b|0)!=1){break d}break b}break b}yb(c);jb=f+32|0;break a}a=P()|0;O()|0;yb(c);T(a|0);L()}v[23588]=0;R(58,a|0,e|0);a=v[23588];v[23588]=0;if((a|0)!=1){yb(e);jb=e+16|0;return}a=P()|0;O()|0;yb(e);T(a|0);L()}function h2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;g=jb-16|0;jb=g;a:{if(!(c&1024)){break a}i=g,j=Oi(b),v[i+8>>2]=j;c=Fk(v[b+4>>2],w[b+11|0]);b:{if(!c){break b}if(w[od(b)|0]!=43){if(w[od(b)|0]!=45){break b}}d=d+1|0;wJ(g+8|0)}if(c>>>0>=d>>>0){break a}e=v[ec(g,v[g+8>>2])>>2];c=d-Fk(v[b+4>>2],w[b+11|0])|0;c:{e=ro(e,Oi(b));d=yd(v[b+4>>2],w[b+11|0]);if(e>>>0<=d>>>0){if(c){f=xl(b);d:{if(c>>>0<=f-d>>>0){f=od(b);if((d|0)==(e|0)){break d}h=e+f|0;Wh(c+h|0,h,d-e|0);break d}Oy(b,f,(c+d|0)-f|0,d,e,c);f=v[b>>2]}mI(e+f|0,c,48);c=c+d|0;sq(b,c);wd(c+f|0,0)}break c}rk();L()}Oi(b)}$c(a,b);jb=g+16|0}function me(a,b){var c=0,d=0,e=0;c=jb-32|0;jb=c;a=Xg(a,-1,-1);a:{b:{if(Pd(w[fm(c+24|0,b,1)|0])){d=v[(v[v[b>>2]-12>>2]+b|0)+24>>2];v[23588]=0;Nk(107,c+8|0,d,0,0);d=v[23588];v[23588]=0;c:{if((d|0)!=1){d=v[c+12>>2];v[a>>2]=v[c+8>>2];v[a+4>>2]=d;d=v[c+20>>2];v[a+8>>2]=v[c+16>>2];v[a+12>>2]=d;break c}a=V(0)|0;O()|0;_(a|0)|0;e=1;dm(v[v[b>>2]-12>>2]+b|0,1);if(v[(v[v[b>>2]-12>>2]+b|0)+20>>2]&1){v[23588]=0;Z(105);a=v[23588];v[23588]=0;if((a|0)!=1){break a}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)==1){break b}T(a|0);L()}$()}Ki(v[v[b>>2]-12>>2]+b|0,e)}jb=c+32|0;return}V(0)|0;O()|0;Ub()}L()}function jL(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=jb-16|0;jb=e;Jh(e+8|0,b);f=jb-16|0;jb=f;_g(f+8|0,v[e+8>>2],v[e+12>>2]);c=v[f+12>>2];b=v[f+8>>2];g=jb-16|0;jb=g;k=g,l=Eb(a),v[k+8>>2]=l;h=b;a=c;b=jb-16|0;jb=b;i=v[g+8>>2];c=i;d=v[c+12>>2];c=v[c+8>>2];a:{if((d|0)<0){break a}j=v[i+4>>2];if(!d&j>>>0<c>>>0|d){break a}v[b+8>>2]=j-c;v[b+12>>2]=0-(d+(c>>>0>j>>>0)|0);v[b>>2]=a;v[b+4>>2]=0;d=VB(b+8|0,b);if((bz(v[d>>2],v[d+4>>2])|0)!=(a|0)){break a}Pi(h,a+h|0,c+v[i>>2]|0);c=v[g+8>>2];h=c;d=a+v[c+8>>2]|0;c=v[c+12>>2];v[h+8>>2]=d;v[h+12>>2]=a>>>0>d>>>0?c+1|0:c}jb=b+16|0;jb=g+16|0;jb=f+16|0;jb=e+16|0}function x6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-32|0;jb=c;v[23588]=0;Y(952,a|0);d=v[23588];v[23588]=0;a:{b:{c:{if((d|0)==1){break c}v[23588]=0;Y(953,b|0);d=v[23588];v[23588]=0;if((d|0)==1){break c}d=v[a+24>>2];b=qc(c+8|0,b);v[23588]=0;e=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=e;X(965,c+16|0,d|0,c|0,1);b=v[23588];v[23588]=0;if((b|0)==1){break c}a=c+16|0;b=fg(Lc(a));yb(a);break b}b=V(0)|0;O()|0;_(b|0)|0;b=0;v[23588]=0;X(939,5538,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$()}jb=c+32|0;return b|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function a$(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=jb-16|0;jb=k;a:{if(a){a=ZF(b);Rk(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;Qk(k,a);Vi(i,k);Fc(k);Nh(k,a);Vi(h,k);Fc(k);l=d,m=$i(a),v[l>>2]=m;l=e,m=aj(a),v[l>>2]=m;bh(k,a);Ac(f,k);yb(k);Oh(k,a);Vi(g,k);Fc(k);a=Pk(a);break a}a=YF(b);Rk(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;Qk(k,a);Vi(i,k);Fc(k);Nh(k,a);Vi(h,k);Fc(k);l=d,m=$i(a),v[l>>2]=m;l=e,m=aj(a),v[l>>2]=m;bh(k,a);Ac(f,k);yb(k);Oh(k,a);Vi(g,k);Fc(k);a=Pk(a)}v[j>>2]=a;jb=k+16|0}function Afa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=jb-32|0;jb=d;md(b,0);Zh(d,1,a);c=d+16|0;Ec(c,d);Be(b+43|0,c);yb(c);v[b>>2]=w[a+48|0]|w[a+49|0]<<8|(w[a+50|0]<<16|w[a+51|0]<<24);v[b+4>>2]=w[a+52|0]|w[a+53|0]<<8|(w[a+54|0]<<16|w[a+55|0]<<24);v[b+8>>2]=w[a+56|0]|w[a+57|0]<<8|(w[a+58|0]<<16|w[a+59|0]<<24);v[b+24>>2]=w[a+62|0]|w[a+63|0]<<8;Al(b,+((w[a+60|0]^8)-120|0)/192);t[d+16|0]=w[a+61|0];t[d|0]=64;f=b,g=w[Wb(c,d)|0]<<2,u[f+30>>1]=g;u[b+34>>1]=0;c=w[a+47|0];if(c&4){u[b+34>>1]=1;v[b>>2]=v[b>>2]>>>1;e=1;c=w[a+47|0]}if(c&32){e=e|4;u[b+34>>1]=e;c=w[a+47|0]}if(c<<24>>24<0){u[b+34>>1]=e|2}jb=d+32|0}function Tia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=jb-80|0;jb=d;e=zf(d+48|0);v[23588]=0;c=Q(400,b|0,e|0)|0;f=v[23588];v[23588]=0;a:{b:{c:{d:{if((f|0)!=1){if(c){break d}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[23588]=0;S(401,a|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){break a}}break c}c=jb-16|0;jb=c;g=c,h=bc(v[e+4>>2]),v[g+12>>2]=h;v[c+8>>2]=8;f=v[Yc(c+12|0,c+8|0)>>2];jb=c+16|0;v[23588]=0;U(190,d|0,b|0,f-8|0);b=v[23588];v[23588]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;zd(e);T(a|0);L()}b=jc(d+24|0,d);gd(e+8|0,b);Ab(b);Ab(d);wk(a,e)}zd(e);jb=d+80|0}function Tea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;v[a>>2]=0;v[a+4>>2]=0;Gc(a+8|0);if(b){if(sh(119304647)>>>0<b>>>0){bd();L()}b=B(b,36);c=sc(b);v[a>>2]=c;v[a+4>>2]=c;f=Fb(a),g=b+c|0,v[f>>2]=g;d=jb-16|0;jb=d;v[d>>2]=a;c=v[a+4>>2];v[d+4>>2]=c;v[d+8>>2]=b+c;b=v[d+4>>2];e=v[d+8>>2];while(1){if((b|0)==(e|0)){kc(d);jb=d+16|0}else{c=Tb(b,0,36);v[c>>2]=0;v[c+4>>2]=0;u[c+22>>1]=0;u[c+24>>1]=0;u[c+26>>1]=0;u[c+28>>1]=0;t[c+21|0]=64;t[c+19|0]=64;t[c+20|0]=100;t[c+15|0]=0;t[c+16|0]=0;t[c+17|0]=0;t[c+18|0]=0;v[c+8>>2]=0;v[c+12>>2]=0;u[c+30>>1]=0;u[c+32>>1]=0;b=b+36|0;v[d+4>>2]=b;continue}break}}return a|0}function ZJ(a,b){var c=0,d=0,e=0,f=0;a:{e=jb-16|0;jb=e;f=jb-32|0;jb=f;c=of(f+16|0,1,0);b:{c:{d:{while(1){d=zc(c);Bx(f+8|0,d,Gb(c)+d|0,x[b>>1]);if(!v[f+12>>2]){break d}d=ch(Gb(c));v[23588]=0;R(59,c|0,d|0);d=v[23588];v[23588]=0;if((d|0)!=1){continue}break}break c}b=v[f+8>>2];d=zc(c);v[23588]=0;R(60,c|0,b-d|0);b=v[23588];v[23588]=0;e:{if((b|0)!=1){v[23588]=0;R(72,e|0,c|0);b=v[23588];v[23588]=0;if((b|0)!=1){break e}break c}break c}yb(c);jb=f+32|0;break b}a=P()|0;O()|0;yb(c);T(a|0);L()}v[23588]=0;R(71,a|0,e|0);a=v[23588];v[23588]=0;if((a|0)!=1){zb(e);jb=e+16|0;break a}a=P()|0;O()|0;zb(e);T(a|0);L()}}function qs(a,b,c){var d=0,e=0;d=a,e=hj(C(C(z[c+1792>>2]*C(75038))+C(C(C(z[c+2048>>2]-z[c+1536>>2])*C(37489))+C(C(C(z[c+1280>>2]+z[c+2304>>2])*C(6574))+C(C(C(z[c+2560>>2]-z[c+1024>>2])*C(5153))+C(C(C(z[c+768>>2]+z[c+2816>>2])*C(2037))+C(C(C(z[c+3072>>2]-z[c+512>>2])*C(459))+C(C(C(z[c+256>>2]+z[c+3328>>2])*C(213))+C(C(z[c+3584>>2]-z[c>>2])*C(29)))))))))),u[d>>1]=e;d=(b<<5)+a|0,e=hj(C(C(z[c+8>>2]*C(-5))+C(C(z[c+520>>2]*C(146))+C(C(z[c+1032>>2]*C(-45))+C(C(z[c+1544>>2]*C(-9975))+C(C(z[c+2056>>2]*C(64019))+C(C(z[c+2568>>2]*C(9727))+C(C(z[c+3080>>2]*C(1567))+C(z[c+3592>>2]*C(104)))))))))),u[d>>1]=e}function h$(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=jb-16|0;jb=k;a:{if(a){a=aG(b);Rk(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;Qk(k,a);Ac(i,k);yb(k);Nh(k,a);Ac(h,k);yb(k);l=d,m=$i(a),t[l|0]=m;l=e,m=aj(a),t[l|0]=m;bh(k,a);Ac(f,k);yb(k);Oh(k,a);Ac(g,k);yb(k);a=Pk(a);break a}a=$F(b);Rk(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;Qk(k,a);Ac(i,k);yb(k);Nh(k,a);Ac(h,k);yb(k);l=d,m=$i(a),t[l|0]=m;l=e,m=aj(a),t[l|0]=m;bh(k,a);Ac(f,k);yb(k);Oh(k,a);Ac(g,k);yb(k);a=Pk(a)}v[j>>2]=a;jb=k+16|0}function dK(a,b){var c=0,d=0,e=0,f=0;a:{e=jb-16|0;jb=e;f=jb-32|0;jb=f;c=of(f+16|0,1,0);b:{c:{d:{while(1){d=zc(c);bK(f+8|0,d,Gb(c)+d|0,w[b|0]);if(!v[f+12>>2]){break d}d=ch(Gb(c));v[23588]=0;R(59,c|0,d|0);d=v[23588];v[23588]=0;if((d|0)!=1){continue}break}break c}b=v[f+8>>2];d=zc(c);v[23588]=0;R(60,c|0,b-d|0);b=v[23588];v[23588]=0;e:{if((b|0)!=1){v[23588]=0;R(72,e|0,c|0);b=v[23588];v[23588]=0;if((b|0)!=1){break e}break c}break c}yb(c);jb=f+32|0;break b}a=P()|0;O()|0;yb(c);T(a|0);L()}v[23588]=0;R(71,a|0,e|0);a=v[23588];v[23588]=0;if((a|0)!=1){zb(e);jb=e+16|0;break a}a=P()|0;O()|0;zb(e);T(a|0);L()}}function O3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[Fb(a)>>2]){c=jb-16|0;jb=c;a=Et(c,a,1);yx(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+16;kc(a);jb=c+16|0;return}e=jb-32|0;jb=e;c=Fb(a);c=fQ(e+8|0,gQ(a,lk(v[a>>2],v[a+4>>2])+1|0),lk(v[a>>2],v[a+4>>2]),c);yx(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+16;f=v[a>>2];d=v[a+4>>2];b=c+4|0;while(1){if((d|0)!=(f|0)){d=d-16|0;yx(v[b>>2]-16|0,d);v[b>>2]=v[b>>2]-16;continue}break}pc(a,b);pc(a+4|0,c+8|0);pc(Fb(a),Bc(c));v[c>>2]=v[c+4>>2];a=v[c+4>>2];while(1){b=v[c+8>>2];if((b|0)!=(a|0)){b=b-16|0;v[c+8>>2]=b;Cs(b);continue}break}a=v[c>>2];if(a){_o(c);Mb(a)}jb=e+32|0}function jha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=jb-16|0;jb=e;i=e,j=zj(b),v[i>>2]=j;f=x[b>>1];d=jb-16|0;jb=d;g=a;c=Sd(a);a:{if(c){b=ic(g);while(1){a=c;c=x[a+14>>1];if(mo(f,c)){b=a;c=v[a>>2];if(c){continue}break a}if(!mo(c,f)){break a}b=a+4|0;c=v[a+4>>2];if(c){continue}break}break a}a=ic(g);b=a}v[d+12>>2]=a;a=v[b>>2];if(!a){a=jb-16|0;jb=a;c=ic(g);f=lh(d,sc(20),mh(a+8|0,c));c=v[f>>2];h=x[v[e>>2]>>1];u[c+16>>1]=0;u[c+14>>1]=h;i=ic(f),j=1,t[i+4|0]=j;jb=a+16|0;Jg(g,v[d+12>>2],b,v[d>>2]);a=be(d);qk(d);h=1}Ig(e+8|0,v[ec(d,a)>>2],h);jb=d+16|0;a=qo(v[e+8>>2]);jb=e+16|0;return a+2|0}function KN(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=jb-16|0;jb=c;a:{if(w[b+791|0]!=27){a=t[b+831|0];break a}d=c+8|0;f=a+1074312|0;Cb(d,f,21);e=a;a=w[b+821|0];a=oy(e,w[b+828|0],Bb(v[v[c+8>>2]>>2],v[c+12>>2])?a:a+16>>>2|0);Cb(d,f,45);b:{if(!(!Bb(v[v[c+8>>2]>>2],v[c+12>>2])|w[b+828|0]!=3)){d=w[b+821|0];c:{if(!(!d|d>>>0>=w[b+829|0])){a=w[b+832|0];e=d+1|0;break c}t[b+832|0]=a;e=1}t[b+821|0]=e;a=a<<24>>24;break b}t[b+821|0]=w[b+821|0]+w[b+829|0]}Cb(c+8|0,f,47);if(!Bb(v[v[c+8>>2]>>2],v[c+12>>2])){break a}t[b+831|0]=a}if(a){g=b,h=Xb(v[b+684>>2]+((B(w[b+830|0],a)+2|0)/8|0)|0,0,256),v[g+684>>2]=h}jb=c+16|0}function pY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;f=c;c=jb-16|0;jb=c;v[23588]=0;Y(952,a|0);e=v[23588];v[23588]=0;a:{b:{c:{d:{if((e|0)==1){break d}v[23588]=0;Y(953,b|0);e=v[23588];v[23588]=0;if((e|0)==1){break d}e=v[a+24>>2];b=qc(c+8|0,b);v[23588]=0;g=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=g;lF(973,e,c,f,d);d=v[23588];v[23588]=0;b=1;if((d|0)!=1){break c}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,8602,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break b}$();b=0}jb=c+16|0;break a}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}return b|0}function oR(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=jb-16|0;jb=d;v[a>>2]=0;v[a+4>>2]=0;nk(a+8|0,0);e=v[b+4>>2];if(e){Zq(a,e);ul(d+8|0,v[b>>2]);Cm(d,v[b>>2],v[b+4>>2]);c=jb-32|0;jb=c;f=v[a+4>>2];e=v[d+8>>2];h=v[d+12>>2];b=v[d>>2];k=v[d+4>>2];g=f+mR(e,h,b,k)|0;v[a+4>>2]=g;a:{b:{if(!f){i=g-1|0;break b}i=g-1|0;if((i^f-1)>>>0>31){break b}v[c+24>>2]=e;v[c+28>>2]=h;j=v[a>>2];break a}j=v[a>>2];v[j+((g>>>0<33?0:i>>>5|0)<<2)>>2]=0;v[c+24>>2]=e;v[c+28>>2]=h}Lo(c+16|0,j,f);e=v[c+28>>2];v[c>>2]=v[c+24>>2];v[c+4>>2]=e;nR(c+8|0,c,b,k,v[c+16>>2],v[c+20>>2]);jb=c+32|0}jb=d+16|0;return a|0}function aY(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;a:{g=jb+-64|0;jb=g;ln(g+16|0,c);v[23588]=0;c=g+28|0;R(113,c|0,d|0);d=v[23588];v[23588]=0;b:{c:{d:{if((d|0)==1){break d}v[23588]=0;c=g+40|0;R(113,c|0,e|0);d=v[23588];v[23588]=0;if((d|0)==1){break d}v[23588]=0;c=g+52|0;R(113,c|0,f|0);d=v[23588];v[23588]=0;if((d|0)==1){break d}Vv(g+8|0,g+16|0);v[23588]=0;X(114,a|0,b|0,v[g+8>>2],v[g+12>>2]);a=v[23588];v[23588]=0;if((a|0)==1){break c}gE(g+16|0);jb=g- -64|0;break a}a=P()|0;O()|0;while(1){c=zb(c-12|0);if((c|0)!=(g+16|0)){continue}break}break b}a=P()|0;O()|0;gE(g+16|0)}T(a|0);L()}}function ST(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=jb-16|0;jb=e;i=e,j=zj(b),v[i>>2]=j;f=v[b>>2];d=jb-16|0;jb=d;g=a;c=Sd(a);a:{if(c){b=ic(g);while(1){a=c;c=v[a+16>>2];if(OT(f,c)){b=a;c=v[a>>2];if(c){continue}break a}if(!OT(c,f)){break a}b=a+4|0;c=v[a+4>>2];if(c){continue}break}break a}a=ic(g);b=a}v[d+12>>2]=a;a=v[b>>2];if(!a){a=jb-16|0;jb=a;c=ic(g);f=lh(d,sc(24),mh(a+8|0,c));c=v[f>>2];h=v[v[e>>2]>>2];v[c+20>>2]=0;v[c+16>>2]=h;i=ic(f),j=1,t[i+4|0]=j;jb=a+16|0;Jg(g,v[d+12>>2],b,v[d>>2]);a=be(d);qk(d);h=1}Ig(e+8|0,v[ec(d,a)>>2],h);jb=d+16|0;a=vd(v[e+8>>2]);jb=e+16|0;return a+4|0}function Gk(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=jb-16|0;jb=e;f=a+36|0;c=v[a+32>>2];a:{b:{while(1){if((b|0)<=(c|0)){break b}c:{d=v[a+20>>2];if(d>>>0>=y[a+24>>2]){sn(e,f,LD(f));td(e+8|0,a,v[e>>2],v[e+4>>2]);c=v[e+12>>2];v[a+24>>2]=c;v[a+20>>2]=0;if(!c){break c}d=0;c=v[a+32>>2]}v[a+20>>2]=d+1;g=w[(a+d|0)+36|0];d=c+8|0;v[a+32>>2]=d;v[a+28>>2]=v[a+28>>2]|g<<c;c=d;continue}break}a=ba(8)|0;v[23588]=0;b=S(167,a|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break a}b=P()|0;O()|0;ca(a|0);T(b|0);L()}v[a+32>>2]=c-b;d=a;a=v[a+28>>2];v[d+28>>2]=a>>>b;jb=e+16|0;return a&(-1<<b^-1)}ha(b|0,30480,168);L()}function e_(a){a=a|0;if(w[468432]){return v[117107]}if(!w[469536]){a=469248;while(1){a=Lb(a)+12|0;if((a|0)!=469536){continue}break}t[469536]=1}qd(469248,89240);qd(469260,89272);qd(469272,89308);qd(469284,89332);qd(469296,89356);qd(469308,89372);qd(469320,89392);qd(469332,89412);qd(469344,89440);qd(469356,89480);qd(469368,89512);qd(469380,89548);qd(469392,89584);qd(469404,89600);qd(469416,89616);qd(469428,89632);qd(469440,89356);qd(469452,89648);qd(469464,89664);qd(469476,89680);qd(469488,89696);qd(469500,89712);qd(469512,89728);qd(469524,89744);t[468432]=1;v[117107]=469248;return 469248}function Lda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=jb-16|0;jb=b;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){e=v[b+8>>2];m=e>>>18|0;n=((((v[b+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+j|0;e=0;while(1){if((e|0)!=2){f=(e<<1)+n|0;g=u[f>>1];v[(e<<2)+b>>2]=g+((B(u[f+4>>1]-g|0,m)|0)/16384|0);e=e+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[b>>2],i);v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],h);Qb(b+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;jb=b+16|0}function E9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[Fb(a)>>2]){c=jb-16|0;jb=c;a=Iz(c,a);Tx(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+4;kc(a);jb=c+16|0;return}e=jb-32|0;jb=e;c=Fb(a);c=Uf(e+8|0,pg(a,uc(v[a>>2],v[a+4>>2])+1|0),uc(v[a>>2],v[a+4>>2]),c);Tx(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+4;f=v[a>>2];d=v[a+4>>2];b=c+4|0;while(1){if((d|0)!=(f|0)){d=d-4|0;Tx(v[b>>2]-4|0,d);v[b>>2]=v[b>>2]-4;continue}break}pc(a,b);pc(a+4|0,c+8|0);pc(Fb(a),Bc(c));v[c>>2]=v[c+4>>2];a=v[c+4>>2];while(1){b=v[c+8>>2];if((b|0)!=(a|0)){b=b-4|0;v[c+8>>2]=b;rg(b);continue}break}a=v[c>>2];if(a){Kz(c);Mb(a)}jb=e+32|0}function qY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;v[23588]=0;Y(952,a|0);c=v[23588];v[23588]=0;a:{b:{c:{d:{if((c|0)==1){break d}v[23588]=0;Y(953,b|0);c=v[23588];v[23588]=0;if((c|0)==1){break d}c=v[a+24>>2];e=qc(d+8|0,b);v[23588]=0;b=v[e+4>>2];v[d>>2]=v[e>>2];v[d+4>>2]=b;b=mF(c,d,1);e=v[23588];v[23588]=0;c=mb;if((e|0)!=1){break c}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,8633,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break b}$();b=0;c=0}jb=d+16|0;a=c;break a}b=P()|0;O()|0;v[23588]=0;Z(18);a=v[23588];v[23588]=0;if((a|0)!=1){T(b|0);L()}V(0)|0;O()|0;Ub();L()}sa(a|0);return b|0}function Wba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=jb+-64|0;jb=c;f=NO(a,1<<b-1);v[f+12>>2]=b;b=1<<b;h=-6.283185307179586/+(b>>>0);a=1;g=b>>>2|0;b=g;while(1){if(b){e=v[10465];d=c+32|0;v[d+8>>2]=v[10464];v[d+12>>2]=e;e=v[10463];v[d>>2]=v[10462];v[d+4>>2]=e;nz(d,h*+(b>>>0));IO(c+48|0,A[c+32>>3],A[c+40>>3]);d=Jd(v[f>>2],a);e=v[c+60>>2];v[d+8>>2]=v[c+56>>2];v[d+12>>2]=e;e=v[c+52>>2];v[d>>2]=v[c+48>>2];v[d+4>>2]=e;b=b>>>1|0;a=a<<1;continue}break}a=nl(c+16|0,1,0);b=v[a+12>>2];v[c+8>>2]=v[a+8>>2];v[c+12>>2]=b;b=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=b;dy(f,0,g,c);jb=c- -64|0;return f|0}function Jg(a,b,c,d){var e=0,f=0;v[d+8>>2]=b;v[d>>2]=0;v[d+4>>2]=0;v[c>>2]=d;b=v[v[a>>2]>>2];if(b){v[a>>2]=b;d=v[c>>2]}f=v[ic(a)>>2];t[d+12|0]=(f|0)==(d|0);while(1){a:{if((d|0)==(f|0)){break a}c=v[d+8>>2];if(w[c+12|0]){break a}b:{if(Bh(c)){b=v[c+8>>2];e=v[b+4>>2];if(!(!e|w[e+12|0])){break b}if(!Bh(d)){rq(c);c=v[c+8>>2]}t[c+12|0]=1;b=v[c+8>>2];t[b+12|0]=0;qq(b);break a}b=v[c+8>>2];e=v[b>>2];if(!(!e|w[e+12|0])){break b}if(Bh(d)){qq(c);c=v[c+8>>2]}t[c+12|0]=1;b=v[c+8>>2];t[b+12|0]=0;rq(b);break a}t[c+12|0]=1;d=b;t[d+12|0]=(d|0)==(f|0);t[e+12|0]=1;continue}break}a=Fb(a);v[a>>2]=v[a>>2]+1}function Gm(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0;i=1;j=d&2147483647;l=j;k=(j|0)==2147418112;a:{if(k&!c?a|b:k&(c|0)!=0|j>>>0>2147418112){break a}j=h&2147483647;k=(j|0)==2147418112;if(k&!g?e|f:k&(g|0)!=0|j>>>0>2147418112){break a}if(!(a|e|(c|g)|(b|f|(j|l)))){return 0}i=d&h;if((i|0)>0|(i|0)>=0){i=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0<e>>>0|b>>>0<f>>>0:c>>>0<g>>>0&(d|0)<=(h|0)|(d|0)<(h|0)){break a}return(a^e|c^g|(b^f|d^h))!=0}i=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0>e>>>0|b>>>0>f>>>0:c>>>0>g>>>0&(d|0)>=(h|0)|(d|0)>(h|0)){break a}i=(a^e|c^g|(b^f|d^h))!=0}return i}function t6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;v[23588]=0;Y(952,a|0);e=v[23588];v[23588]=0;a:{b:{c:{if((e|0)==1){break c}v[23588]=0;Y(953,b|0);e=v[23588];v[23588]=0;if((e|0)==1){break c}e=v[a+24>>2];b=qc(d+8|0,b);v[23588]=0;f=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=f;X(970,e|0,d|0,(c|0)!=0|0,1);c=v[23588];v[23588]=0;b=1;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,9955,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();b=0}jb=d+16|0;return b|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function kI(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;if(_e(a)){dc(a,31);return 0}g=a,h=_e(a),t[g+1375|0]=h;d=fj(a);b=fj(a);fj(a);g=a,h=fj(a),v[g+1112>>2]=h;fj(a);c=_e(a);v[a+1116>>2]=c;if(!hx(a,a+1120|0,c)){dc(a,10);return 0}v[a+1404>>2]=-2;a:{if((b&d)==-1){break a}b=v[a+1116>>2];while(1){if((b|0)<=0){break a}b=b-1|0;if(w[(b+a|0)+1120|0]==255){continue}break}v[a+1408>>2]=d;v[a+1404>>2]=b}if(w[a+1377|0]){b=0;e=v[a+1116>>2];f=(e|0)>0?e:0;c=0;while(1){if((b|0)!=(f|0)){c=w[(a+b|0)+1120|0]+c|0;b=b+1|0;continue}break}v[a- -64>>2]=d;v[a+60>>2]=(v[a+56>>2]+(c+e|0)|0)+27}v[a+1380>>2]=0;return 1}function fm(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=jb-32|0;jb=e;t[a|0]=0;a:{d=v[v[b>>2]-12>>2]+b|0;b:{if(Yg(d)){d=v[d+72>>2];if(d){$q(d)}c:{if(c){break c}c=v[v[b>>2]-12>>2]+b|0;if(!(v[c+4>>2]&4096)){break c}d=e+24|0;fd(d,c);v[23588]=0;f=S(19,d|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break a}$b(e+24|0);c=Rm(e+16|0,b);d=Gc(e+8|0);while(1){d:{if(!op(c,d)){break d}g=Yk(v[c>>2]);if(!uh(v[f+8>>2],1,g)){break d}em(c);continue}break}if(!cj(c,d)){break c}Ki(v[v[b>>2]-12>>2]+b|0,6)}h=a,i=Yg(v[v[b>>2]-12>>2]+b|0),t[h|0]=i;break b}Ki(d,4)}jb=e+32|0;return a}a=P()|0;O()|0;$b(e+24|0);T(a|0);L()}function vw(a,b,c,d,e){var f=0,g=0;f=jb-16|0;jb=f;g=f+8|0;fd(g,b);v[23588]=0;b=S(1136,g|0)|0;g=v[23588];v[23588]=0;a:{if((g|0)==1){break a}v[23588]=0;X(1148,b|0,82976,83008,c|0);b=v[23588];v[23588]=0;if((b|0)==1){break a}v[23588]=0;b=S(1137,f+8|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break a}v[23588]=0;c=S(1149,b|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break a}v[d>>2]=c;v[23588]=0;c=S(1146,b|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break a}v[e>>2]=c;v[23588]=0;R(1147,a|0,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$b(f+8|0);jb=f+16|0;return}a=P()|0;O()|0;$b(f+8|0);T(a|0);L()}function Mda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=jb-16|0;jb=b;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){e=v[b+8>>2];m=e>>>10&4194048;n=(((v[b+12>>2]&2147483647)<<1|e>>>31)&-2)+j|0;e=0;while(1){if((e|0)!=2){f=e+n|0;g=t[f|0];v[(e<<2)+b>>2]=((B(t[f+2|0]-g|0,m)|0)/16384|0)+(g<<8);e=e+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[b>>2],i);v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],h);Qb(b+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;jb=b+16|0}function H$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=jb-32|0;jb=f;v[f+24>>2]=b;a:{if(!(v[c+4>>2]&1)){c=nb[v[v[a>>2]+24>>2]](a,b,c,d,e)|0;break a}a=f+8|0;fd(a,c);v[23588]=0;a=S(1137,a|0)|0;b=v[23588];v[23588]=0;b:{if((b|0)!=1){$b(f+8|0);c:{if(e){Oh(f+8|0,a);break c}Nh(f+8|0,a)}g=f,h=he(f+8|0),v[g>>2]=h;while(1){a=Tk(f+8|0);b=v[f>>2];if(!Ob(b,a)){c=v[f+24>>2];Fc(f+8|0);break a}a=v[b>>2];v[23588]=0;Q(1152,f+24|0,a|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){Ke(f);continue}break}c=P()|0;O()|0;Fc(f+8|0);break b}c=P()|0;O()|0;$b(f+8|0)}T(c|0);L()}jb=f+32|0;return c|0}function Eha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=jb-48|0;jb=e;d=v[a+8>>2];c=v[a>>2];v[23588]=0;d=W(156,c|0,d|0,1)|0;c=v[23588];v[23588]=0;a:{if((c|0)==1){break a}b:{if(!d){break b}v[23588]=0;Y(502,b|0);d=v[23588];v[23588]=0;if((d|0)==1){break a}v[23588]=0;d=S(206,a|0)|0;c=v[23588];v[23588]=0;c:{if((c|0)!=1){while(1){if(!(d&255)){break b}v[23588]=0;c=Q(503,a|0,e+8|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break c}d:{if(!c){break d}c=w[e+8|0];if(c>>>0>63){break d}tc(TS(v[b>>2],c),e+8|0,33)}d=d-1|0;continue}}break a}break a}Ab(a);jb=e+48|0;return}b=P()|0;O()|0;Ab(a);T(b|0);L()}function zw(a,b,c,d,e){var f=0,g=0;f=jb-16|0;jb=f;g=f+8|0;fd(g,b);v[23588]=0;b=S(19,g|0)|0;g=v[23588];v[23588]=0;a:{if((g|0)==1){break a}v[23588]=0;X(1134,b|0,82976,83008,c|0);b=v[23588];v[23588]=0;if((b|0)==1){break a}v[23588]=0;b=S(1119,f+8|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break a}v[23588]=0;c=S(1135,b|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break a}t[d|0]=c;v[23588]=0;c=S(1132,b|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break a}t[e|0]=c;v[23588]=0;R(1133,a|0,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$b(f+8|0);jb=f+16|0;return}a=P()|0;O()|0;$b(f+8|0);T(a|0);L()}function s6(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;e=jb-16|0;jb=e;v[23588]=0;Y(952,a|0);d=v[23588];v[23588]=0;a:{b:{c:{if((d|0)==1){break c}v[23588]=0;Y(953,b|0);d=v[23588];v[23588]=0;if((d|0)==1){break c}d=v[a+24>>2];b=qc(e+8|0,b);v[23588]=0;f=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=f;_a(972,d|0,e|0,+c,1);d=v[23588];v[23588]=0;b=1;if((d|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,5929,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();b=0}jb=e+16|0;return b|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function Qg(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=v[a>>2];c=uc(d,v[a+4>>2]);if(c>>>0<b>>>0){e=jb-32|0;jb=e;b=b-c|0;c=v[Fb(a)>>2];d=v[a+4>>2];a:{if(b>>>0<=c-d>>2>>>0){c=jb-16|0;jb=c;b=Ah(c,a,b);a=v[b+4>>2];d=v[b+8>>2];while(1){if((a|0)==(d|0)){kc(b);jb=c+16|0}else{qv(a);a=a+4|0;v[b+4>>2]=a;continue}break}break a}c=Fb(a);c=Uf(e+8|0,pg(a,uc(v[a>>2],d)+b|0),uc(v[a>>2],v[a+4>>2]),c);f=jb-16|0;jb=f;b=Vm(f,c+8|0,b);d=v[b>>2];while(1){if(v[b+4>>2]!=(d|0)){qv(d);d=v[b>>2]+4|0;v[b>>2]=d;continue}break}Td(b);jb=f+16|0;Dd(a,c);Tf(c)}jb=e+32|0;return}if(b>>>0<c>>>0){Nd(a,d+(b<<2)|0)}}function pD(a){var b=0,c=0,d=0;b=jb-16|0;jb=b;v[b+4>>2]=B(w[a+12|0]|w[a+13|0]<<8|(w[a+14|0]<<16|w[a+15|0]<<24),5)+(w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24));v[b+8>>2]=(w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24))+((w[a+20|0]|w[a+21|0]<<8|(w[a+22|0]<<16|w[a+23|0]<<24))<<3);v[b+12>>2]=(w[a+32|0]|w[a+33|0]<<8|(w[a+34|0]<<16|w[a+35|0]<<24))+((w[a+28|0]|w[a+29|0]<<8|(w[a+30|0]<<16|w[a+31|0]<<24))<<2);a=b+4|0;d=Db(a,3);a:{if((a|0)==(d|0)){break a}c=a;while(1){c=c+4|0;if((d|0)==(c|0)){break a}a=po(v[a>>2],v[c>>2])?c:a;continue}}jb=b+16|0;return v[a>>2]-36|0}function SZ(a){a=a|0;if(w[468424]){return v[117105]}if(!w[469232]){a=468944;while(1){a=Lb(a)+12|0;if((a|0)!=469232){continue}break}t[469232]=1}pd(468944,5037);pd(468956,5028);pd(468968,10796);pd(468980,10540);pd(468992,5264);pd(469004,11572);pd(469016,5121);pd(469028,5612);pd(469040,8846);pd(469052,8829);pd(469064,8837);pd(469076,8856);pd(469088,10023);pd(469100,13166);pd(469112,8919);pd(469124,7674);pd(469136,5264);pd(469148,9712);pd(469160,10428);pd(469172,10808);pd(469184,9209);pd(469196,6466);pd(469208,5495);pd(469220,13084);t[468424]=1;v[117105]=468944;return 468944}function Xt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;KR(c+8|0,b);d=v[c+12>>2];mc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){Zb(a,v[c+12>>2])}jb=c+16|0;if((d|0)!=(e|0)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+24|0]=0;t[b+25|0]=0;t[b+26|0]=0;t[b+27|0]=0;t[b+28|0]=0;t[b+29|0]=0;t[b+30|0]=0;t[b+31|0]=0;t[b+16|0]=0;t[b+17|0]=0;t[b+18|0]=0;t[b+19|0]=0;t[b+20|0]=0;t[b+21|0]=0;t[b+22|0]=0;t[b+23|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0}}function B0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=jb-32|0;jb=c;a:{b:{c:{if(oc(b,-1)){break c}i=c,j=pp(b),t[i+23|0]=j;if(w[a+44|0]){d=-1;if((vk(c+23|0,1,1,v[a+32>>2])|0)==1){break c}break a}f=c+24|0;v[c+16>>2]=f;h=c+32|0;d=c+23|0;while(1){e=$r(v[a+36>>2],v[a+40>>2],d,f,c+12|0,c+24|0,h,c+16|0);if(v[c+12>>2]==(d|0)){break b}if((e|0)==3){if((vk(d,1,1,v[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}g=c+24|0;d=v[c+16>>2]-g|0;if((vk(g,1,d,v[a+32>>2])|0)!=(d|0)){break b}d=v[c+12>>2];if((e|0)==1){continue}break}}d=Ow(b);break a}d=-1}jb=c+32|0;return d|0}function hN(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;a:{if(v[a+480180>>2]!=1){break a}c=w[b+846|0];if(!c){break a}d=v[b+104>>2];if(!d){break a}if(!Zd(v[d>>2],v[d+20>>2])){break a}f=x[d+34>>1];if(!(f&10)){break a}c=w[b+847|0]+w[(c&15)+33232|0]|0;t[b+847|0]=c;if(c<<24>>24>=0){break a}t[b+847|0]=0;h=f&2;c=v[(h?4:12)+d>>2];g=b;b=v[b+760>>2]+1|0;b=b>>>0<v[(h?8:16)+d>>2]-c>>>0?b:0;v[g+760>>2]=b;g=v[d+20>>2];c=b+c|0;b=Ek(f);fc(e+8|0,g+B(c,b)|0,b);b=v[e+8>>2];f=Kb(b,v[e+12>>2]);while(1){if((b|0)==(f|0)){tj(d,a)}else{t[b|0]=w[b|0]^-1;b=b+1|0;continue}break}}jb=e+16|0}
function dL(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a=si(a,b,c,d);t[a+4260|0]=e;v[a>>2]=46284;c=Sb(a+4264|0);d=Sb(a+4276|0);v[a+4328>>2]=0;b=a+4320|0;v[b>>2]=0;v[b+4>>2]=0;v[a+4312>>2]=0;v[a+4316>>2]=0;b=a+4208|0;f=Db(b,0),g=1056964608,v[f>>2]=g;f=Db(b,1),g=1036831949,v[f>>2]=g;f=Db(b,2),g=1038174126,v[f>>2]=g;f=Db(b,3),g=1065353216,v[f>>2]=g;f=Db(b,4),g=1061158912,v[f>>2]=g;f=Db(b,5),g=1059082943,v[f>>2]=g;f=Db(b,6),g=1061997773,v[f>>2]=g;v[23588]=0;R(897,a+44|0,2);b=v[23588];v[23588]=0;if((b|0)!=1){return a|0}b=P()|0;O()|0;vc(d);vc(c);If(a);T(b|0);L()}function Kda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=jb-16|0;jb=b;f=v[a+40>>2];g=v[a+36>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+32>>2];k=v[a+28>>2];l=v[a+8>>2];m=v[a+12>>2];while(1){if(d){h=v[b+12>>2]+i|0;e=t[h|0];e=((B(t[h+1|0]-e|0,v[b+8>>2]>>>10&4194048)|0)/16384|0)+(e<<8)|0;g=g+k|0;v[c>>2]=v[c>>2]+B(e,g>>12);f=f+j|0;v[c+4>>2]=v[c+4>>2]+B(e,f>>12);Qb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=f;v[a+20>>2]=g>>12;v[a+36>>2]=g;v[a+24>>2]=f>>12;jb=b+16|0}function $da(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=jb-16|0;jb=b;g=v[a+16>>2];f=Sf(1,2);e=mb;h=e;Qb(a,f,e);i=v[a+24>>2];j=v[a+20>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){d=d-1|0;m=((((v[b+12>>2]&2147483647)<<1|v[b+8>>2]>>>31)&2147483646)<<1)+g|0;e=0;while(1){if((e|0)!=2){v[(e<<2)+b>>2]=u[(e<<1)+m>>1];e=e+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[b>>2],j);v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],i);Qb(b+8|0,k,l);c=c+8|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;lg(a,f,h);jb=b+16|0}function x0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-32|0;jb=c;d=w[a+52|0];a:{if(oc(b,-1)){if(d){break a}b=v[a+48>>2];e=a,f=oc(b,-1)^1,t[e+52|0]=f;break a}b:{if(!d){break b}e=c,f=pp(v[a+48>>2]),t[e+19|0]=f;c:{d:{e:{d=c+20|0;switch($r(v[a+36>>2],v[a+40>>2],c+19|0,d,c+12|0,c+24|0,c+32|0,d)-1|0){case 0:case 1:break c;case 2:break e;default:break d}}d=v[a+48>>2];v[c+20>>2]=c+25;t[c+24|0]=d}while(1){d=v[c+20>>2];if(d>>>0<=c+24>>>0){break b}d=d-1|0;v[c+20>>2]=d;if((Zr(t[d|0],v[a+32>>2])|0)!=-1){continue}break}}b=-1;break a}t[a+52|0]=1;v[a+48>>2]=b}jb=c+32|0;return b|0}function A6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;v[23588]=0;Y(952,a|0);d=v[23588];v[23588]=0;a:{b:{c:{if((d|0)==1){break c}v[23588]=0;Y(953,b|0);d=v[23588];v[23588]=0;if((d|0)==1){break c}d=v[a+24>>2];b=qc(c+8|0,b);v[23588]=0;f=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=f;e=+ra(963,d|0,c|0,1);b=v[23588];v[23588]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,5966,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();e=0}jb=c+16|0;return+e}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function C6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;v[23588]=0;Y(952,a|0);c=v[23588];v[23588]=0;a:{b:{c:{if((c|0)==1){break c}v[23588]=0;Y(953,b|0);c=v[23588];v[23588]=0;if((c|0)==1){break c}c=v[a+24>>2];b=qc(d+8|0,b);v[23588]=0;e=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=e;b=W(959,c|0,d|0,1)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,9986,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();b=0}jb=d+16|0;return b|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function U6(a){a=a|0;var b=0;b=7976;a:{b:{c:{switch(a-277|0){default:if((a|0)==357){break b}d:{if((a|0)!=257){if((a|0)==267){break d}if(a){break a}b=21619;break a}b=8009;break a}b=17519;break a;case 0:b=5014;break a;case 9:b=8032;break a;case 10:b=8046;break a;case 11:b=5391;break a;case 12:b=5411;break a;case 19:b=8058;break a;case 20:b=7990;break a;case 21:b=12750;break a;case 22:b=12073;break a;case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 13:case 14:case 15:case 16:case 17:case 18:break a;case 23:break c}}b=6022;break a}b=7943}return fg(b)|0}function Jda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=jb-16|0;jb=b;f=v[a+40>>2];g=v[a+36>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+32>>2];k=v[a+28>>2];l=v[a+8>>2];m=v[a+12>>2];while(1){if(d){h=(v[b+12>>2]<<1)+i|0;e=u[h>>1];e=e+((B(u[h+2>>1]-e|0,v[b+8>>2]>>>18|0)|0)/16384|0)|0;g=g+k|0;v[c>>2]=v[c>>2]+B(e,g>>12);f=f+j|0;v[c+4>>2]=v[c+4>>2]+B(e,f>>12);Qb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=f;v[a+20>>2]=g>>12;v[a+36>>2]=g;v[a+24>>2]=f>>12;jb=b+16|0}function Rfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;f=jb-32|0;jb=f;a:{c=v[a+12>>2];b:{if((c|0)==(b|0)){break b}d=b>>>0>c>>>0;c=B(Pg(v[v[a+48>>2]+12>>2]),d?b-c|0:c-b|0);e=Eb(v[a+4>>2]);c:{if(d){e=ec(f+24|0,e);d=f+16|0;Ej(d);e=v[e>>2];v[23588]=0;X(636,a|0,e|0,c|0,d|0);c=v[23588];v[23588]=0;if((c|0)!=1){break c}a=V(92948)|0;if((O()|0)!=(da(92948)|0)){break a}_(a|0)|0;$();break b}c=ec(f+8|0,hB(e,c));e=v[ec(f,Eb(v[a+4>>2]))>>2];d=v[c>>2];c=v[a>>2];c=B(Ys(d,Eb(c)),6)+c|0;if(Ob(d,e)){Nd(a,XL(c+B(Ys(e,d),6)|0,v[a+4>>2],c))}Eb(c)}v[a+12>>2]=b}jb=f+32|0;return}T(a|0);L()}function Oba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=jb-16|0;jb=d;v[d+12>>2]=b;if(b>>>0<1073741808){a:{if(tn(a)>>>0>=b>>>0){break a}h=d,i=Gb(a),v[h+8>>2]=i;e=bm(v[Yc(d+12|0,d+8|0)>>2]);if((e|0)==(tn(a)|0)){break a}f=1;c=tn(a);g=Gb(a);b:{c:{if((e|0)==1){b=a;c=v[a>>2];break c}b=e+1|0;d:{if(c>>>0<e>>>0){b=Bi(b);break d}v[23588]=0;b=S(1226,b|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break d}a=V(0)|0;O()|0;_(a|0)|0;$();break b}f=ef(a);c=zc(a)}li(b,c,Gb(a)+1|0);if(f){Mb(c)}if((e|0)!=1){bf(a,e+1|0);Fd(a,g);ud(a,b);break b}ce(a,g)}}jb=d+16|0;return}hf();L()}function Ao(a,b,c,d,e,f){var g=0;g=jb-16|0;jb=g;t[g+14|0]=d;t[g+15|0]=c;t[g+13|0]=e;t[g+12|0]=f;d=0;a:{b:{while(1){c=d&255;if(c>>>0>3){break b}e=w[g+15|0];Oq(g+8|0,e,w[g+14|0],c>>>0>1);if(!(w[g+8|0]|!e)){d=d+1|0;Ii(g+15|0,g+13|0);Ii(g+14|0,g+12|0);continue}break}c=x[g+8>>1];t[b+2|0]=c;t[b+4|0]=c>>>8;c=w[g+13|0];t[b+5|0]=w[g+12|0];t[b+3|0]=c;t[g+7|0]=0;de(a,0,g+7|0);break a}d=w[g+15|0];e=Ji(d);c=w[g+13|0];if(e>>>0>Ji(c)>>>0){Ii(g+15|0,g+13|0);Ii(g+14|0,g+12|0);d=w[g+15|0];c=w[g+13|0]}t[b+4|0]=0;t[b+2|0]=0;t[b+5|0]=w[g+12|0];t[b+3|0]=c;de(a,d,g+14|0)}jb=g+16|0}function xt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=jb-16|0;jb=c;v[c+12>>2]=b;if(b>>>0<4294967280){a:{if(ad(a)>>>0>=b>>>0){break a}h=c,i=Gb(a),v[h+8>>2]=i;d=Mg(v[Yc(c+12|0,c+8|0)>>2]);if((d|0)==(ad(a)|0)){break a}f=Gb(a);b:{c:{if((d|0)==10){g=1;b=a;e=v[a>>2];break c}b=d+1|0;d:{if(ad(a)>>>0<d>>>0){b=sc(b);break d}v[23588]=0;b=S(1225,b|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){break d}a=V(0)|0;O()|0;_(a|0)|0;$();break b}g=ef(a);e=zc(a)}b=ve(b,e,Gb(a)+1|0);if(g){Mb(e)}if((d|0)!=10){bf(a,d+1|0);Fd(a,f);ud(a,b);break b}ce(a,f)}}jb=c+16|0;return}hf();L()}function r8(a){a=a|0;var b=0,c=0;c=jb-16|0;jb=c;b=v[v[a+16>>2]+24620>>2];b=Hc(Mka(Lka(b,b>>31,3840,0),mb,1e3,0),mb);v[a+4316>>2]=b;v[23588]=0;v[c+12>>2]=0;U(903,a+4264|0,b|0,c+12|0);b=v[23588];v[23588]=0;a:{b:{c:{if((b|0)!=1){d:{if(!w[a+4260|0]){break d}b=v[a+4316>>2];v[23588]=0;v[c+12>>2]=0;U(903,a+4276|0,b|0,c+12|0);b=v[23588];v[23588]=0;if((b|0)!=1){break d}b=V(92948)|0;break c}v[c+12>>2]=0;b=c+12|0;_K(a+4288|0,b);v[c+12>>2]=0;_K(a+4300|0,b);break b}b=V(92948)|0}if((O()|0)!=(da(92948)|0)){break a}_(b|0)|0;v[a+4316>>2]=0;$()}jb=c+16|0;return}T(b|0);L()}function Uk(a,b,c){var d=0,e=0;e=jb-16|0;jb=e;v[a+4>>2]=0;d=4;a:{b:{c:{if(!Pd(w[fm(e+8|0,a,1)|0])){break c}d=v[(v[v[a>>2]-12>>2]+a|0)+24>>2];v[23588]=0;b=W(106,d|0,b|0,c|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){v[a+4>>2]=b;d=(b|0)==(c|0)?0:6;break c}b=V(0)|0;O()|0;_(b|0)|0;d=1;dm(v[v[a>>2]-12>>2]+a|0,1);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[23588]=0;Z(105);a=v[23588];v[23588]=0;if((a|0)!=1){break a}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)==1){break b}T(a|0);L()}$()}Ki(v[v[a>>2]-12>>2]+a|0,d);jb=e+16|0;return a}V(0)|0;O()|0;Ub()}L()}function vP(a,b){var c=0,d=0;t[a+15|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+14|0]=5;u[a+12>>1]=0;v[a+8>>2]=128;v[a>>2]=256;v[a+4>>2]=64;v[a+28>>2]=0;t[a+27|0]=60;v[a+40>>2]=0;v[a+44>>2]=0;t[a+33|0]=2;t[a+34|0]=0;t[a+35|0]=0;t[a+36|0]=2;t[a+23|0]=0;t[a+24|0]=0;t[a+25|0]=255;t[a+26|0]=0;t[a+32|0]=0;Ez(a+48|0);Ez(a+68|0);Ez(a+88|0);zt(a+492|0);zt(a+524|0);Lj(a,0,0);Kj(a,0,0);v[a+40>>2]=0;v[a+44>>2]=0;du(a,b);b=a+108|0;d=dA(b);c=1;while(1){if((b|0)!=(d|0)){t[b|0]=c;c=c+1|0;b=b+1|0;continue}break}return a}function ur(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-16|0;jb=d;a=Lb(a);a:{b:{c:{switch(b|0){case 0:v[23588]=0;b=Q(1,d|0,15826)|0;c=v[23588];v[23588]=0;if((c|0)==1){break a}Ib(a,b);zb(b);break b;case 1:v[23588]=0;b=Q(1,d|0,15851)|0;c=v[23588];v[23588]=0;if((c|0)!=1){Ib(a,b);zb(b);break b}break a;case 2:v[23588]=0;b=Q(1,d|0,15799)|0;c=v[23588];v[23588]=0;if((c|0)!=1){Ib(a,b);zb(b);break b}break a;case 3:break c;default:break b}}v[23588]=0;b=Q(1,d|0,15773)|0;c=v[23588];v[23588]=0;if((c|0)==1){break a}Ib(a,b);zb(b)}jb=d+16|0;return}b=P()|0;O()|0;zb(a);T(b|0);L()}function I0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=jb-32|0;jb=c;a:{b:{c:{if(Cn(b)){break c}v[c+20>>2]=b;if(w[a+44|0]){d=-1;if((vk(c+20|0,4,1,v[a+32>>2])|0)==1){break c}break a}f=c+24|0;v[c+16>>2]=f;h=c+32|0;d=c+20|0;while(1){e=$r(v[a+36>>2],v[a+40>>2],d,f,c+12|0,c+24|0,h,c+16|0);if(v[c+12>>2]==(d|0)){break b}if((e|0)==3){if((vk(d,1,1,v[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}g=c+24|0;d=v[c+16>>2]-g|0;if((vk(g,1,d,v[a+32>>2])|0)!=(d|0)){break b}d=v[c+12>>2];if((e|0)==1){continue}break}}d=Cn(b)?0:b;break a}d=-1}jb=c+32|0;return d|0}function ms(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0;h=jb-240|0;jb=h;v[h+236>>2]=d;v[h+232>>2]=c;v[h>>2]=a;a:{b:{c:{d:{if((c|0)!=1){j=a;k=1;break d}j=a;k=1;if(d){break d}i=a;break c}while(1){i=j-v[(e<<2)+g>>2]|0;if((nb[b|0](i,a)|0)<=0){i=j;break c}e:{if(!((e|0)<2|f)){f=v[((e<<2)+g|0)-8>>2];l=j-4|0;if((nb[b|0](l,i)|0)>=0){break e}if((nb[b|0](l-f|0,i)|0)>=0){break e}}v[(k<<2)+h>>2]=i;c=XH(c,d);ns(h+232|0,c);k=k+1|0;e=c+e|0;f=0;j=i;d=v[h+236>>2];c=v[h+232>>2];if(d|(c|0)!=1){continue}break b}break}i=j;break b}if(f){break a}}WH(h,k);dx(i,b,e,g)}jb=h+240|0}function aea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=jb-16|0;jb=b;g=v[a+16>>2];f=Sf(1,2);e=mb;h=e;Qb(a,f,e);i=v[a+24>>2];j=v[a+20>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){d=d-1|0;m=(((v[b+12>>2]&2147483647)<<1|v[b+8>>2]>>>31)&-2)+g|0;e=0;while(1){if((e|0)!=2){v[(e<<2)+b>>2]=t[e+m|0]<<8;e=e+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[b>>2],j);v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],i);Qb(b+8|0,k,l);c=c+8|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;lg(a,f,h);jb=b+16|0}function _H(a,b){var c=0,d=0,e=0;if(!w[464260]){d=Fa()|0;t[464260]=1;t[464261]=d}a:{b:{c:{d:{switch(a|0){case 0:break b;case 1:case 4:break d;default:break c}}if(!w[464261]){break c}e=+Ea();break a}v[116064]=28;return-1}e=+Na()}c=e/1e3;e:{if(D(c)<0x8000000000000000){d=D(c)>=1?~~(c>0?F(H(c*2.3283064365386963e-10),4294967295):I((c-+(~~c>>>0>>>0))*2.3283064365386963e-10))>>>0:0;a=~~c>>>0;break e}d=-2147483648;a=0}v[b>>2]=a;c=(e-(+(Lka(a,d,1e3,0)>>>0)+ +(mb|0)*4294967296))*1e3*1e3;f:{if(D(c)<2147483648){a=~~c;break f}a=-2147483648}v[b+4>>2]=a;return 0}function HR(a){var b=0,c=0,d=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1196314451){break a}c=w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24);if(c>>>0<1108){break a}b=a+1104|0;if((c-1108|0)!=(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))|c>>>0>262144){break a}c=a+1094|0;if(w[c|0]|w[c+1|0]<<8){break a}b=a+1096|0;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))-5>>>0<4294967292){break a}if(!Wt(a+8|0)){break a}a=a+40|0;while(1){d=(a|0)==(c|0);if(d|w[a+32|0]>15|w[a+33|0]>64){break a}b=Wt(a);a=a+34|0;if(b){continue}break}}return d}function E0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-32|0;jb=c;d=w[a+52|0];a:{if(Cn(b)){if(d){break a}b=v[a+48>>2];e=a,f=Cn(b)^1,t[e+52|0]=f;break a}b:{if(!d){break b}v[c+16>>2]=v[a+48>>2];c:{d:{e:{d=c+20|0;switch($r(v[a+36>>2],v[a+40>>2],c+16|0,d,c+12|0,c+24|0,c+32|0,d)-1|0){case 0:case 1:break c;case 2:break e;default:break d}}d=v[a+48>>2];v[c+20>>2]=c+25;t[c+24|0]=d}while(1){d=v[c+20>>2];if(d>>>0<=c+24>>>0){break b}d=d-1|0;v[c+20>>2]=d;if((Zr(t[d|0],v[a+32>>2])|0)!=-1){continue}break}}b=-1;break a}t[a+52|0]=1;v[a+48>>2]=b}jb=c+32|0;return b|0}function QA(a,b){var c=0,d=0;a:{b:{c:{d:{e:{f:{g:{h:{d=w[a+3|0];switch(d|0){case 9:break d;case 10:break e;case 16:case 17:break g;case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:break h;default:break a}}if(!w[a|0]){break a}switch(d|0){case 9:break d;case 10:break e;case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:break f;case 16:case 17:break g;default:break c}}c=8;break c}c=w[a|0];if(!(c&7)){break c}}c=b+1>>>1|0;b=((d|0)==10)<<4;break b}c=16}c=B(c>>>3|0,b);b=((d|0)==10)<<4}c=b+B(nq(w[a+1|0]),c)|0}return c}function aba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=jb-208|0;jb=e;u[a+480212>>1]=0;v[a+480240>>2]=65536;v[a+480244>>2]=65536;TM(a+946304|0);f=a+906300|0;g=ek(f);d=e+48|0;Tb(d,0,160);d=VM(d);v[23588]=0;U(820,f|0,g|0,d|0);f=v[23588];v[23588]=0;a:{if((f|0)!=1){yy(d);d=je(e+24|0,b);v[23588]=0;f=v[d+12>>2];v[e+8>>2]=v[d+8>>2];v[e+12>>2]=f;v[e+16>>2]=v[d+16>>2];f=v[d+4>>2];v[e>>2]=v[d>>2];v[e+4>>2]=f;a=W(821,a|0,e|0,c|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){a=P()|0;O()|0;break a}Ab(b);jb=e+208|0;return a|0}a=P()|0;O()|0;yy(d)}Ab(b);T(a|0);L()}function Zda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=jb-16|0;jb=b;j=v[a+16>>2];h=Sf(1,2);e=mb;k=e;Qb(a,h,e);e=v[a+40>>2];f=v[a+36>>2];g=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=g;g=v[a+32>>2];l=v[a+28>>2];m=v[a+8>>2];n=v[a+12>>2];while(1){if(d){i=u[(v[b+12>>2]<<1)+j>>1];f=f+l|0;v[c>>2]=v[c>>2]+B(i,f>>12);e=e+g|0;v[c+4>>2]=v[c+4>>2]+B(e>>12,i);Qb(b+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=e;v[a+20>>2]=f>>12;v[a+36>>2]=f;v[a+24>>2]=e>>12;lg(a,h,k);jb=b+16|0}function lca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=jb-16|0;jb=g;h=x[c>>1];i=c;e=jb-16|0;jb=e;f=b;d=Sd(b);a:{if(d){c=ic(f);while(1){b=d;d=x[b+14>>1];if(Dk(h,d)){c=b;d=v[b>>2];if(d){continue}break a}if(!Dk(d,h)){break a}c=b+4|0;d=v[b+4>>2];if(d){continue}break}break a}b=ic(f);c=b}v[e+12>>2]=b;b=v[c>>2];if(!b){b=jb-16|0;jb=b;d=ic(f);d=lh(e,sc(16),mh(b+8|0,d));Mi(v[d>>2]+14|0,x[i>>1]);k=ic(d),l=1,t[k+4|0]=l;jb=b+16|0;Jg(f,v[e+12>>2],c,v[e>>2]);b=be(e);qk(e);j=1}c=g+8|0;Ig(c,v[ec(e,b)>>2],j);jb=e+16|0;tP(a,c);jb=g+16|0}function l5(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=jb-32|0;jb=c;a:{f=a+36|0;b=v[f>>2];d=v[a+40>>2];b:{if(Ob(b,d)){Gc(c+24|0);break b}b=c+8|0;In(b,a);v[23588]=0;b=S(1012,b|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break a}v[c+24>>2]=b;Wf(c+8|0);d=v[a+40>>2];b=v[a+36>>2]}b=(g=f,h=v[c+24>>2],i=Ob(b,d),i?g:h);a=v[a+8>>2];c:{if((a|0)==-1){g=c,h=Eb(v[b>>2]),v[g+8>>2]=h;a=Eb(v[b+4>>2]);while(1){b=v[c+8>>2];if(!Ob(b,a)){break c}e=e+A[b>>3];Ux(c+8|0);continue}}e=A[lf(v[b>>2],a)>>3]}al(c+24|0);jb=c+32|0;return+e}a=P()|0;O()|0;Wf(c+8|0);T(a|0);L()}function xja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=jb-16|0;jb=f;g=x[Il(v[a>>2],v[a+4>>2],b)>>1];a:{b:{if(!Gq(a,b)){break b}c=v[a+24>>2];d=Eb(v[c+484360>>2]);v[f+8>>2]=d;h=Eb(v[c+484364>>2]);while(1){if(!Ob(d,h)){break b}e=0;i=Dl(v[d>>2],v[d+4>>2]);c:{while(1){if((e|0)!=(i|0)){if(!(!((a|0)!=(d|0)|(b|0)!=(e|0))|x[cc(v[d>>2],e)>>1]!=(g|0))){c=OR(v[a+24>>2]+484344|0,g);if((c|0)!=65535){break c}}e=e+1|0;continue}break}d=v[Az(f+8|0)>>2];continue}break}j=Il(v[a>>2],v[a+4>>2],b),k=c,u[j>>1]=k;break a}c=g}jb=f+16|0;return c&65535}function dfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;v[a>>2]=0;v[a+4>>2]=0;Gc(a+8|0);if(b){c=jb-16|0;jb=c;v[c+12>>2]=477218588;v[c+8>>2]=2147483647;d=v[Jb(c+12|0,c+8|0)>>2];jb=c+16|0;if(b>>>0>d>>>0){bd();L()}b=B(b,9);c=sc(b);v[a>>2]=c;v[a+4>>2]=c;e=Fb(a),f=b+c|0,v[e>>2]=f;c=jb-16|0;jb=c;v[c>>2]=a;d=v[a+4>>2];v[c+4>>2]=d;v[c+8>>2]=b+d;b=v[c+4>>2];d=v[c+8>>2];while(1){if((b|0)==(d|0)){kc(c);jb=c+16|0}else{t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;b=b+9|0;v[c+4>>2]=b;continue}break}}return a|0}function MC(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=jb-16|0;jb=f;v[f+8>>2]=e;v[f+12>>2]=d;_f(a);xt(a,c);d=0;e=0;a:while(1){if(c>>>0>d>>>0){i=c-d|0;v[f+4>>2]=i;g=v[Jb(f+12|0,f+4|0)>>2];h=g+e|0;l=e>>>0>h>>>0?e:h;j=Iu(Hr(a,b+d|0,g),1,13);while(1)if((e|0)==(l|0)){v[f+4>>2]=i-g;e=h+1|0;d=v[Jb(f+8|0,f+4|0)>>2]+(d+g|0)|0;continue a}else{b:{c:{d:{k=t[Sc(j,e)|0];switch(k-10|0){case 1:case 2:break b;case 0:case 3:break c;default:break d}}if(k){break b}}m=Sc(j,e),n=32,t[m|0]=n}e=e+1|0;continue}}break}jb=f+16|0}function _da(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=jb-16|0;jb=b;j=v[a+16>>2];h=Sf(1,2);e=mb;k=e;Qb(a,h,e);e=v[a+40>>2];f=v[a+36>>2];g=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=g;g=v[a+32>>2];l=v[a+28>>2];m=v[a+8>>2];n=v[a+12>>2];while(1){if(d){i=t[v[b+12>>2]+j|0]<<8;f=f+l|0;v[c>>2]=v[c>>2]+B(i,f>>12);e=e+g|0;v[c+4>>2]=v[c+4>>2]+B(e>>12,i);Qb(b+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=e;v[a+20>>2]=f>>12;v[a+36>>2]=f;v[a+24>>2]=e>>12;lg(a,h,k);jb=b+16|0}function s5(a){a=a|0;var b=0,c=0;v[23588]=0;Y(952,a|0);b=v[23588];v[23588]=0;if((b|0)!=1){a=v[a+24>>2];b=v[a+24>>2];c=x[b+1074448>>1];a:{if(c>>>0>=sj(Vb(v[b+484360>>2],w[b+484376|0]))>>>0){a=x[v[a+24>>2]+1074446>>1];break a}a=v[a+24>>2];b=x[cc(v[Vb(v[a+484360>>2],w[a+484376|0])>>2],c)>>1];a=Qm(v[a+484344>>2],v[a+484348>>2],b)?b:-1}return a|0}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,9716,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function Pn(a,b,c,d){var e=0,f=0;e=jb-16|0;jb=e;a:{b:{c:{if(!d){break c}d=c>>31;d=(d^c)-d|0;if(d>>>0<224){break c}Cb(e+8|0,a+1074312|0,3);if(Bb(v[v[e+8>>2]>>2],v[e+12>>2])){break c}if(!(t[(B(b,872)+a|0)+1075843|0]&1)){break a}c=B((c>>31)+((c|0)>0)|0,d&15);c=d>>>0>239?c<<2:c;break b}if(t[(B(b,872)+a|0)+1075843|0]&1){Cb(e+8|0,a+1074312|0,3);if(!Bb(v[v[e+8>>2]>>2],v[e+12>>2])){break a}}c=c<<2}if(!c){break a}f=B(b,872)+a|0;d=v[f+1075648>>2];a=Op(a,v[f+1075080>>2],d);if(!a){break a}nb[v[v[a>>2]+84>>2]](a,c,(d?w[d+33|0]:13)<<24>>24,b)}jb=e+16|0}function GI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;a:{b:{c:{a=v[a+32>>2];e=Gs(a);d:{if(!e){if(Fs(a)>>>0<=b>>>0){break d}a=Gi(a,b+1&65535);u[a+34>>1]=x[a+34>>1]&64511|(c?1024:0);break b}if(b>>>0<e>>>0){break c}}a=ba(8)|0;v[23588]=0;b=Q(55,d|0,6003)|0;c=v[23588];v[23588]=0;e:{if((c|0)!=1){a=rc(a,b);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}c=P()|0;O()|0;yb(b);break e}c=P()|0;O()|0;ca(a|0)}T(c|0);L()}a=v[(a+(b<<2)|0)+900384>>2];if(!a){break b}t[a+15|0]=w[a+15|0]&253|(c?2:0)}jb=d+16|0;return}L()}function kx(a,b,c){var d=0,e=0,f=C(0),g=C(0),h=C(0),i=C(0),j=0,k=C(0),l=C(0),m=C(0);e=jb-32|0;jb=e;g=z[a+24>>2];f=z[a+12>>2];h=z[a+48>>2];i=z[a+36>>2];oI(C(-z[a>>2]),C(g+f),C(h+i),e+20|0);oI(z[a+60>>2],C(h-i),C(g-f),e+8|0);z[e+12>>2]=-z[e+12>>2];a=0;while(1){if((a|0)!=3){d=a<<2;j=d+c|0;g=z[j>>2];f=z[d+(e+20|0)>>2];h=z[d+71248>>2];i=z[d+71260>>2];k=z[d+(e+8|0)>>2];z[j>>2]=C(f*h)-C(i*k);j=b+d|0;l=z[(0-a<<2)+71256>>2];d=5-a<<2;m=z[d+71248>>2];f=C(C(f*i)+C(k*h));z[j>>2]=C(g*l)-C(m*f);z[b+d>>2]=C(g*m)+C(f*l);a=a+1|0;continue}break}jb=e+32|0}function co(a){var b=0,c=0,d=0,e=0,f=0,g=0;c=x[v[a+4>>2]+28>>1]>>>(!w[a+77|0]<<1)|0;d=x[a+24>>1];b=c+(d<<2)|0;v[a+40>>2]=((b&3)<<4)+27824;e=b>>>2|0;b=b>>>0<48;f=b?12-e|0:0;u[a+32>>1]=f;u[a+36>>1]=b?1:1<<e-12;u[a+34>>1]=-1<<f^-1;if((d|0)==15){u[a+36>>1]=4095}b=c+(x[a+26>>1]<<2)|0;v[a+52>>2]=((b&3)<<4)+27824;d=b>>>2|0;b=b>>>0<48;e=b?12-d|0:0;u[a+44>>1]=e;c=c+(x[a+30>>1]<<2)|0;v[a+64>>2]=((c&3)<<4)+27824;f=c>>>2|0;c=c>>>0<48;g=c?12-f|0:0;u[a+56>>1]=g;u[a+48>>1]=b?1:1<<d-12;u[a+60>>1]=c?1:1<<f-12;u[a+46>>1]=-1<<e^-1;u[a+58>>1]=-1<<g^-1}function Vd(a){var b=0,c=0,d=0;b=jb-16|0;jb=b;v[b+4>>2]=1130;v[b>>2]=a;v[b+8>>2]=0;d=jb-16|0;jb=d;if(v[a>>2]!=-1){a:{c=ec(d,Lf(d+8|0,b));while(1){if(v[a>>2]==1){continue}break}b:{if(!v[a>>2]){ud(a,1);c=v[v[c>>2]>>2];v[23588]=0;Y(1131,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break b}v[a>>2]=-1}break a}b=V(0)|0;O()|0;_(b|0)|0;ud(a,0);v[23588]=0;Z(105);a=v[23588];v[23588]=0;c:{if((a|0)==1){a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){break c}V(0)|0;O()|0;Ub()}L()}T(a|0);L()}}jb=d+16|0;jb=b+16|0;return v[a+4>>2]-1|0}function yaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;a:{f=jb-32|0;jb=f;a=Sb(a);b:{c:{d:{e:{while(1){e=v[b+8>>2];g=v[b>>2];v[23588]=0;e=W(156,g|0,e|0,8)|0;g=v[23588];v[23588]=0;if((g|0)==1){break c}if(e){v[23588]=0;U(866,f|0,b|0,c|0);e=v[23588];v[23588]=0;if((e|0)==1){break e}v[23588]=0;R(867,a|0,f|0);e=v[23588];v[23588]=0;if((e|0)==1){break d}zd(f);e=ZA(v[a+4>>2]);Yh(f,v[e>>2],v[e+4>>2]);if(v[f>>2]!=(d|0)){continue}}break}jb=f+32|0;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;zd(f);break b}b=P()|0;O()|0}Yd(a);T(b|0);L()}}function xda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=jb-16|0;jb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+8>>2];k=v[a+12>>2];while(1){if(d){e=(v[b+12>>2]<<1)+i|0;f=v[b+8>>2]>>>21&2040;e=(((B(u[e>>1],u[f+39714>>1])+B(u[e-2>>1],u[f+39712>>1])|0)+B(u[e+2>>1],u[f+39716>>1])|0)+B(u[e+4>>1],u[f+39718>>1])|0)/16384|0;v[c>>2]=v[c>>2]+B(e,h);v[c+4>>2]=v[c+4>>2]+B(e,g);Qb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;jb=b+16|0}function pL(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0,f=0;Nx(a);c=Xd(c,C(0));a:{switch(b|0){case 0:z[a+4220>>2]=c;return;case 1:z[a+4224>>2]=c;return;case 2:z[a+4228>>2]=c;Ss(a);return;case 3:t[a+4240|0]=c>=C(.5);Ss(a);return;case 4:b=jb-16|0;jb=b;e=b,f=Sh(C(c*C(32))),v[e+12>>2]=f;v[b+8>>2]=0;v[b+4>>2]=5;d=v[Ij(b+12|0,b+8|0,b+4|0)>>2];jb=b+16|0;v[a+4232>>2]=d;return;case 5:t[a+4241|0]=c>=C(.5);return;case 6:t[a+4242|0]=c>=C(.5);return;case 7:t[a+4244|0]=c>=C(.5);return;case 8:if(c==C(0)){Mx(a)}A[a+4256>>3]=c;break;default:break a}}}function Faa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-48|0;jb=d;c=d+24|0;Bj(c,b,1819307379);gd(a+40|0,c);Ab(c);Bj(c,b,1953721961);gd(a+60|0,c);Ab(c);Bj(c,b,543520099);gd(a+120|0,c);Ab(c);Bj(c,b,1414744396);v[23588]=0;c=Q(402,c|0,13719)|0;e=v[23588];v[23588]=0;a:{if((e|0)!=1){b:{if(c){v[23588]=0;U(770,d|0,d+24|0,2);c=v[23588];v[23588]=0;if((c|0)==1){break b}Tt(a+140|0,d);Yd(d)}v[23588]=0;U(771,d|0,b|0,1634890872);b=v[23588];v[23588]=0;if((b|0)!=1){break a}}}a=P()|0;O()|0;Ab(d+24|0);T(a|0);L()}gd(a+80|0,d);Ab(d);Ab(d+24|0);jb=d+48|0}function k$(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=jb-416|0;jb=h;d=h+416|0;v[h+12>>2]=d;c=jb-144|0;jb=c;v[c+28>>2]=c+132;i=c+32|0;fG(v[a+8>>2],i,c+28|0,e,f,g);v[c+16>>2]=0;v[c+20>>2]=0;v[c+12>>2]=i;e=h+16|0;g=uc(e,v[h+12>>2]);f=jb-16|0;jb=f;i=ji(f+8|0,v[a+8>>2]);a=IG(e,c+12|0,g,c+16|0);ii(i);jb=f+16|0;if((a|0)==-1){Xr(12513);L()}v[h+12>>2]=(a<<2)+e;jb=c+144|0;c=v[h+12>>2];a=jb-16|0;jb=a;v[a+8>>2]=b;while(1){if((c|0)!=(e|0)){mH(a+8|0,v[e>>2]);e=e+4|0;continue}break}jb=a+16|0;jb=d;return v[a+8>>2]}function GW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;v[c+12>>2]=v[v[a+1060>>2]>>2]-v[a+1064>>2];v[c+8>>2]=16384;d=v[Jb(c+12|0,c+8|0)>>2];v[a+1072>>2]=d;v[c+4>>2]=17;while(1){a:{if(!d){break a}e=v[c+4>>2];if((e|0)>17){break a}f=1<<e-1;d=Gk(a,e);b:{c:{d:{if((e|0)<=6){if((d|0)!=(f|0)){break d}cr(c+4|0,Gk(a,4));break b}if(e>>>0>16){break c}e=f-8|0;if((e|0)>(d|0)|(d|0)>(f+7|0)){break d}cr(c+4|0,d-e|0);break b}cD(a,d,f,b);break b}e=d&(f^-1);if(d&f){v[c+4>>2]=e+1;break b}cD(a,e,0,b)}d=v[a+1072>>2];continue}break}jb=c+16|0}function C5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-32|0;jb=c;e=Sb(a);a=b;b=0;a:{b:{c:{d:{e:{while(1){d=v[a+24>>2];if(x[d+480188>>1]<=b>>>0){break a}v[23588]=0;R(1008,c|0,(d+(b<<5)|0)+480289|0);d=v[23588];v[23588]=0;if((d|0)!=1){d=v[a+24>>2];v[23588]=0;U(1009,c+16|0,d|0,c|0);d=v[23588];v[23588]=0;if((d|0)==1){break e}v[23588]=0;R(183,e|0,c+16|0);d=v[23588];v[23588]=0;if((d|0)==1){break d}b=b+1|0;yb(c+16|0);yb(c);continue}break}b=P()|0;O()|0;break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;yb(c+16|0)}yb(c)}We(e);T(b|0);L()}jb=c+32|0}function IM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+12>>2]=16777216;h=e+12|0;d=v[a>>2];c=uc(d,v[a+4>>2]);a:{if(c>>>0<b>>>0){f=jb-32|0;jb=f;b=b-c|0;c=v[Fb(a)>>2];d=v[a+4>>2];b:{if(b>>>0<=c-d>>2>>>0){xC(a,b,h);break b}c=Fb(a);c=Uf(f+8|0,pg(a,uc(v[a>>2],d)+b|0),uc(v[a>>2],v[a+4>>2]),c);g=jb-16|0;jb=g;b=Vm(g,c+8|0,b);d=v[b>>2];while(1){if(v[b+4>>2]!=(d|0)){fq(d,v[h>>2]);d=v[b>>2]+4|0;v[b>>2]=d;continue}break}Td(b);jb=g+16|0;Dd(a,c);Tf(c)}jb=f+32|0;break a}if(b>>>0<c>>>0){Nd(a,d+(b<<2)|0)}}uy(a);jb=e+16|0}function Fy(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=jb-16|0;jb=d;g=kt(a,a+1074376|0,b,c);a:{if(!g){break a}h=a+1074312|0;Cb(d+8|0,h,117);if(Bb(v[v[d+8>>2]>>2],v[d+12>>2])){break a}e=B(b,872)+a|0;i=e+1075648|0;c=v[i>>2];if(!c|!w[c+33|0]){break a}f=a;a=e+1074992|0;e=Op(f,v[a+88>>2],c);if(!e){break a}Cb(d+8|0,h,34);f=!Bb(v[v[d+8>>2]>>2],v[d+12>>2]);c=sg(w[a+797|0]-u[a+770>>1]|0);b:{if(f|(c<<24)-16777216>>24<0){break b}a=v[a+656>>2];if(!a){break b}c=w[Kb(a+108|0,c-1|0)|0]}nb[v[v[e>>2]+88>>2]](e,g,c&255,t[v[i>>2]+33|0],b)}jb=d+16|0}function FW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;v[c+12>>2]=v[v[a+1060>>2]>>2]-v[a+1064>>2];v[c+8>>2]=32768;d=v[Jb(c+12|0,c+8|0)>>2];v[a+1072>>2]=d;v[c+4>>2]=9;while(1){a:{if(!d){break a}e=v[c+4>>2];if((e|0)>9){break a}f=1<<e-1;d=Gk(a,e);b:{c:{d:{if((e|0)<=6){if((d|0)!=(f|0)){break d}cr(c+4|0,Gk(a,3));break b}if(e>>>0>8){break c}e=f-4|0;if((e|0)>(d|0)|(d|0)>(f+3|0)){break d}cr(c+4|0,d-e|0);break b}bD(a,d,f,b);break b}e=d&(f^-1);if(d&f){v[c+4>>2]=e+1;break b}bD(a,e,0,b)}d=v[a+1072>>2];continue}break}jb=c+16|0}function lja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{d=jb-32|0;jb=d;a=Sb(a);b:{c:{d:{e:{while(1){c=v[b+8>>2];e=v[b>>2];v[23588]=0;c=W(156,e|0,c|0,8)|0;e=v[23588];v[23588]=0;if((e|0)==1){break c}if(c){v[23588]=0;R(398,d|0,b|0);c=v[23588];v[23588]=0;if((c|0)==1){break e}v[23588]=0;R(399,a|0,d|0);c=v[23588];v[23588]=0;if((c|0)==1){break d}zd(d);c=ZA(v[a+4>>2]);Yh(d,v[c>>2],v[c+4>>2]);if((bc(v[d>>2])|0)!=1162757187){continue}}break}jb=d+32|0;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;zd(d);break b}b=P()|0;O()|0}Yd(a);T(b|0);L()}}function yda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=jb-16|0;jb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+8>>2];k=v[a+12>>2];while(1){if(d){e=v[b+12>>2]+i|0;f=v[b+8>>2]>>>21&2040;e=(((B(t[e|0],u[f+39714>>1])+B(t[e-1|0],u[f+39712>>1])|0)+B(t[e+1|0],u[f+39716>>1])|0)+B(t[e+2|0],u[f+39718>>1])<<8)/16384|0;v[c>>2]=v[c>>2]+B(e,h);v[c+4>>2]=v[c+4>>2]+B(e,g);Qb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;jb=b+16|0}function dka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;md(b,0);g=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);v[b>>2]=g;e=w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24);v[b+12>>2]=e;f=w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24);v[b+16>>2]=f;c=w[a+12|0]|w[a+13|0]<<8;u[b+32>>1]=64;v[b+24>>2]=c;c=w[a+14|0];u[b+30>>1]=c?c+1|0:256;d=x[b+34>>1]&32767|!w[a+14|0]<<15;u[b+34>>1]=d;c=w[a+15|0];if(!(!(c&1)|e>>>0>=f>>>0)){d=d|8;u[b+34>>1]=d;c=w[a+15|0]}if(c&2){v[b+16>>2]=f>>>1;v[b+12>>2]=e>>>1;v[b>>2]=g>>>1;u[b+34>>1]=d|1}}function R4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=C(0);v[23588]=0;Y(952,a|0);d=v[23588];v[23588]=0;a:{if((d|0)==1){break a}v[23588]=0;Y(1024,c|0);d=v[23588];v[23588]=0;if((d|0)==1){break a}d=v[a+24>>2];e=z[d+48>>2];d=v[d+24>>2];v[23588]=0;b=Za(1025,d|0,C(e),b|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break a}v[c>>2]=b;return 1}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,10303,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function $fa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-80|0;jb=c;d=zf(c+48|0);v[23588]=0;e=Q(624,b|0,d|0)|0;f=v[23588];v[23588]=0;a:{b:{c:{d:{if((f|0)!=1){if(e){break d}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[23588]=0;S(625,a|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){break a}}break c}e=v[d+4>>2];v[23588]=0;U(190,c|0,b|0,(e>>>0<9?0:e-8|0)|0);b=v[23588];v[23588]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;zd(d);T(a|0);L()}b=jc(c+24|0,c);gd(d+8|0,b);Ab(b);Ab(c);wk(a,d)}zd(d);jb=c+80|0}function Ui(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=jb-16|0;jb=f;o(+b);g=j(1)|0;d=j(0)|0;c=g&2147483647;e=c+-1048576|0;a:{if((e|0)==2145386495|e>>>0<2145386495){h=d<<28;e=c>>>4|0;c=(c&15)<<28|d>>>4;d=e+1006632960|0;break a}if((c|0)==2146435072|c>>>0>2146435072){h=d<<28;c=(g&15)<<28|d>>>4;d=g>>>4|2147418112;break a}if(!(c|d)){c=0;d=0;break a}e=c;c=c?E(c):E(d)+32|0;Kf(f,d,e,0,0,c+49|0);i=v[f>>2];h=v[f+4>>2];e=15372-c<<16;c=v[f+8>>2];d=e|v[f+12>>2]^65536}v[a>>2]=i;v[a+4>>2]=h;v[a+8>>2]=c;v[a+12>>2]=g&-2147483648|d;jb=f+16|0}function wba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-16|0;jb=e;f=Lb(a);a=0;a:{b:{c:{d:{while(1){d=v[b>>2];if(xd(d,v[b+4>>2])>>>0<=a>>>0){break c}e:{if(!a){d=Md(d,0);break e}v[23588]=0;Q(800,f|0,c|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break b}d=Md(v[b>>2],a)}v[23588]=0;R(801,e|0,d|0);d=v[23588];v[23588]=0;if((d|0)!=1){v[23588]=0;Q(800,f|0,e|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break d}a=a+1|0;yb(e);continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(e);break a}jb=e+16|0;return}a=P()|0;O()|0}yb(f);T(a|0);L()}function vha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-80|0;jb=c;d=zf(c+48|0);v[23588]=0;e=Q(507,b|0,d|0)|0;f=v[23588];v[23588]=0;a:{b:{c:{d:{if((f|0)!=1){if(e){break d}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[23588]=0;S(508,a|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){break a}}break c}e=x[d+2>>1]|x[d+4>>1]<<16;v[23588]=0;U(190,c|0,b|0,e|0);b=v[23588];v[23588]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;zd(d);T(a|0);L()}b=jc(c+24|0,c);gd(d+8|0,b);Ab(b);Ab(c);LS(a,d)}zd(d);jb=c+80|0}function lW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=jb-32|0;jb=d;md(b,0);Zh(d,1,a+33|0);e=d+16|0;Ec(e,d);Be(b+43|0,e);yb(e);f=w[a+50|0]|w[a+51|0]<<8|(w[a+52|0]<<16|w[a+53|0]<<24);v[b>>2]=f;v[b+24>>2]=w[a+54|0]|w[a+55|0]<<8;t[d+16|0]=w[a+56|0];t[d|0]=64;h=b,i=w[Wb(e,d)|0]<<2,u[h+30>>1]=i;e=w[a+57|0]|w[a+58|0]<<8|(w[a+59|0]<<16|w[a+60|0]<<24);v[b+4>>2]=e;g=w[a+61|0]|w[a+62|0]<<8|(w[a+63|0]<<16|w[a+64|0]<<24);c=c?e?f:g:g;v[b+8>>2]=c;if(!(!w[a|0]|c>>>0<=e+2>>>0|c>>>0>f>>>0)){u[b+34>>1]=x[b+34>>1]|2}jb=d+32|0}function oy(a,b,c){var d=0,e=0;e=jb-16|0;jb=e;Cb(e+8|0,a+1074312|0,21);a:{if(Bb(v[v[e+8>>2]>>2],v[e+12>>2])){c=c&255;b:{switch((b&3)-1|0){default:d=t[c+33440|0];break a;case 0:d=64-(c+1>>>1|0)|0;break a;case 1:d=(c>>>0<128)<<6;break a;case 2:break b}}d=oM(Tn(a))+-64|0;break a}d=t[(c>>>1&31)+32128|0];if(x[a+480182>>1]&1032){break a}a=c&63;c:{switch((b&3)-1|0){default:d=t[a+33312|0];break a;case 0:d=(a>>>0<32?0:255)-(a<<2)|0;break a;case 1:d=a>>>0<32?127:-127;break a;case 2:break c}}d=t[a+33376|0]}a=d;jb=e+16|0;return a}function PQ(a,b,c,d,e,f){b=w[(b&15)+27024|0];t[a+3|0]=b;a:{b:{switch(b-11|0){case 0:b=w[a+5|0];c=b&15;if(c){t[a+5|0]=c;return}t[a+5|0]=b&240;return;case 3:b=w[a+5|0];b=B(b&240,10)|b&15;t[a+5|0]=b;d=b&255;b=x[e>>1];if(!(d|(b|0)==65535)){t[a+5|0]=b;t[a+3|0]=12;u[e>>1]=65535}wc(f,c);return;case 1:u[e>>1]=w[a+5|0];v[f>>2]=63;t[a+3|0]=0;return;case 5:b=w[a+5|0];if(d>>>0<=20){c=((b&255)>>>0)/10|0;b=c<<4|B(c,-10)+b;t[a+5|0]=b}if(b&255){break a}t[a+3|0]=0;return;case 7:break a;default:break b}}if(w[a+5|0]){break a}t[a+3|0]=0}}function Dga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=jb-608|0;jb=f;b=jb-16|0;jb=b;d=f+8|0;XR(b+8|0,d);c=v[b+12>>2];ld(b,a,v[b+8>>2],v[b+12>>2]);e=v[b+4>>2];if((e|0)==(c|0)){hd(a,v[b+12>>2])}jb=b+16|0;c=(c|0)==(e|0);if(!c){WR(d)}b=-1;a:{if(!c){break a}b=0;if(!YR(f+8|0)){break a}b=-1;if(!eg(a,1024)){break a}b=0;d=jb-1024|0;jb=d;c=jb-16|0;jb=c;fA(c+8|0,d);e=v[c+12>>2];ld(c,a,v[c+8>>2],v[c+12>>2]);g=v[c+4>>2];if((e|0)==(g|0)){hd(a,v[c+12>>2])}jb=c+16|0;if((e|0)==(g|0)){b=gA(d,0)>>>0<17}jb=d+1024|0}jb=f+608|0;return b|0}function Gba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;if(v[a+4>>2]!=v[Fb(a)>>2]){c=jb-16|0;jb=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+7;iO(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+7;kc(c);jb=c+16|0;return}f=jb-32|0;jb=f;g=Fb(a);h=f+8|0;d=dz(v[a>>2],v[a+4>>2])+1|0;c=jb-16|0;jb=c;v[c+12>>2]=d;a:{e=sh(613566756);if(d>>>0<=e>>>0){d=ez(a);if(d>>>0<e>>>1>>>0){v[c+8>>2]=d<<1;e=v[Yc(c+8|0,c+12|0)>>2]}jb=c+16|0;break a}bd();L()}c=lO(h,e,dz(v[a>>2],v[a+4>>2]),g);iO(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+7;kO(a,c);jO(c);jb=f+32|0}function R6(a){a=a|0;var b=0,c=0,d=0;b=jb-32|0;jb=b;a:{b:{if(!a){a=fg(21619);break b}v[23588]=0;c=Q(55,b|0,a|0)|0;a=v[23588];v[23588]=0;c:{d:{if((a|0)!=1){v[23588]=0;R(938,b+16|0,c|0);a=v[23588];v[23588]=0;if((a|0)==1){break d}d=b+16|0;a=fg(Lc(d));yb(d);yb(c);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;yb(c)}_(a|0)|0;a=0;v[23588]=0;X(939,10936,0,0,0);c=v[23588];v[23588]=0;if((c|0)==1){break a}$()}jb=b+32|0;return a|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function DX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-16|0;jb=e;f=Lb(a);a=0;a:{b:{c:{d:{while(1){d=v[b>>2];if(xd(d,v[b+4>>2])>>>0<=a>>>0){break c}e:{if(!a){d=Md(d,0);break e}v[23588]=0;Q(98,f|0,c|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break b}d=Md(v[b>>2],a)}v[23588]=0;R(153,e|0,d|0);d=v[23588];v[23588]=0;if((d|0)!=1){v[23588]=0;Q(98,f|0,e|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break d}a=a+1|0;zb(e);continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;zb(e);break a}jb=e+16|0;return}a=P()|0;O()|0}zb(f);T(a|0);L()}function mu(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=jb-16|0;jb=g;v[g+12>>2]=0;v[g+8>>2]=a;i=jb-16|0;jb=i;b=gc(i+8|0,v[g+8>>2],v[g+12>>2]);e=jb-16|0;jb=e;d=118;v[e+12>>2]=118;c=v[b+4>>2];a:{if(!c){c=v[b>>2];break a}f=32-c|0;v[e+8>>2]=f;d=v[b>>2];j=v[d>>2];h=f;f=v[Jb(e+8|0,e+12|0)>>2];v[d>>2]=(-1<<c&-1>>>h-f^-1)&j;j=v[e+12>>2];c=d+4|0;v[b>>2]=c;d=j-f|0}h=c;c=d>>>5<<2;Tb(h,0,c);f=d&31;v[e+12>>2]=f;if((d&-32)!=(d|0)){h=b;b=c+v[b>>2]|0;v[h>>2]=b;v[b>>2]=v[b>>2]&(-1>>>32-f^-1)}jb=e+16|0;jb=i+16|0;jb=g+16|0;return a}function Nfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{d=jb-32|0;jb=d;a=Sb(a);b:{c:{d:{e:{while(1){c=v[b+8>>2];e=v[b>>2];v[23588]=0;c=W(156,e|0,c|0,8)|0;e=v[23588];v[23588]=0;if((e|0)==1){break c}if(c){v[23588]=0;R(653,d|0,b|0);c=v[23588];v[23588]=0;if((c|0)==1){break e}v[23588]=0;R(654,a|0,d|0);c=v[23588];v[23588]=0;if((c|0)==1){break d}zd(d);c=ZA(v[a+4>>2]);Yh(d,v[c>>2],v[c+4>>2]);if(v[d>>2]!=1413891155){continue}}break}jb=d+32|0;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;zd(d);break b}b=P()|0;O()|0}Yd(a);T(b|0);L()}}function a7(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;t[a+4202|0]=1;c=jk(C(C(y[v[a+16>>2]+24620>>2])*C(.04500000178813934)));d=jk(C(C(c>>>0)*C(1.1892070770263672)));e=jk(C(C(d>>>0)*C(1.1892070770263672)));h=jk(C(C(e>>>0)*C(1.1892070770263672)));f=jk(C(C(c+e>>>0)*C(.11546666920185089)));g=jk(C(C(d+h>>>0)*C(.11546666920185089)));b=a+4272|0;i=Db(b,0),j=c-f|0,v[i>>2]=j;i=Db(b,1),j=e-f|0,v[i>>2]=j;i=Db(b,2),j=d-g|0,v[i>>2]=j;i=Db(b,3),j=h-g|0,v[i>>2]=j;i=Db(b,4),j=f,v[i>>2]=j;i=Db(b,5),j=g,v[i>>2]=j;CK(a);BK(a)}function baa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;f=jb-16|0;jb=f;v[f+12>>2]=b;a:{if(ct(a)>>>0>=b>>>0){e=v[a>>2];g=xk(e,v[a+4>>2]);v[f+8>>2]=g;d=v[Jb(f+12|0,f+8|0)>>2];while(1){if(d){d=d-1|0;e=VL(e,c)+52|0;continue}break}if(b>>>0>g>>>0){Zx(a,b-g|0,c);break a}TL(a,v[a>>2]+B(b,52)|0);break a}if(v[a>>2]){dt(a);d=v[a>>2];ct(a);Mb(d);h=Fb(a),i=0,v[h>>2]=i;v[a>>2]=0;v[a+4>>2]=0}d=SL(a,b);if(sh(82595524)>>>0<d>>>0){bd();L()}e=RL(d);v[a>>2]=e;v[a+4>>2]=e;h=Fb(a),i=e+B(d,52)|0,v[h>>2]=i;Zx(a,b,c)}jb=f+16|0}function Oaa(a){a=a|0;var b=0,c=0;b=32224;a=Sb(a);a:{b:{while(1){c:{if((b|0)==32624){b=32624;break c}d:{c=v[a+4>>2];if(!oc(v[a>>2],c)){if(!vi(v[b+4>>2],v[Aj(c)>>2])){break d}}v[23588]=0;R(844,a|0,b+4|0);c=v[23588];v[23588]=0;if((c|0)!=1){break d}break b}b=b+8|0;continue}break}while(1){if((b|0)==32672){break a}e:{c=v[a+4>>2];f:{if(!oc(v[a>>2],c)){if(!vi(v[b+8>>2],v[Aj(c)>>2])){break f}}v[23588]=0;R(844,a|0,b+8|0);c=v[23588];v[23588]=0;if((c|0)==1){break e}}b=b+12|0;continue}break}}b=P()|0;O()|0;vc(a);T(b|0);L()}}function SJ(a,b){var c=0,d=0;c=v[a>>2];v[a>>2]=b;if(c){v[23588]=0;Y(813,c|0);a=v[23588];v[23588]=0;a:{if((a|0)!=1){a=v[c+4>>2];if(a){if(v[a>>2]){d=v[a>>2];b=v[a+4>>2];while(1){if((b|0)!=(d|0)){b=b-4|0;rg(b);continue}break}v[a+4>>2]=d;b=v[a>>2];Uh(a);Mb(b)}Mb(a)}v[c+4>>2]=0;ZM(c+1298408|0);Cy(c+1298344|0);yb(c+1298332|0);zb(c+1298320|0);yb(c+1298308|0);By(c+1298304|0);Ay(c+1298300|0);mt(c+1298264|0);Ny(c+1074376|0);YM(c+906300|0);zz(c+484360|0);QM(c+484344|0);vc(c+480248|0);break a}V(0)|0;O()|0;Ub();L()}Mb(c)}}function Sha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(v[a+4>>2]!=v[Fb(a)>>2]){c=jb-16|0;jb=c;a=Tv(c,a);d=v[a+4>>2];v[23588]=0;R(488,d|0,b|0);b=v[23588];v[23588]=0;a:{if((b|0)!=1){v[a+4>>2]=v[a+4>>2]+12;kc(a);jb=c+16|0;break a}b=P()|0;O()|0;kc(a);T(b|0);L()}return}d=jb-32|0;jb=d;c=Fb(a);c=Hk(d+8|0,jn(a,xd(v[a>>2],v[a+4>>2])+1|0),xd(v[a>>2],v[a+4>>2]),c);e=v[c+8>>2];v[23588]=0;R(488,e|0,b|0);b=v[23588];v[23588]=0;b:{if((b|0)!=1){v[c+8>>2]=v[c+8>>2]+12;yr(a,c);Sv(c);jb=d+32|0;break b}a=P()|0;O()|0;Sv(c);T(a|0);L()}}function oP(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=b?33:32;c=w[a+16|0];k=c?-1:1;l=c?1:-1;e=v[a+8>>2]-1|0;m=c?e-(w[a+17|0]!=0&(e|0)!=0)|0:0;f=v[a+12>>2];n=(f|0)>0?f:0;o=c?0:e;h=v[a>>2]+B(f,62)|0;d=b?1:-1;p=B(f,d)<<1;c=e;a:while(1){if((i|0)!=(j|0)){g=B(c,f);q=v[a+4>>2];b=0;while(1)if((b|0)==(n|0)){b:{if((c|0)==(e|0)){b=m;g=k;if((d|0)>0){break b}}b=c+d|0;c=!c&(d|0)<0;b=c?o:b;g=c?l:d}h=h+p|0;i=i+1|0;c=b;d=g;continue a}else{u[(b<<1)+h>>1]=x[q+(b+g<<1)>>1];b=b+1|0;continue}}break}}function dN(a,b,c){var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;a:{if(b){t[c|0]=b;break a}b=w[c|0]}e=v[a+480180>>2];b=e&1048580?(b&240?-16:15)&b:b;c=b&240;f=b&255;b=b&15;b:{c:{d:{if(!(!c|(b|0)!=15)){if(!(w[a+480209|0]&16)){break b}b=f>>>3&30;break d}g=v[a+480208>>2]&4096;if(!(!b|(c|0)!=240)){if(!g){break b}b=0-(b<<1)|0;break c}if(g){break b}if(c){if(b?e&59314208:0){break b}b=f>>>3&30;break d}b=0-(b<<1)|0}if(!b){break b}}a=a+1074456|0;v[d+12>>2]=v[a>>2]+(b<<!(e&59314208));oe(d+12|0,0,256);v[a>>2]=v[d+12>>2]}jb=d+16|0}function HY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(Zg(a,v[b+8>>2],e)){nw(b,c,d);return}a:{if(Zg(a,v[b>>2],e)){if(!(v[b+16>>2]!=(c|0)&v[b+20>>2]!=(c|0))){if((d|0)!=1){break a}v[b+32>>2]=1;return}v[b+32>>2]=d;b:{if(v[b+44>>2]==4){break b}u[b+52>>1]=0;a=v[a+8>>2];nb[v[v[a>>2]+20>>2]](a,b,c,c,1,e);if(w[b+53|0]){v[b+44>>2]=3;if(!w[b+52|0]){break b}break a}v[b+44>>2]=4}v[b+20>>2]=c;v[b+40>>2]=v[b+40>>2]+1;if(v[b+36>>2]!=1|v[b+24>>2]!=2){break a}t[b+54|0]=1;return}a=v[a+8>>2];nb[v[v[a>>2]+24>>2]](a,b,c,d,e)}}function FI(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-16|0;jb=d;a:{b:{c:{a=v[a+32>>2];c=Gs(a);d:{if(!c){if(Fs(a)>>>0<=b>>>0){break d}c=(w[Gi(a,b+1&65535)+35|0]&4)>>>2|0;break b}if(b>>>0<c>>>0){break c}}a=ba(8)|0;v[23588]=0;b=Q(55,d|0,6003)|0;c=v[23588];v[23588]=0;e:{if((c|0)!=1){a=rc(a,b);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}c=P()|0;O()|0;yb(b);break e}c=P()|0;O()|0;ca(a|0)}T(c|0);L()}a=v[(a+(b<<2)|0)+900384>>2];c=1;if(!a){break b}c=(w[a+15|0]&2)>>>1|0}jb=d+16|0;return c|0}L()}function Dfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-80|0;jb=c;d=zf(c+48|0);v[23588]=0;e=Q(659,b|0,d|0)|0;f=v[23588];v[23588]=0;a:{b:{c:{d:{if((f|0)!=1){if(e){break d}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[23588]=0;S(660,a|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){break a}}break c}e=v[d+4>>2];v[23588]=0;U(190,c|0,b|0,e|0);b=v[23588];v[23588]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;zd(d);T(a|0);L()}b=jc(c+24|0,c);gd(d+8|0,b);Ab(b);Ab(c);wk(a,d)}zd(d);jb=c+80|0}function CG(a,b,c,d){var e=0,f=0,g=0;f=jb-16|0;jb=f;a:{b:{if((a|0)!=(b|0)){c:{g=v[116064];v[116064]=0;Gd();d=BG(a,f+12|0,d);e=mb;d:{a=v[116064];if(a){if(v[f+12>>2]!=(b|0)){break c}if((a|0)!=68){break d}v[c>>2]=4;a=2147483647;if(!!d&(e|0)>=0|(e|0)>0){break a}break b}v[116064]=g;if(v[f+12>>2]==(b|0)){break d}break c}if((e|0)<0&d>>>0<=2147483647|(e|0)<-1){v[c>>2]=4;break b}if((e|0)>=0&d>>>0>=2147483648|(e|0)>0){v[c>>2]=4;a=2147483647;break a}a=d;break a}}v[c>>2]=4;a=0;break a}a=-2147483648}jb=f+16|0;return a}function A5(a){a=a|0;var b=0,c=0,d=0,e=0;c=jb-32|0;jb=c;e=Sb(a);Wd(c+24|0);a=0;b=v[c+28>>2];d=v[c+24>>2];v[23588]=0;R(181,e|0,XI(d,b)|0);b=v[23588];v[23588]=0;a:{if((b|0)!=1){b:{while(1){b=v[c+24>>2];if((XI(b,v[c+28>>2])|0)<=(a|0)){jb=c+32|0;return}b=v[b+(a<<3)>>2];v[23588]=0;b=Q(55,c+8|0,b|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){v[23588]=0;R(183,e|0,b|0);d=v[23588];v[23588]=0;if((d|0)==1){break b}yb(b);a=a+1|0;continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(b);break a}a=P()|0;O()|0}We(e);T(a|0);L()}function nga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;fc(c+8|0,b,26);d=v[c+12>>2];mc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){Zb(a,v[c+12>>2])}jb=c+16|0;if((d|0)!=(e|0)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+24|0]=0;t[b+25|0]=0;t[b+16|0]=0;t[b+17|0]=0;t[b+18|0]=0;t[b+19|0]=0;t[b+20|0]=0;t[b+21|0]=0;t[b+22|0]=0;t[b+23|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0}}function AI(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;d=jb-32|0;jb=d;A[d+24>>3]=c;a:{b:{c:{if(b>>>0>=256){b=ba(8)|0;v[23588]=0;d=Q(55,d+8|0,10656)|0;a=v[23588];v[23588]=0;if((a|0)==1){break c}a=rc(b,d);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(d);break b}a=v[a+32>>2];v[d+8>>2]=0;v[d+12>>2]=-1074790400;v[d>>2]=0;v[d+4>>2]=1072693248;e=(a+B(b,872)|0)+1075684|0,f=yl(A[Gg(d+24|0,d+8|0,d)>>3]*128+128),v[e>>2]=f;jb=d+32|0;return}a=P()|0;O()|0;ca(b|0)}T(a|0)}L()}function ZC(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=w[a+8|0];h=v[a>>2];e=v[a+4>>2];f=Lc(b);a=Gb(b);b=jb-16|0;jb=b;v[b+8>>2]=a;v[b+12>>2]=e;a=h;g=v[Jb(b+12|0,b+8|0)>>2];c=g;while(1){a:{if(!c){c=0;break a}i=w[f|0];t[a|0]=i;if(!i){break a}f=f+1|0;a=a+1|0;c=c-1|0;continue}break}b:{if((d-1&255)>>>0<=1){t[b+7|0]=0;om(a,((a+e|0)-g|0)+c|0,b+7|0);break b}if((d-3&255)>>>0>1){break b}t[b+6|0]=32;om(a,((a+e|0)-g|0)+c|0,b+6|0)}c:{switch(d-1|0){case 0:case 3:t[(v[b+12>>2]+h|0)-1|0]=0;break;default:break c}}jb=b+16|0}function Q9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=C(0);e=jb-16|0;jb=e;f=qf(a,c);me(e,v[a+36>>2]);h=a;a:{if(!f){Rc(e,a+32|0,5);c=0;if(Bb(v[v[e>>2]>>2],v[e+4>>2])){break a}}c=0;d=jb-32|0;jb=d;g=v[a+36>>2];Jk(g,d+24|0);i=d,j=Dc(v[d+24>>2],v[d+28>>2]),v[i+16>>2]=j;v[d+12>>2]=256;ck(b,v[Jb(d+16|0,d+12|0)>>2]);a=v[b>>2];while(1){if(uc(a,v[b+4>>2])>>>0<=c>>>0){jb=d+32|0}else{v[d+16>>2]=0;Dp(g,d+16|0);a=v[b>>2];i=Db(a,c),k=z[d+16>>2],z[i>>2]=k;c=c+1|0;continue}break}c=f}Xe(h,c);jb=e+16|0}function Z_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;h=jb-16|0;jb=h;d=Gb(a);e=tn(a);g=_d(b,c);a:{if(!g){break a}b:{f=zc(a);if(f>>>0<=b>>>0){f=(Gb(a)<<2)+f>>>0>=b>>>0}else{f=0}if(!f){if(e-d>>>0<g>>>0){XF(a,e,(d+g|0)-e|0,d,d)}e=zc(a)+(d<<2)|0;while(1){if((b|0)==(c|0)){break b}ud(e,v[b>>2]);b=b+4|0;e=e+4|0;continue}}b=GG(h,b,c);c=zc(b);d=Gb(b);v[23588]=0;W(1172,a|0,c|0,d|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){Fc(b);break a}a=P()|0;O()|0;Fc(b);T(a|0);L()}ud(e,0);Qh(a,d+g|0)}jb=h+16|0;return a|0}function Mq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if((a|0)!=(b|0)){if(!ef(a)){if(!ef(b)){c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2];return}d=Lc(b);b=Gb(b);c=jb-16|0;jb=c;a:{if(b>>>0<=10){ce(a,b);a=ve(a,d,b);t[c+15|0]=0;ie(a+b|0,c+15|0);break a}f=a;a=w[a+11|0];hp(f,10,b-10|0,a,0,a,b,d)}jb=c+16|0;return}d=Lc(b);b=Gb(b);c=jb-16|0;jb=c;e=Kl(a);b:{if(e>>>0>b>>>0){e=v[a>>2];Fd(a,b);a=ve(e,d,b);t[c+15|0]=0;ie(a+b|0,c+15|0);break b}f=a;a=v[a+4>>2];hp(f,e-1|0,(b-e|0)+1|0,a,0,a,b,d)}jb=c+16|0}}function _ja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-32|0;jb=c;md(b,0);Zh(c,1,a);d=c+16|0;Ec(d,c);Be(b+43|0,d);yb(d);v[b+24>>2]=w[a+32|0]|w[a+33|0]<<8|(w[a+34|0]<<16|w[a+35|0]<<24);u[b+34>>1]=x[b+34>>1]&65533|(w[a+13|0]|w[a+14|0]<<8)<<1&2;v[b>>2]=w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24);v[b+4>>2]=w[a+20|0]|w[a+21|0]<<8|(w[a+22|0]<<16|w[a+23|0]<<24);v[b+8>>2]=w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24);t[c+16|0]=w[a+15|0];t[c|0]=64;e=b,f=w[Wb(d,c)|0]<<2,u[e+30>>1]=f;jb=c+32|0}function IE(a,b,c,d){var e=0,f=0,g=0;e=jb-80|0;jb=e;f=zf(e+48|0);v[23588]=0;d=Q(d|0,b|0,f|0)|0;g=v[23588];v[23588]=0;a:{b:{c:{d:{if((g|0)!=1){if(d){break d}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[23588]=0;S(c|0,a|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){break a}}break c}c=v[f+4>>2];v[23588]=0;U(190,e|0,b|0,bc(c)|0);b=v[23588];v[23588]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;zd(f);T(a|0);L()}b=jc(e+24|0,e);gd(f+8|0,b);Ab(b);Ab(e);wk(a,f)}zd(f);jb=e+80|0}function Em(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;a:{if(f&64){c=f+-64|0;b=c&31;if((c&63)>>>0>=32){c=0;b=e>>>b|0}else{c=e>>>b|0;b=((1<<b)-1&e)<<32-b|d>>>b}d=0;e=0;break a}if(!f){break a}i=d;h=64-f|0;g=h&31;if((h&63)>>>0>=32){h=i<<g;j=0}else{h=(1<<g)-1&i>>>32-g|e<<g;j=i<<g}i=b;b=f&31;if((f&63)>>>0>=32){g=0;b=c>>>b|0}else{g=c>>>b|0;b=((1<<b)-1&c)<<32-b|i>>>b}b=j|b;c=g|h;g=d;d=f&31;if((f&63)>>>0>=32){h=0;d=e>>>d|0}else{h=e>>>d|0;d=((1<<d)-1&e)<<32-d|g>>>d}e=h}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=d;v[a+12>>2]=e}function y5(a,b){a=a|0;b=b|0;var c=C(0),d=0,e=C(0);v[23588]=0;Y(952,a|0);d=v[23588];v[23588]=0;if((d|0)!=1){a=v[v[a+24>>2]+24>>2];if(!((b|0)<0|x[a+480188>>1]<=b>>>0)){a=a+B(b,872)|0;c=C(C(w[a+1075834|0])*C(.0078125));e=C(c*c);c=C(C(w[a+1075835|0])*C(.0078125));c=C(K(C(e+C(c*c))))}return C(c)}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,9337,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)!=1){$();return C(C(0))}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function gka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;v[a>>2]=0;v[a+4>>2]=0;Gc(a+8|0);if(b){if(sh(715827882)>>>0<b>>>0){bd();L()}d=B(b,6);c=sc(d);v[a>>2]=c;v[a+4>>2]=c;f=Fb(a),g=c+d|0,v[f>>2]=g;d=jb-16|0;jb=d;c=Fq(d,a,b);b=v[c+4>>2];e=v[c+8>>2];while(1){if((b|0)==(e|0)){kc(c);jb=d+16|0}else{t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+4|0]=6;t[b+5|0]=0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=8;t[b+3|0]=4;b=b+6|0;v[c+4>>2]=b;continue}break}}t[a+16|0]=6;v[a+12>>2]=2015363072;return a|0}function Fl(a,b,c){var d=0;d=512;a:{if(b){break a}d=0;if(!(w[a+35|0]&2)){break a}Ko(a)}d=x[a+34>>1]&-513|d;u[a+34>>1]=d;if(b){v[a>>2]=4;u[a+34>>1]=d&65470;Ng(a);b=w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24);t[a+76|0]=b;t[a+77|0]=b>>>8;t[a+78|0]=b>>>16;t[a+79|0]=b>>>24;b=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[a+68|0]=c;t[a+69|0]=c>>>8;t[a+70|0]=c>>>16;t[a+71|0]=c>>>24;t[a+72|0]=b;t[a+73|0]=b>>>8;t[a+74|0]=b>>>16;t[a+75|0]=b>>>24}}function PO(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=vt(b);v[a>>2]=0;v[a+4>>2]=0;Gc(a+8|0);mz(a,2048);g=jb-16|0;jb=g;f=kr(g,a,2048);d=v[f+4>>2];i=v[f+8>>2];while(1){if((d|0)==(i|0)){kc(f);jb=g+16|0}else{v[d>>2]=0;v[d+4>>2]=0;d=d+8|0;v[f+4>>2]=d;continue}break}while(1){a:{c=1;if((e|0)!=1024){if((e|0)==2048){break a}c=+(e-1024|0);j=vt(K(c*c*-9.5367431640625e-7+1)*b);c=c*.0372006759294457;c=j*Ci(c)/(h*c)}k=af(v[a>>2],e),l=c*.011841342921061943,A[k>>3]=l;e=e+1|0;continue}break}}function g_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=v[a>>2];c=uc(d,v[a+4>>2]);if(c>>>0<b>>>0){f=jb-32|0;jb=f;d=b-c|0;c=v[Fb(a)>>2];b=v[a+4>>2];a:{if(d>>>0<=c-b>>2>>>0){Bt(a,d);break a}c=sw(a);g=pg(a,uc(v[a>>2],b)+d|0);e=uc(v[a>>2],v[a+4>>2]);b=f+8|0;og(b+12|0,c);if(g){c=QF(v[b+16>>2],g)}else{c=0}v[b>>2]=c;e=c+(e<<2)|0;v[b+8>>2]=e;v[b+4>>2]=e;h=Bc(b),i=c+(g<<2)|0,v[h>>2]=i;ML(b,d);Dd(a,b);eQ(b);a=v[b>>2];if(a){SF(v[b+16>>2],a,Kz(b))}}jb=f+32|0;return}if(b>>>0<c>>>0){Nd(a,d+(b<<2)|0)}}function I8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;t[d+15|0]=b;b=w[a+11|0];a:{b:{c:{if(!ff(b)){c=10;b=yf(b);if((b|0)==10){break c}ce(a,b+1|0);c=a;break a}b=v[a+4>>2];c=uu(v[a+8>>2])-1|0;if((b|0)!=(c|0)){break b}}e=jb-16|0;jb=e;g=od(a);f=-17;b=c;if(b>>>0<=2147483622){v[e+8>>2]=b<<1;v[e+12>>2]=b+1;f=Mg(v[Yc(e+12|0,e+8|0)>>2])+1|0}c=sc(f);if(b){ve(c,g,b)}if((b|0)!=10){Mb(g)}ud(a,c);bf(a,f);jb=e+16|0}c=v[a>>2];Fd(a,b+1|0)}a=b+c|0;ie(a,d+15|0);t[d+14|0]=0;ie(a+1|0,d+14|0);jb=d+16|0}function Eea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a:{f=jb-48|0;jb=f;Iq(f+8|0,c);v[23588]=0;c=f+20|0;R(575,c|0,d|0);d=v[23588];v[23588]=0;b:{c:{d:{if((d|0)==1){break d}v[23588]=0;c=f+32|0;R(575,c|0,e|0);d=v[23588];v[23588]=0;if((d|0)==1){break d}Ov(f,f+8|0);v[23588]=0;X(296,a|0,b|0,v[f>>2],v[f+4>>2]);a=v[23588];v[23588]=0;if((a|0)==1){break c}lQ(f+8|0);jb=f+48|0;break a}a=P()|0;O()|0;while(1){c=yb(c-12|0);if((c|0)!=(f+8|0)){continue}break}break b}a=P()|0;O()|0;lQ(f+8|0)}T(a|0);L()}}function HX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a:{f=jb-48|0;jb=f;Zo(f+8|0,c);v[23588]=0;c=f+20|0;R(139,c|0,d|0);d=v[23588];v[23588]=0;b:{c:{d:{if((d|0)==1){break d}v[23588]=0;c=f+32|0;R(139,c|0,e|0);d=v[23588];v[23588]=0;if((d|0)==1){break d}Ov(f,f+8|0);v[23588]=0;X(114,a|0,b|0,v[f>>2],v[f+4>>2]);a=v[23588];v[23588]=0;if((a|0)==1){break c}vr(f+8|0);jb=f+48|0;break a}a=P()|0;O()|0;while(1){c=zb(c-12|0);if((c|0)!=(f+8|0)){continue}break}break b}a=P()|0;O()|0;vr(f+8|0)}T(a|0);L()}}function iia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=jb-32|0;jb=c;e=c+8|0;f=Sb(e+8|0);v[23588]=0;d=S(202,b|0)|0;g=v[23588];v[23588]=0;a:{b:{if((g|0)==1){break b}v[23588]=0;U(244,e|0,b|0,d|0);d=v[23588];v[23588]=0;if((d|0)==1){break b}d=v[e>>2];v[23588]=0;Q(188,b|0,d|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;hc(f);T(a|0);L()}Tu(c,e);v[23588]=0;U(463,a|0,v[c>>2],v[c+4>>2]);a=v[23588];v[23588]=0;if((a|0)!=1){Tc(c+8|0);jb=c+32|0;return}a=P()|0;O()|0;Tc(c+8|0);T(a|0);L()}function Hfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-32|0;jb=d;md(b,0);iB(d,a+1|0);c=d+16|0;Ec(c,d);Be(b+43|0,c);yb(c);v[b+24>>2]=w[a+73|0]|w[a+74|0]<<8|(w[a+75|0]<<16|w[a+76|0]<<24);c=w[a+54|0]|w[a+55|0]<<8|(w[a+56|0]<<16|w[a+57|0]<<24);v[b>>2]=c;v[b+4>>2]=w[a+58|0]|w[a+59|0]<<8|(w[a+60|0]<<16|w[a+61|0]<<24);e=w[a+62|0]|w[a+63|0]<<8|(w[a+64|0]<<16|w[a+65|0]<<24);if(e){v[b+8>>2]=e+1}u[b+30>>1]=(w[a+68|0]<<1)+2;u[b+34>>1]=x[b+34>>1]&65533|w[a|0]>>>6&2;wc(b+8|0,c);wc(b+4|0,v[b+8>>2]);jb=d+32|0}function yM(a,b){var c=0,d=0,e=0,f=0,g=0;d=jb-32|0;jb=d;a:{f=b-4e3&65535;if(f>>>0<61537){break a}c=B(b,104)+a|0;e=c+484380|0;if(!Zd(v[e>>2],v[c+484400>>2])){break a}g=a+1298224|0;c=a+1074992|0;while(1){if((c|0)==(g|0)){Dm(e);v[e>>2]=0;a=(B(b,104)+a|0)+484414|0;u[a>>1]=x[a>>1]&65470;v[d+24>>2]=0;v[d+8>>2]=0;v[d+16>>2]=0;v[d+20>>2]=0;v[d>>2]=0;v[d+4>>2]=0;Fl(e,0,d);break a}if(v[c+104>>2]==(e|0)){v[c+76>>2]=0;v[c>>2]=0;v[c+4>>2]=0;v[c+16>>2]=0}c=c+872|0;continue}}jb=d+32|0;return f>>>0>61536}function qP(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;j=b?33:32;c=v[a+8>>2]-1|0;e=v[a+12>>2];f=v[a>>2]+B(e,31)|0;g=b?1:-1;d=g;a:while(1){b:{b=0;if((h|0)==(j|0)){break b}while(1)if((b|0)>=(e|0)){b=B(e,g);i=v[a+8>>2]-1|0;c:{if(!((i|0)!=(c|0)|(d|0)<=0)){if(!w[a+16|0]){d=1;c=0;break c}d=-1;c=c-(w[a+17|0]!=0&(c|0)!=0)|0;break c}if(!((d|0)>=0|c)){c=w[a+16|0];d=c?1:-1;c=c?0:i;break c}c=c+d|0}f=b+f|0;h=h+1|0;continue a}else{t[b+f|0]=w[v[a+4>>2]+(B(c,e)+b|0)|0];b=b+1|0;e=v[a+12>>2];continue}}break}}function ky(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a:{if((c|0)<2){break a}k=c-2>>>1|0;f=d-a|0;if((k|0)<f>>1){break a}h=f+1|0;e=(h<<1)+a|0;g=x[e>>1];i=f+2|0;if((i|0)<(c|0)){j=x[e+2>>1];f=Jp(b,g&65535,j);e=f?e+2|0:e;h=f?i:h;g=f?j:g}i=x[d>>1];if(Jp(b,g&65535,i)){break a}while(1){b:{f=e;u[d>>1]=g;if((h|0)>(k|0)){break b}d=h<<1;h=d|1;e=(h<<1)+a|0;g=x[e>>1];j=d+2|0;if((j|0)<(c|0)){l=x[e+2>>1];d=Jp(b,g&65535,l);e=d?e+2|0:e;h=d?j:h;g=d?l:g}d=f;if(!Jp(b,g&65535,i)){continue}}break}u[f>>1]=i}}function Or(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=jb-16|0;jb=i;a:{b:{if(!a){break b}h=v[e+12>>2];g=c-b|0;if((g|0)>0){g=g>>>2|0;if((Pm(a,b,g)|0)!=(g|0)){break b}}b=d-b>>2;b=(b|0)<(h|0)?h-b|0:0;if((b|0)>0){f=nG(i,b,f);h=zc(f);v[23588]=0;h=W(1155,a|0,h|0,b|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break a}Fc(f);if((b|0)!=(h|0)){break b}}b=d-c|0;if((b|0)>0){b=b>>>2|0;if((Pm(a,c,b)|0)!=(b|0)){break b}}Co(e);j=a}jb=i+16|0;return j|0}a=P()|0;O()|0;Fc(f);T(a|0);L()}function X4(a,b){a=a|0;b=b|0;var c=0,d=0;v[23588]=0;Y(952,a|0);c=v[23588];v[23588]=0;if((c|0)!=1){a=v[a+24>>2];c=-1;a:{if((b|0)<0){break a}d=v[a+24>>2];if(sj(Vb(v[d+484360>>2],w[d+484376|0]))>>>0<=b>>>0){break a}a=v[a+24>>2];c=x[cc(v[Vb(v[a+484360>>2],w[a+484376|0])>>2],b)>>1]}return c|0}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,9751,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function qH(a){var b=0,c=0;a:{b=v[a+4>>2];b=v[v[b>>2]-12>>2]+b|0;b:{if(!v[b+24>>2]){break b}if(!Yg(b)|!(v[b+4>>2]&8192)){break b}if(IH()){break b}b=v[a+4>>2];b=v[(v[v[b>>2]-12>>2]+b|0)+24>>2];v[23588]=0;b=S(1105,b|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){if((b|0)!=-1){break b}a=v[a+4>>2];b=v[v[a>>2]-12>>2];v[23588]=0;Y(1106,a+b|0);a=v[23588];v[23588]=0;if((a|0)!=1){break b}}a=V(0)|0;O()|0;_(a|0)|0;v[23588]=0;Z(18);a=v[23588];v[23588]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Ub();L()}function Fz(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=jb-16|0;jb=d;f=a+14|0;c=v[a>>2];e=v[a+4>>2];if(oc(c,e)){b=c}else{u[c>>1]=0;vf(c+2|0,b);g=d,h=ym(Eb(v[a>>2]),1),v[g+8>>2]=h;while(1){e=Eb(v[a+4>>2]);c=v[d+8>>2];if(Ob(c,e)){g=c,h=x[ke(c,ym(c,-1))>>1],u[g>>1]=h;vf(c+2|0,b);xQ(d+8|0);continue}else{e=v[a+4>>2];b=v[a>>2]}break}}vf(f,_d(b,e)-1&255);vf(a+13|0,w[a+14|0]);vf(a+16|0,_d(v[a>>2],v[a+4>>2])-1&255);vf(a+15|0,w[a+16|0]);if(w[a+17|0]!=255){vf(a+17|0,_d(v[a>>2],v[a+4>>2])-1&255)}jb=d+16|0}function Mv(a){var b=0,c=0,d=0;if(y[a+4>>2]<y[Fb(a)>>2]){b=jb-16|0;jb=b;a=zD(b,a);c=v[a+4>>2];v[23588]=0;Y(170,c|0);c=v[23588];v[23588]=0;a:{if((c|0)!=1){v[a+4>>2]=v[a+4>>2]+36;kc(a);jb=b+16|0;break a}b=P()|0;O()|0;kc(a);T(b|0);L()}return}c=jb-32|0;jb=c;b=Fb(a);b=xD(c+8|0,yD(a,jr(v[a>>2],v[a+4>>2])+1|0),jr(v[a>>2],v[a+4>>2]),b);d=v[b+8>>2];v[23588]=0;Y(170,d|0);d=v[23588];v[23588]=0;b:{if((d|0)!=1){v[b+8>>2]=v[b+8>>2]+36;wD(a,b);Bv(b);jb=c+32|0;break b}a=P()|0;O()|0;Bv(b);T(a|0);L()}}function yk(a){var b=0,c=0;a:{b=v[a+4>>2];b=v[v[b>>2]-12>>2]+b|0;b:{if(!v[b+24>>2]){break b}if(!Yg(b)|!(v[b+4>>2]&8192)){break b}if(IH()){break b}b=v[a+4>>2];b=v[(v[v[b>>2]-12>>2]+b|0)+24>>2];v[23588]=0;b=S(22,b|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){if((b|0)!=-1){break b}a=v[a+4>>2];b=v[v[a>>2]-12>>2];v[23588]=0;R(16,a+b|0,1);a=v[23588];v[23588]=0;if((a|0)!=1){break b}}a=V(0)|0;O()|0;_(a|0)|0;v[23588]=0;Z(18);a=v[23588];v[23588]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Ub();L()}function zJ(a){var b=0,c=0,d=0,e=0,f=0;while(1){d=v[a+16>>2];if(d>>>0<=e>>>0){while(1){if(!(y[a+12>>2]<=d>>>0)){while(1){e=xy(v[a>>2]);c=mb;f=v[a+36>>2];if((c|0)==(f|0)&y[a+32>>2]<=e>>>0|c>>>0>f>>>0){continue}break}c=b;b=v[a+8>>2];b=(e&v[a+48>>2])+(b>>>0<31?c<<b+1:0)|0;d=d+1|0;continue}break}}else{while(1){d=xy(v[a>>2]);c=mb;f=v[a+28>>2];if((c|0)==(f|0)&y[a+24>>2]<=d>>>0|c>>>0>f>>>0){continue}break}c=b;b=v[a+8>>2];b=(d&v[a+40>>2])+(b>>>0<32?c<<b:0)|0;e=e+1|0;continue}break}return b}function uha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[Fb(a)>>2]){c=jb-16|0;jb=c;a=nV(c,a);BA(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+28;kc(a);jb=c+16|0;return}e=jb-32|0;jb=e;c=Fb(a);c=lV(e+8|0,mV(a,Jq(v[a>>2],v[a+4>>2])+1|0),Jq(v[a>>2],v[a+4>>2]),c);BA(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+28;f=v[a>>2];d=v[a+4>>2];b=c+4|0;while(1){if((d|0)!=(f|0)){d=d-28|0;BA(v[b>>2]-28|0,d);v[b>>2]=v[b>>2]-28;continue}break}pc(a,b);pc(a+4|0,c+8|0);pc(Fb(a),Bc(c));v[c>>2]=v[c+4>>2];kV(c);jb=e+32|0}function Dj(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[Fb(a)>>2]){c=jb-16|0;jb=c;a=nV(c,a);GB(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+28;kc(a);jb=c+16|0;return}e=jb-32|0;jb=e;c=Fb(a);c=lV(e+8|0,mV(a,Jq(v[a>>2],v[a+4>>2])+1|0),Jq(v[a>>2],v[a+4>>2]),c);GB(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+28;f=v[a>>2];d=v[a+4>>2];b=c+4|0;while(1){if((d|0)!=(f|0)){d=d-28|0;GB(v[b>>2]-28|0,d);v[b>>2]=v[b>>2]-28;continue}break}pc(a,b);pc(a+4|0,c+8|0);pc(Fb(a),Bc(c));v[c>>2]=v[c+4>>2];kV(c);jb=e+32|0}function fJ(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;if((e|0)==10){Gx(a,b,c,d);return}g=d;i=B(e,e);k=B(i,e);j=B(i,i);a:{while(1){h=f|1;if(e>>>0>g>>>0){break a}h=f|2;if(g>>>0<i>>>0){break a}h=f|3;if(g>>>0<k>>>0){break a}if(g>>>0<j>>>0){h=f+4|0}else{f=f+4|0;g=(g>>>0)/(j>>>0)|0;continue}break}}f=h;if((f|0)>(c-b|0)){v[a+4>>2]=61;v[a>>2]=c;return}f=b+f|0;c=f;while(1){c=c-1|0;b=(d>>>0)/(e>>>0)|0;t[c|0]=w[(d-B(b,e)|0)+4898|0];g=d>>>0>=e>>>0;d=b;if(g){continue}break}v[a+4>>2]=0;v[a>>2]=f}function gF(a,b,c,d,e,f,g,h){var i=0,j=0;i=jb-16|0;jb=i;v[23588]=0;Y(952,a|0);j=v[23588];v[23588]=0;a:{b:{if((j|0)!=1){c:{j=v[a+24>>2];v[23588]=0;ia(h|0,i|0,j|0,b|0,c|0,d|0,e|0,(f|0)!=0|0);b=v[23588];v[23588]=0;if((b|0)==1){break c}b=fg(Lc(i));yb(i);break b}}b=V(0)|0;O()|0;_(b|0)|0;b=0;v[23588]=0;X(939,g|0,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$()}jb=i+16|0;return b}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function VL(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;if((a|0)!=(b|0)){c=jb-16|0;jb=c;d=v[b>>2];f=v[b+4>>2];e=pk(d,f);a:{if(e>>>0<=Cu(a)>>>0){g=f;h=v[a>>2];i=pk(h,v[a+4>>2]);j=i>>>0>=e>>>0;if(!j){v[c+12>>2]=d;v[c+12>>2]=v[c+12>>2]+B(i,6);g=v[c+12>>2]}d=XL(d,g,h);if(!j){$x(a,g,f,e-pk(v[a>>2],v[a+4>>2])|0);break a}Nd(a,d);break a}WL(a);lu(a,IA(a,e));$x(a,d,f,e)}jb=c+16|0}v[a+12>>2]=v[b+12>>2];v[a+16>>2]=v[b+16>>2];v[a+20>>2]=v[b+20>>2];UL(a+24|0,b+24|0);Mq(a+36|0,b+36|0);return a}function OQ(a){var b=0,c=0;a:{if(Rb(a+60|0,13774,4)){break a}b=w[a+28|0]|w[a+29|0]<<8;b:{if(b>>>0<=63){if((b|0)==26){break b}break a}if(b>>>0>2112){break a}}b=w[a+42|0];if(b>>>0>64&(b|0)!=88|(w[a+48|0]|w[a+49|0]<<8)>>>0>64|(w[a+50|0]|w[a+51|0]<<8)>>>0>96){break a}b=w[a+52|0]|w[a+53|0]<<8;if(b>>>0>129&(b|0)!=257|(w[a+30|0]|w[a+31|0]<<8)|(w[a+38|0]|w[a+39|0]<<8|(w[a+40|0]<<16|w[a+41|0]<<24)|(w[a+44|0]|w[a+45|0]<<8|(w[a+46|0]<<16|w[a+47|0]<<24))!=1)){break a}c=RQ(a+20|0)}return c}function Kf(a,b,c,d,e,f){var g=0,h=0,i=0;a:{if(f&64){d=b;e=f+-64|0;b=e&31;if((e&63)>>>0>=32){e=d<<b;d=0}else{e=(1<<b)-1&d>>>32-b|c<<b;d=d<<b}b=0;c=0;break a}if(!f){break a}g=d;d=f&31;if((f&63)>>>0>=32){h=g<<d;i=0}else{h=(1<<d)-1&g>>>32-d|e<<d;i=g<<d}g=b;e=64-f|0;d=e&31;if((e&63)>>>0>=32){e=0;b=c>>>d|0}else{e=c>>>d|0;b=((1<<d)-1&c)<<32-d|g>>>d}d=i|b;e=e|h;b=f&31;if((f&63)>>>0>=32){h=g<<b;b=0}else{h=(1<<b)-1&g>>>32-b|c<<b;b=g<<b}c=h}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=d;v[a+12>>2]=e}function xu(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=jb-16|0;jb=g;h=Kb(b,0);f=(w[h|0]&15)<<8|w[Kb(b,1)|0];d=0;a:{if(!f){break a}d=0;if((f|0)==4095){break a}while(1){d=108;if((e|0)==84){break a}b:{d=x[(e<<1)+32672>>1];if(d>>>0<=f>>>0){if(!e|(f|0)==(d|0)|(x[(e<<1)+32670>>1]-f|0)>=(f-d|0)){break b}d=e+24|0;break a}e=e+1|0;continue}break}d=e+25|0}t[c|0]=d;e=Kb(b,2);d=w[e|0];f=w[h|0];t[c+3|0]=0;t[c+1|0]=f&16|d>>>4;c=w[e|0];i=g,j=w[Kb(b,3)|0],t[i+15|0]=j;de(a,c&15,g+15|0);jb=g+16|0}function L3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-32|0;jb=e;d=of(e+16|0,1,0);a:{b:{while(1){f=zc(d);AJ(e+8|0,f,Gb(d)+f|0,w[b|0],c);if(!v[e+12>>2]){break b}f=ch(Gb(d));v[23588]=0;R(59,d|0,f|0);f=v[23588];v[23588]=0;if((f|0)!=1){continue}break}break a}b=v[e+8>>2];c=zc(d);v[23588]=0;R(60,d|0,b-c|0);b=v[23588];v[23588]=0;c:{if((b|0)!=1){v[23588]=0;R(61,a|0,d|0);a=v[23588];v[23588]=0;if((a|0)!=1){break c}break a}break a}yb(d);jb=e+32|0;return}a=P()|0;O()|0;yb(d);T(a|0);L()}function dy(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-48|0;jb=e;a:{if(!c){b=Jd(v[a>>2],b);a=v[d+12>>2];v[b+8>>2]=v[d+8>>2];v[b+12>>2]=a;a=v[d+4>>2];v[b>>2]=v[d>>2];v[b+4>>2]=a;break a}f=v[d+12>>2];v[e+24>>2]=v[d+8>>2];v[e+28>>2]=f;f=v[d+4>>2];v[e+16>>2]=v[d>>2];v[e+20>>2]=f;f=c>>>1|0;dy(a,b,f,e+16|0);g=A[d>>3];h=A[d+8>>3];d=Jd(v[a>>2],c);ui(e+32|0,g,h,A[d>>3],A[d+8>>3]);d=v[e+44>>2];v[e+8>>2]=v[e+40>>2];v[e+12>>2]=d;d=v[e+36>>2];v[e>>2]=v[e+32>>2];v[e+4>>2]=d;dy(a,b|c,f,e)}jb=e+48|0}function hD(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=jb-16|0;jb=f;g=v[b+16>>2];v[a+4>>2]=0;v[a>>2]=g;a:{if(!g){break a}e=b+80|0;c=v[b+84>>2];if(c>>>0<=15){d=v[e>>2]}else{v[f+12>>2]=c-16;d=v[Yc(e,f+12|0)>>2]}v[a+8>>2]=d;c=v[b+88>>2];if(!(c&2)){break a}d=c;c=v[b+104>>2];b:{if(!(!gD(d,c)|v[e>>2]!=v[c+12>>2])){e=1;d=v[b+84>>2];if((d|0)==v[c+16>>2]){break b}}e=0;d=v[b+84>>2];if((d|0)!=v[c+8>>2]){break a}}h=a,i=B((v[c>>2]-d|0)+(e?112:48)|0,Ek(x[c+34>>1]))+g|0,v[h+4>>2]=i}jb=f+16|0}function fF(a,b,c,d,e,f,g){var h=0,i=0;h=jb-16|0;jb=h;v[23588]=0;Y(952,a|0);i=v[23588];v[23588]=0;a:{b:{if((i|0)!=1){c:{i=v[v[a+24>>2]+24>>2];v[23588]=0;ma(g|0,h|0,i|0,b|0,c|0,d|0,e|0);b=v[23588];v[23588]=0;if((b|0)==1){break c}b=fg(Lc(h));yb(h);break b}}b=V(0)|0;O()|0;_(b|0)|0;b=0;v[23588]=0;X(939,f|0,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$()}jb=h+16|0;return b}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function NM(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=v[a+104>>2];e=(g<<3)+a|0;c=((g+7>>>0)%12<<3)+a|0;f=v[c>>2];c=v[c+4>>2];h=v[a+96>>2];i=v[a+100>>2];a:{if(!(h|i)){b=v[e+4>>2];d=v[e>>2];j=(b|0)==(c|0)&d>>>0>f>>>0|c>>>0<b>>>0;break a}b=v[e+4>>2];d=v[e>>2];j=!(c|f)|((b|0)==(c|0)&d>>>0>=f>>>0|c>>>0<b>>>0)}b=b+i|0;d=h+d|0;b=d>>>0<h>>>0?b+1|0:b;v[e>>2]=f-d;v[e+4>>2]=c-(b+(f>>>0<d>>>0)|0)&65535;v[a+104>>2]=(g+1>>>0)%12;v[a+96>>2]=j;v[a+100>>2]=0;mb=v[e+4>>2];return v[e>>2]}function M2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;e=To(a);v[e>>2]=61212;c=Bc(e);a=jb-16|0;jb=a;d=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=d;d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;d=jb-16|0;jb=d;b=v[a+12>>2];v[d+8>>2]=v[a+8>>2];v[d+12>>2]=b;b=v[a+4>>2];v[d>>2]=v[a>>2];v[d+4>>2]=b;b=$I(d);c=dn(c);t[c+8|0]=0;v[c+4>>2]=b;v[c>>2]=61612;Sb(c+12|0);v[c>>2]=61376;b=v[a+4>>2];v[c+24>>2]=v[a>>2];v[c+28>>2]=b;b=v[a+12>>2];v[c+32>>2]=v[a+8>>2];v[c+36>>2]=b;jb=d+16|0;jb=a+16|0;return e|0}function JJ(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=jb-16|0;jb=d;v[d+12>>2]=c;a:{if(!b){a=a+120|0;Gn(a);g=FJ(a,v[d+12>>2]),h=0,t[g+20|0]=h;break a}e=jb-16|0;jb=e;v[e+12>>2]=c;b:{if((b|0)==1){b=a+120|0;Gn(b);g=wx(b,a,v[e+12>>2]),h=1,t[g+20|0]=h;break b}f=jb-16|0;jb=f;v[f+12>>2]=c;c:{if((b|0)==2){a=a+120|0;Gn(a);a=FJ(a,v[f+12>>2]);ee(a+12|0);t[a+20|0]=2;break c}b=jb-16|0;jb=b;v[b+12>>2]=c;c=a+120|0;Gn(c);g=wx(c,a,v[b+12>>2]),h=3,t[g+20|0]=h;jb=b+16|0}jb=f+16|0}jb=e+16|0}jb=d+16|0}function t3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=jb-16|0;jb=c;a:{d=Sh(C(z[a+24>>2]*C(65536)));if((d|0)==65536){break a}j=d>>31;k=v[b>>2];g=v[b+4>>2];l=v[b+8>>2];b:while(1){if((f|0)==(l|0)){break a}m=B(f,g);e=0;while(1)if((e|0)==(g|0)){f=f+1|0;continue b}else{h=(e+m<<2)+k|0;i=v[h>>2];n=h,o=Hc(Mka(Lka(i,i>>31,d,j),mb,65536,0),mb),v[n>>2]=o;e=e+1|0;continue}}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;uJ(a,c);jb=c+16|0}function oS(a,b,c,d){var e=0,f=0,g=0;f=jb-16|0;jb=f;while(1){a:{e=x[c>>1]<<1;u[c>>1]=e;t[b|0]=(e&65534)>>>0>255;e=w[c|0];u[c>>1]=e;if(!e){if(!nf(a,f+15|0)){break a}e=w[f+15|0];u[c>>1]=e<<1|1;t[b|0]=e>>>7;u[c>>1]=w[c|0]}t[d|0]=w[b|0]+(w[d|0]<<1);e=x[c>>1]<<1;u[c>>1]=e;t[b|0]=(e&65534)>>>0>255;e=w[c|0];u[c>>1]=e;if(!e){e=nf(a,f+14|0);if(e){g=w[f+14|0];u[c>>1]=g<<1|1;t[b|0]=g>>>7;u[c>>1]=w[c|0]}if(!e){break a}if(w[b|0]){continue}break a}if(w[b|0]){continue}}break}jb=f+16|0}function k3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=jb-16|0;jb=c;a:{d=Sh(C(z[a+24>>2]*C(65536)));if((d|0)==65536){break a}j=d>>31;k=v[b>>2];g=v[b+4>>2];l=v[b+8>>2];b:while(1){if((f|0)==(l|0)){break a}m=B(f,g);e=0;while(1)if((e|0)==(g|0)){f=f+1|0;continue b}else{h=(e+m<<2)+k|0;i=v[h>>2];n=h,o=Hc(Mka(Lka(i,i>>31,d,j),mb,65536,0),mb),v[n>>2]=o;e=e+1|0;continue}}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;mJ(a,c);jb=c+16|0}function H9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=jb-48|0;jb=f;d=v[a+36>>2];Sl(v[v[d>>2]-12>>2]+d|0,0);e=v[b>>2];d=v[e+12>>2];g=v[e+8>>2];if(d|g){h=v[a+36>>2];d=v[a+20>>2]+d|0;e=v[a+16>>2];g=g+e|0;e=Xg(f+32|0,g,e>>>0>g>>>0?d+1|0:d);d=v[e+12>>2];v[f+8>>2]=v[e+8>>2];v[f+12>>2]=d;d=v[e+4>>2];v[f>>2]=v[e>>2];v[f+4>>2]=d;Xj(h,f)}d=f+16|0;me(d,v[a+36>>2]);vz(v[a+36>>2],c,v[v[b>>2]+16>>2]);c=v[b>>2];b=Lk(d,Kb(v[a+40>>2],v[c>>2]),x[c+20>>1]);Xe(a,c);_b(b);jb=f+48|0}function W2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=jb-16|0;jb=d;v[d+4>>2]=1;g=d,h=sc(56),v[g+8>>2]=h;c=To(v[d+8>>2]);v[c>>2]=61712;e=Bc(c);c=jb-16|0;jb=c;f=v[b+12>>2];v[c+8>>2]=v[b+8>>2];v[c+12>>2]=f;f=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=f;b=dn(e);v[b>>2]=62076;Sb(b+4|0);t[b+20|0]=0;v[b+16>>2]=0;v[b>>2]=61876;e=v[c+4>>2];v[b+24>>2]=v[c>>2];v[b+28>>2]=e;e=v[c+12>>2];v[b+32>>2]=v[c+8>>2];v[b+36>>2]=e;t[b+40|0]=0;jb=c+16|0;b=a;a=Vo(d);Uo(b,Bc(a),a);en(d);jb=d+16|0}function Qha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=jb-16|0;jb=e;i=e,j=zj(b),v[i>>2]=j;g=x[b>>1];c=jb-16|0;jb=c;f=a;d=Sd(a);a:{if(d){b=ic(f);while(1){a=d;d=x[a+16>>1];if(mo(g,d)){b=a;d=v[a>>2];if(d){continue}break a}if(!mo(d,g)){break a}b=a+4|0;d=v[a+4>>2];if(d){continue}break}break a}a=ic(f);b=a}v[c+12>>2]=a;a=v[b>>2];if(!a){nT(c,f,e);Jg(f,v[c+12>>2],b,v[c>>2]);a=be(c);mT(c);h=1}Ig(e+8|0,v[ec(c,a)>>2],h);jb=c+16|0;a=vd(v[e+8>>2]);jb=e+16|0;return a+4|0}function taa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=jb-32|0;jb=d;Hi(d,2,a+2|0);e=d+16|0;Ec(e,d);Cc(b+492|0,e);f=b+236|0;g=c+1|0;yb(e);c=0;while(1){if((c|0)==120){v[b>>2]=(w[a+223|0]|w[a+224|0]<<8)<<5;a=a+158|0;$L(w[a|0]&15,w[a+1|0]&15,w[a+2|0]&15,w[a+3|0]&15,w[a+4|0]&15,a+5|0,b+48|0);$L(w[a|0]>>>4|0,w[a+1|0]>>>4|0,w[a+2|0]>>>4|0,w[a+3|0]>>>4|0,w[a+4|0]>>>4|0,a+35|0,b+68|0);jb=d+32|0}else{h=cc(f,c),i=w[(a+c|0)+31|0]+g|0,u[h>>1]=i;c=c+1|0;continue}break}}function KL(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=jb-16|0;jb=e;i=e,j=zj(b),v[i>>2]=j;g=x[b>>1];c=jb-16|0;jb=c;f=a;d=Sd(a);a:{if(d){b=ic(f);while(1){a=d;d=x[a+16>>1];if(Xs(g,d)){b=a;d=v[a>>2];if(d){continue}break a}if(!Xs(d,g)){break a}b=a+4|0;d=v[a+4>>2];if(d){continue}break}break a}a=ic(f);b=a}v[c+12>>2]=a;a=v[b>>2];if(!a){nT(c,f,e);Jg(f,v[c+12>>2],b,v[c>>2]);a=be(c);mT(c);h=1}Ig(e+8|0,v[ec(c,a)>>2],h);jb=c+16|0;a=vd(v[e+8>>2]);jb=e+16|0;return a+4|0}function nW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=jb-32|0;jb=d;md(b,0);Zh(d,1,a+33|0);c=d+16|0;Ec(c,d);Be(b+43|0,c);yb(c);e=w[a+50|0]|w[a+51|0]<<8;v[b>>2]=e;v[b+24>>2]=w[a+52|0]|w[a+53|0]<<8;t[d+16|0]=w[a+54|0];t[d|0]=64;g=b,h=w[Wb(c,d)|0]<<2,u[g+30>>1]=h;f=w[a+55|0]|w[a+56|0]<<8;v[b+4>>2]=f;c=w[a+57|0]|w[a+58|0]<<8;v[b+8>>2]=c;a:{if((c|0)==65535){v[b+4>>2]=0;v[b+8>>2]=0;break a}if(!w[a|0]|c>>>0<=f+2>>>0|c>>>0>e>>>0){break a}u[b+34>>1]=x[b+34>>1]|2}jb=d+32|0}function zG(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;a:{b:{if((a|0)!=(b|0)){c:{d:{f=w[a|0];if((f|0)!=45){break d}a=a+1|0;if((b|0)!=(a|0)){break d}break c}h=v[116064];v[116064]=0;Gd();a=Aw(a,e+12|0,d);d=mb;g=v[116064];e:{if(g){if(v[e+12>>2]!=(b|0)){break c}if(!d&a>>>0>65535|d|(g|0)==68){break e}break b}v[116064]=h;if((b|0)!=v[e+12>>2]){break c}if(!d&a>>>0<65536){break b}}v[c>>2]=4;a=65535;break a}}v[c>>2]=4;a=0;break a}a=(f|0)==45?0-a|0:a}jb=e+16|0;return a&65535}function uf(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0;h=Lka(b,c,h,i);i=mb;j=h;h=Lka(d,e,f,g);e=j+h|0;d=mb+i|0;i=e;h=i>>>0<h>>>0?d+1|0:d;j=i;k=g;e=0;l=c;d=0;i=Lka(g,e,c,d);g=j+i|0;c=mb+h|0;j=g;g=g>>>0<i>>>0?c+1|0:c;h=f;i=b;f=Lka(h,0,i,0);b=mb;c=0;d=Lka(h,c,l,d);b=b+d|0;c=mb+c|0;c=b>>>0<d>>>0?c+1|0:c;h=c;c=c+j|0;d=g;d=c>>>0<h>>>0?d+1|0:d;h=c;c=d;d=Lka(i,m,k,e)+b|0;e=mb;e=b>>>0>d>>>0?e+1|0:e;g=a;i=e;h=i+h|0;v[g+8>>2]=h;v[g+12>>2]=h>>>0<i>>>0?c+1|0:c;v[g>>2]=f;v[g+4>>2]=d}function m9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=si(a,b,c,d);v[a>>2]=44076;b=Sb(a+4208|0);v[a+4236>>2]=-1;v[a+4240>>2]=0;v[a+4228>>2]=1049926264;v[a+4232>>2]=0;v[a+4220>>2]=1056964608;v[a+4224>>2]=1056964608;t[a+4244|0]=0;Tb(a+4248|0,0,48);v[23588]=0;Z(810);c=v[23588];v[23588]=0;a:{if((c|0)==1){break a}e=a,f=UM(),v[e+4296>>2]=f;Ss(a);Rs(a);v[23588]=0;R(897,a+44|0,2);c=v[23588];v[23588]=0;if((c|0)==1){break a}return a|0}c=P()|0;O()|0;hc(b);If(a);T(c|0);L()}function Yo(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if((a|0)!=(b|0)){if(!ff(w[a+11|0])){c=w[b+11|0];if(!ff(c)){d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;v[a+8>>2]=v[b+8>>2];return}d=od(b);b=yd(v[b+4>>2],c);a:{if(b>>>0<=10){ce(a,b);wd(ve(a,d,b)+b|0,0);break a}e=a;a=yf(w[a+11|0]);oq(e,10,b-10|0,a,0,a,b,d)}return}d=od(b);b=yd(v[b+4>>2],w[b+11|0]);c=uu(v[a+8>>2]);b:{if(b>>>0<c>>>0){c=v[a>>2];Fd(a,b);wd(ve(c,d,b)+b|0,0);break b}e=a;a=v[a+4>>2];oq(e,c-1|0,(b-c|0)+1|0,a,0,a,b,d)}}}function Tq(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=jb-16|0;jb=i;a:{b:{if(!a){break b}g=v[e+12>>2];h=c-b|0;if((h|0)>0){if((Pm(a,b,h)|0)!=(h|0)){break b}}b=d-b|0;b=(b|0)<(g|0)?g-b|0:0;if((b|0)>0){f=of(i,b,f);g=zc(f);v[23588]=0;g=W(23,a|0,g|0,b|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break a}yb(f);if((b|0)!=(g|0)){break b}}b=d-c|0;if((b|0)>0){if((Pm(a,c,b)|0)!=(b|0)){break b}}Co(e);j=a}jb=i+16|0;return j|0}a=P()|0;O()|0;yb(f);T(a|0);L()}function Qy(a,b,c){var d=0,e=0;d=jb-16|0;jb=d;e=v[a+480180>>2];a:{if((e|0)!=1048576){if((e|0)!=4){break a}e=w[b+813|0];if(c){t[b+813|0]=e&240|c&15;break a}c=e&15;break a}if(c){t[b+813|0]=c;break a}c=w[b+813|0]}b:{if(!(t[b+851|0]&1)|!v[b+700>>2]){break b}c=c&255;if(!c){break b}fk(a,b,b+700|0,0-(c<<2)|0,0);if(v[b+700>>2]<65536){break b}Cb(d+8|0,a+1074312|0,7);if(Bb(v[v[d+8>>2]>>2],v[d+12>>2])|(v[a+480180>>2]!=4?w[a+480208|0]&16:0)){break b}v[b+700>>2]=65535}jb=d+16|0}function CE(a,b,c,d,e,f){var g=0;a:{g=jb-48|0;jb=g;ln(g+8|0,c);v[23588]=0;c=g+20|0;R(f|0,c|0,d|0);d=v[23588];v[23588]=0;b:{c:{d:{if((d|0)==1){break d}v[23588]=0;c=g+32|0;R(113,c|0,e|0);d=v[23588];v[23588]=0;if((d|0)==1){break d}Ov(g,g+8|0);v[23588]=0;X(114,a|0,b|0,v[g>>2],v[g+4>>2]);a=v[23588];v[23588]=0;if((a|0)==1){break c}vr(g+8|0);jb=g+48|0;break a}a=P()|0;O()|0;while(1){c=zb(c-12|0);if((c|0)!=(g+8|0)){continue}break}break b}a=P()|0;O()|0;vr(g+8|0)}T(a|0);L()}}function I9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;g=jb-48|0;jb=g;e=v[a+36>>2];Sl(v[v[e>>2]-12>>2]+e|0,0);f=v[b>>2];e=v[f+12>>2];h=v[f+8>>2];if(e|h){i=v[a+36>>2];e=v[a+20>>2]+e|0;f=v[a+16>>2];h=h+f|0;f=Xg(g+32|0,h,f>>>0>h>>>0?e+1|0:e);e=v[f+12>>2];v[g+8>>2]=v[f+8>>2];v[g+12>>2]=e;e=v[f+4>>2];v[g>>2]=v[f>>2];v[g+4>>2]=e;Xj(i,g)}e=g+16|0;me(e,v[a+36>>2]);FL(d,v[a+36>>2],c);c=v[b>>2];b=Lk(e,Kb(v[a+40>>2],v[c>>2]),x[c+20>>1]);Xe(a,c);_b(b);jb=g+48|0}function G9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;g=jb-48|0;jb=g;e=v[a+36>>2];Sl(v[v[e>>2]-12>>2]+e|0,0);f=v[b>>2];e=v[f+12>>2];h=v[f+8>>2];if(e|h){i=v[a+36>>2];e=v[a+20>>2]+e|0;f=v[a+16>>2];h=h+f|0;f=Xg(g+32|0,h,f>>>0>h>>>0?e+1|0:e);e=v[f+12>>2];v[g+8>>2]=v[f+8>>2];v[g+12>>2]=e;e=v[f+4>>2];v[g>>2]=v[f>>2];v[g+4>>2]=e;Xj(i,g)}e=g+16|0;me(e,v[a+36>>2]);BL(c,v[a+36>>2],d);c=v[b>>2];b=Lk(e,Kb(v[a+40>>2],v[c>>2]),x[c+20>>1]);Xe(a,c);_b(b);jb=g+48|0}function xE(a,b,c,d){var e=0,f=0,g=0;f=jb-32|0;jb=f;e=of(f+16|0,1,0);a:{b:{while(1){g=zc(e);AJ(f+8|0,g,Gb(e)+g|0,v[b>>2],c);if(!v[f+12>>2]){break b}g=ch(Gb(e));v[23588]=0;R(59,e|0,g|0);g=v[23588];v[23588]=0;if((g|0)!=1){continue}break}break a}b=v[f+8>>2];c=zc(e);v[23588]=0;R(60,e|0,b-c|0);b=v[23588];v[23588]=0;c:{if((b|0)!=1){v[23588]=0;R(d|0,a|0,e|0);a=v[23588];v[23588]=0;if((a|0)!=1){break c}break a}break a}yb(e);jb=f+32|0;return}a=P()|0;O()|0;yb(e);T(a|0);L()}function wE(a,b,c,d){var e=0,f=0,g=0;f=jb-32|0;jb=f;e=of(f+16|0,1,0);a:{b:{while(1){g=zc(e);fJ(f+8|0,g,Gb(e)+g|0,v[b>>2],c);if(!v[f+12>>2]){break b}g=ch(Gb(e));v[23588]=0;R(59,e|0,g|0);g=v[23588];v[23588]=0;if((g|0)!=1){continue}break}break a}b=v[f+8>>2];c=zc(e);v[23588]=0;R(60,e|0,b-c|0);b=v[23588];v[23588]=0;c:{if((b|0)!=1){v[23588]=0;R(d|0,a|0,e|0);a=v[23588];v[23588]=0;if((a|0)!=1){break c}break a}break a}yb(e);jb=f+32|0;return}a=P()|0;O()|0;yb(e);T(a|0);L()}function z1(){var a=0,b=0,c=0,d=0,e=0,f=0;c=jb-48|0;jb=c;if(_H(0,c+32|0)){is(v[116064],12594);L()}a=hs(c+16|0,v[c+32>>2]);f=hs(c+8|0,v[c+36>>2]/1e3|0);b=jb-32|0;jb=b;a=_G(b+8|0,a);e=v[a>>2];d=v[a+4>>2];a=v[f+4>>2];v[b>>2]=v[f>>2];v[b+4>>2]=a;d=v[b+4>>2]+d|0;a=v[b>>2];e=e+a|0;v[b+16>>2]=e;v[b+20>>2]=a>>>0>e>>>0?d+1|0:d;a=rl(b+24|0,b+16|0);d=v[a+4>>2];a=v[a>>2];jb=b+32|0;v[c+24>>2]=a;v[c+28>>2]=d;b=rl(c+40|0,c+24|0);a=v[b+4>>2];b=v[b>>2];jb=c+48|0;mb=a;return b|0}function Vs(a,b,c){var d=0,e=0;d=(c|0)!=0;a:{b:{c:{d:{if(!(a&3)|!c){break d}e=b&255;while(1){if((e|0)==w[a|0]){break c}c=c-1|0;d=(c|0)!=0;a=a+1|0;if(!(a&3)){break d}if(c){continue}break}}if(!d){break a}if(w[a|0]==(b&255)|c>>>0<4){break c}d=B(b&255,16843009);while(1){e=d^v[a>>2];if((e^-1)&e-16843009&-2139062144){break b}a=a+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(!c){break a}}while(1){if(w[a|0]==(b&255)){return a}a=a+1|0;c=c-1|0;if(c){continue}break}}return 0}function afa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb+-64|0;jb=c;Am(c+48|0,b);re(c+16|0,v[c+48>>2],v[c+52>>2]);b=ee(c+8|0);v[23588]=0;d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;b=Eg(166,c+24|0,v[c+16>>2],v[c+20>>2],c);d=v[23588];v[23588]=0;a:{if((d|0)!=1){d=Sb(a);a=v[c+52>>2];e=v[c+48>>2];v[23588]=0;U(703,b|0,d|0,ed(e,a)>>>5|0);a=v[23588];v[23588]=0;if((a|0)==1){a=P()|0;O()|0;Di(d);Ab(b);break a}Ab(b);hc(c+48|0);jb=c- -64|0;return}a=P()|0;O()|0}hc(c+48|0);T(a|0);L()}function Zea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb+-64|0;jb=c;Am(c+48|0,b);re(c+16|0,v[c+48>>2],v[c+52>>2]);b=ee(c+8|0);v[23588]=0;d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;b=Eg(166,c+24|0,v[c+16>>2],v[c+20>>2],c);d=v[23588];v[23588]=0;a:{if((d|0)!=1){d=Sb(a);a=v[c+52>>2];e=v[c+48>>2];v[23588]=0;U(704,b|0,d|0,ed(e,a)>>>2|0);a=v[23588];v[23588]=0;if((a|0)==1){a=P()|0;O()|0;vc(d);Ab(b);break a}Ab(b);hc(c+48|0);jb=c- -64|0;return}a=P()|0;O()|0}hc(c+48|0);T(a|0);L()}function Yea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb+-64|0;jb=c;Am(c+48|0,b);re(c+16|0,v[c+48>>2],v[c+52>>2]);b=ee(c+8|0);v[23588]=0;d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;b=Eg(166,c+24|0,v[c+16>>2],v[c+20>>2],c);d=v[23588];v[23588]=0;a:{if((d|0)!=1){d=Sb(a);a=v[c+52>>2];e=v[c+48>>2];v[23588]=0;U(705,b|0,d|0,ed(e,a)>>>8|0);a=v[23588];v[23588]=0;if((a|0)==1){a=P()|0;O()|0;Ot(d);Ab(b);break a}Ab(b);hc(c+48|0);jb=c- -64|0;return}a=P()|0;O()|0}hc(c+48|0);T(a|0);L()}function Xea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb+-64|0;jb=c;Am(c+48|0,b);re(c+16|0,v[c+48>>2],v[c+52>>2]);b=ee(c+8|0);v[23588]=0;d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;b=Eg(166,c+24|0,v[c+16>>2],v[c+20>>2],c);d=v[23588];v[23588]=0;a:{if((d|0)!=1){d=Sb(a);a=v[c+52>>2];e=v[c+48>>2];v[23588]=0;U(706,b|0,d|0,ed(e,a)>>>4|0);a=v[23588];v[23588]=0;if((a|0)==1){a=P()|0;O()|0;Bm(d);Ab(b);break a}Ab(b);hc(c+48|0);jb=c- -64|0;return}a=P()|0;O()|0}hc(c+48|0);T(a|0);L()}function Py(a,b,c){var d=0,e=0;d=jb-16|0;jb=d;e=v[a+480180>>2];a:{if((e|0)!=1048576){if((e|0)!=4){break a}e=w[b+814|0];if(c){t[b+814|0]=e&240|c&15;break a}c=e&15;break a}if(c){t[b+813|0]=c;break a}c=w[b+813|0]}b:{if(!(t[b+851|0]&1)|!v[b+700>>2]){break b}c=c&255;if(!c){break b}fk(a,b,b+700|0,0-c|0,0);if(v[b+700>>2]<65536){break b}Cb(d+8|0,a+1074312|0,7);if(Bb(v[v[d+8>>2]>>2],v[d+12>>2])|(v[a+480180>>2]!=4?w[a+480208|0]&16:0)){break b}v[b+700>>2]=65535}jb=d+16|0}function tY(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0;v[23588]=0;m=a;a=b;b=0;a=Ma(1048,m|b,a|0,c|0,d|0,b|e,f|0)|0;b=v[23588];v[23588]=0;a:{b:{if((b|0)==1){a=V(0)|0;O()|0;_(a|0)|0;v[23588]=0;ia(935,8803,g|0,h|0,i|0,j|0,k|0,l|0);a=v[23588];v[23588]=0;if((a|0)==1){break b}$();a=-255}break a}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}return a|0}function Y1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=jb-16|0;jb=d;a:{g=v[c+12>>2];if(!g){break a}e=Ik(d,c+16|0);f=Fk(v[b+4>>2],w[b+11|0]);h=f-1|0;c=0;while(1){if((c|0)==(f|0)){zb(e);break a}b:{c:{if(!c|(c>>>0)%(g>>>0)){break c}if((c|0)==(h|0)){if(w[od(b)|0]==43){break c}if(w[od(b)|0]==45){break c}}v[23588]=0;W(84,b|0,f-c|0,e|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break b}}c=c+1|0;continue}break}a=P()|0;O()|0;zb(e);T(a|0);L()}$c(a,b);jb=d+16|0}function c6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0;v[23588]=0;Y(977,a|0);f=v[23588];v[23588]=0;a:{b:{if((f|0)!=1){f=v[a+28>>2];g=v[v[f>>2]+72>>2];v[23588]=0;b=Va(g|0,f|0,b|0,c|0,+d,+e)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,11218,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function PL(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=v[a>>2];c=uc(d,v[a+4>>2]);if(c>>>0<=127){f=jb-32|0;jb=f;c=128-c|0;e=v[Fb(a)>>2];d=v[a+4>>2];a:{if(c>>>0<=e-d>>2>>>0){Yx(a,c,b);break a}e=Fb(a);d=Uf(f+8|0,pg(a,uc(v[a>>2],d)+c|0),uc(v[a>>2],v[a+4>>2]),e);g=jb-16|0;jb=g;c=Vm(g,d+8|0,c);e=v[c>>2];while(1){if(v[c+4>>2]!=(e|0)){dk(e,z[b>>2]);e=v[c>>2]+4|0;v[c>>2]=e;continue}break}Td(c);jb=g+16|0;Dd(a,d);Tf(d)}jb=f+32|0;return}if((c|0)!=128){Nd(a,d+512|0)}}function vG(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;a:{if((a|0)!=(b|0)){b:{c:{f=w[a|0];if((f|0)!=45){break c}a=a+1|0;if((b|0)!=(a|0)){break c}break b}h=v[116064];v[116064]=0;Gd();a=Aw(a,e+12|0,d);d=mb;d:{g=v[116064];if(g){if(v[e+12>>2]!=(b|0)){break b}if((g|0)!=68){break d}v[c>>2]=4;b=-1;a=-1;break a}v[116064]=h;if(v[e+12>>2]==(b|0)){break d}break b}c=(f|0)==45;b=c?0-a|0:a;a=c?0-(d+((a|0)!=0)|0)|0:d;break a}}v[c>>2]=4;b=0;a=0}jb=e+16|0;mb=a;return b}function d$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=jb-16|0;jb=f;d=Gb(a);e=ad(a);g=Rh(b,c);a:{if(!g){break a}b:{if(!Zs(a,b)){if(e-d>>>0<g>>>0){rm(a,e,(d+g|0)-e|0,d,d,0,0)}e=zc(a)+d|0;while(1){if((b|0)==(c|0)){break b}ie(e,b);b=b+1|0;e=e+1|0;continue}}b=Th(f,b,c);c=Lc(b);d=Gb(b);v[23588]=0;W(1065,a|0,c|0,d|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){yb(b);break a}a=P()|0;O()|0;yb(b);T(a|0);L()}t[f+15|0]=0;ie(e,f+15|0);Qh(a,d+g|0)}jb=f+16|0;return a|0}function aaa(a,b){a=a|0;b=b|0;var c=0,d=0;a:{v[a>>2]=0;v[a+4>>2]=0;Gc(a+8|0);c=pk(v[b>>2],v[b+4>>2]);if(c){lu(a,c);$x(a,v[b>>2],v[b+4>>2],c)}v[a+20>>2]=v[b+20>>2];c=v[b+16>>2];v[a+12>>2]=v[b+12>>2];v[a+16>>2]=c;v[23588]=0;c=Q(878,a+24|0,b+24|0)|0;d=v[23588];v[23588]=0;b:{c:{if((d|0)!=1){v[23588]=0;Q(54,a+36|0,b+36|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break c}v[a+48>>2]=v[b+48>>2];break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;vc(c)}uk(a);T(b|0);L()}}function Gha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=Eb(v[b>>2]);h=Eb(v[b+4>>2]);g=jb-16|0;jb=g;v[g+8>>2]=d;while(1){a:{if(!Ob(d,h)){break a}e=jb-16|0;jb=e;f=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);t[e+8|0]=f;t[e+9|0]=f>>>8;t[e+10|0]=f>>>16;t[e+11|0]=f>>>24;f=w[d+4|0]|w[d+5|0]<<8;t[e+12|0]=f;t[e+13|0]=f>>>8;jb=e+16|0;if(x[e+8>>1]==(c|0)){break a}d=v[Mm(g+8|0)>>2];continue}break}jb=g+16|0;if(oc(d,Eb(v[b+4>>2]))){Ih(a);return}zo(a,d)}function $N(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=jb-16|0;jb=d;j=d,k=zj(b),v[j>>2]=k;c=jb-16|0;jb=c;g=Iy(a,c+12|0,w[b|0],v[b+4>>2]);b=v[g>>2];if(!b){e=jb-16|0;jb=e;b=ic(a);h=lh(c,sc(28),mh(e+8|0,b));b=v[h>>2];f=v[d>>2];i=v[f+4>>2];f=v[f>>2];v[b+24>>2]=0;v[b+16>>2]=f;v[b+20>>2]=i;j=ic(h),k=1,t[j+4|0]=k;jb=e+16|0;Jg(a,v[c+12>>2],g,v[c>>2]);b=be(c);qk(c);e=1}Ig(d+8|0,v[ec(c,b)>>2],e);jb=c+16|0;a=vd(v[d+8>>2]);jb=d+16|0;return a+8|0}function vE(a,b,c,d,e){var f=0,g=0,h=0;a:{f=jb-32|0;jb=f;h=Sb(a);b:{c:{d:{e:{while(1){a=v[b+8>>2];g=v[b>>2];v[23588]=0;a=W(156,g|0,a|0,8)|0;g=v[23588];v[23588]=0;if((g|0)==1){break c}if(!a){break d}v[23588]=0;U(e|0,f|0,b|0,c|0);a=v[23588];v[23588]=0;if((a|0)!=1){v[23588]=0;R(d|0,h|0,f|0);a=v[23588];v[23588]=0;if((a|0)==1){break e}zd(f);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;zd(f);break b}jb=f+32|0;break a}a=P()|0;O()|0}Yd(h);T(a|0);L()}}function f6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;v[23588]=0;Y(977,a|0);e=v[23588];v[23588]=0;a:{b:{if((e|0)!=1){e=v[a+28>>2];f=v[v[e>>2]+12>>2];v[23588]=0;b=fa(f|0,e|0,b|0,c|0,d|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,11363,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function b4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;b=jb-48|0;jb=b;v[b+40>>2]=e;v[b+44>>2]=f;c=gc(b+32|0,c,d);d=v[c+4>>2];v[b+8>>2]=v[c>>2];v[b+12>>2]=d;a:{a=at(a,b+8|0,b+40|0);if(a+1>>>0>=3){a=ba(8)|0;v[23588]=0;b=Q(55,b+16|0,8017)|0;c=v[23588];v[23588]=0;b:{if((c|0)!=1){a=rc(a,b);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}c=P()|0;O()|0;yb(b);break b}c=P()|0;O()|0;ca(a|0)}T(c|0);L()}jb=b+48|0;return a|0}L()}function Oda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=jb-16|0;jb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+8>>2];k=v[a+12>>2];while(1){if(d){f=v[b+12>>2]+i|0;e=t[f|0];e=((B(t[f+1|0]-e|0,v[b+8>>2]>>>10&4194048)|0)/16384|0)+(e<<8)|0;v[c>>2]=v[c>>2]+B(e,h);v[c+4>>2]=v[c+4>>2]+B(e,g);Qb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;jb=b+16|0}function rca(a,b,c){a=a|0;b=b|0;c=c|0;a:{switch(b|0){case 0:hh(a,0,c);return;case 1:hh(a,1,c);return;case 2:hh(a,2,c);return;case 3:hh(a,3,c);return;case 4:hh(a,4,c);return;case 5:hh(a,5,c);return;case 6:dP(a,23696,c);return;case 7:dP(a,24720,c);return;case 8:hh(a,6,c);return;case 9:hh(a,7,c);return;case 10:hh(a,8,c);return;case 11:hh(a,9,c);return;case 12:hh(a,10,c);return;case 13:hh(a,11,c);return;case 14:hh(a,12,c);return;default:break a}}Lb(a)}function e6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;v[23588]=0;Y(977,a|0);e=v[23588];v[23588]=0;a:{b:{if((e|0)!=1){e=v[a+28>>2];f=v[v[e>>2]+8>>2];v[23588]=0;b=fa(f|0,e|0,b|0,c|0,d|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,11399,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function WV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;a:{b:{if(!eg(a,7)){break b}c=0;if(!nC(a,17792)){break a}if(!eg(a,1)){break b}c=-1;if(!hd(a,Nq(a))){break a}c=jb-16|0;jb=c;f=d+8|0;Eo(c+8|0,f);e=v[c+12>>2];ld(c,a,v[c+8>>2],v[c+12>>2]);g=v[c+4>>2];if((g|0)==(e|0)){hd(a,v[c+12>>2])}jb=c+16|0;e=(e|0)==(g|0);if(!e){Ru(f)}c=-1;if(!e){break a}c=0;if(!aC(w[d+8|0],w[d+9|0])){break a}c=Ae(a,b,$B(d+8|0),mb);break a}c=-1}jb=d+16|0;return c|0}function ep(a,b,c,d,e){var f=0,g=0,h=0;a:{f=jb-32|0;jb=f;h=Sb(a);b:{c:{d:{e:{while(1){a=v[b+8>>2];g=v[b>>2];v[23588]=0;a=W(156,g|0,a|0,e|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break c}if(!a){break d}v[23588]=0;R(d|0,f|0,b|0);a=v[23588];v[23588]=0;if((a|0)!=1){v[23588]=0;R(c|0,h|0,f|0);a=v[23588];v[23588]=0;if((a|0)==1){break e}zd(f);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;zd(f);break b}jb=f+32|0;break a}a=P()|0;O()|0}Yd(h);T(a|0);L()}}function MX(a,b){a=a|0;b=b|0;var c=0;a=Lb(a);a:{if(w[b+16|0]){v[23588]=0;Q(133,a|0,4948)|0;c=v[23588];v[23588]=0;if((c|0)==1){break a}}if(w[b+17|0]){v[23588]=0;Q(133,a|0,12460)|0;c=v[23588];v[23588]=0;if((c|0)==1){break a}}if(rh(v[a+4>>2],w[a+11|0])){v[23588]=0;Q(133,a|0,10017)|0;c=v[23588];v[23588]=0;if((c|0)==1){break a}}if(w[b+18|0]){v[23588]=0;Q(133,a|0,11053)|0;b=v[23588];v[23588]=0;if((b|0)==1){break a}}return}b=P()|0;O()|0;zb(a);T(b|0);L()}function x1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=jb-32|0;jb=e;v[e+16>>2]=b;d=v[a+48>>2];v[e+20>>2]=c-((d|0)!=0);f=v[a+44>>2];v[e+28>>2]=d;v[e+24>>2]=f;a:{b:{if(bx(fb(v[a+60>>2],e+16|0,2,e+12|0)|0)){b=32}else{d=v[e+12>>2];if((d|0)>0){break b}b=d?32:16}v[a>>2]=b|v[a>>2];break a}g=d;f=v[e+20>>2];if(f>>>0>=d>>>0){break a}d=v[a+44>>2];v[a+4>>2]=d;v[a+8>>2]=d+(g-f|0);if(v[a+48>>2]){v[a+4>>2]=d+1;t[(b+c|0)-1|0]=w[d|0]}g=c}jb=e+32|0;return g|0}function Uaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=jb-16|0;jb=e;d=x[a+30>>1];if(d){b=On(b<<16>>16,d<<16>>16)}u[e+14>>1]=b;a=a+52|0;a:{if(!rh(v[c+4>>2],w[c+11|0])){Yo(KL(a,e+14|0),c);break a}b=Xx(a,e+14|0);if(!Hg(b,wf(a))){break a}c=jb-16|0;jb=c;b=v[ec(c,b)>>2];d=jb-16|0;jb=d;f=Kg(ec(d+8|0,b));if((b|0)==v[a>>2]){v[a>>2]=v[f>>2]}g=Fb(a);v[g>>2]=v[g>>2]-1;JL(v[ic(a)>>2],b);a=v[f>>2];jb=d+16|0;KA(vd(b));Mb(b);ec(c+8|0,a);jb=c+16|0}jb=e+16|0}function iD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{d=jb-16|0;jb=d;b:{c:{if(!b){b=Lc(c);e=b;f=Gb(c)+b|0;c=Rh(b,f);if(c>>>0<4294967280){d:{if(El(c)){ce(a,c);break d}g=Mg(c)+1|0;b=sc(g);ud(a,b);bf(a,g);Fd(a,c);a=b}while(1){if((e|0)!=(f|0)){wd(a,w[e|0]);a=a+1|0;e=e+1|0;continue}break}wd(a,0);break c}hf();L()}AP(d,b,c);v[23588]=0;R(50,a|0,d|0);a=v[23588];v[23588]=0;if((a|0)==1){break b}Fc(d)}jb=d+16|0;break a}a=P()|0;O()|0;Fc(d);T(a|0);L()}}function cF(a,b,c,d){var e=0,f=C(0);v[23588]=0;Y(952,a|0);e=v[23588];v[23588]=0;if((e|0)!=1){a=v[v[a+24>>2]+24>>2];a:{if((b|0)<0|x[a+480188>>1]<=b>>>0){break a}a=a+B(b,872)|0;if(!(t[a+1075081|0]&1)){break a}f=C(C(w[a+d|0])*C(.0078125))}return f}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,c|0,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)!=1){$();return C(0)}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function a6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;v[23588]=0;Y(977,a|0);d=v[23588];v[23588]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+64>>2];v[23588]=0;U(f|0,d|0,b|0,(c|0)!=0|0);b=v[23588];v[23588]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,6663,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function _5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;v[23588]=0;Y(977,a|0);d=v[23588];v[23588]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+56>>2];v[23588]=0;U(f|0,d|0,b|0,(c|0)!=0|0);b=v[23588];v[23588]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,6717,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function Nda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=jb-16|0;jb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+8>>2];k=v[a+12>>2];while(1){if(d){f=(v[b+12>>2]<<1)+i|0;e=u[f>>1];e=e+((B(u[f+2>>1]-e|0,v[b+8>>2]>>>18|0)|0)/16384|0)|0;v[c>>2]=v[c>>2]+B(e,h);v[c+4>>2]=v[c+4>>2]+B(e,g);Qb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;jb=b+16|0}function Gfa(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-32|0;jb=d;md(b,0);iB(d,a+1|0);c=d+16|0;Ec(c,d);Be(b+43|0,c);yb(c);v[b+24>>2]=w[a+78|0]|w[a+79|0]<<8;c=w[a+58|0]|w[a+59|0]<<8|(w[a+60|0]<<16|w[a+61|0]<<24);v[b>>2]=c;v[b+4>>2]=w[a+62|0]|w[a+63|0]<<8|(w[a+64|0]<<16|w[a+65|0]<<24);v[b+8>>2]=w[a+66|0]|w[a+67|0]<<8|(w[a+68|0]<<16|w[a+69|0]<<24);u[b+30>>1]=(w[a+73|0]<<1)+2;u[b+34>>1]=x[b+34>>1]&65533|w[a|0]>>>6&2;wc(b+8|0,c);wc(b+4|0,v[b+8>>2]);jb=d+32|0}function zC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=v[a>>2];c=Qc(d,v[a+4>>2]);if(c>>>0<b>>>0){e=jb-32|0;jb=e;b=b-c|0;c=v[Fb(a)>>2];d=v[a+4>>2];a:{if(b>>>0<=c-d>>1>>>0){sC(a,b);break a}c=Fb(a);c=Mj(e+8|0,Nj(a,Qc(v[a>>2],d)+b|0),Qc(v[a>>2],v[a+4>>2]),c);f=jb-16|0;jb=f;b=No(f,c+8|0,b);d=v[b>>2];while(1){if(v[b+4>>2]!=(d|0)){rC(d);d=v[b>>2]+2|0;v[b>>2]=d;continue}break}Td(b);jb=f+16|0;Dd(a,c);Ni(c)}jb=e+32|0;return}if(b>>>0<c>>>0){Nd(a,d+(b<<1)|0)}}function B3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=jb-16|0;jb=d;a:{g=v[c+12>>2];if(!g){break a}e=xh(d,c+16|0);f=Gb(b);h=f-1|0;c=0;while(1){if((c|0)==(f|0)){yb(e);break a}b:{c:{if(!c|(c>>>0)%(g>>>0)){break c}if((c|0)==(h|0)){if(w[Sc(b,0)|0]==43){break c}if(w[Sc(b,0)|0]==45){break c}}v[23588]=0;W(77,b|0,f-c|0,e|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break b}}c=c+1|0;continue}break}a=P()|0;O()|0;yb(e);T(a|0);L()}$c(a,b);jb=d+16|0}function dF(a,b,c,d){var e=0,f=C(0);v[23588]=0;Y(952,a|0);e=v[23588];v[23588]=0;if((e|0)!=1){a=v[v[a+24>>2]+24>>2];a:{if((b|0)<0|x[a+480188>>1]<=b>>>0){break a}a=a+B(b,872)|0;if(t[a+1075081|0]&1){break a}f=C(C(w[a+d|0])*C(.0078125))}return f}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,c|0,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)!=1){$();return C(0)}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function nc(a,b){var c=0,d=0,e=0;c=v[a+1396>>2];if((c|0)>=0){a:{b:{if((b|0)<=(c|0)){break b}if((b|0)>24){return nc(a,24)+(nc(a,b-24|0)<<24)|0}if(!c){v[a+1392>>2]=0}while(1){if((b|0)<=(c|0)){break b}c=-1;e=ps(a);d=0;if((e|0)==-1){break a}d=v[a+1396>>2];c=d+8|0;v[a+1396>>2]=c;v[a+1392>>2]=v[a+1392>>2]+(e<<d);continue}}if((b|0)>(c|0)){aa(10027,13110,1632,6833);L()}d=v[a+1392>>2];v[a+1392>>2]=d>>>b;c=c-b|0;d=d&(-1<<b^-1)}v[a+1396>>2]=c}return d}function fg(a){var b=0,c=0,d=0;d=xp(xg(a)+1|0,1);if(d){a:{c=d;b:{if((c^a)&3){b=w[a|0];break b}if(a&3){while(1){b=w[a|0];t[c|0]=b;if(!b){break a}c=c+1|0;a=a+1|0;if(a&3){continue}break}}b=v[a>>2];if((b^-1)&b-16843009&-2139062144){break b}while(1){v[c>>2]=b;b=v[a+4>>2];c=c+4|0;a=a+4|0;if(!(b-16843009&(b^-1)&-2139062144)){continue}break}}t[c|0]=b;if(!(b&255)){break a}while(1){b=w[a+1|0];t[c+1|0]=b;c=c+1|0;a=a+1|0;if(b){continue}break}}}return d}function _2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-48|0;jb=e;v[e+40>>2]=c;v[e+44>>2]=d;a=gc(e+32|0,a,b);b=v[a+4>>2];v[e+8>>2]=v[a>>2];v[e+12>>2]=b;a:{a=at(3,e+8|0,e+40|0);if(a+1>>>0>=3){b=ba(8)|0;v[23588]=0;c=Q(55,e+16|0,8017)|0;a=v[23588];v[23588]=0;b:{if((a|0)!=1){a=rc(b,c);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}a=P()|0;O()|0;ca(b|0)}T(a|0);L()}jb=e+48|0;return a|0}L()}function Ls(a){var b=0,c=0,d=0,e=0;a:{while(1){if(!a){b=0;if(v[23584]){b=Ls(v[23584])}if(!v[23508]){break a}c=b|c;a=v[23508];continue}break}d=v[a+76>>2]>=0;b:{c:{if(v[a+20>>2]==v[a+28>>2]){break c}nb[v[a+36>>2]](a,0,0)|0;if(v[a+20>>2]){break c}b=-1;if(d){break b}break a}b=v[a+8>>2];e=v[a+4>>2];if((b|0)!=(e|0)){b=e-b|0;nb[v[a+40>>2]](a,b,b>>31,1)|0}b=0;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;if(!d){break a}}}return b|c}function Jk(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=jb-16|0;jb=e;v[b>>2]=0;v[b+4>>2]=0;t[e+15|0]=0;Mh(a,e+15|0);c=w[e+15|0];f=(c&252)>>>2|0;i=-1<<(c&3)^-1;while(1){v[b>>2]=f;v[b+4>>2]=d;if(!g&(h|0)==(i|0)){jb=e+16|0}else{t[e+15|0]=0;Mh(a,e+15|0);c=v[b>>2];j=v[b+4>>2];f=w[e+15|0];d=g;g=h+1|0;d=g?d:d+1|0;h=g;g=d;k=c;d=(h<<3)-2|0;c=d&31;if((d&63)>>>0>=32){d=f<<c;c=0}else{d=(1<<c)-1&f>>>32-c;c=f<<c}f=k|c;d=d|j;continue}break}}function pM(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;d=ad(a);a:{b:{c:{f=Rh(b,c);if(d>>>0<f>>>0){if(Zs(a,b)){break c}g=d;h=f-d|0;d=Gb(a);rm(a,g,h,d,0,d,0)}d=zc(a);while(1){if((b|0)==(c|0)){break b}ie(d,b);b=b+1|0;d=d+1|0;continue}}b=Th(e,b,c);c=Lc(b);d=Gb(b);v[23588]=0;U(57,a|0,c|0,d|0);c=v[23588];v[23588]=0;if((c|0)!=1){yb(b);break a}a=P()|0;O()|0;yb(b);T(a|0);L()}t[e+15|0]=0;ie(d,e+15|0);Qh(a,f)}jb=e+16|0;return a|0}function eM(a,b,c,d,e,f,g,h){var i=0,j=0;i=jb-16|0;jb=i;v[i+12>>2]=d;a:{if(!(w[a+12|0]|w[a+13|0]<<8|(w[a+14|0]<<16|w[a+15|0]<<24))){break a}v[i+8>>2]=w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24);j=b;b=v[Jb(i+8|0,i+12|0)>>2];v[j>>2]=b;b=Cd(w[a+12|0]|w[a+13|0]<<8|(w[a+14|0]<<16|w[a+15|0]<<24),b,d);v[c>>2]=((h^1)&b>>>0<d>>>0)+b;b=x[e>>1]|f;u[e>>1]=b;if((w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24))!=1){break a}u[e>>1]=b|g}jb=i+16|0}function $w(a,b){a:{if(a){if(b>>>0<=127){break a}b:{if(!v[v[116090]>>2]){if((b&-128)==57216){break a}break b}if(b>>>0<=2047){t[a+1|0]=b&63|128;t[a|0]=b>>>6|192;return 2}if(!((b&-8192)!=57344&b>>>0>=55296)){t[a+2|0]=b&63|128;t[a|0]=b>>>12|224;t[a+1|0]=b>>>6&63|128;return 3}if(b-65536>>>0<=1048575){t[a+3|0]=b&63|128;t[a|0]=b>>>18|240;t[a+2|0]=b>>>6&63|128;t[a+1|0]=b>>>12&63|128;return 4}}v[116064]=25;a=-1}else{a=1}return a}t[a|0]=b;return 1}function k6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=jb-32|0;jb=e;v[e+24>>2]=c;c=v[dg(e+16|0,e+24|0)>>2];v[23588]=0;f=v[b+12>>2];v[e+8>>2]=v[b+8>>2];v[e+12>>2]=f;f=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=f;fa(946,a+8|0,e|0,c|0,d|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){a=WI(a);b=VI(a+88|0);c=UI(a+92|0);d=TI(a+96|0);v[a>>2]=62440;v[b>>2]=62556;v[c>>2]=62636;v[d>>2]=62676;De(e+24|0);jb=e+32|0;return a|0}a=P()|0;O()|0;De(e+24|0);T(a|0);L()}function _ea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=jb-4096|0;jb=c;Am(a,b);a:while(1){if(ed(v[a>>2],v[a+4>>2])>>>12>>>0>e>>>0){f=e<<12;b=0;d=0;while(1)if((b|0)==2048){g=f|2048;b=0;while(1){if((b|0)!=2048){h=Kb(v[a>>2],b+g|0);i=Kb(c,b<<1);d=w[h|0]+d|0;t[i|0]=d;b=b+1|0;continue}break}ph(c,vQ(c),Qf(Eb(v[a>>2]),f));e=e+1|0;continue a}else{g=Kb(v[a>>2],b+f|0);h=Kb(c,b<<1|1);d=w[g|0]+d|0;t[h|0]=d;b=b+1|0;continue}}break}jb=c+4096|0}function Y5(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;v[23588]=0;Y(977,a|0);d=v[23588];v[23588]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+48>>2];v[23588]=0;ua(f|0,d|0,b|0,+c);b=v[23588];v[23588]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,11598,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function O5(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;v[23588]=0;Y(977,a|0);d=v[23588];v[23588]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+96>>2];v[23588]=0;ua(f|0,d|0,b|0,+c);b=v[23588];v[23588]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,11536,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function M5(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;v[23588]=0;Y(977,a|0);d=v[23588];v[23588]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+88>>2];v[23588]=0;ua(f|0,d|0,b|0,+c);b=v[23588];v[23588]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,10987,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function L8(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-16|0;jb=d;c=jb-32|0;jb=c;oi(c,b);v[23588]=0;U(917,c+16|0,0,c|0);b=v[23588];v[23588]=0;a:{b:{c:{if((b|0)!=1){v[23588]=0;R(918,d|0,c+16|0);b=v[23588];v[23588]=0;if((b|0)==1){break c}Fc(c+16|0);yb(c);jb=c+32|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;Fc(c+16|0)}yb(c);T(a|0);L()}v[23588]=0;Q(915,a|0,d|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){zb(d);jb=d+16|0;return}a=P()|0;O()|0;zb(d);T(a|0);L()}function bca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=v[a>>2];d=qg(e,v[a+4>>2]);if(d>>>0<b>>>0){e=jb-32|0;jb=e;a:{b:{d=b-d|0;b=v[Fb(a)>>2];f=v[a+4>>2];c:{if(d>>>0<=b-f>>5>>>0){yz(a,d,c);break c}b=Fb(a);b=Dt(e+8|0,cq(a,qg(v[a>>2],f)+d|0),qg(v[a>>2],v[a+4>>2]),b);v[23588]=0;U(757,b|0,d|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break b}cP(a,b);wz(b)}jb=e+32|0;break a}a=P()|0;O()|0;wz(b);T(a|0);L()}return}if(b>>>0<d>>>0){fP(a,e+(b<<5)|0)}}function Ri(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=v[a>>2];c=ed(d,v[a+4>>2]);if(c>>>0<b>>>0){e=jb-32|0;jb=e;b=b-c|0;c=v[Fb(a)>>2];d=v[a+4>>2];a:{if(b>>>0<=c-d>>>0){rE(a,b);break a}c=Fb(a);c=Yl(e+8|0,Wl(a,ed(v[a>>2],d)+b|0),ed(v[a>>2],v[a+4>>2]),c);f=jb-16|0;jb=f;b=Xv(f,c+8|0,b);d=v[b>>2];while(1){if(v[b+4>>2]!=(d|0)){qE(d);d=v[b>>2]+1|0;v[b>>2]=d;continue}break}Td(b);jb=f+16|0;Dd(a,c);Xl(c)}jb=e+32|0;return}if(b>>>0<c>>>0){Nd(a,b+d|0)}}function Xga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;v[a>>2]=0;v[a+4>>2]=0;Gc(a+8|0);if(b){if(sh(178956970)>>>0<b>>>0){bd();L()}d=B(b,24);c=sc(d);v[a>>2]=c;v[a+4>>2]=c;g=Fb(a),h=c+d|0,v[g>>2]=h;d=jb-16|0;jb=d;b=kE(d,a,b);c=v[b+4>>2];e=v[b+8>>2];a:{while(1){if((c|0)==(e|0)){break a}v[23588]=0;Y(576,c|0);f=v[23588];v[23588]=0;if((f|0)!=1){c=c+24|0;v[b+4>>2]=c;continue}break}a=P()|0;O()|0;kc(b);T(a|0);L()}kc(b);jb=d+16|0}return a|0}function Wia(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=jb-32|0;jb=g;a:{if(x[a+480192>>1]<b>>>0){break a}b=v[((b<<2)+a|0)+900380>>2];if(!b){break a}h=g+16|0;UT(h,b);i=g,j=Eb(v[g+16>>2]),v[i+8>>2]=j;h=Yf(h);while(1){b=v[g+8>>2];if(Ob(b,h)){b=x[qo(b)>>1];if(b>>>0<=x[a+480190>>1]){b=B(b,104)+a|0;t[b+484421|0]=f;t[b+484418|0]=c;t[b+484420|0]=e;t[b+484419|0]=d}Kg(g+8|0);continue}else{qu(g+16|0)}break}}jb=g+32|0}function rO(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=jb-16|0;jb=e;j=e,k=zj(b),v[j>>2]=k;c=jb-16|0;jb=c;f=iz(a,c+12|0,x[b>>1],v[b+4>>2]);b=v[f>>2];if(!b){b=jb-16|0;jb=b;d=ic(a);g=lh(c,sc(36),mh(b+8|0,d));d=v[g>>2]+16|0;h=v[e>>2];i=v[h+4>>2];v[d>>2]=v[h>>2];v[d+4>>2]=i;Sb(d+8|0);j=ic(g),k=1,t[j+4|0]=k;jb=b+16|0;Jg(a,v[c+12>>2],f,v[c>>2]);b=be(c);wO(c);d=1}Ig(e+8|0,v[ec(c,b)>>2],d);jb=c+16|0;a=vd(v[e+8>>2]);jb=e+16|0;return a+8|0}function n4(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=jb-16|0;jb=h;a:{b:{c:{if(g?!f|(!d|!e):1){a=ba(8)|0;v[23588]=0;b=Q(55,h|0,8160)|0;c=v[23588];v[23588]=0;if((c|0)==1){break c}a=rc(a,b);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}d=P()|0;O()|0;yb(b);break b}dl(a,b,4);c=ux(a,c,d,e,f,g);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);jb=h+16|0;return c|0}d=P()|0;O()|0;ca(a|0)}T(d|0)}L()}function U4(a,b){a=a|0;b=b|0;var c=0,d=0;v[23588]=0;Y(952,a|0);c=v[23588];v[23588]=0;if((c|0)!=1){a=v[v[a+24>>2]+24>>2];c=0;a:{if(!ss(b)){break a}d=v[a+484344>>2];if(!xe(d,v[a+484348>>2],b&65535)){break a}c=v[Yb(d,b)+12>>2]}return c|0}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,6627,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function B4(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=jb-16|0;jb=h;a:{b:{c:{if(g?!f|(!d|!e):1){a=ba(8)|0;v[23588]=0;b=Q(55,h|0,8160)|0;c=v[23588];v[23588]=0;if((c|0)==1){break c}a=rc(a,b);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}d=P()|0;O()|0;yb(b);break b}dl(a,b,4);c=tx(a,c,d,e,f,g);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);jb=h+16|0;return c|0}d=P()|0;O()|0;ca(a|0)}T(d|0)}L()}function xV(a){a=a|0;var b=0,c=0,d=0;b=v[a>>2];if(b){hL(v[b+12>>2],b);b=v[a>>2];nb[v[v[b>>2]+8>>2]](b);v[a>>2]=0}a=a+4|0;Kc(a);b=jb-32|0;jb=b;a:{b:{d=jp(a);c=ed(v[a>>2],v[a+4>>2]);c:{if(d>>>0<=c>>>0){break c}v[23588]=0;c=fa(906,b+8|0,c|0,c|0,Fb(a)|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){Dd(a,c);Xl(c);break c}a=V(0)|0;O()|0;_(a|0)|0;v[23588]=0;Z(18);a=v[23588];v[23588]=0;if((a|0)==1){break b}}jb=b+32|0;break a}V(0)|0;O()|0;Ub();L()}}function YS(a,b){var c=0,d=0,e=0,f=0;d=v[a>>2];c=uc(d,v[a+4>>2]);if(c>>>0<b>>>0){e=jb-32|0;jb=e;b=b-c|0;c=v[Fb(a)>>2];d=v[a+4>>2];a:{if(b>>>0<=c-d>>2>>>0){DA(a,b);break a}c=Fb(a);c=Uf(e+8|0,pg(a,uc(v[a>>2],d)+b|0),uc(v[a>>2],v[a+4>>2]),c);f=jb-16|0;jb=f;b=Vm(f,c+8|0,b);d=v[b>>2];while(1){if(v[b+4>>2]!=(d|0)){Nm(d);d=v[b>>2]+4|0;v[b>>2]=d;continue}break}Td(b);jb=f+16|0;Dd(a,c);Tf(c)}jb=e+32|0;return}if(b>>>0<c>>>0){Nd(a,d+(b<<2)|0)}}function wG(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;a:{b:{if((a|0)!=(b|0)){c:{d:{f=w[a|0];if((f|0)!=45){break d}a=a+1|0;if((b|0)!=(a|0)){break d}break c}h=v[116064];v[116064]=0;Gd();a=Aw(a,e+12|0,d);d=mb;g=v[116064];e:{if(g){if(v[e+12>>2]!=(b|0)){break c}if((g|0)==68|d){break e}break b}v[116064]=h;if((b|0)!=v[e+12>>2]){break c}if(!d){break b}}v[c>>2]=4;a=-1;break a}}v[c>>2]=4;a=0;break a}a=(f|0)==45?0-a|0:a}jb=e+16|0;return a}function Lea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=jb-16|0;jb=c;d=Zc(c+8|0,16,1,1,0);v[c+4>>2]=0;md(a,0);yc(b);a:{b:{if(Sq(b,13711)){cd(b,12);if(!Bo(b)){Jo(d,2)}cd(b,24);break b}if(Fh(b,13583)){yc(b);v[c+4>>2]=4;e=1;break a}wd(d,8)}e=0}f=a,g=(cf(b)>>>0)/(B(w[d|0],nq(w[d+1|0]))>>>3>>>0)|0,v[f>>2]=g;b=vg(d,a,b);if(!(!b|!e)){d=v[a+20>>2];f=c,g=Hj(v[a>>2],x[a+34>>1]),v[f>>2]=g;Tb(d,0,v[Jb(c+4|0,c)>>2])}jb=c+16|0;return(b|0)!=0|0}function AP(a,b,c){a:{switch(b|0){case 0:ih(a,0,c);return;case 1:ih(a,1,c);return;case 2:ih(a,2,c);return;case 3:ih(a,3,c);return;case 4:ih(a,4,c);return;case 5:ih(a,5,c);return;case 6:pP(a,23696,c);return;case 7:pP(a,24720,c);return;case 8:ih(a,6,c);return;case 9:ih(a,7,c);return;case 10:ih(a,8,c);return;case 11:ih(a,9,c);return;case 12:ih(a,10,c);return;case 13:ih(a,11,c);return;case 14:ih(a,12,c);return;default:break a}}Lb(a)}function MU(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=v[a+1064>>2];a:{while(1){if((b|0)>255){break a}f=(B(b,6)+a|0)+1072|0,g=Gk(a,7),t[f|0]=g;d=Gk(a,1);e=Gk(a,1);c=v[a+1060>>2];if((c|0)>255){break a}b=v[a+1064>>2]+1|0;v[a+1060>>2]=b;v[a+1064>>2]=b;b:{if(d){u[(B(c,6)+a|0)+1068>>1]=b;MU(a);b=v[a+1064>>2];break b}u[(B(c,6)+a|0)+1068>>1]=65535}v[a+1060>>2]=b;if(e){u[(B(c,6)+a|0)+1070>>1]=b;continue}break}u[(B(c,6)+a|0)+1070>>1]=65535}}function Bha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=v[a>>2];c=Bf(d,v[a+4>>2]);if(c>>>0<b>>>0){d=jb-32|0;jb=d;a:{b:{c=b-c|0;b=v[Fb(a)>>2];e=v[a+4>>2];c:{if(c>>>0<=(b-e|0)/20>>>0){wC(a,c);break c}b=Fb(a);b=lB(d+8|0,mB(a,Bf(v[a>>2],e)+c|0),Bf(v[a>>2],v[a+4>>2]),b);v[23588]=0;R(506,b|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break b}kB(a,b);vu(b)}jb=d+32|0;break a}a=P()|0;O()|0;vu(b);T(a|0);L()}return}if(b>>>0<c>>>0){uC(a,d+B(b,20)|0)}}function d6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[23588]=0;Y(977,a|0);c=v[23588];v[23588]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+76>>2];v[23588]=0;R(e|0,c|0,b|0);b=v[23588];v[23588]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,11228,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function Q5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[23588]=0;Y(977,a|0);c=v[23588];v[23588]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+16>>2];v[23588]=0;R(e|0,c|0,b|0);b=v[23588];v[23588]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,12699,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function L5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[23588]=0;Y(977,a|0);c=v[23588];v[23588]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+84>>2];v[23588]=0;R(e|0,c|0,b|0);b=v[23588];v[23588]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,12182,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function K5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[23588]=0;Y(977,a|0);c=v[23588];v[23588]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+80>>2];v[23588]=0;R(e|0,c|0,b|0);b=v[23588];v[23588]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,11077,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function J5(a,b){a=a|0;b=+b;var c=0,d=0,e=0;v[23588]=0;Y(977,a|0);c=v[23588];v[23588]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+104>>2];v[23588]=0;oa(e|0,c|0,+b);c=v[23588];v[23588]=0;if((c|0)!=1){break b}}d=V(0)|0;O()|0;_(d|0)|0;v[23588]=0;X(939,15098,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[23588]=0;Z(18);d=v[23588];v[23588]=0;if((d|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function wF(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0;i=jb-16|0;jb=i;if(1073741806-b>>>0>=c>>>0){j=zc(a);k=1073741807;if(b>>>0<=536870886){v[i+8>>2]=b<<1;v[i+12>>2]=b+c;k=bm(v[Yc(i+12|0,i+8|0)>>2])+1|0}c=Bi(k);if(e){li(c,j,e)}if(g){li(c+(e<<2)|0,h,g)}l=e+f|0;h=d-l|0;if((d|0)!=(l|0)){d=e<<2;li((d+c|0)+(g<<2)|0,(d+j|0)+(f<<2)|0,h)}if((b|0)!=1){Mb(j)}ud(a,c);bf(a,k);b=a;a=h+(e+g|0)|0;Fd(b,a);ud(c+(a<<2)|0,0);jb=i+16|0;return}hf();L()}function v1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=jb-16|0;jb=e;while(1){a:{if((c|0)<=(f|0)){break a}g=v[a+16>>2];d=v[a+12>>2];b:{if(g>>>0>d>>>0){v[e+12>>2]=2147483647;v[e+8>>2]=g-d;v[e+4>>2]=c-f;g=d;d=v[sd(e+12|0,sd(e+8|0,e+4|0))>>2];b=ve(b,g,d);v[a+12>>2]=v[a+12>>2]+d;b=b+d|0;break b}d=nb[v[v[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}h=b,i=pp(d),t[h|0]=i;d=1;b=b+1|0}f=d+f|0;continue}break}jb=e+16|0;return f|0}function W5(a,b){a=a|0;b=+b;var c=0,d=0,e=0;v[23588]=0;Y(977,a|0);c=v[23588];v[23588]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+40>>2];v[23588]=0;oa(e|0,c|0,+b);c=v[23588];v[23588]=0;if((c|0)!=1){break b}}d=V(0)|0;O()|0;_(d|0)|0;v[23588]=0;X(939,11636,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[23588]=0;Z(18);d=v[23588];v[23588]=0;if((d|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function R5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[23588]=0;Y(977,a|0);c=v[23588];v[23588]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+20>>2];v[23588]=0;R(e|0,c|0,b|0);b=v[23588];v[23588]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,9272,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function P5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[23588]=0;Y(977,a|0);c=v[23588];v[23588]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+100>>2];v[23588]=0;d=+ta(e|0,c|0,b|0);b=v[23588];v[23588]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,11554,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();d=0}return+d}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function Z5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[23588]=0;Y(977,a|0);c=v[23588];v[23588]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+52>>2];v[23588]=0;d=+ta(e|0,c|0,b|0);b=v[23588];v[23588]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,11617,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();d=0}return+d}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function XX(a){a=a|0;var b=0,c=0,d=0,e=0;c=jb-32|0;jb=c;b=xc(c,16736);v[23588]=0;U(120,c+16|0,a|0,b|0);a=v[23588];v[23588]=0;a:{if((a|0)!=1){zb(b);a=0;b=0;while(1){d=v[c+16>>2];if(!(b>>>0<=3&xd(d,v[c+20>>2])>>>0>b>>>0)){Rl(c+16|0);jb=c+32|0;return a|0}v[23588]=0;d=S(121,Md(d,b)|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){a=(d&255)<<24-(b<<3)|a;b=b+1|0;continue}break}a=P()|0;O()|0;Rl(c+16|0);break a}a=P()|0;O()|0;zb(b)}T(a|0);L()}function U5(a,b){a=a|0;b=+b;var c=0,d=0,e=0;v[23588]=0;Y(977,a|0);c=v[23588];v[23588]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+32>>2];v[23588]=0;oa(e|0,c|0,+b);c=v[23588];v[23588]=0;if((c|0)!=1){break b}}d=V(0)|0;O()|0;_(d|0)|0;v[23588]=0;X(939,7737,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[23588]=0;Z(18);d=v[23588];v[23588]=0;if((d|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function Sq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-32|0;jb=c;a:{if(!w[b+7|0]){while(1){if((d|0)==7){d=0;t[c+27|0]=0;t[c+28|0]=0;t[c+29|0]=0;t[c+30|0]=0;v[c+24>>2]=0;e=gc(c+8|0,c+24|0,7);mc(c+16|0,v[a>>2],v[a+8>>2],v[e>>2],v[e+4>>2]);b:{if(v[c+20>>2]!=7){break b}if(Rb(c+24|0,b,7)){break b}Zb(a,7);d=1}jb=c+32|0;break a}e=b+d|0;d=d+1|0;if(w[e|0]){continue}break}aa(17430,9039,413,13074);L()}aa(17409,9039,411,13074);L()}return d|0}function S5(a,b){a=a|0;b=+b;var c=0,d=0,e=0;v[23588]=0;Y(977,a|0);c=v[23588];v[23588]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+24>>2];v[23588]=0;oa(e|0,c|0,+b);c=v[23588];v[23588]=0;if((c|0)!=1){break b}}d=V(0)|0;O()|0;_(d|0)|0;v[23588]=0;X(939,7685,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[23588]=0;Z(18);d=v[23588];v[23588]=0;if((d|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function NL(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=jb-32|0;jb=d;v[d+16>>2]=c;v[d+24>>2]=b;i=d,j=he(a),v[i+8>>2]=j;c=d+24|0;b=Nn(c,d+8|0);c=Nn(d+16|0,c);a:{if(Gb(a)>>>0>=b>>>0){if((c|0)==-1){EL(a,b);break a}f=a;e=jb-16|0;jb=e;v[e+12>>2]=c;if(c){g=Gb(f);h=zc(f);c=g-b|0;v[e+8>>2]=c;a=v[Jb(e+12|0,e+8|0)>>2];v[e+12>>2]=a;b:{if((a|0)==(c|0)){a=c;break b}b=b+h|0;Wh(b,a+b|0,c-a|0)}Vx(f,h,g-a|0)}jb=e+16|0;break a}rk();L()}jb=d+32|0}function N5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[23588]=0;Y(977,a|0);c=v[23588];v[23588]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+92>>2];v[23588]=0;d=+ta(e|0,c|0,b|0);b=v[23588];v[23588]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,11007,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();d=0}return+d}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function bea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=jb-16|0;jb=b;i=v[a+16>>2];f=Sf(1,2);g=mb;Qb(a,f,g);j=v[a+24>>2];k=v[a+20>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;e=v[a+8>>2];l=v[a+12>>2];while(1){if(d){h=u[(v[b+12>>2]<<1)+i>>1];v[c>>2]=v[c>>2]+B(h,k);v[c+4>>2]=v[c+4>>2]+B(j,h);Qb(b+8|0,e,l);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;lg(a,f,g);jb=b+16|0}function NQ(a){var b=0,c=0,d=0;b=jb-16|0;jb=b;v[b+4>>2]=((w[a+48|0]|w[a+49|0]<<8)<<1)+((w[a+32|0]|w[a+33|0]<<8)<<4);v[b+8>>2]=((w[a+50|0]|w[a+51|0]<<8)<<1)+((w[a+34|0]|w[a+35|0]<<8)<<4);v[b+12>>2]=(B(w[a+52|0]|w[a+53|0]<<8,5)+((w[a+36|0]|w[a+37|0]<<8)<<4)|0)+32;a=b+4|0;d=Db(a,3);a:{if((a|0)==(d|0)){break a}c=a;while(1){c=c+4|0;if((d|0)==(c|0)){break a}a=kp(v[a>>2],v[c>>2])?c:a;continue}}jb=b+16|0;a=v[a>>2];mb=a>>31;return a}function Ks(a,b){var c=0,d=0,e=0,f=0,g=0;e=jb-16|0;jb=e;c=Sd(a);d=ic(a);f=jb-16|0;jb=f;while(1){if(c){g=ot(c+16|0,b);d=g?d:c;c=v[(g?c+4|0:c)>>2];continue}break}c=v[ec(f+8|0,d)>>2];jb=f+16|0;a:{if(Ob(c,Yf(a))){if(!ot(b,vd(c))){break a}}c=Yf(a)}if(!oc(c,Yf(a))){b=v[ec(e+8|0,c)>>2];c=jb-16|0;jb=c;d=Kg(ec(c+8|0,b));if((b|0)==v[a>>2]){v[a>>2]=v[d>>2]}d=Fb(a);v[d>>2]=v[d>>2]-1;JL(v[ic(a)>>2],b);jb=c+16|0;wm(vd(b));Mb(b)}jb=e+16|0}function b6(a,b){a=a|0;b=b|0;var c=0,d=0;v[23588]=0;Y(977,a|0);c=v[23588];v[23588]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];d=v[v[c>>2]+68>>2];v[23588]=0;b=Q(d|0,c|0,b|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,6690,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function $5(a,b){a=a|0;b=b|0;var c=0,d=0;v[23588]=0;Y(977,a|0);c=v[23588];v[23588]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];d=v[v[c>>2]+60>>2];v[23588]=0;b=Q(d|0,c|0,b|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,6741,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function rJ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=jb-16|0;jb=g;v[g+8>>2]=b;j=g,k=he(a),v[j>>2]=k;b=Nn(g+8|0,g);h=jb-16|0;jb=h;a:{f=Gb(a);if(b>>>0<=f>>>0){if(c){e=ad(a);b:{if(e-f>>>0>=c>>>0){e=zc(a);if((b|0)==(f|0)){break b}i=b+e|0;Wh(i+c|0,i,f-b|0);break b}rm(a,e,(c+f|0)-e|0,f,b,0,c);e=v[a>>2]}zB(b+e|0,c,d);b=c+f|0;Qh(a,b);t[h+15|0]=0;ie(b+e|0,h+15|0)}jb=h+16|0;break a}rk();L()}he(a);jb=g+16|0}function ug(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;u[d+12>>1]=65535;u[d+14>>1]=b;f=d+12|0;b=x[Vc(42956,d+14|0)>>1];e=v[a>>2];c=Qc(e,v[a+4>>2]);a:{if(b>>>0>c>>>0){e=jb-32|0;jb=e;b=b-c|0;c=v[Fb(a)>>2];g=v[a+4>>2];b:{if(b>>>0<=c-g>>1>>>0){Go(a,b,f);break b}c=Fb(a);c=Mj(e+8|0,Nj(a,Qc(v[a>>2],g)+b|0),Qc(v[a>>2],v[a+4>>2]),c);KC(c,b,f);Dd(a,c);Ni(c)}jb=e+32|0;break a}if(b>>>0<c>>>0){Nd(a,e+(b<<1)|0)}}jb=d+16|0}function cea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=jb-16|0;jb=b;i=v[a+16>>2];f=Sf(1,2);g=mb;Qb(a,f,g);j=v[a+24>>2];k=v[a+20>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;e=v[a+8>>2];l=v[a+12>>2];while(1){if(d){h=t[v[b+12>>2]+i|0]<<8;v[c>>2]=v[c>>2]+B(h,k);v[c+4>>2]=v[c+4>>2]+B(j,h);Qb(b+8|0,e,l);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;lg(a,f,g);jb=b+16|0}function US(a,b,c,d,e){var f=0,g=0,h=0,i=0;h=-1;f=d&2147483647;i=f;g=(f|0)==2147418112;a:{if(g&!c?a|b:g&(c|0)!=0|f>>>0>2147418112){break a}f=e&2147483647;g=(f|0)==2147418112;if(g?0:g&0|f>>>0>2147418112){break a}if(!(a|c|(f|i|b))){return 0}f=d&e;if((f|0)>0|(f|0)>=0){if(!c&(d|0)==(e|0)?0:(d|0)<(e|0)){break a}return(a|c|(d^e|b))!=0}if(!c&(d|0)==(e|0)?a|b:(c|0)!=0&(d|0)>=(e|0)|(d|0)>(e|0)){break a}h=(a|c|(d^e|b))!=0}return h}function f_(a){a=a|0;if(w[468416]){return v[117103]}if(!w[468936]){a=468768;while(1){a=Lb(a)+12|0;if((a|0)!=468936){continue}break}t[468936]=1}qd(468768,88900);qd(468780,88928);qd(468792,88956);qd(468804,88988);qd(468816,89028);qd(468828,89064);qd(468840,89092);qd(468852,89128);qd(468864,89144);qd(468876,89160);qd(468888,89176);qd(468900,89192);qd(468912,89208);qd(468924,89224);t[468416]=1;v[117103]=468768;return 468768}function Ts(a){var b=0,c=0,d=0;b=w[a+4266|0];z[a+4236>>2]=C(b>>>0)*C(.00390625);z[a+4240>>2]=C(256-b|0)*C(.00390625);c=w[a+4267|0];b=w[a+4265|0];z[a+4244>>2]=C(B(c,b)|0)*C(152587890625e-16);d=c|-256;z[a+4256>>2]=C(B(d,b|-256)|0)*C(152587890625e-16);z[a+4252>>2]=C(B(b,d)|0)*C(152587890625e-16);z[a+4248>>2]=C(B(256-b|0,c)|0)*C(152587890625e-16);b=a;c=v[a+4232>>2];a=w[a+4264|0];v[b+4228>>2]=(B(c,(a?a:-89)&255)+250>>>0)/500}function aF(a,b,c,d,e,f,g,h,i){var j=0;v[23588]=0;Y(952,a|0);j=v[23588];v[23588]=0;a:{b:{if((j|0)!=1){j=v[a+24>>2];v[23588]=0;b=va(i|0,j|0,b|0,c|0,d|0,e|0,f|0,g|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,h|0,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();b=0}return b}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function Lfa(a){a=a|0;var b=0,c=0,d=0;b=jb-16|0;jb=b;t[b+15|0]=128;a=Om(a,127,b+15|0);v[23588]=0;t[b+14|0]=64;d=W(577,a+12|0,127,b+14|0)|0;c=v[23588];v[23588]=0;a:{b:{if((c|0)!=1){v[23588]=0;t[b+13|0]=0;Q(652,a+24|0,b+13|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break b}v[a+36>>2]=-1;v[a+40>>2]=108855296;v[a+44>>2]=0;v[a+48>>2]=0;u[a+52>>1]=0;jb=b+16|0;return a|0}b=P()|0;O()|0;break a}b=P()|0;O()|0;hc(d)}hc(a);T(b|0);L()}function gI(a){var b=0,c=C(0),d=C(0),e=C(0),f=C(0),g=C(0),h=C(0),i=0,j=0,k=0,l=C(0),m=C(0),n=C(0),o=C(0),p=0;c=z[a>>2];i=a-16|0;d=z[i>>2];e=C(c+d);b=a-8|0;f=z[b>>2];j=a-24|0;g=z[j>>2];h=C(f+g);z[a>>2]=e+h;z[b>>2]=e-h;b=a-12|0;h=z[b>>2];k=a-28|0;l=z[k>>2];e=C(h+l);p=b;b=a-4|0;m=z[b>>2];a=a-20|0;n=z[a>>2];o=C(m+n);z[p>>2]=o-e;f=C(f-g);g=C(m-n);z[k>>2]=f+g;c=C(c-d);d=C(h-l);z[i>>2]=c+d;z[j>>2]=c-d;z[b>>2]=e+o;z[a>>2]=g-f}function d4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;v[23588]=0;Y(952,a|0);d=v[23588];v[23588]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+24>>2];v[23588]=0;U(1047,d|0,b|0,c|0);b=v[23588];v[23588]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,10271,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function Cx(a,b,c,d,e){var f=0,g=0;a:{if(!ss(b)){break a}f=v[a+484344>>2];if(!xe(f,v[a+484348>>2],b&65535)){break a}b=Yb(f,b);if(v[b+12>>2]<=(c|0)|e>>>0>5|x[a+480188>>1]<=d>>>0|(c|d)<0){break a}b=id(v[b>>2],v[v[b+48>>2]+12>>2],c,d&65535);b:{c:{switch(e|0){case 1:b=b+1|0;break b;case 2:b=b+2|0;break b;case 3:b=b+3|0;break b;case 4:b=b+4|0;break b;case 0:break b;case 5:break c;default:break a}}b=b+5|0}g=w[b|0]}return g}function Ae(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=jb-16|0;jb=e;g=Vg(a);a:{b:{if(!b){i=e,j=Vg(a),v[i+8>>2]=j;v[e+12>>2]=0;break b}f=v[b+4>>2];h=v[b>>2];v[e+8>>2]=h;v[e+12>>2]=f;a=v[a+12>>2];v[e>>2]=2048;v[e+4>>2]=0;b=a+c|0;d=a>>>0>b>>>0?d+1|0:d;a=Yq(e+8|0,e);c=v[a>>2];a=v[a+4>>2];if(!a&c>>>0>g>>>0|a){a=-1;if(!d&b>>>0<=g>>>0){break b}break a}a=0;if((d|0)==(f|0)&b>>>0>h>>>0|d>>>0>f>>>0){break a}}a=1}jb=e+16|0;return a}function sY(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;v[23588]=0;a=Ka(1050,a|0,b|0,c|0,d|0)|0;b=v[23588];v[23588]=0;a:{b:{if((b|0)==1){a=V(0)|0;O()|0;_(a|0)|0;v[23588]=0;ia(935,11100,e|0,f|0,g|0,h|0,i|0,j|0);a=v[23588];v[23588]=0;if((a|0)==1){break b}$();a=-255}break a}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}return a|0}function m8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=si(a,b,c,d);v[a>>2]=45156;c=Sb(a+4256|0);b=a+4208|0;e=Db(b,0),f=1056964608,v[e>>2]=f;e=Db(b,1),f=1017370378,v[e>>2]=f;e=Db(b,2),f=1028670828,v[e>>2]=f;e=Db(b,3),f=1059760811,v[e>>2]=f;e=Db(b,4),f=1017370378,v[e>>2]=f;e=Db(b,5),f=1065353216,v[e>>2]=f;v[23588]=0;R(897,a+44|0,2);b=v[23588];v[23588]=0;if((b|0)!=1){return a|0}b=P()|0;O()|0;vc(c);If(a);T(b|0);L()}function h1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=jb-16|0;jb=e;while(1){a:{if((c|0)<=(g|0)){break a}d=v[a+12>>2];f=v[a+16>>2];b:{if(d>>>0<f>>>0){v[e+12>>2]=2147483647;v[e+8>>2]=f-d>>2;v[e+4>>2]=c-g;f=d;d=v[sd(e+12|0,sd(e+8|0,e+4|0))>>2];li(b,f,d);f=d<<2;v[a+12>>2]=f+v[a+12>>2];b=b+f|0;break b}d=nb[v[v[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}v[b>>2]=d;d=1;b=b+4|0}g=d+g|0;continue}break}jb=e+16|0;return g|0}function qia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=v[a>>2];d=pk(e,v[a+4>>2]);if(d>>>0<b>>>0){e=jb-32|0;jb=e;d=b-d|0;b=v[Fb(a)>>2];f=v[a+4>>2];a:{if(d>>>0<=(b-f|0)/6>>>0){NA(a,d,c);break a}b=Fb(a);b=iT(e+8|0,IA(a,pk(v[a>>2],f)+d|0),pk(v[a>>2],v[a+4>>2]),b);hT(b,d,c);c=b+4|0;fT(v[a>>2],v[a+4>>2],c);pc(a,c);pc(a+4|0,b+8|0);pc(Fb(a),Bc(b));v[b>>2]=v[b+4>>2];gT(b)}jb=e+32|0;return}if(b>>>0<d>>>0){Nd(a,e+B(b,6)|0)}}function h4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;v[23588]=0;Y(952,a|0);d=v[23588];v[23588]=0;a:{b:{if((d|0)!=1){d=v[a+24>>2];v[23588]=0;e=+ra(1043,d|0,b|0,c|0);b=v[23588];v[23588]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,5353,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();e=0}return+e}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function dW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;v[d+12>>2]=-1;if(zg(a,d+8|0)){v[d+4>>2]=w[d+8|0];f=v[Jb(d+4|0,d+12|0)>>2];c=jb+-64|0;jb=c;e=c+40|0;Nf(e,a,f);g=v[c+40>>2];a=c+8|0;bg(a,3,Ie(e),g);v[23588]=0;R(222,c+24|0,a|0);a=v[23588];v[23588]=0;a:{if((a|0)!=1){gc(c,b,11);a=c+24|0;Ml(c,a);yb(a);Tc(c+40|0);jb=c- -64|0;e=!f|(g|0)!=0;break a}a=P()|0;O()|0;Tc(c+40|0);T(a|0);L()}}jb=d+16|0;return e|0}function QE(a,b,c,d,e,f){var g=0,h=0;g=jb-256|0;jb=g;v[g+248>>2]=37;v[g+252>>2]=0;h=g+248|0;Qr(h|1,10537,f,v[b+4>>2]);f=Gd();v[g>>2]=d;v[g+4>>2]=e;d=g+224|0;e=$g(d,24,f,h,g)+d|0;f=_i(d,e,b);h=g+16|0;fd(h,b);v[23588]=0;ia(1153,d|0,f|0,e|0,g+32|0,g+28|0,g+24|0,h|0);d=v[23588];v[23588]=0;a:{if((d|0)!=1){$b(g+16|0);a=Or(a,g+32|0,v[g+28>>2],v[g+24>>2],b,c);jb=g+256|0;break a}a=P()|0;O()|0;$b(g+16|0);T(a|0);L()}return a}function CO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-32|0;jb=d;v[a+4>>2]=0;a:{if(b){b:{if(Ct(a)>>>0>=b>>>0){v[a+4>>2]=b;break b}e=go(d+16|0);v[23588]=0;f=Q(728,a|0,b|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break a}v[23588]=0;R(729,e|0,f|0);f=v[23588];v[23588]=0;if((f|0)==1){break a}v[e+4>>2]=b;Lt(a,e);Ve(e)}ul(d+8|0,v[a>>2]);pv(v[d+8>>2],v[d+12>>2],b,w[c|0])}jb=d+32|0;return}a=P()|0;O()|0;Ve(e);T(a|0);L()}function X5(a){a=a|0;var b=0,c=0,d=0;v[23588]=0;Y(977,a|0);b=v[23588];v[23588]=0;a:{b:{if((b|0)!=1){b=v[a+28>>2];d=v[v[b>>2]+44>>2];v[23588]=0;c=+la(d|0,b|0);b=v[23588];v[23588]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,11654,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function SE(a,b,c,d,e,f){var g=0,h=0;g=jb-112|0;jb=g;v[g+104>>2]=37;v[g+108>>2]=0;h=g+104|0;Qr(h|1,10537,f,v[b+4>>2]);f=Gd();v[g>>2]=d;v[g+4>>2]=e;d=g+80|0;e=$g(d,24,f,h,g)+d|0;f=_i(d,e,b);h=g+16|0;fd(h,b);v[23588]=0;ia(1150,d|0,f|0,e|0,g+32|0,g+28|0,g+24|0,h|0);d=v[23588];v[23588]=0;a:{if((d|0)!=1){$b(g+16|0);a=Tq(a,g+32|0,v[g+28>>2],v[g+24>>2],b,c);jb=g+112|0;break a}a=P()|0;O()|0;$b(g+16|0);T(a|0);L()}return a}function fI(a,b){var c=0,d=0,e=0;if(!w[b+21|0]){dc(a,21);return-1}if(v[a+1396>>2]<=9){$k(a)}d=v[a+1392>>2];c=u[(((d&1023)<<1)+b|0)+36>>1];a:{if((c|0)>=0){e=d;d=c&65535;c=w[d+v[b+8>>2]|0];v[a+1392>>2]=e>>>c;c=v[a+1396>>2]-c|0;v[a+1396>>2]=(c|0)>0?c:0;c=(c|0)>=0?d:-1;break a}c=hm(a,b)}if(!((c|0)>=v[b+2092>>2]?w[b+23|0]:0)){if(!(!(v[a+1384>>2]?w[a+1376|0]:1)|(c|0)>=0)){dc(a,21)}return c}aa(7526,13110,1793,5753);L()}function V5(a){a=a|0;var b=0,c=0,d=0;v[23588]=0;Y(977,a|0);b=v[23588];v[23588]=0;a:{b:{if((b|0)!=1){b=v[a+28>>2];d=v[v[b>>2]+36>>2];v[23588]=0;c=+la(d|0,b|0);b=v[23588];v[23588]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,7754,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function T5(a){a=a|0;var b=0,c=0,d=0;v[23588]=0;Y(977,a|0);b=v[23588];v[23588]=0;a:{b:{if((b|0)!=1){b=v[a+28>>2];d=v[v[b>>2]+28>>2];v[23588]=0;c=+la(d|0,b|0);b=v[23588];v[23588]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,7702,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function z4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=jb-16|0;jb=f;a:{b:{c:{if(!(e?d:0)){a=ba(8)|0;v[23588]=0;b=Q(55,f|0,8160)|0;c=v[23588];v[23588]=0;if((c|0)==1){break c}a=rc(a,b);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}e=P()|0;O()|0;yb(b);break b}dl(a,b,2);c=tx(a,c,d,e,0,0);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);jb=f+16|0;return c|0}e=P()|0;O()|0;ca(a|0)}T(e|0)}L()}function l4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=jb-16|0;jb=f;a:{b:{c:{if(!(e?d:0)){a=ba(8)|0;v[23588]=0;b=Q(55,f|0,8160)|0;c=v[23588];v[23588]=0;if((c|0)==1){break c}a=rc(a,b);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}e=P()|0;O()|0;yb(b);break b}dl(a,b,2);c=ux(a,c,d,e,0,0);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);jb=f+16|0;return c|0}e=P()|0;O()|0;ca(a|0)}T(e|0)}L()}function ix(a){var b=0,c=0,d=0;a:{b:{if(!v[a+1384>>2]){b=v[a+1380>>2];if((b|0)==-1){v[a+1388>>2]=v[a+1116>>2]-1;if(!os(a)){v[a+1384>>2]=1;return 0}if(!(t[a+1375|0]&1)){break b}b=v[a+1380>>2]}d=b+1|0;v[a+1380>>2]=d;c=w[(a+b|0)+1120|0];if((c|0)!=255){v[a+1388>>2]=b;v[a+1384>>2]=1}if(v[a+1116>>2]<=(d|0)){v[a+1380>>2]=-1}if(w[a+1376|0]){break a}t[a+1376|0]=c}return c}dc(a,32);return 0}aa(15721,13110,1564,6039);L()}function Uv(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=od(a);a=yd(v[a+4>>2],w[a+11|0]);d=od(b);b=yd(v[b+4>>2],w[b+11|0]);a:{if(a>>>0>=c>>>0){if(!b){break a}c=c+e|0;a=a+e|0;b=b+d|0;b:{if((b|0)==(d|0)){break b}c:{b=b-d|0;if((b|0)>(a-c|0)){break c}g=1-b|0;h=w[d|0];while(1){f=a-c|0;if((f|0)<(b|0)){break c}c=nu(c,g+f|0,h);if(!c){break c}if(!Rv(c,d,b)){break b}c=c+1|0;continue}}c=a}c=(a|0)==(c|0)?-1:c-e|0}else{c=-1}}return c}function TZ(a){a=a|0;if(w[468408]){return v[117101]}if(!w[468760]){a=468592;while(1){a=Lb(a)+12|0;if((a|0)!=468760){continue}break}t[468760]=1}pd(468592,5243);pd(468604,5250);pd(468616,5216);pd(468628,5224);pd(468640,5207);pd(468652,5257);pd(468664,5234);pd(468676,9708);pd(468688,9914);pd(468700,11214);pd(468712,12782);pd(468724,5506);pd(468736,10718);pd(468748,6590);t[468408]=1;v[117101]=468592;return 468592}function xba(a){a=a|0;var b=0;a=Lb(a);v[23588]=0;R(46,a|0,4);b=v[23588];v[23588]=0;a:{b:{if((b|0)==1){break b}v[23588]=0;R(47,a|0,32);b=v[23588];v[23588]=0;if((b|0)==1){break b}v[23588]=0;R(47,a|0,10);b=v[23588];v[23588]=0;if((b|0)==1){break b}v[23588]=0;R(47,a|0,13);b=v[23588];v[23588]=0;if((b|0)==1){break b}v[23588]=0;R(47,a|0,9);b=v[23588];v[23588]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;yb(a);T(b|0);L()}}
function e3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=jb-16|0;jb=c;g=v[a+4>>2];v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;hJ(a,c);a:{if(z[a+24>>2]==C(1)){break a}d=v[b+4>>2];h=v[b+8>>2];b:while(1){if((e|0)==(h|0)){break a}i=B(v[a+16>>2],e+g|0);j=v[a+12>>2];b=0;while(1)if((b|0)==(d|0)){e=e+1|0;continue b}else{f=(b+i<<2)+j|0;z[f>>2]=z[a+24>>2]*z[f>>2];b=b+1|0;continue}}}jb=c+16|0}function HI(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{b:{c:{d:{if((b|0)>=0){a=v[a+32>>2];if((Pg(a)|0)>(b|0)){break d}}b=ba(8)|0;v[23588]=0;c=Q(55,c|0,10656)|0;a=v[23588];v[23588]=0;if((a|0)==1){break c}a=rc(b,c);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}jb=c+16|0;return(v[(a+B(b,872)|0)+1075080>>2]&134218752)!=0|0}a=P()|0;O()|0;ca(b|0)}T(a|0)}L()}function $E(a,b,c,d,e,f,g){var h=0;v[23588]=0;Y(952,a|0);h=v[23588];v[23588]=0;a:{b:{if((h|0)!=1){h=v[a+24>>2];v[23588]=0;b=ja(g|0,h|0,b|0,c|0,d|0,e|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,f|0,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();b=0}return b}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function k4(a,b){a=a|0;b=b|0;var c=0,d=0;v[23588]=0;Y(952,a|0);c=v[23588];v[23588]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[23588]=0;R(1042,c|0,b|0);b=v[23588];v[23588]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,10821,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function CX(a){a=a|0;var b=0;a=Lb(a);v[23588]=0;R(73,a|0,4);b=v[23588];v[23588]=0;a:{b:{if((b|0)==1){break b}v[23588]=0;R(51,a|0,32);b=v[23588];v[23588]=0;if((b|0)==1){break b}v[23588]=0;R(51,a|0,10);b=v[23588];v[23588]=0;if((b|0)==1){break b}v[23588]=0;R(51,a|0,13);b=v[23588];v[23588]=0;if((b|0)==1){break b}v[23588]=0;R(51,a|0,9);b=v[23588];v[23588]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;zb(a);T(b|0);L()}}function n3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=jb-16|0;jb=c;g=v[a+4>>2];v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;pJ(a,c);a:{if(z[a+24>>2]==C(1)){break a}d=v[b+4>>2];h=v[b+8>>2];b:while(1){if((e|0)==(h|0)){break a}i=e+g|0;j=v[a+12>>2];b=0;while(1)if((b|0)==(d|0)){e=e+1|0;continue b}else{f=v[(b<<2)+j>>2]+(i<<2)|0;z[f>>2]=z[a+24>>2]*z[f>>2];b=b+1|0;continue}}}jb=c+16|0}function RE(a,b,c,d,e){var f=0,g=0,h=0;f=jb-160|0;jb=f;v[f+152>>2]=37;v[f+156>>2]=0;g=f+152|0;Qr(g|1,10704,e,v[b+4>>2]);e=Gd();v[f>>2]=d;d=f+139|0;e=$g(d,13,e,g,f)+d|0;g=_i(d,e,b);h=f+16|0;fd(h,b);v[23588]=0;ia(1153,d|0,g|0,e|0,f+32|0,f+28|0,f+24|0,h|0);d=v[23588];v[23588]=0;a:{if((d|0)!=1){$b(f+16|0);a=Or(a,f+32|0,v[f+28>>2],v[f+24>>2],b,c);jb=f+160|0;break a}a=P()|0;O()|0;$b(f+16|0);T(a|0);L()}return a}function pu(a,b){var c=0;c=jb-16|0;jb=c;v[c+12>>2]=b;a:{b:{switch(a|0){case 0:a=b;b=a>>31<<6|a>>>26;a=a<<6;a=Hc(Mka(a- -8192|0,b-((a>>>0<4294959104)-1|0)|0,16384,0),mb);break a;case 1:a=b>>31;a=a<<6|b>>>26;b=(b<<6)+2048|0;a=b>>>0<2048?a+1|0:a;a=Hc(Mka(b,a,4096,0),mb);break a;default:break b}}v[c+8>>2]=1;a=yl(lK(8192/+v[Oe(c+12|0,c+8|0)>>2])*24+8)}v[c+12>>2]=a;jb=c+16|0;a=(a|0)<64?a:64;return(a|0)>0?a:0}function hp(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0;i=jb-16|0;jb=i;if(-18-b>>>0>=c>>>0){j=zc(a);k=-17;if(b>>>0<=2147483622){v[i+8>>2]=b<<1;v[i+12>>2]=b+c;k=Mg(v[Yc(i+12|0,i+8|0)>>2])+1|0}c=sc(k);if(e){ve(c,j,e)}if(g){ve(c+e|0,h,g)}l=e+f|0;h=d-l|0;if((d|0)!=(l|0)){ve((c+e|0)+g|0,(e+j|0)+f|0,h)}if((b|0)!=10){Mb(j)}ud(a,c);bf(a,k);b=a;a=h+(e+g|0)|0;Fd(b,a);t[i+7|0]=0;ie(a+c|0,i+7|0);jb=i+16|0;return}hf();L()}function PA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=c;c=0;a:{if(!b){break a}if(!Pb(v[a>>2],v[a+8>>2],b)){break a}if(b>>>0<=3){c=jb-16|0;jb=c;if(Pb(v[a>>2],v[a+8>>2],b)){while(1){if((d|0)==4){_l(c,v[c+12>>2]);d=v[c>>2]}else{t[c+11|0]=0;b:{if(b>>>0>d>>>0){zg(a,c+11|0);e=t[c+11|0];g=e>>>31|0;break b}e=0-g|0}t[(c+12|0)+d|0]=e;d=d+1|0;continue}break}}jb=c+16|0;c=d;break a}c=Bg(a);Zb(a,b-4|0)}t[f|0]=c}function JI(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{b:{c:{d:{if((b|0)>=0){a=v[a+32>>2];if((Pg(a)|0)>(b|0)){break d}}b=ba(8)|0;v[23588]=0;c=Q(55,c|0,10656)|0;a=v[23588];v[23588]=0;if((a|0)==1){break c}a=rc(b,c);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}jb=c+16|0;return+(+v[(a+B(b,872)|0)+1075740>>2]*.015625)}a=P()|0;O()|0;ca(b|0)}T(a|0)}L()}function mn(a,b,c,d,e,f){var g=0;v[23588]=0;Y(952,a|0);g=v[23588];v[23588]=0;a:{b:{if((g|0)!=1){g=v[a+24>>2];v[23588]=0;b=fa(f|0,g|0,b|0,c|0,d|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,e|0,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();b=0}return b}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function h6(a){a=a|0;var b=0;v[23588]=0;Y(977,a|0);b=v[23588];v[23588]=0;if((b|0)!=1){v[a+24>>2]=0;b=v[a+28>>2];if(b){nb[v[v[b>>2]+4>>2]](b)}v[a+28>>2]=0;b=v[a+20>>2];if(b){Mb(b);v[a+20>>2]=0}Mb(a);return}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,5054,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function t1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=jb-16|0;jb=e;while(1){a:{if((c|0)<=(f|0)){break a}g=v[a+28>>2];d=v[a+24>>2];if(g>>>0<=d>>>0){if(((i=a,j=yf(t[b|0]),h=v[v[a>>2]+52>>2],nb[h](i|0,j|0)|0)|0)==-1){break a}f=f+1|0;b=b+1|0}else{v[e+12>>2]=g-d;v[e+8>>2]=c-f;g=d;d=v[sd(e+12|0,e+8|0)>>2];ve(g,b,d);v[a+24>>2]=d+v[a+24>>2];f=f+d|0;b=b+d|0}continue}break}jb=e+16|0;return f|0}function qaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=jb-32|0;jb=d;Me(d,2,a+6|0);e=d+16|0;Ec(e,d);Cc(b+492|0,e);f=b+236|0;g=c+1|0;yb(e);c=0;while(1){if((c|0)==128){v[b>>2]=(w[a+226|0]|w[a+227|0]<<8)<<5;ay(a+180|0,b+48|0,0);ay(a+228|0,b+88|0,2);ay(a+276|0,b+68|0,1);if(!(w[a+324|0]|w[a+325|0]<<8)){Tb(f,0,256)}jb=d+32|0}else{h=cc(f,c),i=w[(a+c|0)+38|0]+g|0,u[h>>1]=i;c=c+1|0;continue}break}}function fea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;a:{c=v[b+4>>2];if(!c){break a}f=a+480190|0;u[d>>1]=x[f>>1];u[d+14>>1]=c-1;c=x[Vc(d,d+14|0)>>1];while(1){if(!c){break a}Cb(d,v[b>>2],c);b:{if(Bb(v[v[d>>2]>>2],v[d+4>>2])){break b}if(yM(a,c&65535)){e=Mc(d,21619);Cc(((c<<5)+a|0)+946304|0,e);yb(e)}if(c>>>0<2){break b}e=x[f>>1];if((e|0)!=(c|0)){break b}u[f>>1]=e-1}c=c-1|0;continue}}jb=d+16|0}function SM(a,b){var c=0,d=0,e=0,f=0;c=v[a>>2];v[a>>2]=b;if(c){b=jb-16|0;jb=b;d=Eb(v[c>>2]);v[b+8>>2]=d;f=Eb(v[c+4>>2]);while(1){a:{b:{if(Ob(d,f)){while(1){a=v[d>>2];e=v[a>>2];if(!e){break b}hL(a,e);a=v[v[e>>2]+8>>2];v[23588]=0;Y(a|0,e|0);a=v[23588];v[23588]=0;if((a|0)!=1){continue}break}V(0)|0;O()|0;Ub();L()}a=vc(c);jb=b+16|0;break a}ac(a+20|0);ac(a+8|0);Mb(a);d=v[Ke(b+8|0)>>2];continue}break}Mb(a)}}function H2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=jb-32|0;jb=e;a:{if(w[b+8|0]){f=v[b+12>>2];h=e,i=ed(f,v[b+16>>2])-c|0,v[h+28>>2]=i;v[e+24>>2]=v[d+4>>2];g=v[Jb(e+28|0,e+24|0)>>2];f=Qf(Eb(f),c);c=Qf(Qf(Eb(v[b+12>>2]),c),g);b=v[d>>2];ph(f,c,b);fc(a,b,g);break a}g=v[d+4>>2];d=v[d>>2];v[e+16>>2]=d;v[e+20>>2]=g;f=v[v[b>>2]+40>>2];v[e+8>>2]=d;v[e+12>>2]=g;nb[f|0](a,b,c,e+8|0)}jb=e+32|0}function $e(a){var b=0,c=0,d=0;b=jb-16|0;jb=b;o(+a);d=j(1)|0;j(0)|0;d=d&2147483647;a:{if(d>>>0<=1072243195){c=1;if(d>>>0<1044816030){break a}c=fp(a,0);break a}c=a-a;if(d>>>0>=2146435072){break a}b:{switch(rF(a,b)&3){case 0:c=fp(A[b>>3],A[b+8>>3]);break a;case 1:c=-gp(A[b>>3],A[b+8>>3],1);break a;case 2:c=-fp(A[b>>3],A[b+8>>3]);break a;default:break b}}c=gp(A[b>>3],A[b+8>>3],1)}a=c;jb=b+16|0;return a}function gX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;f=jb-16|0;jb=f;v[f+4>>2]=1;i=f,j=sc(32),v[i+8>>2]=j;e=To(v[f+8>>2]);v[e>>2]=42968;g=Bc(e);e=jb-16|0;jb=e;b=Pl(e+8|0,v[b>>2],v[b+4>>2]);d=v[d>>2];c=v[c>>2];h=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=h;b=dn(g);v[b>>2]=43104;Pl(b+4|0,v[e>>2],v[e+4>>2]);v[b+16>>2]=d;v[b+12>>2]=c;le(e);jb=e+16|0;b=a;a=Vo(f);Uo(b,Bc(a),a);en(f);jb=f+16|0}function TE(a,b,c,d,e){var f=0,g=0,h=0;f=jb-80|0;jb=f;v[f+72>>2]=37;v[f+76>>2]=0;g=f+72|0;Qr(g|1,10704,e,v[b+4>>2]);e=Gd();v[f>>2]=d;d=f+59|0;e=$g(d,13,e,g,f)+d|0;g=_i(d,e,b);h=f+16|0;fd(h,b);v[23588]=0;ia(1150,d|0,g|0,e|0,f+32|0,f+28|0,f+24|0,h|0);d=v[23588];v[23588]=0;a:{if((d|0)!=1){$b(f+16|0);a=Tq(a,f+32|0,v[f+28>>2],v[f+24>>2],b,c);jb=f+80|0;break a}a=P()|0;O()|0;$b(f+16|0);T(a|0);L()}return a}function y$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=jb-208|0;jb=a;f=Gd();v[a>>2]=e;g=a+176|0;i=$g(g,20,f,9222,a);e=i+g|0;g=_i(g,e,c);f=a+8|0;fd(f,c);v[23588]=0;f=S(1136,f|0)|0;h=v[23588];v[23588]=0;if((h|0)!=1){$b(a+8|0);h=f;f=a+16|0;pG(h,a+176|0,e,f);h=b;b=f+(i<<2)|0;b=Or(h,f,(e|0)==(g|0)?b:((g-a<<2)+a|0)-688|0,b,c,d);jb=a+208|0;return b|0}b=P()|0;O()|0;$b(a+8|0);T(b|0);L()}function p4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;a:{b:{c:{if(!d){a=ba(8)|0;v[23588]=0;c=Q(55,e|0,8160)|0;b=v[23588];v[23588]=0;if((b|0)==1){break c}a=rc(a,c);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}b=P()|0;O()|0;yb(c);break b}dl(a,b,1);c=ux(a,c,d,0,0,0);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);jb=e+16|0;return c|0}b=P()|0;O()|0;ca(a|0)}T(b|0)}L()}function D4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;a:{b:{c:{if(!d){a=ba(8)|0;v[23588]=0;c=Q(55,e|0,8160)|0;b=v[23588];v[23588]=0;if((b|0)==1){break c}a=rc(a,c);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}b=P()|0;O()|0;yb(c);break b}dl(a,b,1);c=tx(a,c,d,0,0,0);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);jb=e+16|0;return c|0}b=P()|0;O()|0;ca(a|0)}T(b|0)}L()}function wy(a,b){a=a|0;b=b|0;var c=C(0),d=0,e=0,f=0;t[a+1074368|0]=b;KM(a+1074332|0,b);a=a+906300|0;f=ek(a);while(1){if((a|0)!=(f|0)){b=v[a>>2];if(b){c=C(1);d=v[b+20>>2];if(d){c=C(C(w[d+26|0])*C(.10000000149011612))}c=c<C(.10000000149011612)?C(1):c;if(nb[v[v[b>>2]+140>>2]](b)|0){d=v[b+16>>2];e=d+1074332|0;c=C(C(c/z[e+8>>2])*C(C(y[d+480232>>2])/z[e+20>>2]))}z[b+4196>>2]=c}a=a+160|0;continue}break}}function f4(a,b){a=a|0;b=+b;var c=0;v[23588]=0;Y(952,a|0);c=v[23588];v[23588]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[23588]=0;b=+Ya(1044,c|0,+b);c=v[23588];v[23588]=0;if((c|0)!=1){break b}}c=V(0)|0;O()|0;_(c|0)|0;v[23588]=0;X(939,7566,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();b=0}return+b}a=P()|0;O()|0;v[23588]=0;Z(18);c=v[23588];v[23588]=0;if((c|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function eia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-16|0;jb=e;c=qf(a,c);me(e,v[a+36>>2]);a:{b:{if(!c){Rc(e,a+32|0,5);d=-1;if(!Bb(v[v[e>>2]>>2],v[e+4>>2])){break b}break a}d=v[c+16>>2]}f=v[a+36>>2];c:{d:{switch(d+1|0){case 0:case 2:d=jb-32|0;jb=d;t[d+24|0]=0;Yi(d+8|0,d+24|0);vn(d+16|0,f,v[d+8>>2],v[d+12>>2]);t[b|0]=w[d+24|0];jb=d+32|0;break c;default:break d}}lT(f,b,d)}f=c}Xe(a,f);jb=e+16|0}function wt(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[b+40>>2]=0;v[b+44>>2]=0;f=b- -64|0;v[f>>2]=0;v[f+4>>2]=0;v[b+56>>2]=0;v[b+60>>2]=0;v[b+48>>2]=0;v[b+52>>2]=0;while(1){if((d|0)==1e4){a:{d=Eb(v[c>>2]);v[e+8>>2]=d;f=Eb(v[c+4>>2]);while(1){if(!Ob(d,f)){break a}g=d,h=GO(b,A[d>>3]),A[g>>3]=h;d=v[ut(e+8|0)>>2];continue}}}else{GO(b,A[af(v[c>>2],0)>>3]);d=d+1|0;continue}break}vl(a,c);jb=e+16|0}function nC(a,b){var c=0,d=0,e=0;c=jb-32|0;jb=c;a:{if(!w[b+7|0]){while(1){if((d|0)==7){d=0;t[c+27|0]=0;t[c+28|0]=0;t[c+29|0]=0;t[c+30|0]=0;v[c+24>>2]=0;e=gc(c+8|0,c+24|0,7);ld(c+16|0,a,v[e>>2],v[e+4>>2]);b:{if(v[c+20>>2]!=7){break b}if(Rb(c+24|0,b,7)){break b}hd(a,7);d=1}jb=c+32|0;break a}e=b+d|0;d=d+1|0;if(w[e|0]){continue}break}aa(17430,9039,413,13074);L()}aa(17409,9039,411,13074);L()}return d}function yI(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;d=jb-16|0;jb=d;a:{b:{c:{if(b>>>0>=256){b=ba(8)|0;v[23588]=0;d=Q(55,d|0,10656)|0;a=v[23588];v[23588]=0;if((a|0)==1){break c}a=rc(b,d);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(d);break b}e=(v[a+32>>2]+B(b,872)|0)+1075766|0,f=Qz(c*32768),u[e>>1]=f;jb=d+16|0;return}a=P()|0;O()|0;ca(b|0)}T(a|0)}L()}function _fa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;b=-1;a:{if(!eg(a,8)){break a}b=jb-32|0;jb=b;v[b+24>>2]=0;v[b+28>>2]=0;d=gc(b+8|0,b+24|0,8);ld(b+16|0,a,v[d>>2],v[d+4>>2]);b:{if(v[b+20>>2]!=8){break b}if(Rb(b+24|0,14090,8)){break b}hd(a,8);e=1}jb=b+32|0;b=0;if(!e){break a}b=-1;if(!Qj(a,c+8|0)){break a}b=0;if(!bc(v[c+12>>2])){break a}b=!(bc(v[c+8>>2])&-2139062144)}jb=c+16|0;return b|0}function _3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=jb-32|0;jb=b;c=gc(b+24|0,c,d);d=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=d;a:{a=at(a,b,0);if(a+1>>>0>=3){a=ba(8)|0;v[23588]=0;b=Q(55,b+8|0,8017)|0;c=v[23588];v[23588]=0;b:{if((c|0)!=1){a=rc(a,b);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}c=P()|0;O()|0;yb(b);break b}c=P()|0;O()|0;ca(a|0)}T(c|0);L()}jb=b+32|0;return a|0}L()}function xr(a){var b=0,c=0;hn(a,1,13515);v[23588]=0;b=ga(126)|0;c=v[23588];v[23588]=0;a:{if((c|0)==1){break a}v[a+12>>2]=b;v[23588]=0;b=ga(127)|0;c=v[23588];v[23588]=0;if((c|0)==1){break a}t[a+16|0]=b;v[23588]=0;b=ga(128)|0;c=v[23588];v[23588]=0;if((c|0)==1){break a}t[a+18|0]=0;t[a+17|0]=b;v[23588]=0;Y(129,a+20|0);b=v[23588];v[23588]=0;if((b|0)==1){break a}return}b=P()|0;O()|0;zb(a);T(b|0);L()}function so(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=jb-16|0;jb=f;v[f+12>>2]=c;a:{if(!Pb(v[b>>2],v[b+8>>2],c)){break a}wc(f+12|0,65535);ug(a,x[f+12>>1]);c=Eb(v[a>>2]);v[f>>2]=c;h=Eb(v[a+4>>2]);while(1){if(!Ob(c,h)){break a}a=f+11|0;if(!zg(b,a)){Ch(a)}a=w[f+11|0];u[c>>1]=a;g=65535;b:{if((a|0)!=(d|0)){g=65534;if((a|0)!=(e|0)){break b}}u[c>>1]=g}c=v[Re(f)>>2];continue}}jb=f+16|0}function kea(a,b){a=a|0;b=b|0;var c=0,d=0;if(y[a+4>>2]<y[Fb(a)>>2]){c=jb-16|0;jb=c;a=Iz(c,a);_l(v[a+4>>2],w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24));v[a+4>>2]=v[a+4>>2]+4;kc(a);jb=c+16|0;return}d=jb-32|0;jb=d;c=Fb(a);c=Uf(d+8|0,pg(a,uc(v[a>>2],v[a+4>>2])+1|0),uc(v[a>>2],v[a+4>>2]),c);_l(v[c+8>>2],w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24));v[c+8>>2]=v[c+8>>2]+4;Dd(a,c);Tf(c);jb=d+32|0}function BE(a,b,c,d,e){var f=0,g=0;a:{f=jb-80|0;jb=f;nA(b);g=f+56|0;Nf(g,a,c);a=v[f+56>>2];c=f+8|0;bg(c,e,Ie(g),a);v[23588]=0;R(222,f+24|0,c|0);a=v[23588];v[23588]=0;b:{c:{if((a|0)!=1){v[23588]=0;U(11,f+40|0,d|0,f+24|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}a=f+40|0;Ib(b,a);zb(a);yb(f+24|0);Tc(f+56|0);jb=f+80|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(f+24|0)}Tc(f+56|0);T(a|0);L()}}function $4(a){a=a|0;var b=0,c=0;v[23588]=0;Y(952,a|0);b=v[23588];v[23588]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[23588]=0;b=S(1020,b|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,7238,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function Ffa(a,b){a=a|0;b=b|0;var c=0,d=0;a:{a=Wz(a,b);v[23588]=0;c=Q(657,a+12|0,b+12|0)|0;d=v[23588];v[23588]=0;b:{c:{if((d|0)!=1){v[23588]=0;Q(658,a+24|0,b+24|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break c}c=v[b+40>>2];v[a+36>>2]=v[b+36>>2];v[a+40>>2]=c;u[a+52>>1]=x[b+52>>1];c=v[b+48>>2];v[a+44>>2]=v[b+44>>2];v[a+48>>2]=c;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;hc(c)}hc(a);T(b|0);L()}}function tea(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=jb-16|0;jb=b;u[b+12>>1]=0;u[b+14>>1]=1;Ef(b+14|0,x[v[v[a+24>>2]+8>>2]+12>>1]);e=b+12|0;d=jb-16|0;jb=d;c=x[b+14>>1];v[d+12>>2]=c;a:{if(Xm(a)>>>0>=c>>>0){g=v[a>>2];f=Qc(g,v[a+4>>2]);v[d+8>>2]=f;$t(g,v[Jb(d+12|0,d+8|0)>>2],e);if(c>>>0>f>>>0){Go(a,c-f|0,e);break a}Nd(a,v[a>>2]+(c<<1)|0);break a}mP(a);hq(a,Nj(a,c));Go(a,c,e)}jb=d+16|0;jb=b+16|0}function s3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=C(0),g=0,h=0,i=0,j=0,k=0,l=0;c=jb-16|0;jb=c;a:{f=z[a+24>>2];if(f==C(1)){break a}i=v[b>>2];j=+f;g=v[b+4>>2];k=v[b+8>>2];b:while(1){if((e|0)==(k|0)){break a}l=B(e,g);d=0;while(1)if((d|0)==(g|0)){e=e+1|0;continue b}else{h=(d+l<<3)+i|0;A[h>>3]=A[h>>3]*j;d=d+1|0;continue}}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;tJ(a,c);jb=c+16|0}function qd(a,b){var c=0,d=0,e=0,f=0,g=0;a:{e=KG(b);c=tn(a);if(e>>>0<=c>>>0){f=zc(a);d=f;c=e;if(c){b:{if((b|0)==(d|0)){break b}if(d-b>>>0>=c<<2>>>0){if(!c){break b}while(1){v[d>>2]=v[b>>2];d=d+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}break b}if(!c){break b}while(1){c=c-1|0;g=c<<2;v[g+d>>2]=v[b+g>>2];if(c){continue}break}}}Qh(a,e);ud((e<<2)+f|0,0);break a}d=a;a=Gb(a);wF(d,c,e-c|0,a,0,a,e,b)}}function m5(a){a=a|0;var b=0,c=0;v[23588]=0;Y(952,a|0);b=v[23588];v[23588]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[23588]=0;c=+la(1011,b|0);b=v[23588];v[23588]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,7638,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function m3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=C(0),g=0,h=0,i=0,j=0,k=0,l=0;c=jb-16|0;jb=c;a:{f=z[a+24>>2];if(f==C(1)){break a}i=v[b>>2];j=+f;g=v[b+4>>2];k=v[b+8>>2];b:while(1){if((e|0)==(k|0)){break a}l=B(e,g);d=0;while(1)if((d|0)==(g|0)){e=e+1|0;continue b}else{h=(d+l<<3)+i|0;A[h>>3]=A[h>>3]*j;d=d+1|0;continue}}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;nJ(a,c);jb=c+16|0}function j3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=C(0),g=0,h=0,i=0,j=0,k=0,l=0;c=jb-16|0;jb=c;a:{f=z[a+24>>2];if(f==C(1)){break a}i=v[b>>2];j=+f;g=v[b+4>>2];k=v[b+8>>2];b:while(1){if((e|0)==(k|0)){break a}l=B(e,g);d=0;while(1)if((d|0)==(g|0)){e=e+1|0;continue b}else{h=(d+l<<3)+i|0;A[h>>3]=A[h>>3]*j;d=d+1|0;continue}}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;lJ(a,c);jb=c+16|0}function d3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=C(0),g=0,h=0,i=0,j=0,k=0,l=0;c=jb-16|0;jb=c;a:{f=z[a+24>>2];if(f==C(1)){break a}i=v[b>>2];j=+f;g=v[b+4>>2];k=v[b+8>>2];b:while(1){if((e|0)==(k|0)){break a}l=B(e,g);d=0;while(1)if((d|0)==(g|0)){e=e+1|0;continue b}else{h=(d+l<<3)+i|0;A[h>>3]=A[h>>3]*j;d=d+1|0;continue}}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;gJ(a,c);jb=c+16|0}function KS(a){var b=0;a:{if(Rb(a,14231,3)|(w[a+3|0]-52&255)>>>0<252){break a}if(bc(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))+788>>>0<840){break a}if(bc(w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24))>>>0<52){break a}if(bc(w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24))-1>>>0<51){break a}b=bc(w[a+32|0]|w[a+33|0]<<8|(w[a+34|0]<<16|w[a+35|0]<<24))>>>0<4294967216}return b}function BR(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-32|0;jb=c;a:{if(!w[b+8|0]){while(1){if((d|0)==8){v[c+24>>2]=0;v[c+28>>2]=0;d=gc(c+8|0,c+24|0,8);mc(c+16|0,v[a>>2],v[a+8>>2],v[d>>2],v[d+4>>2]);d=0;b:{if(v[c+20>>2]!=8){break b}if(Rb(c+24|0,b,8)){break b}Zb(a,8);d=1}jb=c+32|0;break a}e=b+d|0;d=d+1|0;if(w[e|0]){continue}break}aa(17430,9039,413,13074);L()}aa(17409,9039,411,13074);L()}return d|0}function Ci(a){var b=0,c=0;b=jb-16|0;jb=b;o(+a);c=j(1)|0;j(0)|0;c=c&2147483647;a:{if(c>>>0<=1072243195){if(c>>>0<1045430272){break a}a=gp(a,0,0);break a}if(c>>>0>=2146435072){a=a-a;break a}b:{switch(rF(a,b)&3){case 0:a=gp(A[b>>3],A[b+8>>3],1);break a;case 1:a=fp(A[b>>3],A[b+8>>3]);break a;case 2:a=-gp(A[b>>3],A[b+8>>3],1);break a;default:break b}}a=-fp(A[b>>3],A[b+8>>3])}jb=b+16|0;return a}function XV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;v[a>>2]=0;v[a+4>>2]=0;if(!Pb(v[b>>2],v[b+8>>2],c)){c=cf(b)}v[a>>2]=c;c=v[b>>2];a:{if(nb[v[v[c>>2]+16>>2]](c)|0){c=a;a=v[b>>2];e=c,f=(nb[v[v[a>>2]+20>>2]](a)|0)+v[b+8>>2]|0,v[e+4>>2]=f;break a}Ri(a+8|0,v[a>>2]);c=v[a+8>>2];a=v[a+12>>2];if(oc(c,a)){break a}re(d+8|0,c,a);mc(d,v[b>>2],v[b+8>>2],v[d+8>>2],v[d+12>>2])}jb=d+16|0}function I$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=jb-96|0;jb=a;f=Gd();v[a>>2]=e;g=a- -64|0;i=$g(g,20,f,9222,a);e=i+g|0;g=_i(g,e,c);f=a+8|0;fd(f,c);v[23588]=0;f=S(19,f|0)|0;h=v[23588];v[23588]=0;if((h|0)!=1){$b(a+8|0);h=f;f=a+16|0;tG(h,a- -64|0,e,f);h=b;b=f+i|0;b=Tq(h,f,(e|0)==(g|0)?b:((g-a|0)+a|0)-48|0,b,c,d);jb=a+96|0;return b|0}b=P()|0;O()|0;$b(a+8|0);T(b|0);L()}function uG(a,b,c){var d=0,e=0,f=C(0),g=0,h=C(0);e=jb-16|0;jb=e;a:{b:{c:{if((a|0)!=(b|0)){g=v[116064];v[116064]=0;Gd();d=jb-16|0;jb=d;Ew(d,a,e+12|0,0);f=oF(v[d>>2],v[d+4>>2],v[d+8>>2],v[d+12>>2]);jb=d+16|0;a=v[116064];if(!a){break c}if(v[e+12>>2]!=(b|0)){break b}h=f;if((a|0)!=68){break a}break b}v[c>>2]=4;break a}v[116064]=g;if(v[e+12>>2]==(b|0)){break a}}v[c>>2]=4;f=h}jb=e+16|0;return f}function qx(a,b,c){var d=0,e=0;d=jb-32|0;jb=d;a:{if(w[a+20|0]){break a}b=b+c|0;b=b>>>0<c>>>0?-1:b;c=v[a+16>>2];if(b>>>0<=c>>>0){break a}b=bJ(b,4096);aJ(a,b-c|0);c=v[a+16>>2];b=gc(d+16|0,Kb(v[a+4>>2],c),b-c|0);c=v[v[a>>2]+44>>2];e=v[b+4>>2];v[d+8>>2]=v[b>>2];v[d+12>>2]=e;nb[c|0](d+24|0,a,d+8|0);v[a+16>>2]=v[a+16>>2]+v[d+28>>2];if(!(nb[v[v[a>>2]+40>>2]](a)|0)){break a}t[a+20|0]=1}jb=d+32|0}function oq(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0;i=jb-16|0;jb=i;if(-18-b>>>0>=c>>>0){j=od(a);k=-17;if(b>>>0<=2147483622){v[i+8>>2]=b<<1;v[i+12>>2]=b+c;k=Mg(v[Yc(i+12|0,i+8|0)>>2])+1|0}c=sc(k);if(e){ve(c,j,e)}if(g){ve(c+e|0,h,g)}l=e+f|0;h=d-l|0;if((d|0)!=(l|0)){ve((c+e|0)+g|0,(e+j|0)+f|0,h)}if((b|0)!=10){Mb(j)}ud(a,c);bf(a,k);b=a;a=h+(e+g|0)|0;Fd(b,a);wd(a+c|0,0);jb=i+16|0;return}hf();L()}function NB(a,b,c){var d=0,e=0,f=0;d=v[c+16>>2];a:{if(!d){if(oC(c)){break a}d=v[c+16>>2]}f=v[c+20>>2];if(d-f>>>0<b>>>0){return nb[v[c+36>>2]](c,a,b)|0}b:{if(v[c+80>>2]<0){d=0;break b}e=b;while(1){d=e;if(!d){d=0;break b}e=d-1|0;if(w[e+a|0]!=10){continue}break}e=nb[v[c+36>>2]](c,a,d)|0;if(e>>>0<d>>>0){break a}a=a+d|0;b=b-d|0;f=v[c+20>>2]}tc(f,a,b);v[c+20>>2]=v[c+20>>2]+b;e=b+d|0}return e}function gS(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+24|0]=0;t[a+25|0]=0;t[a+26|0]=0;t[a+27|0]=0;t[a+28|0]=0;t[a+29|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function aQ(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+24|0]=0;t[a+25|0]=0;t[a+26|0]=0;t[a+27|0]=0;t[a+28|0]=0;t[a+29|0]=0;t[a+30|0]=0;t[a+31|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function M1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=od(c);c=yd(v[c+4>>2],w[c+11|0]);a:{d=yd(v[a+4>>2],w[a+11|0]);if(d>>>0>=b>>>0){e=xl(a);if(c>>>0<=e-d>>>0){if(!c){break a}e=od(a);h=e+b|0;if((b|0)!=(d|0)){g=b+e|0;Wh(c+g|0,g,d-b|0);f=(f>>>0>=g>>>0?d+e>>>0>f>>>0?c:0:0)+f|0}Wh(h,f,c);b=c+d|0;sq(a,b);wd(b+e|0,0);break a}oq(a,e,(c+d|0)-e|0,d,b,0,c,f);break a}rk();L()}return a|0}function Jja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;fc(c+8|0,b,15);d=v[c+12>>2];mc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){Zb(a,v[c+12>>2])}jb=c+16|0;if((d|0)!=(e|0)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0}}function Y7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=si(a,b,c,d);v[a>>2]=45776;b=Sb(a+4208|0);v[a+4240>>2]=0;v[a+4244>>2]=0;c=v[c+24620>>2];v[a+4260>>2]=0;v[a+4256>>2]=c;v[a+4236>>2]=0;c=a+4228|0;v[c>>2]=1048576e3;v[c+4>>2]=1048576e3;v[a+4220>>2]=1056964608;v[a+4224>>2]=1056964608;v[23588]=0;R(897,a+44|0,2);c=v[23588];v[23588]=0;if((c|0)!=1){return a|0}c=P()|0;O()|0;vc(b);If(a);T(c|0);L()}function Qja(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;v[a>>2]=0;v[a+4>>2]=0;Gc(a+8|0);if(sh(1073741823)>>>0<=8191){bd();L()}b=sc(32768);v[a>>2]=b;v[a+4>>2]=b;e=Fb(a),f=b+32768|0,v[e>>2]=f;b=jb-16|0;jb=b;v[b>>2]=a;c=v[a+4>>2];v[b+4>>2]=c;v[b+8>>2]=c+32768;c=v[b+4>>2];d=v[b+8>>2];while(1){if((c|0)==(d|0)){kc(b);jb=b+16|0}else{u[c>>1]=0;u[c+2>>1]=0;c=c+4|0;v[b+4>>2]=c;continue}break}return a|0}function Dha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;fc(c+8|0,b,14);d=v[c+12>>2];mc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){Zb(a,v[c+12>>2])}jb=c+16|0;if((d|0)!=(e|0)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0}}function sG(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;a:{b:{c:{if((a|0)!=(b|0)){g=v[116064];v[116064]=0;Gd();d=jb-16|0;jb=d;Ew(d,a,e+12|0,1);f=Hw(v[d>>2],v[d+4>>2],v[d+8>>2],v[d+12>>2]);jb=d+16|0;a=v[116064];if(!a){break c}if(v[e+12>>2]!=(b|0)){break b}h=f;if((a|0)!=68){break a}break b}v[c>>2]=4;break a}v[116064]=g;if(v[e+12>>2]==(b|0)){break a}}v[c>>2]=4;f=h}jb=e+16|0;return f}function gH(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-32|0;jb=d;e=Mc(d,c);v[23588]=0;U(1108,d+16|0,b|0,e|0);c=v[23588];v[23588]=0;a:{b:{if((c|0)!=1){v[23588]=0;a=Q(1109,a|0,d+16|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break b}yb(d+16|0);yb(e);v[a>>2]=92220;c=v[b+4>>2];v[a+8>>2]=v[b>>2];v[a+12>>2]=c;jb=d+32|0;return a|0}c=P()|0;O()|0;break a}c=P()|0;O()|0;yb(d+16|0)}yb(e);T(c|0);L()}function _E(a,b,c,d,e){var f=0;f=jb-16|0;jb=f;a:{b:{c:{if(!d){a=ba(8)|0;v[23588]=0;c=Q(55,f|0,8160)|0;b=v[23588];v[23588]=0;if((b|0)==1){break c}a=rc(a,c);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}b=P()|0;O()|0;yb(c);break b}dl(a,b,e);c=WE(a,c,e,d,60384,61156);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);jb=f+16|0;return c}b=P()|0;O()|0;ca(a|0)}T(b|0)}L()}function ZE(a,b,c,d,e){var f=0;f=jb-16|0;jb=f;a:{b:{c:{if(!d){a=ba(8)|0;v[23588]=0;c=Q(55,f|0,8160)|0;b=v[23588];v[23588]=0;if((b|0)==1){break c}a=rc(a,c);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}b=P()|0;O()|0;yb(c);break b}dl(a,b,e);c=WE(a,c,e,d,59556,60328);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);jb=f+16|0;return c}b=P()|0;O()|0;ca(a|0)}T(b|0)}L()}function QI(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;a:{b:{c:{if(b<=0|b>4){a=ba(8)|0;v[23588]=0;c=Q(55,c|0,7814)|0;d=v[23588];v[23588]=0;if((d|0)==1){break c}a=rc(a,c);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}d=P()|0;O()|0;yb(c);break b}a=v[a+32>>2];e=a,f=Pe(65536/b),v[e+480244>>2]=f;Mp(a);jb=c+16|0;return}d=P()|0;O()|0;ca(a|0)}T(d|0)}L()}function OI(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;a:{b:{c:{if(b<=0|b>4){a=ba(8)|0;v[23588]=0;c=Q(55,c|0,7835)|0;d=v[23588];v[23588]=0;if((d|0)==1){break c}a=rc(a,c);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}d=P()|0;O()|0;yb(c);break b}a=v[a+32>>2];e=a,f=Pe(b*65536),v[e+480240>>2]=f;Mp(a);jb=c+16|0;return}d=P()|0;O()|0;ca(a|0)}T(d|0)}L()}function x9(a){a=a|0;var b=0,c=0;b=v[a+20>>2];v[b+148>>2]=-1;v[23588]=0;R(285,b+4|0,8);b=v[23588];v[23588]=0;if((b|0)!=1){b=v[a+4264>>2];c=v[v[a+20>>2]+4>>2];a=v[a+4260>>2];t[c|0]=a;t[c+1|0]=a>>>8;t[c+2|0]=a>>>16;t[c+3|0]=a>>>24;t[c+4|0]=b;t[c+5|0]=b>>>8;t[c+6|0]=b>>>16;t[c+7|0]=b>>>24;return}b=V(92948)|0;if((O()|0)==(da(92948)|0)){_(b|0)|0;Kc(v[a+20>>2]+4|0);$();return}T(b|0);L()}function DI(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{b:{c:{if(b>>>0>=256){b=ba(8)|0;v[23588]=0;c=Q(55,c|0,10656)|0;a=v[23588];v[23588]=0;if((a|0)==1){break c}a=rc(b,c);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}a=v[a+32>>2]+B(b,872)|0;v[a+1075008>>2]=0;v[a+1075068>>2]=0;jb=c+16|0;return}a=P()|0;O()|0;ca(b|0)}T(a|0)}L()}function Xja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;a:{e=Le(a);b:{if(e>>>0>1){break b}c:{if(e){v[23588]=0;U(329,d|0,a|0,c|0);a=v[23588];v[23588]=0;if((a|0)!=1){Km(b,d);hc(d);break c}a=V(30480)|0;if((O()|0)!=(da(30480)|0)){break a}_(a|0)|0;$();break b}if(!Pb(v[a>>2],v[a+8>>2],c)){break b}Yu(a,b,c)}f=ed(v[b>>2],v[b+4>>2])>>>0>=c>>>0}jb=d+16|0;return f|0}T(a|0);L()}function Xi(a,b,c,d,e){var f=0,g=0,h=0;f=jb-16|0;jb=f;v[f+8>>2]=b;b=0;g=6;a:{b:{if(cj(a,f+8|0)){break b}h=Yk(v[a>>2]);g=4;if(!uh(v[d+8>>2],64,h)){break b}b=wn(d,h);while(1){c:{b=b-48|0;h=em(a);if(!op(h,f+8|0)|(e|0)<2){break c}g=Yk(v[h>>2]);if(!uh(v[d+8>>2],64,g)){break a}e=e-1|0;b=wn(d,g)+B(b,10)|0;continue}break}g=2;if(!cj(h,f+8|0)){break a}}v[c>>2]=v[c>>2]|g}jb=f+16|0;return b}function zI(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{b:{c:{if(b>>>0>=256){b=ba(8)|0;v[23588]=0;c=Q(55,c|0,10656)|0;a=v[23588];v[23588]=0;if((a|0)==1){break c}a=rc(b,c);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}jb=c+16|0;return+(+(v[(v[a+32>>2]+B(b,872)|0)+1075684>>2]-128|0)*.0078125)}a=P()|0;O()|0;ca(b|0)}T(a|0)}L()}function s1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=a+32|0;Mq(c,b);v[a+44>>2]=0;b=v[a+48>>2];if(b&8){b=zc(c)+Gb(c)|0;v[a+44>>2]=b;d=zc(c);An(a,d,d,b);b=v[a+48>>2]}a:{if(!(b&16)){break a}b=Gb(c);e=a,f=b+zc(c)|0,v[e+44>>2]=f;Ix(c,ad(c));d=zc(c);Pw(a,d,Gb(c)+d|0);if(!(w[a+48|0]&3)){break a}while(1){if((b|0)<0){bs(a,2147483647);b=b-2147483647|0;continue}break}if(!b){break a}bs(a,b)}}function _4(a){a=a|0;var b=0,c=0,d=0,e=0;c=jb-32|0;jb=c;a:{e=a+36|0;b=v[e>>2];d=v[a+40>>2];b:{if(Ob(b,d)){Gc(c+24|0);break b}b=c+8|0;In(b,a);v[23588]=0;b=S(1012,b|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break a}v[c+24>>2]=b;Wf(c+8|0);d=v[a+40>>2];b=v[a+36>>2]}if(!Ob(b,d)){e=v[c+24>>2];b=v[e>>2]}a=Qi(b,v[e+4>>2]);al(c+24|0);jb=c+32|0;return a|0}a=P()|0;O()|0;Wf(c+8|0);T(a|0);L()}function Fh(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-32|0;jb=c;a:{if(!w[b+4|0]){while(1){if((d|0)==4){d=0;v[c+28>>2]=0;e=gc(c+8|0,c+28|0,4);mc(c+16|0,v[a>>2],v[a+8>>2],v[e>>2],v[e+4>>2]);b:{if(v[c+20>>2]!=4){break b}if(Rb(c+28|0,b,4)){break b}Zb(a,4);d=1}jb=c+32|0;break a}e=b+d|0;d=d+1|0;if(w[e|0]){continue}break}aa(17430,9039,413,13074);L()}aa(17409,9039,411,13074);L()}return d|0}function xI(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{b:{c:{if(b>>>0>=256){b=ba(8)|0;v[23588]=0;c=Q(55,c|0,10656)|0;a=v[23588];v[23588]=0;if((a|0)==1){break c}a=rc(b,c);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}jb=c+16|0;return+(+u[(v[a+32>>2]+B(b,872)|0)+1075766>>1]*30517578125e-15)}a=P()|0;O()|0;ca(b|0)}T(a|0)}L()}function q6(a){a=a|0;var b=0;v[23588]=0;Y(952,a|0);b=v[23588];v[23588]=0;if((b|0)!=1){b=v[a+24>>2];if(b){Mb(Js(b))}v[a+24>>2]=0;b=v[a+20>>2];if(b){Mb(b);v[a+20>>2]=0}Mb(a);return}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,5081,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function gha(a){a=a|0;var b=0,c=0,d=0,e=0;e=jb-16|0;jb=e;b=sc(2500);c=jb-2496|0;jb=c;CR(a,c,c+2496|0);a=0;while(1){if((a|0)==624){v[b+2496>>2]=0;a:{if(v[b>>2]<0){break a}a=1;while(1){if((a|0)!=624){d=a<<2;a=a+1|0;if(!v[b+d>>2]){continue}break a}break}v[b>>2]=-2147483648}jb=c+2496|0}else{d=a<<2;v[d+b>>2]=v[c+d>>2];a=a+1|0;continue}break}a=v[Lf(e+8|0,b)>>2];jb=e+16|0;return a|0}function f1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=jb-16|0;jb=f;while(1){a:{if((c|0)<=(g|0)){break a}d=v[a+24>>2];e=v[a+28>>2];if(d>>>0>=e>>>0){if((nb[v[v[a>>2]+52>>2]](a,v[b>>2])|0)==-1){break a}g=g+1|0;b=b+4|0}else{v[f+12>>2]=e-d>>2;v[f+8>>2]=c-g;e=d;d=v[sd(f+12|0,f+8|0)>>2];li(e,b,d);e=d<<2;v[a+24>>2]=e+v[a+24>>2];g=g+d|0;b=b+e|0}continue}break}jb=f+16|0;return g|0}function cS(a,b){var c=0,d=0,e=0;c=jb-32|0;jb=c;a:{if(!w[b+5|0]){while(1){if((d|0)==5){d=0;t[c+28|0]=0;v[c+24>>2]=0;e=gc(c+8|0,c+24|0,5);mc(c+16|0,v[a>>2],v[a+8>>2],v[e>>2],v[e+4>>2]);b:{if(v[c+20>>2]!=5){break b}if(Rb(c+24|0,b,5)){break b}Zb(a,5);d=1}jb=c+32|0;break a}e=b+d|0;d=d+1|0;if(w[e|0]){continue}break}aa(17430,9039,413,13074);L()}aa(17409,9039,411,13074);L()}return d}function m6(a,b){a=a|0;b=b|0;var c=0;v[23588]=0;Y(952,a|0);c=v[23588];v[23588]=0;a:{b:{if((c|0)!=1){v[a+16>>2]=b;b=v[a+20>>2];if(!b){break b}Mb(b);v[a+20>>2]=0;return}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,5663,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$()}return}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function F9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;c=sc(64);v[23588]=0;e=S(835,c|0)|0;f=v[23588];v[23588]=0;a:{if((f|0)!=1){c=Lf(d,e);e=v[c>>2];v[23588]=0;a=W(895,e|0,a|0,b|0)|0;b=v[23588];v[23588]=0;b:{c:{if((b|0)!=1){if((a|0)==1){break c}Gc(d+8|0);break b}a=P()|0;O()|0;rg(c);break a}dg(d+8|0,c)}rg(c);jb=d+16|0;return v[d+8>>2]}a=P()|0;O()|0;Mb(c)}T(a|0);L()}function h9(a,b){a=a|0;b=b|0;var c=C(0);a:{switch(b|0){case 0:return C(z[a+4220>>2]);case 1:return C(z[a+4224>>2]);case 2:return C(z[a+4228>>2]);case 3:return C(w[a+4240|0]?C(1):C(0));case 4:return C(C(C(v[a+4232>>2])*C(.03125)));case 5:return C(w[a+4241|0]?C(1):C(0));case 6:return C(w[a+4242|0]?C(1):C(0));case 7:c=w[a+4244|0]?C(1):C(0);break;default:break a}}return C(c)}function IP(a,b){var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;a=Lb(a);d=Gb(b);v[23588]=0;R(46,a|0,d|0);d=v[23588];v[23588]=0;a:{if((d|0)!=1){e=c,f=qt(b),v[e+8>>2]=f;e=c,f=pt(b),v[e>>2]=f;while(1){if(!yi(c+8|0,c)){break a}b=w[v[c+8>>2]];v[23588]=0;R(47,a|0,((b|0)==13?10:b)<<24>>24);b=v[23588];v[23588]=0;if((b|0)!=1){Ge(c+8|0);continue}break}}b=P()|0;O()|0;yb(a);T(b|0);L()}jb=c+16|0}function NK(a){var b=C(0),c=0,d=C(0);b=z[a+4224>>2];z[a+4260>>2]=K(C(C(1)-C(b*b)));t[a+4264|0]=z[a+4236>>2]>C(.5);d=C(y[a+4256>>2]);b=C(C(C(C(z[a+4228>>2]*C(1999))+C(1))/C(1e3))*d);a:{if(b<C(4294967296)&b>=C(0)){c=~~b>>>0;break a}c=0}v[a+4248>>2]=c;c=a+4252|0;b=C(C(C(C(z[a+4232>>2]*C(1999))+C(1))/C(1e3))*d);b:{if(b<C(4294967296)&b>=C(0)){a=~~b>>>0;break b}a=0}v[c>>2]=a}function $T(a){var b=0,c=0;a:{if(Rb(a,15187,3)){break a}c=w[a+3|0];if(c>>>0>9){break a}if((Hb(w[a+202|0]|w[a+203|0]<<8)-1e4&65535)>>>0<57516){break a}b=1;b:{if(c>>>0>5){break b}if(!Hb(w[a+228|0]|w[a+229|0]<<8)){break a}if(!Hb(w[a+230|0]|w[a+231|0]<<8)){break a}b=0;if(Hb(w[a+232|0]|w[a+233|0]<<8)>>>0>4095){break b}b=Hb(w[a+234|0]|w[a+235|0]<<8)>>>0<100}return b}return 0}function qja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;v[a>>2]=0;v[a+4>>2]=0;Gc(a+8|0);if(b){if(sh(2147483647)>>>0<b>>>0){bd();L()}e=b<<1;d=sc(e);v[a>>2]=d;v[a+4>>2]=d;g=Fb(a),h=d+e|0,v[g>>2]=h;e=jb-16|0;jb=e;d=_h(e,a,b);b=v[d+4>>2];f=v[d+8>>2];while(1){if((b|0)==(f|0)){kc(d);jb=e+16|0}else{Jj(b,w[c|0]|w[c+1|0]<<8);b=b+2|0;v[d+4>>2]=b;continue}break}}return a|0}function oD(a,b,c){var d=0,e=0,f=0,g=0;a:{d=ro(b,Oi(a));c=ro(c,b);if(yd(v[a+4>>2],w[a+11|0])>>>0>=d>>>0){if((c|0)==-1){bB(a,od(a),d);break a}b=a;e=jb-16|0;jb=e;v[e+12>>2]=c;if(c){f=yd(v[b+4>>2],w[b+11|0]);g=od(b);c=f-d|0;v[e+8>>2]=c;a=v[Jb(e+12|0,e+8|0)>>2];v[e+12>>2]=a;b:{if((a|0)==(c|0)){a=c;break b}d=d+g|0;Wh(d,a+d|0,c-a|0)}bB(b,g,f-a|0)}jb=e+16|0;break a}rk();L()}}function wx(a,b,c){var d=0,e=0,f=0;v[a>>2]=0;v[a+4>>2]=0;Gc(a+8|0);if(c){Ak(a,c);d=jb-16|0;jb=d;e=Ah(d,a,c);c=v[e+4>>2];f=v[e+8>>2];while(1){if((c|0)==(f|0)){kc(e);jb=d+16|0}else{v[c>>2]=0;Gc(c);c=c+4|0;v[e+4>>2]=c;continue}break}}c=0;e=0;d=jb-16|0;jb=d;f=d+8|0;while(1){if(c>>>0<32){c=c+48|0;e=OM(b);continue}break}v[f>>2]=e;Sn(f);jb=d+16|0;v[a+12>>2]=v[f>>2];return a}function Hx(a){var b=C(0),c=C(0),d=0,e=C(0),f=0;b=C(y[v[a+16>>2]+24620>>2]);c=C(C(C(nb[v[v[a>>2]+208>>2]](a))*b)/C(1e3));d=a,e=C(C(c*C(nb[v[v[a>>2]+200>>2]](a)))*C(2048)),z[d+4248>>2]=e;d=a,f=Sh(C(C(c+C(2))*C(4096))),v[d+4256>>2]=f;c=C(nb[v[v[a>>2]+212>>2]](a));z[a+4252>>2]=c;b=C(c/b);if(!(nb[v[v[a>>2]+196>>2]](a)|0)){b=VK(C(b*C(3.1415927410125732)))}z[a+4244>>2]=b+b}function Gy(a,b,c,d){a:{if(v[a+1074392>>2]!=(c|0)){break a}b:{if(d){c=B(b,872)+a|0;v[c+1075688>>2]=0;d=c+1075e3|0;v[d>>2]=0;v[d+4>>2]=0;d=c+1075080|0;c=v[d>>2]|4096;v[d>>2]=c;break b}c=B(b,872)+a|0;v[c+1075680>>2]=0;c=v[c+1075080>>2]}d=B(b,872)+a|0;v[d+1075080>>2]=c|2097152;sm(a,b,255,0);if(!(w[d+1075081|0]&2)){break a}a=v[a+1298300>>2];if(!Ed(a)){break a}qj(a,b,0)}}function D2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;v[a>>2]=0;v[a+4>>2]=0;Gc(a+8|0);if(c){if(sh(357913941)>>>0<c>>>0){bd();L()}d=cE(c);v[a>>2]=d;v[a+4>>2]=d;f=Fb(a),g=d+B(c,12)|0,v[f>>2]=g;e=Md(b,c);d=jb-16|0;jb=d;c=Pt(d,a,c);v[23588]=0;U(1083,b|0,e|0,c+4|0);b=v[23588];v[23588]=0;a:{if((b|0)!=1){kc(c);jb=d+16|0;break a}a=P()|0;O()|0;kc(c);T(a|0);L()}}return a|0}function im(a){if((a|0)>=0){if(a>>>0<=16383){if(a>>>0<=15){return t[a+72688|0]}if(a>>>0<=511){return t[(a>>>5|0)+72688|0]+5|0}return t[(a>>>10|0)+72688|0]+10|0}if(a>>>0<=16777215){if(a>>>0<=524287){return t[(a>>>15|0)+72688|0]+15|0}return t[(a>>>20|0)+72688|0]+20|0}if(a>>>0<=536870911){return t[(a>>>25|0)+72688|0]+25|0}a=t[(a>>>30|0)+72688|0]+30|0}else{a=0}return a}function y3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;a:{b:{if((bk(w[a+140|0])|0)!=1){break b}if((KJ(a)|0)!=(b|0)){break b}d=a+120|0;zs(w[d+20|0]);b=jb-16|0;jb=b;v[b+8>>2]=c+8;a=jb-16|0;jb=a;e=v[14443];v[a+8>>2]=v[14442];v[a+12>>2]=e;e=v[14441];v[a>>2]=v[14440];v[a+4>>2]=e;nb[v[vp(a,bk(w[d+20|0]))>>2]](b+8|0,d);jb=a+16|0;jb=b+16|0;break a}JJ(a,1,b)}jb=c+16|0}function p6(a){a=a|0;var b=0;v[23588]=0;Y(952,a|0);b=v[23588];v[23588]=0;a:{b:{if((b|0)!=1){v[a+16>>2]=0;b=v[a+20>>2];if(!b){break b}Mb(b);v[a+20>>2]=0;return}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,8876,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$()}return}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function UE(a,b,c){var d=0;d=jb-16|0;jb=d;a:{b:{c:{if(b>>>0>=256){b=ba(8)|0;v[23588]=0;c=Q(55,d|0,10656)|0;a=v[23588];v[23588]=0;if((a|0)==1){break c}a=rc(b,c);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}a=(v[a+32>>2]+B(b,872)|0)+1075080|0;v[a>>2]=v[a>>2]|c;jb=d+16|0;return}a=P()|0;O()|0;ca(b|0)}T(a|0)}L()}function RI(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{b:{c:{if(b-513>>>0<=4294966814){b=ba(8)|0;v[23588]=0;c=Q(55,c|0,9323)|0;a=v[23588];v[23588]=0;if((a|0)==1){break c}a=rc(b,c);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}v[v[a+32>>2]+1074420>>2]=B(b,1e4);jb=c+16|0;return}a=P()|0;O()|0;ca(b|0)}T(a|0)}L()}function DV(a,b){var c=0,d=0;b=!v[a+24>>2]|b;v[a+16>>2]=b;if(b&v[a+20>>2]){a=jb-16|0;jb=a;c=ba(16)|0;b=jb-16|0;jb=b;if(!w[464880]){t[464880]=1}gc(b+8|0,1,94040);d=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=d;jb=b+16|0;b=v[a+12>>2];a=v[a+8>>2];v[23588]=0;a=kF(1110,c,8903,a,b);b=v[23588];v[23588]=0;if((b|0)!=1){ha(a|0,78372,1111);L()}a=P()|0;O()|0;ca(c|0);T(a|0);L()}}function dia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;f=jb-16|0;jb=f;c=qf(a,c);me(f,v[a+36>>2]);a:{if(!c){Rc(f,a+32|0,5);e=0;if(Bb(v[v[f>>2]>>2],v[f+4>>2])){break a}}h=v[a+36>>2];g=jb-16|0;jb=g;e=Lb(g);v[23588]=0;fa(457,b|0,h|0,e|0,d|0)|0;b=v[23588];v[23588]=0;b:{if((b|0)!=1){zb(e);jb=g+16|0;break b}a=P()|0;O()|0;zb(e);T(a|0);L()}e=c}Xe(a,e);jb=f+16|0}function Wi(a,b,c,d,e){var f=0,g=0,h=0;f=jb-16|0;jb=f;v[f+8>>2]=b;b=0;g=6;a:{b:{if(_j(a,f+8|0)){break b}g=4;h=Xk(v[a>>2]);if(!Wk(d,64,h)){break b}b=un(d,h);while(1){c:{b=b-48|0;h=Bn(a);if(!cs(h,f+8|0)|(e|0)<2){break c}g=Xk(v[h>>2]);if(!Wk(d,64,g)){break a}e=e-1|0;b=un(d,g)+B(b,10)|0;continue}break}g=2;if(!_j(h,f+8|0)){break a}}v[c>>2]=v[c>>2]|g}jb=f+16|0;return b}function QC(a){var b=0,c=0,d=0,e=0,f=0;a:{b:{if(Rb(a,11074,2)){if(Rb(a,13728,2)){break a}if(w[a+110|0]<=64){break b}break a}if(w[a+110|0]>64){break a}}if(t[a+112|0]<0|w[a+111|0]>128){break a}while(1){d=(b|0)==128;if(d){break a}c=a+b|0;e=t[c+113|0];if((e|0)<-2){break a}f=w[c+241|0];if(!f&(e|0)>=0|f>>>0>15){break a}b=b+1|0;if(w[c+369|0]<64){continue}break}}return d}function Pr(a,b,c){var d=0,e=0;if(c&2048){t[a|0]=43;a=a+1|0}if(c&1024){t[a|0]=35;a=a+1|0}d=c&260;if((d|0)!=260){t[a|0]=46;t[a+1|0]=42;a=a+2|0}c=c&16384;while(1){e=w[b|0];if(e){t[a|0]=e;a=a+1|0;b=b+1|0;continue}break}a:{b:{if((d|0)!=256){if((d|0)!=4){break b}b=c?70:102;break a}b=c?69:101;break a}b=c?65:97;if((d|0)==260){break a}b=c?71:103}t[a|0]=b;return(d|0)!=260}function n6(a){a=a|0;var b=0;v[23588]=0;Y(952,a|0);b=v[23588];v[23588]=0;a:{b:{if((b|0)!=1){a=v[a+20>>2];if(!a){break b}return fg(a)|0}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,12095,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();return 0}return fg(21619)|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function lka(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-16|0;jb=d;c=d+8|0;Hu(c,a,b);Of(b,w[d+8|0],w[Nc(c)|0]);a=w[b+3|0];a:{if((a|0)!=9){if((a|0)!=19){break a}a=w[b+5|0];c=a&240;if((c|0)!=128){if((c|0)!=64){if((c|0)!=48){break a}t[b+3|0]=45;t[b+5|0]=a&15;break a}if((a|0)!=64){break a}t[b+3|0]=0;t[b|0]=254;break a}t[b+3|0]=20;t[b+5|0]=a&15|160;break a}t[b+3|0]=0}jb=d+16|0}function hW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;c=-1;a:{if(!eg(a,7)){break a}c=0;if(!nC(a,11694)){break a}c=jb-16|0;jb=c;kC(c+8|0,d);e=v[c+12>>2];ld(c,a,v[c+8>>2],v[c+12>>2]);f=v[c+4>>2];if((f|0)==(e|0)){hd(a,v[c+12>>2])}jb=c+16|0;e=(e|0)==(f|0);if(!e){jC(d)}c=-1;if(!e){break a}c=0;if(!mC(w[d+1|0])){break a}c=Ae(a,b,lC(d),mb)}jb=d+16|0;return c|0}function d8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=si(a,b,c,d);v[a>>2]=45396;b=a+4208|0;e=Db(b,0),f=1060320051,v[e>>2]=f;e=Db(b,1),f=1041865114,v[e>>2]=f;e=Db(b,2),f=1065353216,v[e>>2]=f;e=Db(b,3),f=1049951732,v[e>>2]=f;e=Db(b,4),f=1049951732,v[e>>2]=f;v[23588]=0;R(897,a+44|0,2);b=v[23588];v[23588]=0;if((b|0)!=1){return a|0}b=P()|0;O()|0;If(a);T(b|0);L()}function tN(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=(B(b,872)+a|0)+1429|0;e=v[a+16>>2];if(e){d=w[d|0]}else{t[d|0]=0;d=0}f=v[a+40>>2];b=B(b,872)+a|0;a=b+1467|0;t[a|0]=w[a|0]|64;a=b+1468|0;h=a;i=v[a>>2];g=(+(e>>>0)+1)*+(c|0)/+(f>>>0);a:{if(D(g)<2147483648){a=~~g;break a}a=-2147483648}v[h>>2]=i+(a+((c|0)<0?d:0-d|0)|0);c=(f|0)==(e+1|0)?c:a;a=c>>31;t[b+1429|0]=(a^c)-a}function sM(a,b){var c=0,d=0,e=0,f=0;a:{if(x[a+480188>>1]<=b>>>0){break a}b:{c:{c=B(b,872)+a|0;d=w[c+1075783|0];switch(d-31|0){case 1:break b;case 0:break c;default:break a}}if(!(w[a+480209|0]&16)){break a}}e=a+1074376|0;f=(d|0)==32;c=t[c+1075785|0];d:{if((c|0)>=0){d=ye(a+901692|0,w[(B(b,872)+a|0)+1075836|0]);break d}d=ye(a+902204|0,c&127)}LN(a,e,b,f,d,c&255)}}function tba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[a>>2]=b;c=jb-16|0;jb=c;d=sc(223888);v[23588]=0;b=Q(802,d|0,b+1074376|0)|0;e=v[23588];v[23588]=0;a:{if((e|0)!=1){b=v[Lf(c+8|0,b)>>2];jb=c+16|0;break a}a=P()|0;O()|0;Mb(d);T(a|0);L()}v[a+4>>2]=b;b=Sb(a+8|0);v[23588]=0;Y(585,a|0);c=v[23588];v[23588]=0;if((c|0)!=1){return a|0}c=P()|0;O()|0;qe(b);zN(a+4|0);T(c|0);L()}function T4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;v[23588]=0;Y(952,a|0);f=v[23588];v[23588]=0;if((f|0)!=1){return Cx(v[v[a+24>>2]+24>>2],b,c,d,e)|0}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,12338,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function SI(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{b:{c:{if(b-65536>>>0<=4294901760){b=ba(8)|0;v[23588]=0;c=Q(55,c|0,5851)|0;a=v[23588];v[23588]=0;if((a|0)==1){break c}a=rc(b,c);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}v[v[a+32>>2]+1074416>>2]=b;jb=c+16|0;return}a=P()|0;O()|0;ca(b|0)}T(a|0)}L()}function xU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-32|0;jb=d;e=Sb(a);a=Eb(v[b>>2]);v[d+24>>2]=a;b=Eb(v[b+4>>2]);a:{while(1){if(Ob(a,b)){Yh(d,v[a>>2],v[a+4>>2]);if((bc(v[d>>2])|0)==(c|0)){zo(d,a);v[23588]=0;R(352,e|0,d|0);a=v[23588];v[23588]=0;if((a|0)==1){break a}Ab(d)}a=v[Mm(d+24|0)>>2];continue}break}jb=d+32|0;return}a=P()|0;O()|0;Ab(d);Uc(e);T(a|0);L()}function Xn(a,b,c,d){a:{if(v[a+480180>>2]==4){if(c){t[b+810|0]=w[b+810|0]&15|c<<4;break a}c=w[b+810|0]>>>4|0;break a}if(d){if(c){t[b+834|0]=c;break a}c=w[b+834|0];break a}if(c){t[b+810|0]=c;break a}c=w[b+810|0]}b:{if(!(t[b+851|0]&1)){break b}c=v[b+688>>2]+((c&255)<<2)|0;v[b+688>>2]=(c|0)<256?c:256;if(!(t[a+480180|0]&1)){break b}v[b+88>>2]=v[b+88>>2]|2097152}}function VE(a,b,c,d,e,f,g){var h=0,i=0,j=0;h=jb-16|0;jb=h;a:{b:{c:{if(b<g|b>f){a=ba(8)|0;v[23588]=0;d=Q(55,h|0,e|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break c}a=rc(a,d);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}e=P()|0;O()|0;yb(d);break b}i=v[a+32>>2]+d|0,j=Pe(b*c),v[i>>2]=j;jb=h+16|0;return}e=P()|0;O()|0;ca(a|0)}T(e|0)}L()}function AG(a,b,c,d){var e=0,f=0,g=0;e=jb-16|0;jb=e;a:{if((a|0)!=(b|0)){g=v[116064];v[116064]=0;Gd();d=BG(a,e+12|0,d);a=mb;f=v[116064];b:{if(f){if(v[e+12>>2]!=(b|0)){break b}if((f|0)!=68){break a}v[c>>2]=4;a=!!d&(a|0)>=0|(a|0)>0;d=a?-1:0;a=a?2147483647:-2147483648;break a}v[116064]=g;if(v[e+12>>2]==(b|0)){break a}}}v[c>>2]=4;d=0;a=0}jb=e+16|0;mb=a;return d}function It(a,b){var c=0,d=0;c=jb-32|0;jb=c;d=c+16|0;kQ(d,a,a+1|0,a+2|0,a+3|0);kQ(c,b,b+1|0,b+2|0,b+3|0);b=Ht(w[v[d>>2]],w[v[c>>2]]);a:{if(!wj(b)){break a}b=w[v[d+4>>2]];a=w[v[c+4>>2]];b=(a|0)==(b|0)?0:b<<24>>24<a<<24>>24?-1:1;if(!wj(b)){break a}b=Ht(w[v[d+8>>2]],w[v[c+8>>2]]);if(!wj(b)){break a}b=Ht(w[v[d+12>>2]],w[v[c+12>>2]])}a=ff(b);jb=c+32|0;return a}function fW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=jb-32|0;jb=e;$u(e+8|0,c);c=w[d|0];v[23588]=0;R(243,e+20|0,c|0);c=v[23588];v[23588]=0;b:{c:{if((c|0)!=1){Wj(e,e+8|0);v[23588]=0;X(114,a|0,b|0,v[e>>2],v[e+4>>2]);a=v[23588];v[23588]=0;if((a|0)==1){break c}Wg(e+8|0);jb=e+32|0;break a}a=P()|0;O()|0;zb(e+8|0);break b}a=P()|0;O()|0;Wg(e+8|0)}T(a|0);L()}}function c5(a){a=a|0;var b=0;v[23588]=0;Y(952,a|0);b=v[23588];v[23588]=0;if((b|0)!=1){a=v[v[a+24>>2]+24>>2];return sj(Vb(v[a+484360>>2],w[a+484376|0]))|0}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,6888,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function i6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=jb-16|0;jb=f;v[f+8>>2]=d;d=v[dg(f,f+8|0)>>2];v[23588]=0;ja(950,a+8|0,b|0,c|0,d|0,e|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){a=WI(a);b=VI(a+88|0);c=UI(a+92|0);d=TI(a+96|0);v[a>>2]=62440;v[b>>2]=62556;v[c>>2]=62636;v[d>>2]=62676;De(f+8|0);jb=f+16|0;return a|0}a=P()|0;O()|0;De(f+8|0);T(a|0);L()}function Jt(a,b){var c=0,d=0;if(a-268435457>>>0>=4026531840){a=a+208|0;Lka(b,0,a,0);a=mb?0:B(a,b)}else{a=0}a:{if(!a){break a}v[23588]=0;b=S(751,a|0)|0;c=v[23588];v[23588]=0;b:{c:{if((c|0)==1){b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;Z(18);c=v[23588];v[23588]=0;b=0;if((c|0)==1){break c}}break b}V(0)|0;O()|0;Ub();L()}if(!b){break a}d=Tb(b,0,a)- -64|0}return d}function b5(a){a=a|0;var b=0;v[23588]=0;Y(952,a|0);b=v[23588];v[23588]=0;if((b|0)!=1){a=v[v[a+24>>2]+24>>2];return tt(v[a+484344>>2],v[a+484348>>2])|0}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,6956,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function _z(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-32|0;jb=d;e=Sb(a);a=Eb(v[b>>2]);v[d+24>>2]=a;b=Eb(v[b+4>>2]);a:{while(1){if(Ob(a,b)){Yh(d,v[a>>2],v[a+4>>2]);if(v[d>>2]==(c|0)){zo(d,a);v[23588]=0;R(352,e|0,d|0);a=v[23588];v[23588]=0;if((a|0)==1){break a}Ab(d)}a=v[Mm(d+24|0)>>2];continue}break}jb=d+32|0;return}a=P()|0;O()|0;Ab(d);Uc(e);T(a|0);L()}function u0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=v[a+84>>2];f=v[e>>2];d=v[e+4>>2];h=v[a+28>>2];g=v[a+20>>2]-h|0;g=d>>>0<g>>>0?d:g;if(g){tc(f,h,g);f=g+v[e>>2]|0;v[e>>2]=f;d=v[e+4>>2]-g|0;v[e+4>>2]=d}d=c>>>0>d>>>0?d:c;if(d){tc(f,b,d);f=d+v[e>>2]|0;v[e>>2]=f;v[e+4>>2]=v[e+4>>2]-d}t[f|0]=0;b=v[a+44>>2];v[a+28>>2]=b;v[a+20>>2]=b;return c|0}function lp(a,b,c){var d=0,e=0,f=0;e=jb-16|0;jb=e;d=e+8|0;fd(d,b);v[23588]=0;b=S(1137,d|0)|0;d=v[23588];v[23588]=0;a:{if((d|0)==1){break a}v[23588]=0;d=S(1146,b|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break a}v[c>>2]=d;v[23588]=0;R(1147,a|0,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$b(e+8|0);jb=e+16|0;return}a=P()|0;O()|0;$b(e+8|0);T(a|0);L()}function kJ(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;g=jb-16|0;jb=g;e=Gb(a);if(e>>>0>=b>>>0){f=ad(a);a:{if(f-e>>>0>=d>>>0){if(!d){break a}f=zc(a);i=f+b|0;if((b|0)!=(e|0)){h=b+f|0;Wh(h+d|0,h,e-b|0);c=(c>>>0>=h>>>0?e+f>>>0>c>>>0?d:0:0)+c|0}Wh(i,c,d);b=d+e|0;Qh(a,b);t[g+15|0]=0;ie(b+f|0,g+15|0);break a}hp(a,f,(d+e|0)-f|0,e,b,0,d,c)}jb=g+16|0;return a}rk();L()}function _Q(a,b){var c=0,d=0,e=0;c=jb-32|0;jb=c;a:{if(!w[b+4|0]){while(1){if((d|0)==4){d=0;v[c+28>>2]=0;e=gc(c+8|0,c+28|0,4);ld(c+16|0,a,v[e>>2],v[e+4>>2]);b:{if(v[c+20>>2]!=4){break b}if(Rb(c+28|0,b,4)){break b}hd(a,4);d=1}jb=c+32|0;break a}e=b+d|0;d=d+1|0;if(w[e|0]){continue}break}aa(17430,9039,413,13074);L()}aa(17409,9039,411,13074);L()}return d}function np(a,b,c){var d=0,e=0,f=0;e=jb-16|0;jb=e;d=e+8|0;fd(d,b);v[23588]=0;b=S(1119,d|0)|0;d=v[23588];v[23588]=0;a:{if((d|0)==1){break a}v[23588]=0;d=S(1132,b|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break a}t[c|0]=d;v[23588]=0;R(1133,a|0,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$b(e+8|0);jb=e+16|0;return}a=P()|0;O()|0;$b(e+8|0);T(a|0);L()}function Taa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=jb-16|0;jb=b;u[a>>1]=0;c=Sb(a+4|0);d=Sb(a+16|0);v[a+36>>2]=0;e=Lb(a+40|0);f=Xf(a+52|0);Kc(c);u[a+28>>1]=65472;v[23588]=0;v[b+12>>2]=1065353216;R(839,c|0,b+12|0);g=v[23588];v[23588]=0;if((g|0)!=1){v[a+32>>2]=0;u[a+30>>1]=0;Kc(d);jb=b+16|0;return a|0}a=P()|0;O()|0;oT(f);zb(e);vc(d);vc(c);T(a|0);L()}function R7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;b=dL(a,b,c,d,e^1);v[b>>2]=46008;a=b+4208|0;f=Db(a,0),g=1056964608,v[f>>2]=g;f=Db(a,1),g=1065353216,v[f>>2]=g;f=Db(a,2),g=1020054733,v[f>>2]=g;f=Db(a,3),g=1065353216,v[f>>2]=g;f=Db(a,4),g=1056964608,v[f>>2]=g;f=Db(a,5),g=1048406533,v[f>>2]=g;f=Db(a,6),g=1056964608,v[f>>2]=g;return b|0}function DL(a,b){var c=0,d=0,e=0,f=0,g=0,h=C(0);c=jb-16|0;jb=c;d=0;a:{if(!Yg(v[v[a>>2]-12>>2]+a|0)){break a}v[c+12>>2]=0;ok(a,c+12|0);e=v[c+12>>2];d=0;if(e>>>0>65535){break a}ck(b,e);while(1){if((f|0)==(e|0)){d=Yg(v[v[a>>2]-12>>2]+a|0)}else{v[c+8>>2]=0;Dp(a,c+8|0);g=Db(v[b>>2],f),h=z[c+8>>2],z[g>>2]=h;f=f+1|0;continue}break}}a=d;jb=c+16|0;return a}function sba(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[Fb(a)>>2]){c=jb-16|0;jb=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+32;kN(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+32;kc(c);jb=c+16|0;return}d=jb-32|0;jb=d;c=Fb(a);c=Dt(d+8|0,cq(a,qg(v[a>>2],v[a+4>>2])+1|0),qg(v[a>>2],v[a+4>>2]),c);kN(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+32;Dd(a,c);cQ(c);jb=d+32|0}function gja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=jb-32|0;jb=e;IT(e+8|0,c);v[23588]=0;R(113,e+20|0,d|0);c=v[23588];v[23588]=0;b:{c:{if((c|0)!=1){Wj(e,e+8|0);v[23588]=0;X(114,a|0,b|0,v[e>>2],v[e+4>>2]);a=v[23588];v[23588]=0;if((a|0)==1){break c}Wg(e+8|0);jb=e+32|0;break a}a=P()|0;O()|0;zb(e+8|0);break b}a=P()|0;O()|0;Wg(e+8|0)}T(a|0);L()}}function aha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=jb-32|0;jb=e;Iq(e+8|0,c);v[23588]=0;R(575,e+20|0,d|0);c=v[23588];v[23588]=0;b:{c:{if((c|0)!=1){Wj(e,e+8|0);v[23588]=0;X(296,a|0,b|0,v[e>>2],v[e+4>>2]);a=v[23588];v[23588]=0;if((a|0)==1){break c}mS(e+8|0);jb=e+32|0;break a}a=P()|0;O()|0;yb(e+8|0);break b}a=P()|0;O()|0;mS(e+8|0)}T(a|0);L()}}function N6(a){a=a|0;var b=0,c=0,d=0,e=0;b=jb-32|0;jb=b;a=Sb(a);v[23588]=0;Y(942,b+16|0);c=v[23588];v[23588]=0;a:{b:{if((c|0)!=1){c=Eb(v[b+16>>2]);d=Eb(v[b+20>>2]);e=v[ec(b+8|0,a)>>2];v[23588]=0;U(943,c|0,d|0,e|0);c=v[23588];v[23588]=0;if((c|0)==1){break b}vc(b+16|0);jb=b+32|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;vc(b+16|0)}We(a);T(c|0);L()}function GT(a){var b=0,c=0,d=0;a:{if(Rb(a+60|0,15507,4)|(w[a+32|0]|w[a+33|0]<<8)>>>0>256|(w[a+49|0]<32|(w[a+36|0]|w[a+37|0]<<8)>>>0>255)){break a}if(t[a+51|0]<4|w[a+50|0]>64){break a}b=a+576|0;a=a- -64|0;while(1){if((a|0)==(b|0)){d=c;break a}b:{switch(w[a+15|0]){case 0:case 1:c=1;break;case 2:break b;default:break a}}a=a+16|0;continue}}return d&1}function j4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;v[23588]=0;Y(952,a|0);d=v[23588];v[23588]=0;if((d|0)!=1){v[a+16>>2]=0;v[a+12>>2]=c;v[a+8>>2]=b;return}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,12959,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function fU(a){var b=0,c=0;a:{if(Rb(a,13832,3)|(w[a+3|0]-1&255)>>>0>3){break a}if(Hb(w[a+196|0]|w[a+197|0]<<8)>>>0>255){break a}if((Hb(w[a+198|0]|w[a+199|0]<<8)-1&65535)>>>0>255){break a}if((Hb(w[a+200|0]|w[a+201|0]<<8)-1&65535)>>>0>31){break a}b=Hb(w[a+202|0]|w[a+203|0]<<8);if(b>>>0>256){break a}c=Hb(w[a+204|0]|w[a+205|0]<<8)>>>0<b>>>0}return c}function bY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=jb-32|0;jb=e;ln(e+8|0,c);v[23588]=0;R(113,e+20|0,d|0);c=v[23588];v[23588]=0;b:{c:{if((c|0)!=1){Wj(e,e+8|0);v[23588]=0;X(114,a|0,b|0,v[e>>2],v[e+4>>2]);a=v[23588];v[23588]=0;if((a|0)==1){break c}Wg(e+8|0);jb=e+32|0;break a}a=P()|0;O()|0;zb(e+8|0);break b}a=P()|0;O()|0;Wg(e+8|0)}T(a|0);L()}}function Qu(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=jb-32|0;jb=e;UB(e+8|0,c);v[23588]=0;R(113,e+20|0,d|0);c=v[23588];v[23588]=0;b:{c:{if((c|0)!=1){Wj(e,e+8|0);v[23588]=0;X(114,a|0,b|0,v[e>>2],v[e+4>>2]);a=v[23588];v[23588]=0;if((a|0)==1){break c}Wg(e+8|0);jb=e+32|0;break a}a=P()|0;O()|0;zb(e+8|0);break b}a=P()|0;O()|0;Wg(e+8|0)}T(a|0);L()}}function gt(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=jb-16|0;jb=e;a:{if(!b){break a}Cb(e+8|0,a+1074312|0,73);j=Bb(v[v[e+8>>2]>>2],v[e+12>>2])?c- -64|0:c;c=120;h=nj(a);k=h^-1;f=1;while(1){if(!c){break a}l=c;c=c>>>1|0;i=f+c|0;g=eh(a,i,j,d);if(!(g>>>0>b>>>0&k)&(!(!g|h)|b>>>0<=g>>>0)){continue}f=i+1|0;c=(c^-1)+l|0;continue}}jb=e+16|0;return f}function Wn(a,b,c,d){a:{if(v[a+480180>>2]==4){d=w[b+810|0];if(c){t[b+810|0]=d&240|c;break a}c=d&15;break a}if(d){if(c){t[b+834|0]=c;break a}c=w[b+834|0];break a}if(c){t[b+810|0]=c;break a}c=w[b+810|0]}b:{if(!(t[b+851|0]&1)){break b}c=v[b+688>>2]-((c&255)<<2)|0;v[b+688>>2]=(c|0)>0?c:0;if(!(t[a+480180|0]&1)){break b}v[b+88>>2]=v[b+88>>2]|2097152}}function J3(a,b){a=a|0;b=b|0;var c=0,d=0;if(y[a+4>>2]<y[Fb(a)>>2]){c=jb-16|0;jb=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+24;VJ(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+24;kc(c);jb=c+16|0;return}d=jb-32|0;jb=d;c=Fb(a);c=nE(d+8|0,pE(a,Qi(v[a>>2],v[a+4>>2])+1|0),Qi(v[a>>2],v[a+4>>2]),c);VJ(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+24;mE(a,c);lE(c);jb=d+32|0}function ow(a,b,c,d){t[a+53|0]=1;a:{if(v[a+4>>2]!=(c|0)){break a}t[a+52|0]=1;c=v[a+16>>2];b:{if(!c){v[a+36>>2]=1;v[a+24>>2]=d;v[a+16>>2]=b;if((d|0)!=1){break a}if(v[a+48>>2]==1){break b}break a}if((b|0)==(c|0)){c=v[a+24>>2];if((c|0)==2){v[a+24>>2]=d;c=d}if(v[a+48>>2]!=1){break a}if((c|0)==1){break b}break a}v[a+36>>2]=v[a+36>>2]+1}t[a+54|0]=1}}function Uu(a,b,c,d){var e=0,f=0;a:{e=w[a|0];f=w[c|0];b:{if(!(w[d|0]|((e|0)!=11|(f-5&255)>>>0>1))){t[a|0]=(f|0)==5?7:6;break b}if(!(w[b|0]|((f|0)!=11|(e-5&255)>>>0>1))){t[a|0]=(e|0)==5?7:6;t[b|0]=w[d|0];break b}if(!((e|0)!=10|(f|0)!=20|w[d|0]!=159)){t[a|0]=42;break b}if(w[b|0]!=159|(f|0)!=10|(e|0)!=20){break a}t[a|0]=42;t[b|0]=w[d|0]}t[c|0]=0}}function $I(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{b=v[a>>2];b:{if(!b){break b}c=v[a+8>>2];if(!c){break b}a=v[a+12>>2];if(!a){break b}e=nb[a|0](b)|0;d=mb;if((d|0)<0){break b}if((nb[c|0](b,0,0,0)|0)<0){break a}if((nb[c|0](b,0,0,2)|0)<0){break a}f=nb[a|0](b)|0;a=mb;nb[c|0](b,e,d,0)|0;if((a|0)<0){break b}g=bz(f,a)}return g}nb[c|0](b,e,d,0)|0;return 0}function RC(a,b){var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;a:{if(b>>>0<3){if(!b){break a}if(!Pb(v[a>>2],v[a+8>>2],b)){break a}while(1)if((d|0)==2){Jj(c+8|0,x[c+14>>1]);d=x[c+8>>1];break a}else{t[c+13|0]=0;f=(c+14|0)+d|0;if(b>>>0>d>>>0){zg(a,c+13|0);e=w[c+13|0]}else{e=0}t[f|0]=e;d=d+1|0;continue}}aa(11143,9039,136,14156);L()}jb=c+16|0;return d&65535}function Ifa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;c=d+11|0;rR(a,c);if(Rb(c,13490,4)){a=1}else{rR(a,d+11|0);t[b|0]=1;a=0}c=jb-16|0;jb=c;a:{b:{a=(d+11|0)+a|0;c:{if(!a){a=0;break c}b=Mc(c,a);v[23588]=0;a=S(655,b|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break b}yb(b)}jb=c+16|0;break a}a=P()|0;O()|0;yb(b);T(a|0);L()}jb=d+16|0;return a|0}function gca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=jb-32|0;jb=d;GA(d+8|0,c);v[23588]=0;R(462,d+20|0,43212);c=v[23588];v[23588]=0;b:{c:{if((c|0)!=1){Wj(d,d+8|0);v[23588]=0;X(114,a|0,b|0,v[d>>2],v[d+4>>2]);a=v[23588];v[23588]=0;if((a|0)==1){break c}Wg(d+8|0);jb=d+32|0;break a}a=P()|0;O()|0;zb(d+8|0);break b}a=P()|0;O()|0;Wg(d+8|0)}T(a|0);L()}}function Uia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;if(y[a+4>>2]<y[Fb(a)>>2]){d=jb-16|0;jb=d;a=Ah(d,a,1);MT(v[a+4>>2],x[b>>1],w[c|0]);v[a+4>>2]=v[a+4>>2]+4;kc(a);jb=d+16|0;return}e=jb-32|0;jb=e;d=Fb(a);d=Uf(e+8|0,pg(a,uc(v[a>>2],v[a+4>>2])+1|0),uc(v[a>>2],v[a+4>>2]),d);MT(v[d+8>>2],x[b>>1],w[c|0]);v[d+8>>2]=v[d+8>>2]+4;Dd(a,d);Tf(d);jb=e+32|0}function Mk(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;f=jb-16|0;jb=f;v[f+8>>2]=a;v[f+12>>2]=b;h=v[a+8>>2]+120|0;zs(w[h+20|0]);g=jb-16|0;jb=g;v[g+8>>2]=f+8;e=jb-16|0;jb=e;i=v[d+4>>2];v[e+8>>2]=v[d>>2];v[e+12>>2]=i;d=v[c+4>>2];v[e>>2]=v[c>>2];v[e+4>>2]=d;nb[v[vp(e,bk(w[h+20|0]))>>2]](g+8|0,h);jb=e+16|0;jb=g+16|0;v[a+4>>2]=v[a+4>>2]+v[b+8>>2];jb=f+16|0}function Dg(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;e=Lc(a);d=Gb(a);c=xg(b);a=0;a:{if(!c){break a}a=e;d=d+a|0;c=b+c|0;b:{if((c|0)==(b|0)){break b}c:{c=c-b|0;if((c|0)>(d-a|0)){break c}g=1-c|0;h=w[b|0];while(1){f=d-a|0;if((c|0)>(f|0)){break c}a=Cp(a,g+f|0,h);if(!a){break c}if(!Lp(a,b,c)){break b}a=a+1|0;continue}}a=d}a=(a|0)==(d|0)?-1:a-e|0}return a}function Bja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=jb-112|0;jb=d;c=jb-16|0;jb=c;f=d+8|0;tU(c+8|0,f);e=v[c+12>>2];ld(c,a,v[c+8>>2],v[c+12>>2]);g=v[c+4>>2];if((g|0)==(e|0)){hd(a,v[c+12>>2])}jb=c+16|0;e=(e|0)==(g|0);if(!e){sU(f)}c=-1;a:{if(!e){break a}c=0;if(!vU(d+8|0)){break a}c=Ae(a,b,uU(w[d+55|0]|w[d+56|0]<<8),mb)}jb=d+112|0;return c|0}function L0(a){a=a|0;a:{v[23588]=0;S(1113,467144)|0;a=v[23588];v[23588]=0;b:{if((a|0)==1){break b}v[23588]=0;S(1113,467480)|0;a=v[23588];v[23588]=0;if((a|0)==1){break b}v[23588]=0;S(1114,467228)|0;a=v[23588];v[23588]=0;if((a|0)==1){break b}v[23588]=0;S(1114,467564)|0;a=v[23588];v[23588]=0;if((a|0)==1){break b}break a}V(0)|0;O()|0;Ub();L()}}function yW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=jb-512|0;jb=d;c=jb-16|0;jb=c;f=d+8|0;OC(c+8|0,f);e=v[c+12>>2];ld(c,a,v[c+8>>2],v[c+12>>2]);g=v[c+4>>2];if((g|0)==(e|0)){hd(a,v[c+12>>2])}jb=c+16|0;e=(e|0)==(g|0);if(!e){NC(f)}c=-1;a:{if(!e){break a}c=0;if(!QC(d+8|0)){break a}c=Ae(a,b,PC(w[d+118|0],w[d+119|0]),mb)}jb=d+512|0;return c|0}function c4(a,b){a=a|0;b=b|0;var c=0;v[23588]=0;Y(952,a|0);c=v[23588];v[23588]=0;if((c|0)!=1){v[v[v[a+24>>2]+24>>2]+480272>>2]=b;return 1}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,5787,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function bO(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=jb-16|0;jb=f;i=v[d+20>>2];h=v[d+52>>2];g=!h|e;t[f+15|0]=g;a:{if(!g|(b|0)!=2){break a}g=c&65535;c=0;while(1){if((c|0)==(g|0)){break a}v[(B(c,872)+d|0)+1380>>2]=0;c=c+1|0;continue}}v[d+24>>2]=0;v[d+16>>2]=0;v[d+20>>2]=0;v[d+48>>2]=h;u[d+72>>1]=x[d+74>>1];de(a,i>>>0>1&e&(b|0)==1,f+15|0);jb=f+16|0}function JY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;e=jb+-64|0;jb=e;d=1;a:{if(Zg(a,b,0)){break a}d=0;if(!b){break a}b=Ky(b,92556,92604);d=0;if(!b){break a}d=e+8|0;Tb(d|4,0,52);v[e+56>>2]=1;v[e+20>>2]=-1;v[e+16>>2]=a;v[e+8>>2]=b;nb[v[v[b>>2]+28>>2]](b,d,v[c>>2],1);a=v[e+32>>2];if((a|0)==1){v[c>>2]=v[e+24>>2]}d=(a|0)==1}jb=e- -64|0;return d|0}function ty(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=jb-16|0;jb=d;e=Rh(b,c);a:{if(e>>>0<=jp(a)>>>0){f=c;g=v[a>>2];h=ed(g,v[a+4>>2]);i=h>>>0>=e>>>0;if(!i){v[d+12>>2]=b;v[d+12>>2]=v[d+12>>2]+h;f=v[d+12>>2]}b=Pi(b,f,g);if(!i){ju(a,f,c,e-ed(v[a>>2],v[a+4>>2])|0);break a}Nd(a,b);break a}rB(a);Nl(a,Wl(a,e));ju(a,b,c,e)}jb=d+16|0}function oz(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+23|0]=0;t[a+24|0]=0;t[a+25|0]=0;t[a+26|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function qZ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;while(1){a:{if((c|0)==(d|0)|e>>>0<=h>>>0){break a}f=1;g=jb-16|0;jb=g;k=ji(g+8|0,v[a+8>>2]);i=Wr(0,c,d-c|0,b?b:468124);ii(k);jb=g+16|0;b:{switch(i+2|0){default:f=i;break;case 0:case 1:break a;case 2:break b}}h=h+1|0;j=f+j|0;c=c+f|0;continue}break}return j|0}function i4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;v[23588]=0;Y(952,a|0);d=v[23588];v[23588]=0;if((d|0)!=1){v[a+4>>2]=c;v[a>>2]=b?b:933;return}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,12989,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function Uj(a,b){a:{if((b|0)>=1024){a=a*898846567431158e293;if(b>>>0<2047){b=b-1023|0;break a}a=a*898846567431158e293;b=((b|0)<3069?b:3069)-2046|0;break a}if((b|0)>-1023){break a}a=a*2004168360008973e-307;if(b>>>0>4294965304){b=b+969|0;break a}a=a*2004168360008973e-307;b=((b|0)>-2960?b:-2960)+1938|0}l(0,0);l(1,b+1023<<20);return a*+n()}function $W(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-32|0;jb=e;f=v[b+16>>2];a:{if(f>>>0<=c>>>0){fc(a,v[d>>2],0);break a}g=v[b+12>>2];b=v[b+4>>2];v[e+20>>2]=v[d+4>>2];v[e+16>>2]=f-c;fc(e+24|0,v[d>>2],v[Jb(e+20|0,e+16|0)>>2]);d=v[v[b>>2]+28>>2];f=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=f;nb[d|0](a,b,c+g|0,e+8|0)}jb=e+32|0}function $G(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=jb-16|0;jb=b;e=b+16|0;a:{while(1){d=v[a+36>>2];c=b+8|0;f=nb[v[v[d>>2]+20>>2]](d,v[a+40>>2],c,e,b+4|0)|0;d=-1;g=c;c=v[b+4>>2]-c|0;if((vk(g,1,c,v[a+32>>2])|0)!=(c|0)){break a}b:{switch(f-1|0){case 1:break a;case 0:continue;default:break b}}break}d=Ls(v[a+32>>2])?-1:0}jb=b+16|0;return d|0}function n5(a){a=a|0;var b=0;v[23588]=0;Y(952,a|0);b=v[23588];v[23588]=0;if((b|0)!=1){return+(+y[v[v[a+24>>2]+24>>2]+1074420>>2]/1e4)}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,15117,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function ae(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;bn(b);f=Lf(e+8|0,b);a:{d=a+8|0;b=v[d>>2];if(uc(b,v[a+12>>2])>>>0<=c>>>0){v[23588]=0;R(1210,d|0,c+1|0);a=v[23588];v[23588]=0;if((a|0)==1){break a}b=v[d>>2]}a=Db(b,c);b=v[a>>2];if(b){fn(b);a=Db(v[d>>2],c)}g=a,h=be(f),v[g>>2]=h;RF(f);jb=e+16|0;return}a=P()|0;O()|0;RF(f);T(a|0);L()}function S2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=jb-16|0;jb=e;g=v[d+4>>2];qx(b,c,g);f=v[b+16>>2];a:{if(f>>>0<=c>>>0){fc(a,v[d>>2],0);break a}v[e+12>>2]=f-c;v[e+8>>2]=g;d=v[d>>2];f=v[Jb(e+12|0,e+8|0)>>2];Bq(e,d,g,0,f);h=v[e>>2];i=v[e+4>>2];ph(Qf(Eb(v[b+4>>2]),c),Qf(Qf(Eb(v[b+4>>2]),c),i),h);Bq(a,d,g,0,f)}jb=e+16|0}function zL(a){var b=0,c=0,d=0;c=jb-32|0;jb=c;a:{d=Uh(a);b=uc(v[a>>2],v[a+4>>2]);b:{if(d>>>0<=b>>>0){break b}v[23588]=0;b=fa(902,c+8|0,b|0,b|0,Fb(a)|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){Dd(a,b);Tf(b);break b}a=V(0)|0;O()|0;_(a|0)|0;v[23588]=0;Z(18);a=v[23588];v[23588]=0;if((a|0)==1){break a}}jb=c+32|0;return}V(0)|0;O()|0;Ub();L()}function o5(a){a=a|0;var b=0;v[23588]=0;Y(952,a|0);b=v[23588];v[23588]=0;if((b|0)!=1){return y[v[v[a+24>>2]+24>>2]+1074420>>2]/1e4|0}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,9290,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function lC(a){var b=0,c=0,d=0,e=0,f=0;d=w[a+9|0]|w[a+10|0]<<8;c=Lka(w[a+3|0],0,18,0);d=d+c|0;b=mb;b=c>>>0>d>>>0?b+1|0:b;c=d;d=b;f=c;c=w[a+6|0]|w[a+7|0]<<8;b=c>>>31|0;e=c<<1;c=f+e|0;b=b+d|0;b=c>>>0<e>>>0?b+1|0:b;d=b;a=w[a+4|0]|w[a+5|0]<<8;b=a>>>30|0;e=a<<2;c=e+c|0;a=b+d|0;a=c>>>0<e>>>0?a+1|0:a;b=c+3|0;a=b>>>0<3?a+1|0:a;mb=a;return b}function G8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=si(a,b,c,d);v[a>>2]=44896;c=Sb(a+4208|0);v[a+4220>>2]=0;v[a+4224>>2]=1056964608;b=a+4228|0;t[b+4|0]=0;t[b+5|0]=4;t[b|0]=69;t[b+1|0]=99;t[b+2|0]=104;t[b+3|0]=111;t[b+6|0]=1;v[23588]=0;R(897,a+44|0,2);b=v[23588];v[23588]=0;if((b|0)!=1){Ps(a);return a|0}b=P()|0;O()|0;vc(c);If(a);T(b|0);L()}function Fga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb+-64|0;jb=c;b=-1;a:{if(!(nb[v[v[a>>2]+32>>2]](a,0,1084)|0)){break a}wl(a,1080);d=c+60|0;lS(a,d);e=d;d=kS(c+40|0);b=0;if(!jS(e,d)){break a}wl(a,20);b=1;while(1){if((b&65535)>>>0>=32){b=y[d+4>>2]>=f>>>0}else{e=c+8|0;iS(a,e);b=b+1|0;f=mA(e)+f|0;continue}break}}jb=c- -64|0;return b|0}function AL(a){var b=0,c=0,d=0;c=jb-32|0;jb=c;a:{d=Sx(a);b=Pj(v[a>>2],v[a+4>>2]);b:{if(d>>>0<=b>>>0){break b}v[23588]=0;b=fa(901,c+8|0,b|0,b|0,Fb(a)|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){Dd(a,b);xL(b);break b}a=V(0)|0;O()|0;_(a|0)|0;v[23588]=0;Z(18);a=v[23588];v[23588]=0;if((a|0)==1){break a}}jb=c+32|0;return}V(0)|0;O()|0;Ub();L()}function kz(a,b,c){var d=0,e=0,f=0;d=Lb(a);a=Gb(b);v[23588]=0;R(48,d|0,a|0);a=v[23588];v[23588]=0;if((a|0)!=1){a:{while(1){if(Gb(b)>>>0>e>>>0){a=65533;f=t[gg(b,e)|0];if((f|0)>=-96){a=v[((f&255)<<2)+c>>2]}v[23588]=0;R(49,d|0,a|0);a=v[23588];v[23588]=0;if((a|0)==1){break a}e=e+1|0;continue}break}return}}a=P()|0;O()|0;Fc(d);T(a|0);L()}function Daa(a){a=a|0;var b=0,c=0;b=jb-32|0;jb=b;t[b+23|0]=0;t[b+24|0]=0;t[b+25|0]=0;t[b+26|0]=0;t[b+27|0]=0;t[b+28|0]=0;t[b+29|0]=0;t[b+30|0]=0;v[b+16>>2]=0;v[b+20>>2]=0;c=gc(b,b+16|0,15);mc(b+8|0,v[a>>2],v[a+8>>2],v[c>>2],v[c+4>>2]);c=0;a:{if(v[b+12>>2]!=15){break a}if(Rb(b+16|0,8485,15)){break a}Zb(a,15);c=1}jb=b+32|0;return c|0}function Kq(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=Eb(v[b>>2]);g=Eb(v[b+4>>2]);e=jb-16|0;jb=e;v[e+8>>2]=d;while(1){a:{if(!Ob(d,g)){break a}f=jb-16|0;jb=f;Yh(f+8|0,v[d>>2],v[d+4>>2]);h=bc(v[f+8>>2]);jb=f+16|0;if((c|0)==(h|0)){break a}d=v[Mm(e+8|0)>>2];continue}break}jb=e+16|0;if(oc(d,Eb(v[b+4>>2]))){Ih(a);return}zo(a,d)}function SC(a,b){var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;a:{if(b>>>0<5){if(!b){break a}if(!Pb(v[a>>2],v[a+8>>2],b)){break a}while(1)if((d|0)==4){_l(c,v[c+12>>2]);d=v[c>>2];break a}else{t[c+11|0]=0;f=(c+12|0)+d|0;if(b>>>0>d>>>0){zg(a,c+11|0);e=w[c+11|0]}else{e=0}t[f|0]=e;d=d+1|0;continue}}aa(11143,9039,136,14156);L()}jb=c+16|0;return d}function IR(a){var b=0,c=0,d=0,e=0,f=0;e=w[a+28|0]|w[a+29|0]<<8;b=Lka(w[a+30|0],0,37,0);c=mb;d=b;b=Lka(w[a+24|0]|w[a+25|0]<<8,0,192,0);d=d+b|0;c=mb+c|0;c=b>>>0>d>>>0?c+1|0:c;b=c;f=e;a=w[a+26|0];c=a>>>26|0;e=d;d=a<<6;e=e+d|0;a=b+c|0;a=d>>>0>e>>>0?a+1|0:a;b=e;c=f+b|0;a=b>>>0>c>>>0?a+1|0:a;b=c+192|0;a=b>>>0<192?a+1|0:a;mb=a;return b}function Via(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;v[c+12>>2]=1;a:{if(Uh(a)){d=v[a>>2];e=uc(d,v[a+4>>2]);v[c+8>>2]=e;f=v[Jb(c+12|0,c+8|0)>>2];while(1){if(f){u[d>>1]=x[b>>1];t[d+2|0]=w[b+2|0];f=f-1|0;d=d+4|0;continue}break}if(!e){QT(a,1-e|0,b);break a}Nd(a,v[a>>2]+4|0);break a}ou(a);Ak(a,pg(a,1));QT(a,1,b)}jb=c+16|0}function Ika(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;fc(c+8|0,b,10);d=v[c+12>>2];mc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){Zb(a,v[c+12>>2])}jb=c+16|0;a=(d|0)==(e|0);if(!a){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0}return a|0}function G2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=0;a:{if(!v[b+28>>2]){break a}e=0;if((nb[v[b+32>>2]](v[b+24>>2],c,0,0)|0)<0){break a}f=v[d+4>>2];c=v[d>>2];while(1){b:{if(!f){break b}e=nb[v[b+28>>2]](v[b+24>>2],c,f)|0;if(!e){break b}f=f-e|0;c=c+e|0;g=e+g|0;h=g>>>0<e>>>0?h+1|0:h;continue}break}e=g}fc(a,v[d>>2],e)}function Zp(a){var b=0,c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;d=Eb(v[a>>2]);e=a;f=Eb(v[a+4>>2]);a=jb-16|0;jb=a;v[a+8>>2]=d;while(1){if(Ob(d,f)){b=b+A[d>>3];d=v[ut(a+8|0)>>2];continue}break}jb=a+16|0;a=Eb(v[e>>2]);v[c+8>>2]=a;b=-b;e=Eb(v[e+4>>2]);while(1){if(Ob(a,e)){b=b+A[a>>3];A[a>>3]=b;a=v[ut(c+8|0)>>2];continue}else{jb=c+16|0}break}}function RK(a){a=a|0;var b=0,c=0;c=jb-16|0;jb=c;b=v[v[a+16>>2]+24620>>2]/5|0;b=Hc(b,b>>31);v[a+4272>>2]=b;v[23588]=0;v[c+12>>2]=0;U(903,a+4256|0,b<<1,c+12|0);b=v[23588];v[23588]=0;a:{if((b|0)==1){b=V(92948)|0;if((O()|0)!=(da(92948)|0)){break a}_(b|0)|0;v[a+4272>>2]=0;$()}v[a+4276>>2]=0;v[a+4268>>2]=0;jb=c+16|0;return}T(b|0);L()}function md(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;Dm(a);v[a+16>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[a>>2]=0;v[a+4>>2]=0;u[a+32>>1]=64;v[a+24>>2]=8363;v[a+28>>2]=16777344;v[a+36>>2]=0;t[a+39|0]=0;t[a+40|0]=0;t[a+41|0]=0;t[a+42|0]=0;d=x[a+34>>1]&-25151;u[a+34>>1]=(b|0)==4?d|32:d;b=Mc(c,21619);Be(a+43|0,b);yb(b);oQ(a);jb=c+16|0}function pX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-16|0;jb=d;v[d>>2]=b;v[d+4>>2]=c;v[d+8>>2]=b;v[d+12>>2]=c;e=jb-16|0;jb=e;c=jb-16|0;jb=c;v[c+4>>2]=1;g=c,h=sc(24),v[g+8>>2]=h;b=To(v[c+8>>2]);v[b>>2]=62132;PD(Bc(b),v[d>>2],v[d+4>>2]);b=e+8|0;f=Vo(c);Uo(b,Bc(f),f);en(c);jb=c+16|0;Cg(a,b);le(b);jb=e+16|0;jb=d+16|0}function eJ(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=v[a>>2];a:{if(!b){break a}c=v[a+8>>2];if(!c){break a}d=v[a+12>>2];if(!d){break a}e=nb[d|0](b)|0;a=mb;f=a;if((a|0)<0){break a}a=0;b:{if((nb[c|0](b,0,0,0)|0)<0){break b}a=0;if((nb[c|0](b,0,0,2)|0)<0){break b}nb[d|0](b)|0;a=mb;a=(a|0)>0|(a|0)>=0}g=a;nb[c|0](b,e,f,0)|0}return g|0}function aN(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;a:{b:{while(1){v[e+12>>2]=b;v[e+8>>2]=d;if(y[Jb(e+12|0,e+8|0)>>2]<=f>>>0){break b}g=Pp(t[Kb(a,f)|0]);h=Pp(t[Kb(c,f)|0]);if((g|0)!=(h|0)){a=g>>>0<h>>>0?-1:1;break a}f=f+1|0;if(g){continue}break}a=0;break a}a=0;if((b|0)==(d|0)){break a}a=b>>>0<d>>>0?-1:1}jb=e+16|0;return a}function wW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=jb-48|0;jb=d;c=jb-16|0;jb=c;f=d+8|0;HC(c+8|0,f);e=v[c+12>>2];ld(c,a,v[c+8>>2],v[c+12>>2]);g=v[c+4>>2];if((g|0)==(e|0)){hd(a,v[c+12>>2])}jb=c+16|0;e=(e|0)==(g|0);if(!e){GC(f)}c=-1;a:{if(!e){break a}c=0;if(!JC(d+8|0)){break a}c=Ae(a,b,IC(w[d+43|0]),mb)}jb=d+48|0;return c|0}function tha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=jb+-64|0;jb=d;c=jb-16|0;jb=c;f=d+8|0;IS(c+8|0,f);e=v[c+12>>2];ld(c,a,v[c+8>>2],v[c+12>>2]);g=v[c+4>>2];if((g|0)==(e|0)){hd(a,v[c+12>>2])}jb=c+16|0;e=(e|0)==(g|0);if(!e){HS(f)}c=-1;a:{if(!e){break a}c=0;if(!KS(d+8|0)){break a}c=Ae(a,b,JS(d+8|0),mb)}jb=d- -64|0;return c|0}function rm(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0;h=jb-16|0;jb=h;i=-17;if(-17-b>>>0>=c>>>0){j=zc(a);if(b>>>0<=2147483622){v[h+8>>2]=b<<1;v[h+12>>2]=b+c;i=Mg(v[Yc(h+12|0,h+8|0)>>2])+1|0}c=sc(i);if(e){ve(c,j,e)}k=e+f|0;if((k|0)!=(d|0)){ve((c+e|0)+g|0,(e+j|0)+f|0,d-k|0)}if((b|0)!=10){Mb(j)}ud(a,c);bf(a,i);jb=h+16|0;return}hf();L()}function dx(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;g=jb-240|0;jb=g;v[g>>2]=a;h=1;a:{if((c|0)<2){break a}e=a;while(1){e=e-4|0;i=c-2|0;f=e-v[(i<<2)+d>>2]|0;if((nb[b|0](a,f)|0)>=0){if((nb[b|0](a,e)|0)>=0){break a}}j=f;f=(nb[b|0](f,e)|0)>=0;e=f?j:e;v[(h<<2)+g>>2]=e;h=h+1|0;c=f?c-1|0:i;if((c|0)>1){continue}break}}WH(g,h);jb=g+240|0}function dca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=jb-32|0;jb=e;v[e+24>>2]=d;c=qf(a,c);me(e+8|0,v[a+36>>2]);f=a;a:{if(!c){Rc(e+8|0,a+32|0,5);d=0;if(Bb(v[v[e+8>>2]>>2],v[e+12>>2])){break a}}d=v[a+36>>2];a=0;zC(b,v[e+24>>2]);while(1){if(y[e+24>>2]>a>>>0){bP(d,cc(v[b>>2],a));a=a+1|0;continue}break}d=c}Xe(f,d);jb=e+32|0}function Y9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;v[d>>2]=v[a+8>>2];e=v[a+8>>2];v[d+8>>2]=a+8;v[d+4>>2]=B(b,52)+e;b=v[d>>2];a:{while(1){if(v[d+4>>2]==(b|0)){break a}v[23588]=0;R(877,b|0,c|0);a=v[23588];v[23588]=0;if((a|0)!=1){b=v[d>>2]+52|0;v[d>>2]=b;continue}break}a=P()|0;O()|0;Td(d);T(a|0);L()}Td(d);jb=d+16|0}function zS(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=jb-16|0;jb=d;e=_d(b,c);a:{if(e>>>0<=Uh(a)>>>0){f=c;g=v[a>>2];h=uc(g,v[a+4>>2]);i=h>>>0>=e>>>0;if(!i){v[d+12>>2]=b;v[d+12>>2]=v[d+12>>2]+(h<<2);f=v[d+12>>2]}b=Pi(b,f,g);if(!i){tA(a,f,c,e-uc(v[a>>2],v[a+4>>2])|0);break a}Nd(a,b);break a}ou(a);Ak(a,pg(a,e));tA(a,b,c,e)}jb=d+16|0}function bG(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=jb-16|0;jb=d;i=v[b>>2];h=v[a>>2];e=v[ic(a)>>2]==1158;f=v[c>>2]-h|0;g=f<<1;f=f>>>0<2147483647?g?g:4:-1;g=ks(e?0:h,f);if(g){if(!e){be(a)}v[d+4>>2]=1123;e=se(d+8|0,g,d+4|0);a=_F(a,e);Wc(e);v[b>>2]=v[a>>2]+(i-h|0);v[c>>2]=v[a>>2]+(f&-4);jb=d+16|0;return}Cw();L()}function Vaa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;if(!Ed(v[a+1298300>>2])){d=v[a+24620>>2];e=jb-16|0;jb=e;b=sc(536);v[23588]=0;d=Q(834,b|0,d|0)|0;f=v[23588];v[23588]=0;a:{if((f|0)!=1){b=v[Lf(e+8|0,d)>>2];jb=e+16|0;break a}a=P()|0;O()|0;Mb(b);T(a|0);L()}v[c+8>>2]=b;b=a+1298300|0;a=c+8|0;RM(b,be(a));Ay(a)}jb=c+16|0}function Sia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-576|0;jb=d;c=jb-16|0;jb=c;ET(c+8|0,d);e=v[c+12>>2];ld(c,a,v[c+8>>2],v[c+12>>2]);f=v[c+4>>2];if((f|0)==(e|0)){hd(a,v[c+12>>2])}jb=c+16|0;e=(e|0)==(f|0);if(!e){DT(d)}c=-1;a:{if(!e){break a}c=0;if(!GT(d)){break a}c=Ae(a,b,FT(x[d+34>>1],x[d+36>>1]),mb)}jb=d+576|0;return c|0}function HE(a,b,c,d,e){var f=0;a:{f=jb-32|0;jb=f;Zo(f+8|0,c);v[23588]=0;R(e|0,f+20|0,d|0);c=v[23588];v[23588]=0;b:{c:{if((c|0)!=1){Wj(f,f+8|0);v[23588]=0;X(114,a|0,b|0,v[f>>2],v[f+4>>2]);a=v[23588];v[23588]=0;if((a|0)==1){break c}Wg(f+8|0);jb=f+32|0;break a}a=P()|0;O()|0;zb(f+8|0);break b}a=P()|0;O()|0;Wg(f+8|0)}T(a|0);L()}}function EE(a,b,c,d,e){var f=0;a:{f=jb-32|0;jb=f;wU(f+8|0,c);v[23588]=0;R(e|0,f+20|0,d|0);c=v[23588];v[23588]=0;b:{c:{if((c|0)!=1){Wj(f,f+8|0);v[23588]=0;X(114,a|0,b|0,v[f>>2],v[f+4>>2]);a=v[23588];v[23588]=0;if((a|0)==1){break c}Wg(f+8|0);jb=f+32|0;break a}a=P()|0;O()|0;zb(f+8|0);break b}a=P()|0;O()|0;Wg(f+8|0)}T(a|0);L()}}function ria(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=v[a>>2];d=ed(e,v[a+4>>2]);if(d>>>0<b>>>0){e=jb-32|0;jb=e;b=b-d|0;d=v[Fb(a)>>2];f=v[a+4>>2];a:{if(b>>>0<=d-f>>>0){Mo(a,b,c);break a}d=Fb(a);d=Yl(e+8|0,Wl(a,ed(v[a>>2],f)+b|0),ed(v[a>>2],v[a+4>>2]),d);dT(d,b,c);Dd(a,d);Xl(d)}jb=e+32|0;return}if(b>>>0<d>>>0){Nd(a,b+e|0)}}function jM(a,b){var c=0,d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;gc(d+8|0,od(b),yd(v[b+4>>2],w[b+11|0]));b=v[d+8>>2];e=v[d+12>>2];c=jb-16|0;jb=c;f=yd(v[a+4>>2],w[a+11|0]);v[c+12>>2]=f;v[c+8>>2]=e;g=Jb(c+12|0,c+8|0);a=Rv(od(a),b,v[g>>2]);a:{if(a){break a}a=-1;if(e>>>0>f>>>0){break a}a=e>>>0<f>>>0}jb=c+16|0;jb=d+16|0;return a>>>31|0}function bl(a,b,c){var d=0,e=0,f=0,g=0,h=0;f=jb-16|0;jb=f;v[f+8>>2]=c;while(1){a:{if((a|0)!=(b|0)){c=jb-32|0;jb=c;d=qc(c+24|0,v[a>>2]);e=v[f+8>>2];g=v[e+4>>2];e=v[e>>2];v[c+16>>2]=e;v[c+20>>2]=g;h=v[d+4>>2];d=v[d>>2];v[c+8>>2]=e;v[c+12>>2]=g;d=Pc(d,h,c+8|0);jb=c+32|0;if(!d){break a}b=a}jb=f+16|0;return b}a=a+8|0;continue}}function Z0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=v[a+44>>2];c=v[a+24>>2];if(e>>>0<c>>>0){v[a+44>>2]=c;e=c}f=v[a+8>>2];c=v[a+12>>2];d=-1;a:{if(f>>>0>=c>>>0){break a}if(oc(b,-1)){An(a,f,c-1|0,e);return Ow(b)|0}g=pp(b);if(!(v[a+48>>2]&16)){d=-1;if(!oc(g,t[c-1|0])){break a}}An(a,f,c-1|0,e);t[v[a+12>>2]]=g;d=b}return d|0}function n7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=si(a,b,c,d);v[a+4272>>2]=1065353216;v[a>>2]=47040;b=a+4208|0;e=Db(b,0),f=1056880300,v[e>>2]=f;e=Db(b,1),f=1050733080,v[e>>2]=f;e=Db(b,2),f=1056964608,v[e>>2]=f;v[23588]=0;R(897,a+44|0,2);b=v[23588];v[23588]=0;if((b|0)!=1){return a|0}b=P()|0;O()|0;If(a);T(b|0);L()}function f7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=si(a,b,c,d);v[a>>2]=47276;b=a+4208|0;e=Db(b,0),f=1065353216,v[e>>2]=f;e=Db(b,1),f=1065353216,v[e>>2]=f;e=Db(b,2),f=1051372203,v[e>>2]=f;e=Db(b,3),f=0,v[e>>2]=f;v[23588]=0;R(897,a+44|0,2);b=v[23588];v[23588]=0;if((b|0)!=1){return a|0}b=P()|0;O()|0;If(a);T(b|0);L()}function Gia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;v[d+12>>2]=c;a:{e=Pb(v[b>>2],v[b+8>>2],c<<2);if(!e){break a}wc(d+12|0,65535);ug(a,x[d+12>>1]);c=Eb(v[a>>2]);v[d>>2]=c;a=Eb(v[a+4>>2]);while(1){if(!Ob(c,a)){break a}f=d+8|0;if(!Ro(b,f)){Nm(f)}u[c>>1]=v[d+8>>2];c=v[Re(d)>>2];continue}}jb=d+16|0;return e|0}function zba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-32|0;jb=d;b=xh(d,b);v[23588]=0;U(799,d+16|0,b|0,c|0);e=v[23588];v[23588]=0;a:{b:{if((e|0)!=1){v[23588]=0;U(56,a|0,d+16|0,c|0);a=v[23588];v[23588]=0;if((a|0)==1){break b}yb(d+16|0);yb(b);jb=d+32|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;yb(d+16|0)}yb(b);T(c|0);L()}function XF(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=jb-16|0;jb=f;g=1073741807;if(1073741807-b>>>0>=c>>>0){h=zc(a);if(b>>>0<=536870886){v[f+8>>2]=b<<1;v[f+12>>2]=b+c;g=bm(v[Yc(f+12|0,f+8|0)>>2])+1|0}c=Bi(g);if(e){li(c,h,e)}if((d|0)!=(e|0)){i=e<<2;li(c+i|0,h+i|0,d-e|0)}if((b|0)!=1){Mb(h)}ud(a,c);bf(a,g);jb=f+16|0;return}hf();L()}function f$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=jb-16|0;jb=d;i=v[b>>2];h=v[a>>2];e=v[ic(a)>>2]==1158;f=v[c>>2]-h|0;g=f<<1;f=f>>>0<2147483647?g?g:1:-1;g=ks(e?0:h,f);if(g){if(!e){be(a)}v[d+4>>2]=1123;e=se(d+8|0,g,d+4|0);a=_F(a,e);Wc(e);v[b>>2]=v[a>>2]+(i-h|0);v[c>>2]=f+v[a>>2];jb=d+16|0;return}Cw();L()}function e5(a){a=a|0;var b=0;v[23588]=0;Y(952,a|0);b=v[23588];v[23588]=0;if((b|0)!=1){return Pg(v[v[a+24>>2]+24>>2])|0}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,7081,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function d5(a){a=a|0;var b=0;v[23588]=0;Y(952,a|0);b=v[23588];v[23588]=0;if((b|0)!=1){return Gs(v[v[a+24>>2]+24>>2])|0}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,6790,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function a5(a){a=a|0;var b=0;v[23588]=0;Y(952,a|0);b=v[23588];v[23588]=0;if((b|0)!=1){return Fs(v[v[a+24>>2]+24>>2])|0}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,7440,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function YB(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[Fb(a)>>2]){c=jb-16|0;jb=c;a=_h(c,a,1);Mi(v[a+4>>2],x[b>>1]);v[a+4>>2]=v[a+4>>2]+2;kc(a);jb=c+16|0;return}d=jb-32|0;jb=d;c=Fb(a);c=Mj(d+8|0,Nj(a,Qc(v[a>>2],v[a+4>>2])+1|0),Qc(v[a>>2],v[a+4>>2]),c);Mi(v[c+8>>2],x[b>>1]);v[c+8>>2]=v[c+8>>2]+2;Dd(a,c);Ni(c);jb=d+32|0}function M9(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[Fb(a)>>2]){c=jb-16|0;jb=c;a=Ah(c,a,1);dk(v[a+4>>2],z[b>>2]);v[a+4>>2]=v[a+4>>2]+4;kc(a);jb=c+16|0;return}d=jb-32|0;jb=d;c=Fb(a);c=Uf(d+8|0,pg(a,uc(v[a>>2],v[a+4>>2])+1|0),uc(v[a>>2],v[a+4>>2]),c);dk(v[c+8>>2],z[b>>2]);v[c+8>>2]=v[c+8>>2]+4;Dd(a,c);Tf(c);jb=d+32|0}function LV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=jb-1968|0;jb=e;c=jb-16|0;jb=c;f=e+8|0;SB(c+8|0,f);d=v[c+12>>2];ld(c,a,v[c+8>>2],v[c+12>>2]);g=v[c+4>>2];if((g|0)==(d|0)){hd(a,v[c+12>>2])}jb=c+16|0;d=(d|0)==(g|0);if(!d){RB(f)}c=-1;a:{if(!d){break a}c=0;if(!TB(e+8|0)){break a}c=Ae(a,b,1024,0)}jb=e+1968|0;return c|0}function D8(a){a=a|0;var b=0,c=0,d=0,e=0;c=jb-16|0;jb=c;v[v[a+20>>2]+148>>2]=-1;Eo(c+8|0,a+4228|0);d=v[a+20>>2];e=v[c+12>>2];b=v[c+8>>2];v[23588]=0;U(921,d+4|0,b|0,Kb(b,e)|0);b=v[23588];v[23588]=0;a:{if((b|0)==1){b=V(92948)|0;if((O()|0)!=(da(92948)|0)){break a}_(b|0)|0;Kc(v[a+20>>2]+4|0);$()}jb=c+16|0;return}T(b|0);L()}function u5(a){a=a|0;var b=0;v[23588]=0;Y(952,a|0);b=v[23588];v[23588]=0;if((b|0)!=1){return+EM(v[v[a+24>>2]+24>>2])}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,10099,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function sj(a){var b=0,c=0,d=0,e=0,f=0;b=v[a+4>>2];if(oc(v[a>>2],b)){a=0}else{b=Fi(b);e=Fi(v[a>>2]);c=jb-16|0;jb=c;v[c+8>>2]=b;while(1){a:{if(!Hg(b,e)){break a}d=jb-16|0;jb=d;v[d+8>>2]=b;f=kP(d+8|0);jb=d+16|0;if(x[v[f>>2]>>1]!=65535){break a}b=v[kP(c+8|0)>>2];continue}break}jb=c+16|0;a=HB(Eb(v[a>>2]),b)}return a&65535}function iw(a,b,c){var d=0;v[23588]=0;Y(952,a|0);d=v[23588];v[23588]=0;if((d|0)!=1){return v[v[v[a+24>>2]+24>>2]+c>>2]}c=V(0)|0;O()|0;_(c|0)|0;v[23588]=0;X(939,b|0,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function ck(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=v[a>>2];c=uc(d,v[a+4>>2]);if(c>>>0<b>>>0){d=jb-32|0;jb=d;b=b-c|0;c=v[Fb(a)>>2];e=v[a+4>>2];a:{if(b>>>0<=c-e>>2>>>0){Bt(a,b);break a}c=Fb(a);c=Uf(d+8|0,pg(a,uc(v[a>>2],e)+b|0),uc(v[a>>2],v[a+4>>2]),c);ML(c,b);Dd(a,c);Tf(c)}jb=d+32|0;return}if(b>>>0<c>>>0){Nd(a,d+(b<<2)|0)}}function bF(a,b,c){var d=0;v[23588]=0;Y(952,a|0);d=v[23588];v[23588]=0;if((d|0)!=1){return x[v[v[a+24>>2]+24>>2]+c>>1]}c=V(0)|0;O()|0;_(c|0)|0;v[23588]=0;X(939,b|0,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function V8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-32|0;jb=d;v[d+28>>2]=c;v[d+8>>2]=33;e=v[a>>2];f=v[a+8>>2];c=v[Jb(d+28|0,d+8|0)>>2];if(!Pb(e,f,c)){c=cf(a)}e=d+8|0;CA(e,b);f=gc(d+16|0,v[d+8>>2],c);mc(d,v[a>>2],v[a+8>>2],v[f>>2],v[f+4>>2]);CA(e,b);Tb(v[d+8>>2]+c|0,0,33-c|0);Zb(a,v[d+28>>2]);jb=d+32|0;return c|0}function BX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-32|0;jb=d;b=Ik(d,b);v[23588]=0;U(154,d+16|0,b|0,c|0);e=v[23588];v[23588]=0;a:{b:{if((e|0)!=1){v[23588]=0;U(4,a|0,d+16|0,c|0);a=v[23588];v[23588]=0;if((a|0)==1){break b}zb(d+16|0);zb(b);jb=d+32|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;zb(d+16|0)}zb(b);T(c|0);L()}function cJ(a){var b=0,c=0,d=0,e=0;b=jb-32|0;jb=b;if(!w[a+20|0]){while(1){if(!(nb[v[v[a>>2]+40>>2]](a)|0)){aJ(a,65536);c=gc(b+16|0,Kb(v[a+4>>2],v[a+16>>2]),65536);d=v[v[a>>2]+44>>2];e=v[c+4>>2];v[b+8>>2]=v[c>>2];v[b+12>>2]=e;nb[d|0](b+24|0,a,b+8|0);v[a+16>>2]=v[a+16>>2]+v[b+28>>2];continue}break}t[a+20|0]=1}jb=b+32|0}function WO(a){a=a|0;var b=0,c=0,d=0;b=jb-16|0;jb=b;if(w[a+534|0]){while(1){d=c&65535;if(d>>>0>=256){t[a+534|0]=0}else{qj(a,d,1);c=c+1|0;continue}break}}t[b+15|0]=0;bi(a+8|0,18,b+15|0);$t(a+26|0,18,29194);t[b+14|0]=255;bi(a+62|0,256,b+14|0);gh(v[a>>2],v[a+4>>2],65535,261,1);gh(v[a>>2],v[a+4>>2],65535,260,0);jb=b+16|0}function Th(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=a;f=jb-16|0;jb=f;a:{e=Rh(b,c);if(e>>>0<4294967280){b:{if(El(e)){ce(d,e);break b}g=Mg(e)+1|0;h=sc(g);ud(d,h);bf(d,g);Fd(d,e);d=h}while(1){if((b|0)!=(c|0)){ie(d,b);d=d+1|0;b=b+1|0;continue}break}t[f+15|0]=0;ie(d,f+15|0);jb=f+16|0;break a}hf();L()}return a|0}function CY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(Zg(a,v[b+8>>2],e)){nw(b,c,d);return}a:{if(!Zg(a,v[b>>2],e)){break a}if(!(v[b+16>>2]!=(c|0)&v[b+20>>2]!=(c|0))){if((d|0)!=1){break a}v[b+32>>2]=1;return}v[b+20>>2]=c;v[b+32>>2]=d;v[b+40>>2]=v[b+40>>2]+1;if(!(v[b+36>>2]!=1|v[b+24>>2]!=2)){t[b+54|0]=1}v[b+44>>2]=4}}function wha(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;v[c>>2]=v[a+8>>2];d=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=B(b,20)+d;b=v[c>>2];a:{while(1){if(v[c+4>>2]==(b|0)){break a}v[23588]=0;Y(228,b|0);a=v[23588];v[23588]=0;if((a|0)!=1){b=v[c>>2]+20|0;v[c>>2]=b;continue}break}a=P()|0;O()|0;Td(c);T(a|0);L()}Td(c);jb=c+16|0}function Zja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=jb-32|0;jb=e;c=jb-16|0;jb=c;f=e+8|0;cC(c+8|0,f);d=v[c+12>>2];ld(c,a,v[c+8>>2],v[c+12>>2]);g=v[c+4>>2];if((g|0)==(d|0)){hd(a,v[c+12>>2])}jb=c+16|0;d=(d|0)==(g|0);if(!d){Su(f)}c=-1;a:{if(!d){break a}c=0;if(!GU(e+8|0)){break a}c=Ae(a,b,72,0)}jb=e+32|0;return c|0}function GN(a,b,c,d){var e=0,f=0;e=jb-16|0;jb=e;f=-2147483648;f=!c|!(t[c+15|0]&1)?f:v[c+8>>2];a:{b:{if(!(!d|!(w[d+34|0]&32))){f=x[d+28>>1];break b}if((f|0)==-2147483648){break a}}aq(b,f,a);Cb(e+8|0,a+1074312|0,10);if(!Bb(v[v[e+8>>2]>>2],v[e+12>>2])|v[a+480208>>2]&16384){break a}v[b+88>>2]=v[b+88>>2]&-257}jb=e+16|0}function zfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-608|0;jb=d;c=jb-16|0;jb=c;gR(c+8|0,d);e=v[c+12>>2];ld(c,a,v[c+8>>2],v[c+12>>2]);f=v[c+4>>2];if((f|0)==(e|0)){hd(a,v[c+12>>2])}jb=c+16|0;e=(e|0)==(f|0);if(!e){fR(d)}c=-1;a:{if(!e){break a}c=0;if(!iR(d)){break a}c=Ae(a,b,hR(x[d+34>>1]),mb)}jb=d+608|0;return c|0}function lR(a){var b=0,c=0;a:{if(Rb(a,3868,4)|w[a+63|0]!=26){break a}b=w[a+65|0];if(w[a+66|0]|(b|0)!=16&(b|0)!=1|(w[a+64|0]&3|(w[a+78|0]|w[a+79|0]<<8)>>>0>127)){break a}if((w[a+80|0]|w[a+81|0]<<8)>>>0>127){break a}b=a+80|0;a=a+78|0;a=Dk(w[a|0]|w[a+1|0]<<8,w[b|0]|w[b+1|0]<<8)?b:a;c=(w[a|0]|w[a+1|0]<<8)!=0}return c}function ey(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=F(c,.999);h=c*3.141592653589793;i=vt(b);while(1){if((e|0)!=32768){f=((e<<12^-1)&28672)+(e>>>3|0)|0;if((f|0)!=16384){d=+(f-16384|0)*.000244140625;g=h*d;d=Ci(g)*vt(K(d*d*-.0625+1)*b)/(i*g)}else{d=1}j=a,k=Qz(c*d*32768),u[j>>1]=k;e=e+1|0;a=a+2|0;continue}break}}function S4(a){a=a|0;var b=0;v[23588]=0;Y(952,a|0);b=v[23588];v[23588]=0;if((b|0)!=1){return+A[v[a+24>>2]+16>>3]}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,7602,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function M4(a){a=a|0;var b=0;v[23588]=0;Y(952,a|0);b=v[23588];v[23588]=0;if((b|0)!=1){return v[v[a+24>>2]+8>>2]}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,10851,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)!=1){$();return-1}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function nja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-240|0;jb=d;c=jb-16|0;jb=c;ZT(c+8|0,d);e=v[c+12>>2];ld(c,a,v[c+8>>2],v[c+12>>2]);f=v[c+4>>2];if((f|0)==(e|0)){hd(a,v[c+12>>2])}jb=c+16|0;e=(e|0)==(f|0);if(!e){YT(d)}c=-1;a:{if(!e){break a}c=0;if(!$T(d)){break a}c=Ae(a,b,_T(v[d+4>>2]),mb)}jb=d+240|0;return c|0}function iea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-32|0;jb=d;v[d+28>>2]=c;v[d+8>>2]=4896;e=v[a>>2];f=v[a+8>>2];c=v[Jb(d+28|0,d+8|0)>>2];if(!Pb(e,f,c)){c=cf(a)}e=d+8|0;EA(e,b);f=gc(d+16|0,v[d+8>>2],c);mc(d,v[a>>2],v[a+8>>2],v[f>>2],v[f+4>>2]);EA(e,b);Tb(v[d+8>>2]+c|0,0,4896-c|0);Zb(a,v[d+28>>2]);jb=d+32|0}function iR(a){var b=0;a:{if(Rb(a+44|0,14113,4)|w[a+28|0]!=26|(w[a+40|0]|w[a+41|0]<<8|w[a+30|0]>2)){break a}if(((w[a+38|0]|w[a+39|0]<<8)-33&65535)>>>0<65504|((w[a+32|0]|w[a+33|0]<<8)-257&65535)>>>0<65280|((w[a+34|0]|w[a+35|0]<<8)-256&65535)>>>0<65281){break a}b=((w[a+36|0]|w[a+37|0]<<8)-1&65535)>>>0<128}return b}function F4(a,b){a=a|0;b=b|0;var c=0,d=0;a=Lb(a);c=Gb(b);v[23588]=0;R(73,a|0,c|0);c=v[23588];v[23588]=0;if((c|0)!=1){a:{b:{while(1){if(Gb(b)>>>0<=d>>>0){break b}c=t[gg(b,d)|0];v[23588]=0;R(51,a|0,yf(yf(c))|0);c=v[23588];v[23588]=0;if((c|0)!=1){d=d+1|0;continue}break}break a}return}}b=P()|0;O()|0;zb(a);T(b|0);L()}function rea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-32|0;jb=d;v[d+28>>2]=c;v[d+8>>2]=263;e=v[a>>2];f=v[a+8>>2];c=v[Jb(d+28|0,d+8|0)>>2];if(!Pb(e,f,c)){c=cf(a)}e=d+8|0;MP(e,b);f=gc(d+16|0,v[d+8>>2],c);mc(d,v[a>>2],v[a+8>>2],v[f>>2],v[f+4>>2]);MP(e,b);Tb(v[d+8>>2]+c|0,0,263-c|0);Zb(a,v[d+28>>2]);jb=d+32|0}function aja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-32|0;jb=d;v[d+28>>2]=c;v[d+8>>2]=102;e=v[a>>2];f=v[a+8>>2];c=v[Jb(d+28|0,d+8|0)>>2];if(!Pb(e,f,c)){c=cf(a)}e=d+8|0;RT(e,b);f=gc(d+16|0,v[d+8>>2],c);mc(d,v[a>>2],v[a+8>>2],v[f>>2],v[f+4>>2]);RT(e,b);Tb(v[d+8>>2]+c|0,0,102-c|0);Zb(a,v[d+28>>2]);jb=d+32|0}function Xx(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=jb-16|0;jb=d;h=x[b>>1];c=Sd(a);e=ic(a);f=jb-16|0;jb=f;while(1){if(c){g=Xs(x[c+16>>1],h);e=g?e:c;c=v[(g?c+4|0:c)>>2];continue}break}c=v[ec(f+8|0,e)>>2];jb=f+16|0;a:{if(Ob(c,Yf(a))){if(!Xs(x[b>>1],x[vd(c)>>1])){break a}}c=Yf(a)}a=v[ec(d+8|0,c)>>2];jb=d+16|0;return a}function Wfa(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[Fb(a)>>2]){c=jb-16|0;jb=c;a=cv(c,a,1);AR(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+20;kc(a);jb=c+16|0;return}d=jb-32|0;jb=d;c=Fb(a);c=lB(d+8|0,mB(a,Bf(v[a>>2],v[a+4>>2])+1|0),Bf(v[a>>2],v[a+4>>2]),c);AR(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+20;kB(a,c);vu(c);jb=d+32|0}function my(a,b,c){var d=0,e=0,f=0;d=jb-16|0;jb=d;f=v[b+656>>2];e=0;a:{if(!f){break a}f=iv(f,c);e=a+1074312|0;Cb(d+8|0,e,31);a=0;if(!Bb(v[v[d+8>>2]>>2],v[d+12>>2])){Cb(d,e,93);a=Bb(v[v[d>>2]>>2],v[d+4>>2])^1}if(!(t[nM(b,c)+6|0]&1)){e=0;if(!(t[f+12|0]&1)|a){break a}}e=oc(v[f>>2],v[f+4>>2])^1}jb=d+16|0;return e}function hca(a,b){a=a|0;b=b|0;var c=0,d=0;if(y[a+4>>2]<y[Fb(a)>>2]){c=jb-16|0;jb=c;a=Lz(c,a,1);xz(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+32;kc(a);jb=c+16|0;return}d=jb-32|0;jb=d;c=Fb(a);c=Dt(d+8|0,cq(a,qg(v[a>>2],v[a+4>>2])+1|0),qg(v[a>>2],v[a+4>>2]),c);xz(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+32;cP(a,c);wz(c);jb=d+32|0}function O_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a:{if(!ef(f)){b=v[f+4>>2];v[a>>2]=v[f>>2];v[a+4>>2]=b;v[a+8>>2]=v[f+8>>2];break a}d=v[f>>2];b:{c:{c=v[f+4>>2];d:{if(Ur(c)){ce(a,c);break d}if(c>>>0>=1073741808){break c}e=bm(c)+1|0;b=Bi(e);ud(a,b);bf(a,e);Fd(a,c);a=b}li(a,d,c+1|0);break b}hf();L()}}}function Eja(a,b){a=a|0;b=b|0;var c=0,d=0;if(y[a+4>>2]<y[Fb(a)>>2]){c=jb-16|0;jb=c;a=cv(c,a,1);nB(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+20;kc(a);jb=c+16|0;return}d=jb-32|0;jb=d;c=Fb(a);c=lB(d+8|0,mB(a,Bf(v[a>>2],v[a+4>>2])+1|0),Bf(v[a>>2],v[a+4>>2]),c);nB(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+20;kB(a,c);vu(c);jb=d+32|0}function DB(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[Fb(a)>>2]){c=jb-16|0;jb=c;a=UU(c,a,1);TU(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+40;kc(a);jb=c+16|0;return}d=jb-32|0;jb=d;c=Fb(a);c=RU(d+8|0,SU(a,Eq(v[a>>2],v[a+4>>2])+1|0),Eq(v[a>>2],v[a+4>>2]),c);TU(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+40;QU(a,c);PU(c);jb=d+32|0}function r$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=jb-32|0;jb=g;h=v[20803];v[g+24>>2]=v[20802];v[g+28>>2]=h;h=v[20801];v[g+16>>2]=v[20800];v[g+20>>2]=h;h=v[20799];v[g+8>>2]=v[20798];v[g+12>>2]=h;h=v[20797];v[g>>2]=v[20796];v[g+4>>2]=h;h=a;a=g+32|0;b=Yj(h,b,c,d,e,f,g,a);jb=a;return b|0}function pha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-32|0;jb=d;v[d+28>>2]=c;v[d+8>>2]=22;e=v[a>>2];f=v[a+8>>2];c=v[Jb(d+28|0,d+8|0)>>2];if(!Pb(e,f,c)){c=cf(a)}e=d+8|0;zu(e,b);f=gc(d+16|0,v[d+8>>2],c);mc(d,v[a>>2],v[a+8>>2],v[f>>2],v[f+4>>2]);zu(e,b);Tb(v[d+8>>2]+c|0,0,22-c|0);Zb(a,v[d+28>>2]);jb=d+32|0}function nha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-32|0;jb=d;v[d+28>>2]=c;v[d+8>>2]=40;e=v[a>>2];f=v[a+8>>2];c=v[Jb(d+28|0,d+8|0)>>2];if(!Pb(e,f,c)){c=cf(a)}e=d+8|0;uA(e,b);f=gc(d+16|0,v[d+8>>2],c);mc(d,v[a>>2],v[a+8>>2],v[f>>2],v[f+4>>2]);uA(e,b);Tb(v[d+8>>2]+c|0,0,40-c|0);Zb(a,v[d+28>>2]);jb=d+32|0}function gO(a,b){a=a|0;b=b|0;var c=0,d=0;if(y[a+4>>2]<y[Fb(a)>>2]){c=jb-16|0;jb=c;a=Pt(c,a,1);$o(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+12;kc(a);jb=c+16|0;return}d=jb-32|0;jb=d;c=Fb(a);c=Hk(d+8|0,jn(a,xd(v[a>>2],v[a+4>>2])+1|0),xd(v[a>>2],v[a+4>>2]),c);$o(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+12;yr(a,c);fO(c);jb=d+32|0}function efa(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[Fb(a)>>2]){c=jb-16|0;jb=c;a=Tv(c,a);Tz(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+12;kc(a);jb=c+16|0;return}d=jb-32|0;jb=d;c=Fb(a);c=Hk(d+8|0,jn(a,xd(v[a>>2],v[a+4>>2])+1|0),xd(v[a>>2],v[a+4>>2]),c);Tz(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+12;HQ(a,c);GQ(c);jb=d+32|0}function mW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-32|0;jb=d;v[d+28>>2]=c;v[d+8>>2]=65;e=v[a>>2];f=v[a+8>>2];c=v[Jb(d+28|0,d+8|0)>>2];if(!Pb(e,f,c)){c=cf(a)}e=d+8|0;bv(e,b);f=gc(d+16|0,v[d+8>>2],c);mc(d,v[a>>2],v[a+8>>2],v[f>>2],v[f+4>>2]);bv(e,b);Tb(v[d+8>>2]+c|0,0,65-c|0);Zb(a,v[d+28>>2]);jb=d+32|0}function ega(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-1120|0;jb=d;c=jb-16|0;jb=c;FR(c+8|0,d+8|0);e=v[c+12>>2];ld(c,a,v[c+8>>2],v[c+12>>2]);f=v[c+4>>2];if((f|0)==(e|0)){hd(a,v[c+12>>2])}jb=c+16|0;c=-1;a:{if((e|0)!=(f|0)){break a}c=0;if(!HR(d+8|0)){break a}c=Ae(a,b,GR(v[d+1112>>2]),mb)}jb=d+1120|0;return c|0}function Xp(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-16|0;jb=d;t[d+15|0]=b;a:{b:{c:{if(!ef(a)){c=10;b=w[a+11|0];if((b|0)==10){break c}ce(a,b+1|0);c=a;break a}c=Kl(a);b=v[a+4>>2];c=c-1|0;if((b|0)!=(c|0)){break b}}rm(a,c,1,c,c,0,0);b=c}c=v[a>>2];Fd(a,b+1|0)}a=b+c|0;ie(a,d+15|0);t[d+14|0]=0;ie(a+1|0,d+14|0);jb=d+16|0}function Ff(a,b,c,d){var e=0,f=0,g=0;a:{if(!Gb(a)|(c-b|0)<5){break a}Sr(b,c);e=c-4|0;c=Lc(a);g=c+Gb(a)|0;b:{while(1){c:{a=t[c|0];f=a-127|0;if(b>>>0>=e>>>0){break c}if((a|0)!=v[b>>2]&(f&255)>>>0>=130){break b}b=b+4|0;c=((g-c|0)>1)+c|0;continue}break}if((f&255)>>>0<130|a>>>0>v[e>>2]-1>>>0){break a}}v[d>>2]=4}}function zja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-224|0;jb=d;c=jb-16|0;jb=c;lU(c+8|0,d);e=v[c+12>>2];ld(c,a,v[c+8>>2],v[c+12>>2]);f=v[c+4>>2];if((f|0)==(e|0)){hd(a,v[c+12>>2])}jb=c+16|0;c=-1;a:{if((e|0)!=(f|0)){break a}c=0;if(!nU(d)){break a}c=Ae(a,b,mU(w[d+216|0],w[d+217|0]),mb)}jb=d+224|0;return c|0}function pja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-32|0;jb=d;v[d+28>>2]=c;v[d+8>>2]=5;e=v[a>>2];f=v[a+8>>2];c=v[Jb(d+28|0,d+8|0)>>2];if(!Pb(e,f,c)){c=cf(a)}e=d+8|0;Do(e,b);f=gc(d+16|0,v[d+8>>2],c);mc(d,v[a>>2],v[a+8>>2],v[f>>2],v[f+4>>2]);Do(e,b);Tb(v[d+8>>2]+c|0,0,5-c|0);Zb(a,v[d+28>>2]);jb=d+32|0}function TX(a,b){a=a|0;b=b|0;var c=0,d=0;if(y[a+4>>2]<y[Fb(a)>>2]){c=jb-16|0;jb=c;a=Tv(c,a);$o(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+12;kc(a);jb=c+16|0;return}d=jb-32|0;jb=d;c=Fb(a);c=Hk(d+8|0,jn(a,xd(v[a>>2],v[a+4>>2])+1|0),xd(v[a>>2],v[a+4>>2]),c);$o(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+12;yr(a,c);Sv(c);jb=d+32|0}function NW(a,b){a=a|0;b=b|0;var c=0,d=0;if(y[a+4>>2]<y[Fb(a)>>2]){c=jb-16|0;jb=c;a=zD(c,a);zv(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+36;kc(a);jb=c+16|0;return}d=jb-32|0;jb=d;c=Fb(a);c=xD(d+8|0,yD(a,jr(v[a>>2],v[a+4>>2])+1|0),jr(v[a>>2],v[a+4>>2]),c);zv(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+36;wD(a,c);Bv(c);jb=d+32|0}function LK(a){var b=0,c=C(0),d=0,e=0;e=v[v[a+16>>2]+24620>>2];b=jb-16|0;jb=b;v[b+12>>2]=0;v[b+8>>2]=1065353216;c=Vh(C(z[kq(a+4208|0,b+12|0,b+8|0)>>2]*C(999)));a:{if(c<C(4294967296)&c>=C(0)){d=~~c>>>0;break a}d=0}jb=b+16|0;b=(e>>>0)/(d+1>>>0)|0;b=b>>>0>2?b:2;v[a+4216>>2]=b;v[a+4220>>2]=b>>>1;wc(a+4224|0,b)}function rL(a){a=a|0;var b=0,c=0;c=jb-16|0;jb=c;b=v[a+4232>>2];b=(b>>>1)+(b>>>6)|0;v[a+4220>>2]=b;v[23588]=0;v[c+12>>2]=0;U(903,a+4208|0,b<<1,c+12|0);b=v[23588];v[23588]=0;a:{if((b|0)==1){b=V(92948)|0;if((O()|0)!=(da(92948)|0)){break a}_(b|0)|0;v[a+4220>>2]=0;$()}v[a+4224>>2]=0;jb=c+16|0;return}T(b|0);L()}function mfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb+-64|0;jb=d;c=jb-16|0;jb=c;Gu(c+8|0,d);e=v[c+12>>2];ld(c,a,v[c+8>>2],v[c+12>>2]);f=v[c+4>>2];if((f|0)==(e|0)){hd(a,v[c+12>>2])}jb=c+16|0;e=(e|0)==(f|0);if(!e){Bu(d)}c=-1;a:{if(!e){break a}c=0;if(!OQ(d)){break a}c=Ae(a,b,NQ(d),mb)}jb=d- -64|0;return c|0}function l0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a=Lb(a);d=yd(v[b+4>>2],w[b+11|0]);e=yd(v[c+4>>2],w[c+11|0]);b=od(b);v[23588]=0;X(102,a|0,b|0,d|0,d+e|0);b=v[23588];v[23588]=0;a:{if((b|0)!=1){b=od(c);v[23588]=0;W(103,a|0,b|0,e|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;zb(a);T(b|0);L()}}function Oy(a,b,c,d,e,f){var g=0,h=0,i=0;g=jb-16|0;jb=g;h=-17;if(-17-b>>>0>=c>>>0){i=od(a);if(b>>>0<=2147483622){v[g+8>>2]=b<<1;v[g+12>>2]=b+c;h=Mg(v[Yc(g+12|0,g+8|0)>>2])+1|0}c=sc(h);if(e){ve(c,i,e)}if((d|0)!=(e|0)){ve((c+e|0)+f|0,e+i|0,d-e|0)}if((b|0)!=10){Mb(i)}ud(a,c);bf(a,h);jb=g+16|0;return}hf();L()}function O8(a,b){a=a|0;b=b|0;var c=0;a:{c=jb-32|0;jb=c;Ds(c,b);v[23588]=0;R(913,c+16|0,c|0);b=v[23588];v[23588]=0;b:{c:{if((b|0)!=1){v[23588]=0;U(914,a|0,0,c+16|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}Fc(c+16|0);zb(c);jb=c+32|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;Fc(c+16|0)}zb(c);T(a|0);L()}}function O2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;a:{if(w[b+40|0]){break a}if(!v[b+28>>2]){t[b+40|0]=1;break a}d=v[c+4>>2];f=v[c>>2];while(1){b:{if(d){e=nb[v[b+28>>2]](v[b+24>>2],f,d)|0;if(e){break b}t[b+40|0]=1}d=g;break a}d=d-e|0;f=e+f|0;g=e+g|0;h=g>>>0<e>>>0?h+1|0:h;continue}}fc(a,v[c>>2],d)}function tja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-208|0;jb=d;c=jb-16|0;jb=c;dU(c+8|0,d);e=v[c+12>>2];ld(c,a,v[c+8>>2],v[c+12>>2]);f=v[c+4>>2];if((f|0)==(e|0)){hd(a,v[c+12>>2])}jb=c+16|0;e=(e|0)==(f|0);if(!e){cU(d)}c=-1;a:{if(!e){break a}c=0;if(!fU(d)){break a}c=Ae(a,b,eU(d),mb)}jb=d+208|0;return c|0}function o6(a){a=a|0;var b=0;v[23588]=0;Y(952,a|0);b=v[23588];v[23588]=0;if((b|0)!=1){return v[a+16>>2]}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,5693,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)!=1){$();return-1}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function Ss(a){var b=0,c=0,d=0;b=mi(+z[a+4228>>2]*8)*.25+-.25;A[a+4248>>3]=b;if(w[a+4240|0]){if(b>45e-5){c=zp(b)/.6931471805599453;b=c-H(c);d=c-b;c=0;a:{if(b<.2075187496394219){break a}c=.4150374992788438;if(b<.5){break a}c=b<.792481250360578?.5849625007211562:1}b=mi(d+c)*.5}else{b=0}A[a+4248>>3]=b}Rs(a)}function Ol(a,b,c,d,e){var f=0;a:{if(c>>>0>255){break a}b:{switch(d-2|0){case 0:d=B(c,872)+b|0;f=oN(v[d+720>>2],v[d+1272>>2],e);if((f+5&255)>>>0>5){break a}return nN(a,b,c,e);case 1:break b;default:break a}}f=nN(a,b,c,e);if((f+5&255)>>>0>5){break a}a=B(c,872)+b|0;f=oN(v[a+720>>2],v[a+1272>>2],e)}return f}function Kia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-192|0;jb=d;c=jb-16|0;jb=c;Lq(c+8|0,d);e=v[c+12>>2];ld(c,a,v[c+8>>2],v[c+12>>2]);f=v[c+4>>2];if((f|0)==(e|0)){hd(a,v[c+12>>2])}jb=c+16|0;e=(e|0)==(f|0);if(!e){yT(d)}c=-1;a:{if(!e){break a}c=0;if(!AT(d)){break a}c=Ae(a,b,zT(d),mb)}jb=d+192|0;return c|0}function I5(a){a=a|0;var b=0;v[23588]=0;Y(977,a|0);b=v[23588];v[23588]=0;a:{if((b|0)==1){b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,11894,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();a=0}return a|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Ub();L()}function Fka(a){a=a|0;var b=0,c=0,d=0;c=jb-32|0;jb=c;b=255;a:{if(rj(v[a>>2],v[a+4>>2])>>>0<=49){b=Bz(c,v[a+12>>2]);v[23588]=0;R(289,a|0,b|0);d=v[23588];v[23588]=0;if((d|0)==1){break a}ql(b);Fj(a,rj(v[a>>2],v[a+4>>2])-1&255);b=rj(v[a>>2],v[a+4>>2])-1|0}jb=c+32|0;return b&255}a=P()|0;O()|0;ql(b);T(a|0);L()}function BB(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=jb-32|0;jb=f;v[f+8>>2]=c;g=f,h=cf(b),v[g+28>>2]=h;c=f+8|0;Nf(c,b,v[Jb(c,f+28|0)>>2]);b=Ie(c);v[23588]=0;ea(236,a|0,b|0,v[f+8>>2],d|0,e|0);a=v[23588];v[23588]=0;if((a|0)!=1){Tc(f+8|0);jb=f+32|0;return}a=P()|0;O()|0;Tc(f+8|0);T(a|0);L()}function _m(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;a:{if(v[c>>2]|v[d>>2]){while(1){if((b|0)==(f|0)){break a}e=v[d>>2];g=v[c>>2];h=c,i=g-kd((kd(0-g|0,31)&255)+g|0,8)|0,v[h>>2]=i;h=d,i=v[d>>2]-kd(e+(kd(0-e|0,31)&255)|0,8)|0,v[h>>2]=i;e=(f<<3)+a|0;v[e>>2]=v[c>>2];v[e+4>>2]=v[d>>2];f=f+1|0;continue}}Tb(a,0,b<<3)}}function Zx(a,b,c){var d=0,e=0;d=jb-16|0;jb=d;v[d>>2]=a;a=v[a+4>>2];v[d+4>>2]=a;v[d+8>>2]=a+B(b,52);b=v[d+4>>2];a=v[d+8>>2];a:{while(1){if((a|0)==(b|0)){break a}v[23588]=0;R(877,b|0,c|0);e=v[23588];v[23588]=0;if((e|0)!=1){b=b+52|0;v[d+4>>2]=b;continue}break}a=P()|0;O()|0;kc(d);T(a|0);L()}kc(d);jb=d+16|0}function Dka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;v[d+12>>2]=c;a:{if(!Pb(v[b>>2],v[b+8>>2],c<<1)){break a}wc(d+12|0,65535);ug(a,x[d+12>>1]);c=Eb(v[a>>2]);v[d>>2]=c;a=Eb(v[a+4>>2]);while(1){if(!Ob(c,a)){break a}Wu(b,d+8|0);e=c,f=Hb(x[d+8>>1]),u[e>>1]=f;c=v[Re(d)>>2];continue}}jb=d+16|0}function vea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-80|0;jb=d;c=jb-16|0;jb=c;aT(c+8|0,d);e=v[c+12>>2];ld(c,a,v[c+8>>2],v[c+12>>2]);f=v[c+4>>2];if((f|0)==(e|0)){hd(a,v[c+12>>2])}jb=c+16|0;e=(e|0)==(f|0);if(!e){FA(d)}c=-1;a:{if(!e){break a}c=0;if(!SP(d)){break a}c=Ae(a,b,RP(d),mb)}jb=d+80|0;return c|0}function sZ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=jb-16|0;jb=f;v[e>>2]=c;a=qw(f+12|0,0,v[a+8>>2]);b=2;a:{if(a+1>>>0<2){break a}c=a-1|0;b=1;if(c>>>0>d-v[e>>2]>>>0){break a}b=f+12|0;while(1){if(c){a=w[b|0];d=v[e>>2];v[e>>2]=d+1;t[d|0]=a;c=c-1|0;b=b+1|0;continue}break}b=0}jb=f+16|0;return b|0}function ru(a){var b=0,c=0;b=v[a+76>>2];if(!((b|0)>=0&(!b|v[116072]!=(b&-1073741825)))){b=v[a+4>>2];if((b|0)!=v[a+8>>2]){v[a+4>>2]=b+1;return w[b|0]}return Lw(a)}b=v[a+76>>2];v[a+76>>2]=b?b:1073741823;c=a+76|0;b=v[a+4>>2];a:{if((b|0)!=v[a+8>>2]){v[a+4>>2]=b+1;a=w[b|0];break a}a=Lw(a)}v[c>>2]=0;return a}function p7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;fd(a,b);v[23588]=0;U(66,d+8|0,b|0,c|0);e=v[23588];v[23588]=0;a:{if((e|0)==1){break a}$b(d+8|0);b=v[b+24>>2];if(b){v[23588]=0;U(67,d|0,b|0,c|0);b=v[23588];v[23588]=0;if((b|0)==1){break a}$b(d)}jb=d+16|0;return}b=P()|0;O()|0;$b(a);T(b|0);L()}function Qr(a,b,c,d){var e=0;a:{if(!(d&2048)){break a}e=d&74;if(!c|((e|0)==8|(e|0)==64)){break a}t[a|0]=43;a=a+1|0}if(d&512){t[a|0]=35;a=a+1|0}while(1){e=w[b|0];if(e){t[a|0]=e;a=a+1|0;b=b+1|0;continue}break}e=d&74;b=111;b:{if((e|0)==64){break b}b=d&16384?88:120;if((e|0)==8){break b}b=c?100:117}t[a|0]=b}function uga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-128|0;jb=d;c=jb-16|0;jb=c;RR(c+8|0,d);e=v[c+12>>2];ld(c,a,v[c+8>>2],v[c+12>>2]);f=v[c+4>>2];if((f|0)==(e|0)){hd(a,v[c+12>>2])}jb=c+16|0;e=(e|0)==(f|0);if(!e){QR(d)}c=-1;a:{if(!e){break a}c=0;if(!SR(d)){break a}c=Ae(a,b,256,0)}jb=d+128|0;return c|0}function kba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=tc(a,b,614);e=c+616|0;a=0;while(1){d=B(a,872);Rp(d+e|0,(b+d|0)+616|0);a=a+1|0;if((a|0)!=256){continue}break}a=Wz(c+223848|0,b+223848|0);v[23588]=0;Q(803,c+223860|0,b+223860|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){return c|0}b=P()|0;O()|0;hc(a);T(b|0);L()}function el(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;Ds(c,b);v[23588]=0;R(1057,c+16|0,c|0);b=v[23588];v[23588]=0;a:{b:{if((b|0)!=1){v[23588]=0;U(914,a|0,0,c+16|0);a=v[23588];v[23588]=0;if((a|0)==1){break b}Fc(c+16|0);zb(c);jb=c+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;Fc(c+16|0)}zb(c);T(b|0);L()}function cca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;c=qf(a,c);me(d,v[a+36>>2]);a:{b:{if(!c){Rc(d,a+32|0,5);e=-1;if(!Bb(v[v[d>>2]>>2],v[d+4>>2])){break b}break a}e=v[c+16>>2]}f=v[a+36>>2];c:{d:{switch(e+1|0){case 0:case 2:hi(f,b);break c;default:break d}}lT(f,b,e)}f=c}Xe(a,f);jb=d+16|0}function _L(a){var b=0,c=0;a:{if(Rb(a,14147,4)){break a}b=w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24);if((b|0)!=-1095062050&(b|0)!=-1346458146){break a}b=w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24);if(!b){break a}c=(b+24|0)==(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))}return c}function pq(a){var b=0,c=0;b=jb-32|0;jb=b;v[b+24>>2]=0;v[b+28>>2]=0;v[b+16>>2]=0;v[b+20>>2]=0;v[b+8>>2]=0;v[b+12>>2]=0;v[b>>2]=0;v[b+4>>2]=0;c=a+288|0;Gz(c,c+512|0,b);v[b+24>>2]=0;v[b+28>>2]=0;v[b+16>>2]=0;v[b+20>>2]=0;v[b+8>>2]=0;v[b+12>>2]=0;v[b>>2]=0;v[b+4>>2]=0;a=a+800|0;Gz(a,vQ(a),b);jb=b+32|0}function bw(a,b,c,d,e){var f=0,g=0;g=c-b|0;a:{if((e|0)>=(g|0)){e=B(32-E(d|1)|0,1233)>>12;f=61;if((g|0)<(e+(y[(e<<2)+25744>>2]<=d>>>0)|0)){break a}}b:{if(d>>>0<=99999999){c=Zw(b,d);break b}c=d;d=(d>>>0)/1e8|0;e=c+B(d,-1e8)|0;c=(e>>>0)/1e4|0;c=dj(dj(KH(b,d),c),e+B(c,-1e4)|0)}f=0}v[a+4>>2]=f;v[a>>2]=c}function F3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;a:{if(!(c&1024)){break a}f=e,g=he(b),v[f+8>>2]=g;b:{if(!Gb(b)){break b}if(w[Sc(b,0)|0]!=43){if(w[Sc(b,0)|0]!=45){break b}}d=d+1|0;wJ(e+8|0)}c=Gb(b);if(c>>>0>=d>>>0){break a}rJ(b,v[lj(e,e+8|0)>>2],d-c|0,48)}$c(a,b);jb=e+16|0}function v8(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=C(0);if(b>>>0<=6){c=Xd(c,C(0));a:{b:{switch(b-3|0){case 0:c=Vh(c);if(c==z[Db(a+4208|0,3)>>2]){break a}v[a+4236>>2]=0;z[a+4240>>2]=C(c*C(.5))+C(.5);break a;case 1:break b;default:break a}}c=C(Vh(C(c*C(4)))*C(.25))}d=Db(a+4208|0,b),e=c,z[d>>2]=e;Hx(a)}}function O7(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=C(0);if(b>>>0<=6){c=Xd(c,C(0));a:{b:{switch(b-1|0){case 0:c=Vh(c);if(c==z[Db(a+4208|0,1)>>2]){break a}v[a+4236>>2]=0;z[a+4240>>2]=C(c*C(.5))+C(.5);break a;case 3:break b;default:break a}}c=C(Vh(C(c*C(4)))*C(.25))}d=Db(a+4208|0,b),e=c,z[d>>2]=e;Hx(a)}}function aO(a,b,c){var d=0,e=0;d=jb-16|0;jb=d;e=v[b+48>>2]+1|0;v[b+52>>2]=e;a:{if(y[Yb(v[a+484344>>2],x[b+70>>1])+12>>2]>e>>>0){break a}if(!c){u[b+74>>1]=x[b+72>>1]+1}v[b+52>>2]=0;Cb(d+8|0,a+1074312|0,63);if(!Bb(v[v[d+8>>2]>>2],v[d+12>>2])){break a}a=v[b+56>>2];v[b+56>>2]=0;v[b+52>>2]=a}jb=d+16|0}function ml(a,b,c){var d=0,e=0;a=Lb(a);d=Gb(b);v[23588]=0;R(48,a|0,d|0);d=v[23588];v[23588]=0;if((d|0)!=1){a:{while(1){if(Gb(b)>>>0>e>>>0){d=v[(w[gg(b,e)|0]<<2)+c>>2];v[23588]=0;R(49,a|0,d|0);d=v[23588];v[23588]=0;if((d|0)==1){break a}e=e+1|0;continue}break}return}}b=P()|0;O()|0;Fc(a);T(b|0);L()}function lL(a){a=a|0;var b=0,c=0,d=0;b=A[a+4264>>3]*+y[v[a+16>>2]+1074376>>2];a:{if(D(b)<0x8000000000000000){d=~~b>>>0;c=D(b)>=1?~~(b>0?F(H(b*2.3283064365386963e-10),4294967295):I((b-+(~~b>>>0>>>0))*2.3283064365386963e-10))>>>0:0;break a}c=-2147483648}A[a+4256>>3]=b-(+(d>>>0)+ +(c|0)*4294967296)}function EY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;if(Zg(a,v[b+8>>2],0)){mw(b,c,d);return}e=v[a+12>>2];f=a+16|0;tF(v[f>>2],v[a+20>>2],b,c,d);a=a+24|0;e=(e<<3)+f|0;a:{if(a>>>0>=e>>>0){break a}while(1){tF(v[a>>2],v[a+4>>2],b,c,d);if(w[b+54|0]){break a}a=a+8|0;if(e>>>0>a>>>0){continue}break}}}function C9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=si(a,b,c,d);v[a>>2]=43836;b=Sb(a+4208|0);v[a+4228>>2]=0;v[a+4220>>2]=0;v[a+4224>>2]=0;v[a+4232>>2]=v[c+24620>>2];vV(a+4260|0,80,150,80,255);v[23588]=0;R(897,a+44|0,2);c=v[23588];v[23588]=0;if((c|0)!=1){return a|0}c=P()|0;O()|0;vc(b);If(a);T(c|0);L()}function R3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[a>>2]=0;v[a+4>>2]=0;Gc(a+8|0);c=lk(v[b+4>>2],v[b+8>>2]);if(c){FO(a,c);d=v[b+4>>2];e=v[b+8>>2];b=jb-16|0;jb=b;a=Et(b,a,c);v[23588]=0;U(1058,d|0,e|0,a+4|0);c=v[23588];v[23588]=0;a:{if((c|0)!=1){kc(a);jb=b+16|0;break a}b=P()|0;O()|0;kc(a);T(b|0);L()}}}function uja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;v[d+8>>2]=c;v[d+12>>2]=-1;if((c|0)!=-1){f=d,g=Gb(a),v[f>>2]=g;e=v[Jb(d+12|0,d)>>2];v[d+4>>2]=e;a=Lp(Lc(a),b,v[Jb(d+4|0,d+8|0)>>2]);a:{if(a){break a}a=-1;if(c>>>0>e>>>0){break a}a=c>>>0<e>>>0}jb=d+16|0;return a|0}rk();L()}function ah(a,b){var c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;a:{if(!b){b=0;break a}c=b>>31;e=(c^b)-c|0;c=E(e);Kf(d,e,0,0,0,c+81|0);e=0+v[d+8>>2]|0;c=(v[d+12>>2]^65536)+(16414-c<<16)|0;c=e>>>0<f>>>0?c+1|0:c;f=b&-2147483648|c;c=v[d+4>>2];b=v[d>>2]}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=e;v[a+12>>2]=f;jb=d+16|0}function IO(a,b,c){var d=0,e=0,f=0,g=0;if(c==0){e=a;b=Es(b);o(0);a=j(1)|0;f=j(0)|0;o(+c);d=j(1)|0;j(0)|0;l(0,f|0);l(1,a&2147483647|d&-2147483648);nl(e,b,+n());return}a:{if(!mf(b)){break a}d=D(c)<N;if(b<0){c=d?c:1;break a}if(d){break a}nl(a,b,mf(c)?M:c);return}b=Es(b);g=Ci(c);nl(a,b*$e(c),g*b)}function uB(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-32|0;jb=e;v[e+8>>2]=c;f=e,g=cf(b),v[f+28>>2]=g;c=e+8|0;Nf(c,b,v[Jb(c,e+28|0)>>2]);b=Ie(c);v[23588]=0;X(337,a|0,b|0,v[e+8>>2],d|0);a=v[23588];v[23588]=0;if((a|0)!=1){Tc(e+8|0);jb=e+32|0;return}a=P()|0;O()|0;Tc(e+8|0);T(a|0);L()}function iba(a,b){a=a|0;b=b|0;var c=0,d=0;a:{if(Pd(w[b+24|0])){a=Xf(a);c=Fi(v[b>>2]);d=wf(b);v[23588]=0;U(806,a|0,c|0,d|0);c=v[23588];v[23588]=0;if((c|0)==1){break a}v[23588]=0;Q(805,a+12|0,b+12|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break a}t[a+24|0]=1}return}b=P()|0;O()|0;xN(a);T(b|0);L()}function WB(a,b,c){var d=0,e=0,f=0;d=jb-32|0;jb=d;v[d+28>>2]=c;v[d+8>>2]=192;e=v[a>>2];f=v[a+8>>2];c=v[Jb(d+28|0,d+8|0)>>2];if(!Pb(e,f,c)){c=cf(a)}e=d+8|0;Lq(e,b);f=gc(d+16|0,v[d+8>>2],c);mc(d,v[a>>2],v[a+8>>2],v[f>>2],v[f+4>>2]);Lq(e,b);Tb(v[d+8>>2]+c|0,0,192-c|0);Zb(a,v[d+28>>2]);jb=d+32|0}function MY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;a:{e=v[b>>2];if(Ed(e)){if(!Qe(c)){qK(c,17734);e=v[b>>2]}b=v[b+4>>2];nb[v[v[b>>2]+24>>2]](d,b,e);v[23588]=0;Q(800,c|0,d|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break a}yb(d)}$c(a,c);jb=d+16|0;return}a=P()|0;O()|0;yb(d);T(a|0);L()}function qQ(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=jb-16|0;jb=e;v[e+12>>2]=6553600;i=e,j=bc(b),v[i+8>>2]=j;f=+(d>>>0)/6553600;g=e+12|0;b=e+8|0;h=zq(f*+y[Jb(g,b)>>2]);v[e+8>>2]=6553600;i=e,j=bc(c),v[i+4>>2]=j;i=e,j=zq(f*+y[Jb(b,e+4|0)>>2]),v[i+12>>2]=j;v[e+8>>2]=d-h;ho(a,h,Jb(b,g));jb=e+16|0}function UT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;a=Xf(a);b=b+236|0;e=yq(b);a:{while(1){if((b|0)!=(e|0)){d=x[b>>1];u[c+14>>1]=d;if(d){v[23588]=0;U(392,c|0,a|0,c+14|0);d=v[23588];v[23588]=0;if((d|0)==1){break a}}b=b+2|0;continue}break}jb=c+16|0;return}b=P()|0;O()|0;qu(a);T(b|0);L()}function CL(a,b){var c=0,d=0,e=0,f=0,g=C(0);c=jb-16|0;jb=c;if(Yg(v[v[a>>2]-12>>2]+a|0)){u[c+14>>1]=0;Vf(a,c+14|0);e=x[c+14>>1];ck(b,e);while(1){if((d|0)!=(e|0)){v[c+8>>2]=0;Dp(a,c+8|0);f=Db(v[b>>2],d),g=z[c+8>>2],z[f>>2]=g;d=d+1|0;continue}break}d=Yg(v[v[a>>2]-12>>2]+a|0)}jb=c+16|0;return d}function zU(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+14|0]=0;t[a+15|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function WJ(a,b){var c=0;c=jb-32|0;jb=c;oi(c,b);v[23588]=0;U(917,c+16|0,0,c|0);b=v[23588];v[23588]=0;a:{b:{if((b|0)!=1){v[23588]=0;R(1060,a|0,c+16|0);a=v[23588];v[23588]=0;if((a|0)==1){break b}Fc(c+16|0);yb(c);jb=c+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;Fc(c+16|0)}yb(c);T(b|0);L()}function Nv(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function Ew(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-160|0;jb=e;v[e+60>>2]=b;v[e+20>>2]=b;v[e+24>>2]=-1;f=e+16|0;ki(f,0,0);TG(e,f,d,1);d=v[e+8>>2];f=v[e+12>>2];g=v[e>>2];h=v[e+4>>2];if(c){v[c>>2]=((v[e+20>>2]+v[e+136>>2]|0)-v[e+60>>2]|0)+b}v[a+8>>2]=d;v[a+12>>2]=f;v[a>>2]=g;v[a+4>>2]=h;jb=e+160|0}function mp(a,b){var c=0,d=0;c=jb-16|0;jb=c;d=c+8|0;fd(d,a);v[23588]=0;a=S(1136,d|0)|0;d=v[23588];v[23588]=0;a:{b:{if((d|0)==1){break b}v[23588]=0;X(1148,a|0,82976,83002,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break b}$b(c+8|0);jb=c+16|0;break a}a=P()|0;O()|0;$b(c+8|0);T(a|0);L()}return b}function jD(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=v[a+92>>2];e=v[a+96>>2];if(d|e){while(1){if((c|0)==(g|0)){v[a+96>>2]=e;v[a+92>>2]=d}else{f=(g<<3)+b|0;h=v[f>>2];d=d-kd((kd(0-d|0,31)&255)+d|0,8)|0;v[f>>2]=h+d;h=v[f+4>>2];e=e-kd((kd(0-e|0,31)&255)+e|0,8)|0;v[f+4>>2]=h+e;g=g+1|0;continue}break}}}function Ry(a,b,c){var d=0;d=v[a+480180>>2];a:{if((d|0)!=1048576){if((d|0)!=4){break a}d=w[b+813|0];if(c){t[b+813|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(c){t[b+813|0]=c;break a}c=w[b+813|0]}b:{if(!(t[b+851|0]&1)|!v[b+700>>2]){break b}c=c&255;if(!c){break b}fk(a,b,b+700|0,c<<2,0)}}function MK(a){a=a|0;var b=0,c=0;c=jb-16|0;jb=c;b=v[a+4256>>2];v[a+4240>>2]=b<<1;v[23588]=0;v[c+12>>2]=0;U(903,a+4208|0,b<<2,c+12|0);b=v[23588];v[23588]=0;a:{if((b|0)==1){b=V(92948)|0;if((O()|0)!=(da(92948)|0)){break a}_(b|0)|0;v[a+4240>>2]=0;$()}v[a+4244>>2]=0;jb=c+16|0;return}T(b|0);L()}function Rha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;_f(b);v[d+12>>2]=0;a:{if(!ok(a,d+12|0)){break a}f=c;c=v[d+12>>2];if(f>>>0<c>>>0){break a}while(1){if((c|0)==(e|0)){e=1;break a}t[d+11|0]=0;if(Mh(a,d+11|0)){Xp(b,t[d+11|0]);e=e+1|0;continue}break}e=0}jb=d+16|0;return e|0}function l$(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;c=jb-128|0;jb=c;v[c+12>>2]=c+116;d=v[a+8>>2];a=c+16|0;fG(d,a,c+12|0,e,f,g);e=v[c+12>>2];d=jb-16|0;jb=d;v[d+8>>2]=b;while(1){if((a|0)!=(e|0)){tH(d+8|0,t[a|0]);a=a+1|0;continue}break}jb=d+16|0;jb=c+128|0;return v[d+8>>2]}function ica(a,b){a=a|0;b=b|0;var c=0;a:{v[a>>2]=0;v[a+4>>2]=0;Gc(a+8|0);c=Qc(v[b>>2],v[b+4>>2]);if(c){hq(a,c);eP(a,v[b>>2],v[b+4>>2],c)}v[23588]=0;Q(3,a+12|0,b+12|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){v[a+24>>2]=v[b+24>>2];u[a+28>>1]=x[b+28>>1];break a}b=P()|0;O()|0;nd(a);T(b|0);L()}}function Zy(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;f=jb-16|0;jb=f;g=v[b+480180>>2];a:{if(g&64671904){b=w[(d&15)+43744|0];t[a+2|0]=0;u[a>>1]=b;break a}Cb(f+8|0,b+1074312|0,66);h=a;a=(c&255)==4&(g|0)==4;b=(d&255)<<a<<4;zl(h,(i=Bb(v[v[f+8>>2]>>2],v[f+12>>2])?0:b,j=b,k=e,k?i:j),a)}jb=f+16|0}function Sy(a,b,c){var d=0;d=v[a+480180>>2];a:{if((d|0)!=1048576){if((d|0)!=4){break a}d=w[b+814|0];if(c){t[b+814|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(c){t[b+813|0]=c;break a}c=w[b+813|0]}b:{if(!(t[b+851|0]&1)|!v[b+700>>2]){break b}c=c&255;if(!c){break b}fk(a,b,b+700|0,c,0)}}function Uz(a,b,c,d,e){var f=0;a:{f=v[a>>2];if(!Zd(f,v[a+20>>2])|c>>>0>=f>>>0|f-c>>>0<d>>>0){break a}Dm(b);b=jo(b,a);v[b+20>>2]=0;v[b>>2]=d;if(!Ng(b)){break a}if(v[a>>2]!=(d|0)){fr(b+68|0)}tc(v[b+20>>2],v[a+20>>2]+c|0,d);v[b+8>>2]=e?d:0;v[b+4>>2]=0;u[b+34>>1]=x[b+34>>1]&65533|(e?2:0)}}function Eaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=jb+-64|0;jb=d;_f(b);e=d+40|0;Nf(e,a,c);a=v[d+40>>2];c=d+8|0;bg(c,1,Ie(e),a);v[23588]=0;R(222,d+24|0,c|0);a=v[23588];v[23588]=0;if((a|0)!=1){a=d+24|0;Ac(b,a);yb(a);Tc(d+40|0);jb=d- -64|0;break a}a=P()|0;O()|0;Tc(d+40|0);T(a|0);L()}}function hX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-32|0;jb=e;v[e+24>>2]=d;v[e+28>>2]=c;v[23588]=0;X(173,e+8|0,b|0,e+28|0,e+24|0);c=v[23588];v[23588]=0;if((c|0)!=1){c=e+16|0;Cv(c,v[e+8>>2],v[e+12>>2]);Cg(a,c);le(c);le(e+8|0);le(b);jb=e+32|0;return}a=P()|0;O()|0;le(b);T(a|0);L()}function eH(a,b,c){var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;a=Hs(a);v[a+32>>2]=b;v[a>>2]=78660;b=d+8|0;as(b,a);v[23588]=0;b=S(1115,b|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){$b(d+8|0);v[a+40>>2]=c;v[a+36>>2]=b;f=a,g=zn(b),t[f+44|0]=g;jb=d+16|0;return}b=P()|0;O()|0;$b(d+8|0);Kn(a);T(b|0);L()}function cH(a,b,c){var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;a=sH(a);v[a+32>>2]=b;v[a>>2]=79028;b=d+8|0;as(b,a);v[23588]=0;b=S(1116,b|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){$b(d+8|0);v[a+40>>2]=c;v[a+36>>2]=b;f=a,g=zn(b),t[f+44|0]=g;jb=d+16|0;return}b=P()|0;O()|0;$b(d+8|0);ds(a);T(b|0);L()}function cD(a,b,c,d){var e=0,f=0,g=0;b=v[a+1076>>2]+((b&c?0-(c<<1)|0:0)+b|0)|0;v[a+1076>>2]=b;c=b+v[a+1080>>2]|0;v[a+1080>>2]=c;e=d;d=v[a+1068>>2];u[e+(d<<1)>>1]=w[a+1084|0]?c:b;v[a+1064>>2]=v[a+1064>>2]+1;f=a,g=Kd(x[v[a+1060>>2]+34>>1])+d|0,v[f+1068>>2]=g;v[a+1072>>2]=v[a+1072>>2]-1}function IL(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;v[d+12>>2]=b;a:{if(Uh(a)>>>0>=b>>>0){f=v[a>>2];e=uc(f,v[a+4>>2]);v[d+8>>2]=e;HL(f,v[Jb(d+12|0,d+8|0)>>2],c);if(b>>>0>e>>>0){Yx(a,b-e|0,c);break a}Nd(a,v[a>>2]+(b<<2)|0);break a}ou(a);Ak(a,pg(a,b));Yx(a,b,c)}jb=d+16|0}function G1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=a+60|0;d=Ms(c);v[a>>2]=78120;v[d>>2]=78140;v[a+60>>2]=78180;v[a>>2]=78160;v[a+4>>2]=0;e=c;c=a+8|0;Jn(e,c);v[a>>2]=78120;v[d>>2]=78140;v[23588]=0;Q(91,c|0,b|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;_k(d);T(a|0);L()}function uT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=jb+-64|0;jb=c;d=c+40|0;Nf(d,a,32);a=v[c+40>>2];e=c+8|0;bg(e,2,Ie(d),a);v[23588]=0;R(222,c+24|0,e|0);a=v[23588];v[23588]=0;if((a|0)!=1){Um(c,b);a=c+24|0;Ml(c,a);yb(a);Tc(c+40|0);jb=c- -64|0;break a}a=P()|0;O()|0;Tc(c+40|0);T(a|0);L()}}function is(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=ba(16)|0;if(!w[470113]){t[470113]=1}a=gc(c+8|0,a,94344);v[23588]=0;e=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=e;a=W(1094,d|0,c|0,b|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){ha(a|0,92256,1095);L()}a=P()|0;O()|0;ca(d|0);T(a|0);L()}function bW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;a:{if(!Pb(v[b>>2],v[b+8>>2],c<<1)){break a}wc(d+12|0,65535);ug(a,x[d+12>>1]);c=Eb(v[a>>2]);v[d>>2]=c;a=Eb(v[a+4>>2]);while(1){if(!Ob(c,a)){break a}Wu(b,d+8|0);u[c>>1]=x[d+8>>1];c=v[Re(d)>>2];continue}}jb=d+16|0}function _p(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;a:{e=ol(a,b);if((e|0)==255){break a}g=v[a>>2];if(ik(g)){break a}f=Md(a+318|0,e);e=UO(e);if(h=1,i=t[Kb(f,10)|0]&1,j=d,j?h:i){gh(g,v[a+4>>2],b,e- -64|0,TO(c,w[Kb(f,2)|0]))}if(d){break a}gh(v[a>>2],v[a+4>>2],b,e+67|0,TO(c,w[Kb(f,3)|0]))}}function sm(a,b,c,d){var e=0,f=0;a:{f=v[(B(b,872)+a|0)+1075648>>2];if(!f){break a}if(!uj(w[f+31|0])){break a}e=w[f+34|0]-1|0;if((e&255)>>>0>249){break a}e=v[Ld(a+906300|0,e)>>2];if(!e){break a}nb[v[v[e>>2]+96>>2]](e,f,c,d,b);if(c>>>0>250){break a}u[(B(b,872)+a|0)+1075834>>1]=65535}}function Vr(a,b,c,d){var e=0,f=0;e=jb-160|0;jb=e;f=-1;v[e+148>>2]=b?b-1|0:0;a=b?a:e+158|0;v[e+144>>2]=a;e=Tb(e,0,144);v[e+76>>2]=-1;v[e+36>>2]=1118;v[e+80>>2]=-1;v[e+44>>2]=e+159;v[e+84>>2]=e+144;a:{if((b|0)<0){v[116064]=61;break a}t[a|0]=0;f=QH(e,c,d,1092,1093)}jb=e+160|0;return f}function KJ(a){var b=0,c=0,d=0,e=0;d=jb-16|0;jb=d;b=a+120|0;zs(w[b+20|0]);c=jb-16|0;jb=c;v[c+8>>2]=d+8;a=jb-16|0;jb=a;e=v[14439];v[a+8>>2]=v[14438];v[a+12>>2]=e;e=v[14437];v[a>>2]=v[14436];v[a+4>>2]=e;b=nb[v[vp(a,bk(w[b+20|0]))>>2]](c+8|0,b)|0;jb=a+16|0;jb=c+16|0;jb=d+16|0;return b}function zK(a,b,c){t[a+12|0]=0;v[c>>2]=0;v[b>>2]=0;v[a+28>>2]=0;v[a+32>>2]=0;u[a+24>>1]=0;v[a+36>>2]=0;v[a+40>>2]=0;v[a+44>>2]=0;v[a+48>>2]=0;yK(a+60|0);yK(a+52|0);Np(a+49956|0);Np(a+58148|0);Np(a+66340|0);Np(a+74532|0);Tb(a+228|0,0,32768);Tb(a+32996|0,0,512);Tb(a+33508|0,0,16384)}function eaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;c=qf(a,c);me(d,v[a+36>>2]);a:{b:{if(!c){Rc(d,a+32|0,5);e=-1;if(!Bb(v[v[d>>2]>>2],v[d+4>>2])){break b}break a}e=v[c+16>>2]}f=v[a+36>>2];c:{if(!((e|0)!=4&(e|0)!=-1)){ok(f,b);break c}yG(f,b,e)}f=c}Xe(a,f);jb=d+16|0}function bC(a,b,c){var d=0,e=0,f=0;d=jb+-64|0;jb=d;_f(b);e=d+40|0;Nf(e,a,c);a=v[d+40>>2];f=d+8|0;bg(f,3,Ie(e),a);v[23588]=0;R(222,d+24|0,f|0);e=v[23588];v[23588]=0;if((e|0)!=1){e=b;b=d+24|0;Ac(e,b);yb(b);Tc(d+40|0);jb=d- -64|0;return!c|(a|0)!=0}a=P()|0;O()|0;Tc(d+40|0);T(a|0);L()}function Zi(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+12>>2]=d;g=ji(e+8|0,b);b=jb-16|0;jb=b;d=v[e+12>>2];v[b+12>>2]=d;v[b+8>>2]=d;f=-1;d=Vr(0,0,c,d);a:{if((d|0)<0){break a}h=a;d=d+1|0;a=Od(d);v[h>>2]=a;if(!a){break a}f=Vr(a,d,c,v[b+12>>2])}jb=b+16|0;ii(g);jb=e+16|0;return f}function Pba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;v[d+12>>2]=b;a:{if(jp(a)>>>0>=b>>>0){f=v[a>>2];e=ed(f,v[a+4>>2]);v[d+8>>2]=e;bi(f,v[Jb(d+12|0,d+8|0)>>2],c);if(b>>>0>e>>>0){Mo(a,b-e|0,c);break a}Nd(a,v[a>>2]+b|0);break a}rB(a);Nl(a,Wl(a,b));Mo(a,b,c)}jb=d+16|0}function Vh(a){var b=C(0),c=0,d=0;c=(p(a),j(2));d=c>>>23&255;if(d>>>0<=149){if(d>>>0<=125){return C(a*C(0))}a=(c|0)>=0?a:C(-a);b=C(C(C(a+C(8388608))+C(-8388608))-a);a:{if(b>C(.5)){a=C(C(a+b)+C(-1));break a}a=C(a+b);if(!(b<=C(-.5))){break a}a=C(a+C(1))}a=(c|0)>=0?a:C(-a)}return a}function Cia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=jb+-64|0;jb=d;e=d+40|0;Nf(e,a,c);a=v[d+40>>2];c=d+8|0;bg(c,2,Ie(e),a);v[23588]=0;R(222,d+24|0,c|0);a=v[23588];v[23588]=0;if((a|0)!=1){a=d+24|0;Gl(b,a);yb(a);Tc(d+40|0);jb=d- -64|0;break a}a=P()|0;O()|0;Tc(d+40|0);T(a|0);L()}}function Baa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=jb+-64|0;jb=d;e=d+40|0;Nf(e,a,c);a=v[d+40>>2];c=d+8|0;bg(c,1,Ie(e),a);v[23588]=0;R(222,d+24|0,c|0);a=v[23588];v[23588]=0;if((a|0)!=1){a=d+24|0;Be(b,a);yb(a);Tc(d+40|0);jb=d- -64|0;break a}a=P()|0;O()|0;Tc(d+40|0);T(a|0);L()}}function gV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=jb+-64|0;jb=d;e=d+40|0;Nf(e,a,c);a=v[d+40>>2];c=d+8|0;bg(c,2,Ie(e),a);v[23588]=0;R(222,d+24|0,c|0);a=v[23588];v[23588]=0;if((a|0)!=1){a=d+24|0;Cc(b,a);yb(a);Tc(d+40|0);jb=d- -64|0;break a}a=P()|0;O()|0;Tc(d+40|0);T(a|0);L()}}function Vq(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;f=jb-16|0;jb=f;v[f+12>>2]=c;c=f+12|0;wc(c,256);wc(c,65535);h=x[f+12>>1];ug(a,h);c=0;while(1){if((c|0)==(h|0)){jb=f+16|0}else{g=w[b+c|0];i=Il(v[a>>2],v[a+4>>2],c),j=(d|0)==(g|0)?-1:(e|0)==(g|0)?-2:g,u[i>>1]=j;c=c+1|0;continue}break}}function FP(a,b){var c=0,d=0,e=0,f=0;c=jb-96|0;jb=c;CR(b,c,c+96|0);b=0;while(1){if((b|0)==12){v[a+104>>2]=0;v[a+96>>2]=!(v[a+88>>2]|v[a+92>>2]);v[a+100>>2]=0;jb=c+96|0}else{d=b<<3;e=d+a|0;f=c+d|0;d=v[f+4>>2];v[e>>2]=v[f>>2];v[e+4>>2]=d&65535;b=b+1|0;continue}break}v[a+112>>2]=0}function E2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-32|0;jb=e;_g(e+24|0,b,c);b=Cg(e+16|0,d);v[23588]=0;c=v[b+4>>2];v[e+8>>2]=v[b>>2];v[e+12>>2]=c;Eg(169,a,v[e+24>>2],v[e+28>>2],e+8|0);a=v[23588];v[23588]=0;if((a|0)!=1){le(d);jb=e+32|0;return}a=P()|0;O()|0;le(d);T(a|0);L()}function ot(a,b){var c=0,d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;Fe(d+8|0,b);b=v[d+8>>2];e=v[d+12>>2];c=jb-16|0;jb=c;f=Gb(a);v[c+12>>2]=f;v[c+8>>2]=e;g=Jb(c+12|0,c+8|0);a=Lp(Lc(a),b,v[g>>2]);a:{if(a){break a}a=-1;if(e>>>0>f>>>0){break a}a=e>>>0<f>>>0}jb=c+16|0;jb=d+16|0;return a>>>31|0}function bD(a,b,c,d){var e=0,f=0;b=v[a+1076>>2]+((b&c?0-(c<<1)|0:0)+b|0)|0;v[a+1076>>2]=b;c=b+v[a+1080>>2]|0;v[a+1080>>2]=c;t[v[a+1068>>2]+d|0]=w[a+1084|0]?c:b;v[a+1064>>2]=v[a+1064>>2]+1;e=a,f=v[a+1068>>2]+Kd(x[v[a+1060>>2]+34>>1])|0,v[e+1068>>2]=f;v[a+1072>>2]=v[a+1072>>2]-1}function OJ(a,b,c){var d=0,e=0;while(1){a:{if((a|0)!=(b|0)){e=v[a>>2];d=xg(e);b:{c:{if((Gb(c)|0)==(d|0)){v[23588]=0;d=W(361,c|0,e|0,d|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break c}d=!d}else{d=0}break b}V(0)|0;O()|0;Ub();L()}if(!d){break a}}else{a=b}return a}a=a+8|0;continue}}function BS(a,b,c,d){var e=0,f=0;e=jb-16|0;jb=e;v[e+12>>2]=a;a:{if(!(!c|b)){a=Pe(+(B(a,d)>>>0)*.25*1e4);break a}if(!(!a|!b)){wc(e+12|0,10);a=B(w[v[e+12>>2]+26800|0],1e4);break a}f=+(a>>>0);if(a-1>>>0<=9){a=Pe(733.8401379310345/f*1e4);break a}a=Pe(f/.264*1e4)}jb=e+16|0;return a}function df(a){var b=0,c=0;b=jb-32|0;jb=b;t[b+8|0]=0;v[b>>2]=0;v[b+4>>2]=4194432;LC(b+9|0);v[a>>2]=v[b>>2];c=v[b+8>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=c;c=v[b+16>>2];v[a+12>>2]=v[b+12>>2];v[a+16>>2]=c;c=v[b+24>>2];v[a+20>>2]=v[b+20>>2];v[a+24>>2]=c;t[a+28|0]=w[b+28|0];jb=b+32|0}function Aba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=jb+-64|0;jb=c;d=c+40|0;Nf(d,a,32);a=v[c+40>>2];e=c+8|0;bg(e,1,Ie(d),a);v[23588]=0;R(222,c+24|0,e|0);a=v[23588];v[23588]=0;if((a|0)!=1){a=c+24|0;Cc(b,a);yb(a);Tc(c+40|0);jb=c- -64|0;break a}a=P()|0;O()|0;Tc(c+40|0);T(a|0);L()}}function w9(a,b){a=a|0;b=b|0;var c=0;a:{b:{c=v[a+20>>2];b=v[c+4>>2];if((ed(b,v[c+8>>2])|0)!=8){break b}if(Rb(b,9516,4)){break b}c=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[a+4260>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[a+4264>>2]=c;break a}Qx(a,a)}Ts(a)}function pka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=jb-624|0;jb=b;d=-1;c=jb-16|0;jb=c;e=b+8|0;iV(c+8|0,e);f=v[c+12>>2];ld(c,a,v[c+8>>2],v[c+12>>2]);g=v[c+4>>2];if((g|0)==(f|0)){hd(a,v[c+12>>2])}jb=c+16|0;a=(f|0)==(g|0);if(!a){hV(e)}if(a){d=jV(b+8|0)}jb=b+624|0;return d|0}function _ba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;a=bQ(d,a+8|0,b);b=v[a>>2];a:{while(1){if(v[a+4>>2]==(b|0)){break a}v[23588]=0;R(754,b|0,c|0);b=v[23588];v[23588]=0;if((b|0)!=1){b=v[a>>2]+32|0;v[a>>2]=b;continue}break}b=P()|0;O()|0;Td(a);T(b|0);L()}Td(a);jb=d+16|0}function Cfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=jb-160|0;jb=b;d=-1;c=jb-16|0;jb=c;e=b+8|0;kR(c+8|0,e);f=v[c+12>>2];ld(c,a,v[c+8>>2],v[c+12>>2]);g=v[c+4>>2];if((g|0)==(f|0)){hd(a,v[c+12>>2])}jb=c+16|0;a=(f|0)==(g|0);if(!a){jR(e)}if(a){d=lR(b+8|0)}jb=b+160|0;return d|0}function eL(a){a=a|0;var b=0,c=0;c=jb-16|0;jb=c;b=v[v[a+16>>2]+1074404>>2];v[23588]=0;v[c+12>>2]=0;U(903,a+4208|0,B(b,254)|0,c+12|0);b=v[23588];v[23588]=0;a:{if((b|0)==1){b=V(92948)|0;if((O()|0)!=(da(92948)|0)){break a}_(b|0)|0;$()}v[a+4220>>2]=0;jb=c+16|0;return}T(b|0);L()}function eC(a,b,c){var d=0,e=0,f=0;d=jb+-64|0;jb=d;e=d+40|0;Nf(e,a,c);a=v[d+40>>2];f=d+8|0;bg(f,3,Ie(e),a);v[23588]=0;R(222,d+24|0,f|0);e=v[23588];v[23588]=0;if((e|0)!=1){e=b;b=d+24|0;Cc(e,b);yb(b);Tc(d+40|0);jb=d- -64|0;return!c|(a|0)!=0}a=P()|0;O()|0;Tc(d+40|0);T(a|0);L()}function dw(a,b,c,d,e){var f=0,g=0;a:{f=jb+-64|0;jb=f;g=f+40|0;Nf(g,a,e);a=v[f+40>>2];e=f+8|0;bg(e,d,Ie(g),a);v[23588]=0;R(222,f+24|0,e|0);a=v[23588];v[23588]=0;if((a|0)!=1){gc(f,b,c);a=f+24|0;Ml(f,a);yb(a);Tc(f+40|0);jb=f- -64|0;break a}a=P()|0;O()|0;Tc(f+40|0);T(a|0);L()}}function SR(a){var b=0;a:{if(Rb(a,15477,4)|((w[a+8|0]|w[a+9|0]<<8)-768&65535)>>>0<65280|(((w[a+112|0]|w[a+113|0]<<8)-65&65535)>>>0<65472|(w[a+106|0]|w[a+107|0]<<8)>>>0>256)){break a}if((w[a+122|0]|w[a+123|0]<<8)>>>0>255){break a}b=(w[a+124|0]|w[a+125|0]<<8)>>>0<4e3}return b}function mV(a,b){var c=0,d=0,e=0;d=jb-16|0;jb=d;v[d+12>>2]=b;c=jb-16|0;jb=c;v[c+12>>2]=153391689;v[c+8>>2]=2147483647;e=Jb(c+12|0,c+8|0);jb=c+16|0;c=b;b=v[e>>2];if(c>>>0<=b>>>0){a=IB(a);if(a>>>0<b>>>1>>>0){v[d+8>>2]=a<<1;b=v[Yc(d+8|0,d+12|0)>>2]}jb=d+16|0;return b}bd();L()}function Tha(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;v[c+8>>2]=b;a:{if(uc(v[a>>2],v[a+4>>2])>>>0>511){break a}if(!Ed(b)){break a}v[23588]=0;R(487,a|0,c+8|0);a=v[23588];v[23588]=0;d=b;if((a|0)!=1){break a}a=P()|0;O()|0;rg(c+8|0);T(a|0);L()}rg(c+8|0);jb=c+16|0;return d|0}function SU(a,b){var c=0,d=0,e=0;d=jb-16|0;jb=d;v[d+12>>2]=b;c=jb-16|0;jb=c;v[c+12>>2]=107374182;v[c+8>>2]=2147483647;e=Jb(c+12|0,c+8|0);jb=c+16|0;c=b;b=v[e>>2];if(c>>>0<=b>>>0){a=OU(a);if(a>>>0<b>>>1>>>0){v[d+8>>2]=a<<1;b=v[Yc(d+8|0,d+12|0)>>2]}jb=d+16|0;return b}bd();L()}function Pja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=jb-32|0;jb=b;d=-1;c=jb-16|0;jb=c;e=b+8|0;zu(c+8|0,e);f=v[c+12>>2];ld(c,a,v[c+8>>2],v[c+12>>2]);g=v[c+4>>2];if((g|0)==(f|0)){hd(a,v[c+12>>2])}jb=c+16|0;a=(f|0)==(g|0);if(!a){zU(e)}if(a){d=AU(b+8|0)}jb=b+32|0;return d|0}function Jha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=jb-16|0;jb=b;d=-1;c=jb-16|0;jb=c;e=b+8|0;Do(c+8|0,e);f=v[c+12>>2];ld(c,a,v[c+8>>2],v[c+12>>2]);g=v[c+4>>2];if((g|0)==(f|0)){hd(a,v[c+12>>2])}jb=c+16|0;a=(f|0)==(g|0);if(!a){VS(e)}if(a){d=WS(b+8|0)}jb=b+16|0;return d|0}function zV(a,b){var c=0,d=0;a:{b:{a=a-12|0;c:{if(a>>>0>31){break c}d=1<<a;c=1;if(d&-2145904587){break a}if(d&65792){break b}if((a|0)!=7){break c}b=b&240;c=1;if(!b|(b|0)==96|(b|0)==224){break a}}return 0}b=(b&240)-96|0;c=0;if(b>>>0>=144){break a}c=297>>>(b>>>4)&1}return c}function xS(a,b){var c=0,d=0;a:{c=v[b>>2];d=v[b+20>>2];if(!Zd(c,d)){break a}if(v[a+20>>2]==(d|0)){v[a+20>>2]=0;c=v[b>>2]}wc(a,c);c=x[a+34>>1]&-2|u[b+34>>1]&1;u[a+34>>1]=c;u[a+34>>1]=c&65471|x[b+34>>1]&64;if(!Ng(a)){break a}tc(v[a+20>>2],v[b+20>>2],Hj(v[a>>2],x[a+34>>1]))}}function UD(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-32|0;jb=e;g=v[b+8>>2];f=v[b>>2];_g(e+16|0,c,d);c=v[v[f>>2]+28>>2];d=v[e+20>>2];v[e+8>>2]=v[e+16>>2];v[e+12>>2]=d;nb[c|0](e+24|0,f,g,e+8|0);_g(a,v[e+24>>2],v[e+28>>2]);v[b+8>>2]=v[b+8>>2]+v[a+4>>2];jb=e+32|0}function s0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;h=(e-d|0)+b|0;a:{while(1){if((d|0)!=(e|0)){a=-1;if((b|0)==(c|0)){break a}f=t[b|0];g=t[d|0];if((f|0)<(g|0)){break a}if((f|0)>(g|0)){return 1}else{d=d+1|0;b=b+1|0;continue}}break}a=(c|0)!=(h|0)}return a|0}function Ih(a){var b=0,c=0,d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;b=jb-16|0;jb=b;v[b+4>>2]=1;f=b,g=sc(16),v[f+8>>2]=g;c=To(v[b+8>>2]);v[c>>2]=42728;f=dn(Bc(c)),g=42860,v[f>>2]=g;c=d+8|0;e=Vo(b);Uo(c,Bc(e),e);en(b);jb=b+16|0;Cg(a,c);le(c);jb=d+16|0;v[a+8>>2]=0;ee(a+12|0);return a}function I3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;In(c,a);if(v[b>>2]){Kc(b);a=v[b>>2];Ar(b);Mb(a);d=Fb(b),e=0,v[d>>2]=e;v[b>>2]=0;v[b+4>>2]=0}v[b>>2]=v[c>>2];v[b+4>>2]=v[c+4>>2];a=Fb(c);d=Fb(b),e=v[a>>2],v[d>>2]=e;v[a>>2]=0;v[c>>2]=0;v[c+4>>2]=0;Wf(c);jb=c+16|0}function Dn(a,b,c){var d=0,e=0,f=0;a:{if(!b){d=a;break a}while(1){d=Oka(a,b,10,0);f=mb;e=Lka(d,f,246,0)+a|0;c=c-1|0;t[c|0]=e|48;e=b>>>0>9;a=d;b=f;if(e){continue}break}}if(d){while(1){c=c-1|0;a=(d>>>0)/10|0;t[c|0]=B(a,246)+d|48;b=d>>>0>9;d=a;if(b){continue}break}}return c}function we(a){var b=0,c=0,d=0;o(+a);b=j(1)|0;j(0)|0;d=b>>>20&2047;if(d>>>0<=1074){if(d>>>0<=1021){return a*0}a=(b|0)>0|(b|0)>=0?a:-a;c=a+4503599627370496+-4503599627370496-a;a:{if(c>.5){a=a+c+-1;break a}a=a+c;if(!(c<=-.5)){break a}a=a+1}a=(b|0)>0|(b|0)>=0?a:-a}return a}function b3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-32|0;jb=d;v[d+24>>2]=c;a:{while(1){if((a|0)==(b|0)){break a}c=Mc(d+8|0,v[a>>2]);v[23588]=0;Q(1075,d+24|0,c|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){yb(c);a=a+4|0;continue}break}a=P()|0;O()|0;yb(c);T(a|0);L()}jb=d+32|0}function on(a,b){var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;a:{if(!b){b=0;break a}d=b;b=E(b);Kf(c,d,0,0,0,b+81|0);e=16414-b<<16;b=0;d=b+v[c+8>>2]|0;e=e+(v[c+12>>2]^65536)|0;e=b>>>0>d>>>0?e+1|0:e;f=d;d=v[c>>2];b=v[c+4>>2]}v[a>>2]=d;v[a+4>>2]=b;v[a+8>>2]=f;v[a+12>>2]=e;jb=c+16|0}function U8(a){a=a|0;var b=0,c=0,d=0,e=0;b=jb-16|0;jb=b;v[b+12>>2]=a;v[b+8>>2]=4104;a=0;d=v[b+8>>2];a:{if(d>>>0<4096){break a}c=v[b+12>>2];e=c+7&-8;c=e-c|0;if(c>>>0>d-4096>>>0){break a}v[b+12>>2]=e;v[b+8>>2]=d-c;a=e}if(!a){aa(6056,8974,88,7360);L()}jb=b+16|0;return a|0}function BP(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=jb-16|0;jb=e;b:{c:{if((b|0)==(c|0)){b=a;a=Lc(d);Th(b,a,Gb(d)+a|0);break c}AP(e,c,d);v[23588]=0;U(44,a|0,b|0,e|0);a=v[23588];v[23588]=0;if((a|0)==1){break b}Fc(e)}jb=e+16|0;break a}a=P()|0;O()|0;Fc(e);T(a|0);L()}}function sV(a){var b=0,c=0,d=0,e=0,f=0,g=0;b=jb-16|0;jb=b;f=Kb(a,31),g=0,t[f|0]=g;t[b+15|0]=0;c=wi(a,fo(a),b+15|0);t[b+14|0]=0;c=Rh(a,c);om(c+a|0,fo(a),b+14|0);while(1){if((c|0)!=(d|0)){e=Kb(a,d);if((w[e|0]-127&255)>>>0<=160){t[e|0]=32}d=d+1|0;continue}break}jb=b+16|0}function Ps(a){var b=0,c=0,d=C(0);b=a+4232|0;c=w[b|0];if(c>>>0>=5){t[b|0]=0;c=0}if(t[a+4233|0]<0){t[a+4233|0]=127}b=t[a+4234|0];if((b|0)<0){t[a+4234|0]=127;b=127}a:{if((c|0)==3){d=C(C(1)-te(C(2),C(-C((b&255)+1|0))));break a}d=te(C(2),C(-C((b&255)>>>0)))}z[a+4224>>2]=d}function VD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=jb-16|0;jb=d;b:{c:{if(!b){b=a;a=od(c);Th(b,a,yd(v[c+4>>2],w[c+11|0])+a|0);break c}wN(d,c);v[23588]=0;U(44,a|0,b|0,d|0);a=v[23588];v[23588]=0;if((a|0)==1){break b}Fc(d)}jb=d+16|0;break a}a=P()|0;O()|0;Fc(d);T(a|0);L()}}function QQ(a){var b=0,c=0,d=0,e=0;c=jb-16|0;jb=c;b=Eb(v[a>>2]);v[c+8>>2]=b;e=Eb(v[a+4>>2]);while(1){a:{d=Ob(b,e);if(!d){break a}a=x[b>>1];b:{if(!((a|0)!=255&(a|0)!=99)){u[b>>1]=65535;break b}if(a>>>0>63){break a}}b=v[Re(c+8|0)>>2];continue}break}jb=c+16|0;return d^1}function yz(a,b,c){var d=0,e=0,f=0;d=jb-16|0;jb=d;a=Lz(d,a,b);b=v[a+4>>2];e=v[a+8>>2];a:{while(1){if((b|0)==(e|0)){break a}v[23588]=0;R(754,b|0,c|0);f=v[23588];v[23588]=0;if((f|0)!=1){b=b+32|0;v[a+4>>2]=b;continue}break}b=P()|0;O()|0;kc(a);T(b|0);L()}kc(a);jb=d+16|0}function nh(a,b){var c=0,d=0,e=0;a:{if(!(b?1:t[a+480180|0]&1)){break a}e=v[a+24616>>2]&524288;b=0;while(1){if((b|0)==127){break a}c=(b<<5)+a|0;u[c+480286>>1]=64;d=c+480280|0;v[d>>2]=v[d>>2]&-257;d=c+480284|0;c=(b&3)-1>>>0<2;u[d>>1]=e?c<<8:c?192:64;b=b+1|0;continue}}}function gp(a,b,c){var d=0,e=0,f=0;d=a*a;f=d*(d*d)*(d*1.58969099521155e-10+-2.5050760253406863e-8)+(d*(d*27557313707070068e-22+-.0001984126982985795)+.00833333333332249);e=d*a;if(!c){return e*(d*f+-.16666666666666632)+a}return a-(d*(b*.5-f*e)-b+e*.16666666666666632)}function _C(a,b){var c=0,d=0;c=jb-16|0;jb=c;d=c+8|0;fd(d,a);v[23588]=0;a=S(19,d|0)|0;d=v[23588];v[23588]=0;a:{if((d|0)==1){break a}v[23588]=0;a=Q(20,a|0,b|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break a}$b(c+8|0);jb=c+16|0;return a}a=P()|0;O()|0;$b(c+8|0);T(a|0);L()}function ZU(a,b,c){var d=0,e=0;d=jb-16|0;jb=d;t[d+15|0]=1;t[d+14|0]=a>>>2;a=w[jf(d+15|0,d+14|0)|0];e=b>>>0<2|a>>>0<15;if(!e){t[d+13|0]=1;t[d+12|0]=(((a+b|0)-2&65535)>>>0)/((b-1&65535)>>>0);a=w[jf(d+13|0,d+12|0)|0]}jb=d+16|0;return(c?a<<4|(e?15:0):a&15|(e?-16:0))&255}function YC(a,b,c){var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;e=v[a+4>>2];f=e+b|0;v[a+4>>2]=f;a:{b:{if(!e){g=f-1|0;break b}g=f-1|0;if((g^e-1)>>>0>31){break b}a=v[a>>2];break a}a=v[a>>2];v[a+((f>>>0<33?0:g>>>5|0)<<2)>>2]=0}Lo(d+8|0,a,e);pv(v[d+8>>2],v[d+12>>2],b,c);jb=d+16|0}function LE(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+12>>2]=c;c=e+12|0;wc(c,d);wc(c,65535);f=x[e+12>>1];ug(a,f);c=0;while(1){if((c|0)==(f|0)){jb=e+16|0}else{d=w[b+c|0];g=Il(v[a>>2],v[a+4>>2],c),h=(d|0)==255?-1:(d|0)==254?-2:d,u[g>>1]=h;c=c+1|0;continue}break}}function C0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{if(!w[a+44|0]){c=(c|0)>0?c:0;while(1){if((c|0)==(d|0)){break a}if(((f=a,g=yf(t[b|0]),e=v[v[a>>2]+52>>2],nb[e](f|0,g|0)|0)|0)==-1){return d|0}else{b=b+1|0;d=d+1|0;continue}}}c=vk(b,1,c,v[a+32>>2])}return c|0}function Bj(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Eb(v[b>>2]);f=Eb(v[b+4>>2]);e=jb-16|0;jb=e;v[e+8>>2]=d;while(1){a:{if(!Ob(d,f)){break a}if(VU(c,v[d>>2],v[d+4>>2])){break a}d=v[Mm(e+8|0)>>2];continue}break}jb=e+16|0;if(oc(d,Eb(v[b+4>>2]))){Ih(a);return}zo(a,d)}function K8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;v[a+4>>2]=b;v[a>>2]=0;b=ku(a+8|0,d);v[23588]=0;Q(916,a+20|0,c|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){v[a+32>>2]=0;v[a+36>>2]=0;t[a+42|0]=0;t[a+40|0]=0;t[a+41|0]=w[a+41|0]&224|25;return a|0}a=P()|0;O()|0;ac(b);T(a|0);L()}function NJ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a=Lb(a);d=xg(b);e=Gb(c);v[23588]=0;X(1064,a|0,b|0,d|0,d+e|0);b=v[23588];v[23588]=0;a:{if((b|0)!=1){b=Lc(c);v[23588]=0;W(1065,a|0,b|0,e|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;yb(a);T(b|0);L()}}function Zr(a,b){var c=0,d=0,e=0;d=-1;a:{if((a|0)==-1){break a}e=v[b+76>>2]>=0;b:{c=v[b+4>>2];c:{if(!c){Xw(b);c=v[b+4>>2];if(!c){break c}}if(v[b+44>>2]-8>>>0<c>>>0){break b}}if(!e){break a}return-1}c=c-1|0;v[b+4>>2]=c;t[c|0]=a;v[b>>2]=v[b>>2]&-17;d=a&255}return d}function $0(a){a=a|0;var b=0,c=0,d=0;c=v[a+44>>2];b=v[a+24>>2];if(c>>>0<b>>>0){v[a+44>>2]=b;c=b}d=-1;a:{if(!(w[a+48|0]&8)){break a}b=v[a+16>>2];if(b>>>0<c>>>0){An(a,v[a+8>>2],v[a+12>>2],c);b=v[a+16>>2]}a=v[a+12>>2];if(a>>>0>=b>>>0){break a}d=yf(t[a|0])}return d|0}function FE(a,b,c,d){var e=0,f=0;a:{e=jb+-64|0;jb=e;f=e+40|0;Nf(f,a,d);a=v[e+40>>2];d=e+8|0;bg(d,c,Ie(f),a);v[23588]=0;R(222,e+24|0,d|0);a=v[23588];v[23588]=0;if((a|0)!=1){a=e+24|0;Be(b,a);yb(a);Tc(e+40|0);jb=e- -64|0;break a}a=P()|0;O()|0;Tc(e+40|0);T(a|0);L()}}function zT(a){var b=0,c=0,d=0,e=0;d=w[a+32|0]|w[a+33|0]<<8;e=w[a+38|0]|w[a+39|0]<<8;c=w[a+34|0]|w[a+35|0]<<8;b=c+(w[a+36|0]|w[a+37|0]<<8)|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=e+b|0;a=b>>>0<c>>>0?a+1|0:a;a=a<<2|b>>>30;c=b<<2;b=d+c|0;a=b>>>0<c>>>0?a+1|0:a;mb=a;return b}function tV(a,b,c){var d=0,e=0;d=jb+-64|0;jb=d;_f(b);e=d+40|0;Nf(e,a,c);a=v[d+40>>2];c=d+8|0;bg(c,2,Ie(e),a);v[23588]=0;R(222,d+24|0,c|0);a=v[23588];v[23588]=0;if((a|0)!=1){a=d+24|0;Ac(b,a);yb(a);Tc(d+40|0);jb=d- -64|0;return}a=P()|0;O()|0;Tc(d+40|0);T(a|0);L()}function _G(a,b){var c=0,d=0,e=0,f=0,g=0;c=jb-16|0;jb=c;d=jb-16|0;jb=d;f=d,g=Lka(v[b>>2],v[b+4>>2],1e6,0),v[f>>2]=g;v[d+4>>2]=mb;b=rl(d+8|0,d);e=v[b+4>>2];b=v[b>>2];jb=d+16|0;v[c+8>>2]=b;v[c+12>>2]=e;b=v[c+12>>2];v[a>>2]=v[c+8>>2];v[a+4>>2]=b;jb=c+16|0;return a}function Y2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a:{c=jb-16|0;jb=c;v[c+4>>2]=1;e=c,f=sc(52),v[e+8>>2]=f;d=v[c+8>>2];v[23588]=0;Q(1082,d|0,b|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){b=a;a=Vo(c);Uo(b,Bc(a),a);en(c);jb=c+16|0;break a}a=P()|0;O()|0;en(c);T(a|0);L()}}function Ml(a,b){var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;d=Lc(b);e=c,f=Gb(b),v[e+12>>2]=f;v[c+8>>2]=v[a+4>>2]-1;ph(d,d+v[Jb(c+12|0,c+8|0)>>2]|0,v[a>>2]);d=v[a>>2];e=c,f=Gb(b),v[e+12>>2]=f;a=v[a+4>>2];v[c+8>>2]=a-1;om(d+v[Jb(c+12|0,c+8|0)>>2]|0,a+d|0,62364);jb=c+16|0}function wC(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;a=cv(c,a,b);b=v[a+4>>2];d=v[a+8>>2];a:{while(1){if((b|0)==(d|0)){break a}v[23588]=0;Y(228,b|0);e=v[23588];v[23588]=0;if((e|0)!=1){b=b+20|0;v[a+4>>2]=b;continue}break}b=P()|0;O()|0;kc(a);T(b|0);L()}kc(a);jb=c+16|0}function mba(a,b){a=a|0;b=b|0;var c=0,d=0;c=w[a+11|0];a:{b:{c:{if(!ff(c)){d=10;c=yf(c);if((c|0)==10){break c}ce(a,c+1|0);d=a;break a}c=v[a+4>>2];d=uu(v[a+8>>2])-1|0;if((c|0)!=(d|0)){break b}}Oy(a,d,1,d,d,0);c=d}d=v[a>>2];Fd(a,c+1|0)}a=c+d|0;wd(a,b);wd(a+1|0,0)}function Rj(a,b){var c=0,d=0,e=0,f=0,g=0;g=v[a+8>>2];while(1){if((b|0)!=(e|0)){d=v[a>>2];if(d){c=v[a+4>>2]}else{v[a>>2]=8;c=g;d=v[a+12>>2];if((c|0)!=(d|0)){c=d-1|0;v[a+12>>2]=c}d=8;c=w[c|0]}v[a>>2]=d-1;v[a+4>>2]=c>>>1;f=c&1|f<<1;e=e+1|0;continue}break}return f}function $k(a){var b=0,c=0;a:{b=v[a+1396>>2];if((b|0)>24){break a}if(!b){v[a+1392>>2]=0}while(1){if(w[a+1376|0]?0:v[a+1384>>2]){break a}c=ps(a);if((c|0)==-1){break a}b=v[a+1396>>2];v[a+1396>>2]=b+8;v[a+1392>>2]=v[a+1392>>2]+(c<<b);if((b|0)<17){continue}break}}}function wja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;b=jb-160|0;jb=b;d=-1;c=jb-16|0;jb=c;iU(c+8|0,b);e=v[c+12>>2];ld(c,a,v[c+8>>2],v[c+12>>2]);f=v[c+4>>2];if((f|0)==(e|0)){hd(a,v[c+12>>2])}jb=c+16|0;a=(e|0)==(f|0);if(!a){hU(b)}if(a){d=jU(b)}jb=b+160|0;return d|0}function kfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;b=jb-208|0;jb=b;d=-1;c=jb-16|0;jb=c;LQ(c+8|0,b);e=v[c+12>>2];ld(c,a,v[c+8>>2],v[c+12>>2]);f=v[c+4>>2];if((f|0)==(e|0)){hd(a,v[c+12>>2])}jb=c+16|0;a=(e|0)==(f|0);if(!a){KQ(b)}if(a){d=MQ(b)}jb=b+208|0;return d|0}function iA(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=jb-1024|0;jb=e;d=jb-16|0;jb=d;fA(d+8|0,e);f=v[d+12>>2];mc(d,v[a>>2],v[a+8>>2],v[d+8>>2],v[d+12>>2]);g=v[d+4>>2];if((g|0)==(f|0)){Zb(a,v[d+12>>2])}jb=d+16|0;if((f|0)==(g|0)){h=gA(e,c)>>>0<=b>>>0}jb=e+1024|0;return h}function Ub(){var a=0;a=v[23587];v[23588]=0;Z(a|0);a=v[23588];v[23588]=0;a:{if((a|0)!=1){v[23588]=0;Z(1227);a=v[23588];v[23588]=0;if((a|0)!=1){break a}}a=V(0)|0;O()|0;_(a|0)|0;v[23588]=0;Z(1227);a=v[23588];v[23588]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ub()}L()}function u9(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=C(0),f=0,g=C(0);d=jb-16|0;jb=d;f=d,g=C(C(nb[v[v[a>>2]+48>>2]](a,b))+c),z[f+12>>2]=g;c=C(0);e=z[d+12>>2];a:{if(!(e<C(0))){c=C(1);if(!(e>C(1))){break a}}z[d+12>>2]=c}nb[v[v[a>>2]+44>>2]](a,b,z[d+12>>2]);jb=d+16|0}function iz(a,b,c,d){var e=0,f=0,g=0;e=Sd(a);a:{if(e){f=ic(a);while(1){a=e;e=x[a+16>>1];g=v[a+20>>2];if(ll(c,d,e,g)){f=a;e=v[a>>2];if(e){continue}break a}if(!ll(e,g,c,d)){break a}f=a+4|0;e=v[a+4>>2];if(e){continue}break}break a}a=ic(a);f=a}v[b>>2]=a;return f}function GG(a,b,c){var d=0,e=0,f=0,g=0;d=a;a:{e=_d(b,c);if(e>>>0<1073741808){b:{if(Ur(e)){ce(d,e);break b}f=bm(e)+1|0;g=Bi(f);ud(d,g);bf(d,f);Fd(d,e);d=g}while(1){if((b|0)!=(c|0)){ud(d,v[b>>2]);d=d+4|0;b=b+4|0;continue}break}ud(d,0);break a}hf();L()}return a}function DP(a,b){var c=0,d=0;v[a+4>>2]=b;v[a>>2]=94360;v[a+20>>2]=0;v[a+24>>2]=0;c=(b>>>5|0)+((b&31)!=0)|0;v[a+12>>2]=c;d=(b>>>0)/(c>>>0)|0;v[a+8>>2]=d;v[a+32>>2]=d>>>0<31?-1>>>31-d|0:-1;v[a+28>>2]=b>>>0<c>>>0?0:-1>>>32-d|0;v[a+16>>2]=(B(c,d)-b|0)+c;return a}function nX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;f=v[b+8>>2];a:{if(f>>>0<=c>>>0){c=v[d>>2];b=0;break a}v[e+12>>2]=f-c;v[e+8>>2]=v[d+4>>2];c=v[b+4>>2]+c|0;f=c;b=v[Jb(e+12|0,e+8|0)>>2];g=c+b|0;c=v[d>>2];Pi(f,g,c)}fc(a,c,b);jb=e+16|0}function Iy(a,b,c,d){var e=0,f=0,g=0;e=Sd(a);a:{if(e){f=ic(a);while(1){a=e;e=w[a+16|0];g=v[a+20>>2];if(Qn(c,d,e,g)){f=a;e=v[a>>2];if(e){continue}break a}if(!Qn(e,g,c,d)){break a}f=a+4|0;e=v[a+4>>2];if(e){continue}break}break a}a=ic(a);f=a}v[b>>2]=a;return f}function uW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;b=jb-48|0;jb=b;d=-1;c=jb-16|0;jb=c;DC(c+8|0,b);e=v[c+12>>2];ld(c,a,v[c+8>>2],v[c+12>>2]);f=v[c+4>>2];if((f|0)==(e|0)){hd(a,v[c+12>>2])}jb=c+16|0;a=(e|0)==(f|0);if(!a){CC(b)}if(a){d=EC(b)}jb=b+48|0;return d|0}function U9(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=0;Lb(c+16|0);v[23588]=0;v[c>>2]=v[c>>2]&-1332|1058;v[c+4>>2]=1;U(101,a|0,b|0,c|0);a=v[23588];v[23588]=0;if((a|0)!=1){Oj(c);jb=c+32|0;return}a=P()|0;O()|0;Oj(c);T(a|0);L()}function Pha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;_f(b);t[c+15|0]=0;a:{if(!Mh(a,c+15|0)){break a}f=w[c+15|0];d=1;while(1){if((e&255)==(f|0)){break a}t[c+14|0]=0;if(Mh(a,c+14|0)){Xp(b,t[c+14|0]);e=e+1|0;continue}break}d=0}jb=c+16|0;return d|0}function I7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=si(a,b,c,d);v[a>>2]=46512;b=a+4208|0;e=Db(b,0),f=1017370378,v[e>>2]=f;e=Db(b,1),f=0,v[e>>2]=f;v[23588]=0;R(897,a+44|0,2);b=v[23588];v[23588]=0;if((b|0)!=1){return a|0}b=P()|0;O()|0;If(a);T(b|0);L()}function p0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a:{while(1){if((d|0)!=(e|0)){a=-1;if((b|0)==(c|0)){break a}f=v[b>>2];g=v[d>>2];if((f|0)<(g|0)){break a}if((f|0)>(g|0)){return 1}else{d=d+4|0;b=b+4|0;continue}}break}a=(b|0)!=(c|0)}return a|0}function of(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=a;e=jb-16|0;jb=e;a:{if(b>>>0<4294967280){b:{if(El(b)){ce(d,b);break b}f=Mg(b)+1|0;g=sc(f);ud(d,g);bf(d,f);Fd(d,b);d=g}c=zB(d,b,c);t[e+15|0]=0;ie(b+c|0,e+15|0);jb=e+16|0;break a}hf();L()}return a|0}function gC(a,b,c){var d=0,e=0;d=jb+-64|0;jb=d;e=d+40|0;Nf(e,a,c);a=v[d+40>>2];c=d+8|0;bg(c,3,Ie(e),a);v[23588]=0;R(222,d+24|0,c|0);a=v[23588];v[23588]=0;if((a|0)!=1){a=d+24|0;Gl(b,a);yb(a);Tc(d+40|0);jb=d- -64|0;return}a=P()|0;O()|0;Tc(d+40|0);T(a|0);L()}function p$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=jb-16|0;jb=g;v[g+8>>2]=b;fd(g,d);v[23588]=0;b=S(1136,g|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){$b(g);jG(a,f+24|0,g+8|0,c,e,b);jb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;$b(g);T(a|0);L()}function o$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=jb-16|0;jb=g;v[g+8>>2]=b;fd(g,d);v[23588]=0;b=S(1136,g|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){$b(g);iG(a,f+16|0,g+8|0,c,e,b);jb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;$b(g);T(a|0);L()}function eca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=b;d=jb-16|0;jb=d;b=qf(a,c);me(d,v[a+36>>2]);a:{b:{if(!b){Rc(d,a+32|0,5);c=-1;if(!Bb(v[v[d>>2]>>2],v[d+4>>2])){break b}break a}c=v[b+16>>2]}vz(v[a+36>>2],e,c);f=1;g=b}Xe(a,g);jb=d+16|0;return f|0}function Xw(a){var b=0,c=0;b=v[a+72>>2];v[a+72>>2]=b-1|b;if(v[a+20>>2]!=v[a+28>>2]){nb[v[a+36>>2]](a,0,0)|0}v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;b=v[a>>2];if(b&4){v[a>>2]=b|32;return-1}c=v[a+44>>2]+v[a+48>>2]|0;v[a+8>>2]=c;v[a+4>>2]=c;return b<<27>>31}function v$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=jb-16|0;jb=g;v[g+8>>2]=b;fd(g,d);v[23588]=0;b=S(19,g|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){$b(g);mG(a,f+24|0,g+8|0,c,e,b);jb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;$b(g);T(a|0);L()}function u$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=jb-16|0;jb=g;v[g+8>>2]=b;fd(g,d);v[23588]=0;b=S(19,g|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){$b(g);lG(a,f+16|0,g+8|0,c,e,b);jb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;$b(g);T(a|0);L()}function $U(a,b,c){var d=0,e=0;d=jb-16|0;jb=d;e=0;a:{if(!a){break a}b:{c:{if(a>>>0<=15){if(b>>>0<2|c){break c}break b}if(b>>>0>1){break b}}e=a|-16;break a}t[d+15|0]=1;t[d+14|0]=(a>>>0)/((b-1&255)>>>0);e=w[jf(d+15|0,d+14|0)|0]}a=e;jb=d+16|0;return a&255}function xA(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;GS(a,b);cd(a,bc(w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24))+504|0);FS(a,d);a:{b=bc(w[b+32|0]|w[b+33|0]<<8|(w[b+34|0]<<16|w[b+35|0]<<24));if(!b){break a}if(!cd(a,b)){break a}AA(a,c);return}Tb(c,0,80)}function lba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{b:{if((b|0)!=437){if((b|0)==1252){break b}d=0;if((b|0)==65001){break a}c:{if((b|0)!=28591){if((b|0)==28605){break c}if((b|0)!=20127){break b}d=1;break a}d=2;break a}d=3;break a}d=5;break a}d=8}iD(a,d,c)}function xg(a){var b=0,c=0,d=0;b=a;a:{if(b&3){while(1){if(!w[b|0]){break a}b=b+1|0;if(b&3){continue}break}}while(1){c=b;b=b+4|0;d=v[c>>2];if(!((d^-1)&d-16843009&-2139062144)){continue}break}while(1){b=c;c=b+1|0;if(w[b|0]){continue}break}}return b-a|0}function u3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=v[b>>2];e=v[b+8>>2];f=v[b+4>>2];a=0;a:while(1){if((a|0)!=(f|0)){g=(a<<2)+d|0;b=0;while(1)if((b|0)==(e|0)){a=a+1|0;continue a}else{c=v[g>>2]+(b<<3)|0;v[c>>2]=0;v[c+4>>2]=0;b=b+1|0;continue}}break}}function I2(a){a=a|0;var b=0,c=0,d=0;b=jb-32|0;jb=b;if(!w[a+8|0]){Ri(a+12|0,v[a+4>>2]);re(b+24|0,v[a+12>>2],v[a+16>>2]);c=v[v[a>>2]+40>>2];d=v[b+28>>2];v[b+8>>2]=v[b+24>>2];v[b+12>>2]=d;nb[c|0](b+16|0,a,0,b+8|0);t[a+8|0]=1}jb=b+32|0;return v[a+12>>2]}function uE(a,b){var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;v[b>>2]=0;t[c+15|0]=0;Mh(a,c+15|0);d=w[c+15|0];e=d>>>2|0;f=d&3;d=0;while(1){v[b>>2]=e;if((d|0)==(f|0)){jb=c+16|0}else{t[c+15|0]=0;Mh(a,c+15|0);d=d+1|0;e=v[b>>2]|w[c+15|0]<<(d<<3)-2;continue}break}}function Fr(a,b,c,d){var e=0;e=jb-32|0;jb=e;v[e+8>>2]=-1;v[e+12>>2]=0;v[e>>2]=0;Lb(e+16|0);v[e+4>>2]=d;v[23588]=0;v[e>>2]=v[e>>2]&-1332|1058;U(c|0,a|0,b|0,e|0);a=v[23588];v[23588]=0;if((a|0)!=1){jm(e);jb=e+32|0;return}a=P()|0;O()|0;jm(e);T(a|0);L()}function C8(a,b){a=a|0;b=b|0;var c=0,d=0;b=jb-16|0;jb=b;a:{b:{d=v[a+20>>2];c=v[d+4>>2];if((ed(c,v[d+8>>2])|0)!=7){break b}if(Rb(c,9516,4)){break b}c=Eb(c);d=Eb(v[v[a+20>>2]+8>>2]);Eo(b+8|0,a+4228|0);ph(c,d,v[b+8>>2]);break a}Qx(a,a)}Ps(a);jb=b+16|0}function MQ(a){var b=0;a:{if(Rb(a,14965,4)){break a}if(Hb(w[a+4|0]|w[a+5|0]<<8)>>>0>2|w[a+6|0]>128){break a}if(Hb(w[a+200|0]|w[a+201|0]<<8)>>>0>3999){break a}if(!Hb(w[a+140|0]|w[a+141|0]<<8)){break a}b=(Hb(w[a+148|0]|w[a+149|0]<<8)|0)==50}return b}function nG(a,b,c){var d=0,e=0,f=0;d=a;a:{if(b>>>0<1073741808){b:{if(Ur(b)){ce(d,b);break b}e=bm(b)+1|0;f=Bi(e);ud(d,f);bf(d,e);Fd(d,b);d=f}e=b;f=d;while(1){v[f>>2]=c;f=f+4|0;e=e-1|0;if(e){continue}break}ud((b<<2)+d|0,0);break a}hf();L()}return a}function RH(a,b){var c=0,d=0,e=0;o(+a);d=j(1)|0;e=j(0)|0;c=d>>>20&2047;if((c|0)!=2047){if(!c){if(a==0){c=0}else{a=RH(a*0x10000000000000000,b);c=v[b>>2]+-64|0}v[b>>2]=c;return a}v[b>>2]=c-1022;l(0,e|0);l(1,d&-2146435073|1071644672);a=+n()}return a}function Hr(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=jb-16|0;jb=f;d=ad(a);e=Gb(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=zc(a);ve(d+e|0,b,c);b=c+e|0;Qh(a,b);t[f+15|0]=0;ie(b+d|0,f+15|0);break a}hp(a,d,(c+e|0)-d|0,e,e,0,c,b)}jb=f+16|0;return a|0}function Ul(a,b,c,d,e,f){var g=0;g=jb-32|0;jb=g;v[g+8>>2]=-1;v[g+12>>2]=0;v[g>>2]=0;Lb(g+16|0);v[g+4>>2]=f;v[23588]=0;v[g>>2]=v[g>>2]&e|d;U(c|0,a|0,b|0,g|0);a=v[23588];v[23588]=0;if((a|0)!=1){Oj(g);jb=g+32|0;return}a=P()|0;O()|0;Oj(g);T(a|0);L()}function Lba(a,b){a=a|0;b=b|0;var c=0,d=0;a:{b:{c:{if(!ef(a)){c=1;d=w[a+11|0];if((d|0)==1){break c}ce(a,d+1|0);c=a;break a}c=Kl(a)-1|0;d=v[a+4>>2];if((c|0)!=(d|0)){break b}}XF(a,c,1,c,c);d=c}c=v[a>>2];Fd(a,d+1|0)}a=(d<<2)+c|0;ud(a,b);ud(a+4|0,0)}function xka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=jb-32|0;jb=d;e=d+16|0;Iq(e,c);Yi(d+8|0,e);v[23588]=0;X(296,a|0,b|0,v[d+8>>2],v[d+12>>2]);a=v[23588];v[23588]=0;if((a|0)!=1){_b(d+16|0);jb=d+32|0;break a}a=P()|0;O()|0;_b(d+16|0);T(a|0);L()}}function tia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=jb-32|0;jb=d;e=d+16|0;GA(e,c);Yi(d+8|0,e);v[23588]=0;X(114,a|0,b|0,v[d+8>>2],v[d+12>>2]);a=v[23588];v[23588]=0;if((a|0)!=1){ac(d+16|0);jb=d+32|0;break a}a=P()|0;O()|0;ac(d+16|0);T(a|0);L()}}function pia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=jb-32|0;jb=d;e=d+16|0;Zo(e,c);Yi(d+8|0,e);v[23588]=0;X(114,a|0,b|0,v[d+8>>2],v[d+12>>2]);a=v[23588];v[23588]=0;if((a|0)!=1){ac(d+16|0);jb=d+32|0;break a}a=P()|0;O()|0;ac(d+16|0);T(a|0);L()}}function pga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=jb-32|0;jb=d;e=d+16|0;Ap(e,c);Yi(d+8|0,e);v[23588]=0;X(296,a|0,b|0,v[d+8>>2],v[d+12>>2]);a=v[23588];v[23588]=0;if((a|0)!=1){_b(d+16|0);jb=d+32|0;break a}a=P()|0;O()|0;_b(d+16|0);T(a|0);L()}}function n$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=jb-16|0;jb=a;v[a+8>>2]=b;fd(a,d);v[23588]=0;b=S(1136,a|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){$b(a);hG(f+20|0,a+8|0,c,e,b);jb=a+16|0;return v[a+8>>2]}b=P()|0;O()|0;$b(a);T(b|0);L()}function jP(a,b,c){var d=0,e=0,f=0,g=0;f=v[b+4>>2];e=b+4|0;dq(v[a>>2],c,e);g=v[a+4>>2];d=b+8|0;while(1){if((c|0)!=(g|0)){Mi(v[d>>2],x[c>>1]);v[d>>2]=v[d>>2]+2;c=c+2|0;continue}break}pc(a,e);pc(a+4|0,d);pc(Fb(a),Bc(b));v[b>>2]=v[b+4>>2];return f}function ifa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=jb-32|0;jb=d;e=d+16|0;IT(e,c);Yi(d+8|0,e);v[23588]=0;X(114,a|0,b|0,v[d+8>>2],v[d+12>>2]);a=v[23588];v[23588]=0;if((a|0)!=1){ac(d+16|0);jb=d+32|0;break a}a=P()|0;O()|0;ac(d+16|0);T(a|0);L()}}function gaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;c=qf(a,c);me(e,v[a+36>>2]);a:{b:{if(!c){Rc(e,a+32|0,5);f=-1;if(!Bb(v[v[e>>2]>>2],v[e+4>>2])){break b}break a}f=v[c+16>>2]}nb[d|0](v[a+36>>2],b,f);g=c}Xe(a,g);jb=e+16|0}function MA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=Sb(a+8|0);v[23588]=0;d=S(202,b|0)|0;e=v[23588];v[23588]=0;b:{if((e|0)==1){break b}v[23588]=0;U(244,a|0,b|0,d|0);a=v[23588];v[23588]=0;if((a|0)==1){break b}break a}a=P()|0;O()|0;hc(c);T(a|0);L()}}function cV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=jb-32|0;jb=d;e=d+16|0;UB(e,c);Yi(d+8|0,e);v[23588]=0;X(114,a|0,b|0,v[d+8>>2],v[d+12>>2]);a=v[23588];v[23588]=0;if((a|0)!=1){ac(d+16|0);jb=d+32|0;break a}a=P()|0;O()|0;ac(d+16|0);T(a|0);L()}}function aw(a,b,c,d,e){var f=0;f=jb-32|0;jb=f;v[f+8>>2]=-1;v[f+12>>2]=0;v[f>>2]=0;v[f+4>>2]=0;Lb(f+16|0);v[23588]=0;v[f>>2]=v[f>>2]&e|d;U(c|0,a|0,b|0,f|0);a=v[23588];v[23588]=0;if((a|0)!=1){Oj(f);jb=f+32|0;return}a=P()|0;O()|0;Oj(f);T(a|0);L()}function ZD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=jb-32|0;jb=d;e=d+16|0;ln(e,c);Yi(d+8|0,e);v[23588]=0;X(114,a|0,b|0,v[d+8>>2],v[d+12>>2]);a=v[23588];v[23588]=0;if((a|0)!=1){ac(d+16|0);jb=d+32|0;break a}a=P()|0;O()|0;ac(d+16|0);T(a|0);L()}}function Gv(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;_g(e+8|0,b,c);v[23588]=0;Qa(171,a|0,v[e+8>>2],v[e+12>>2]);b=v[23588];v[23588]=0;if((b|0)!=1){v[a+8>>2]=0;Cg(a+12|0,d);le(d);jb=e+16|0;return a|0}a=P()|0;O()|0;le(d);T(a|0);L()}function CU(a,b,c){var d=0,e=0,f=0,g=0;f=v[b+4>>2];e=b+4|0;dq(v[a>>2],c,e);g=v[a+4>>2];d=b+8|0;while(1){if((c|0)!=(g|0)){wd(v[d>>2],w[c|0]);v[d>>2]=v[d>>2]+1;c=c+1|0;continue}break}pc(a,e);pc(a+4|0,d);pc(Fb(a),Bc(b));v[b>>2]=v[b+4>>2];return f}function AC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=jb-32|0;jb=d;e=d+16|0;$u(e,c);Yi(d+8|0,e);v[23588]=0;X(114,a|0,b|0,v[d+8>>2],v[d+12>>2]);a=v[23588];v[23588]=0;if((a|0)!=1){ac(d+16|0);jb=d+32|0;break a}a=P()|0;O()|0;ac(d+16|0);T(a|0);L()}}function t$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=jb-16|0;jb=a;v[a+8>>2]=b;fd(a,d);v[23588]=0;b=S(19,a|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){$b(a);kG(f+20|0,a+8|0,c,e,b);jb=a+16|0;return v[a+8>>2]}b=P()|0;O()|0;$b(a);T(b|0);L()}function JO(a){var b=0,c=0,d=0,e=0,f=0;b=jb-16|0;jb=b;c=a;d=v[a>>2];f=lk(d,v[a+4>>2]);a=Eb(d);v[b+8>>2]=a;e=+(f>>>0);c=Eb(v[c+4>>2]);while(1){if(Ob(a,c)){A[a>>3]=A[a>>3]/e;A[a+8>>3]=A[a+8>>3]/e;a=v[eq(b+8|0)>>2];continue}else{jb=b+16|0}break}}function AD(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function $B(a){var b=0,c=0,d=0,e=0;b=w[a+2|0];c=b+(w[a+5|0]|w[a+6|0]<<8)|0;d=b>>>0>c>>>0?1:d;b=c;c=b<<1;b=d<<1|b>>>31;a=w[a+3|0]|w[a+4|0]<<8;d=a>>>30|0;e=c;c=a<<2;e=e+c|0;a=b+d|0;a=c>>>0>e>>>0?a+1|0:a;b=e+47|0;a=b>>>0<47?a+1|0:a;mb=a;return b}function hA(a,b,c){var d=0;d=jb-16|0;jb=d;u[d+12>>1]=c;u[d+14>>1]=b;b=Eb(v[a>>2]);c=Eb(v[a+4>>2]);a=jb-16|0;jb=a;v[a+8>>2]=b;while(1){if(Ob(b,c)){if(x[b>>1]==x[d+14>>1]){u[b>>1]=x[d+12>>1]}b=v[Re(a+8|0)>>2];continue}break}jb=a+16|0;jb=d+16|0}function fp(a,b){var c=0,d=0,e=0,f=0;c=a*a;d=c*.5;e=1-d;f=1-e-d;d=c*c;return e+(f+(c*(c*(c*(c*2480158728947673e-20+-.001388888888887411)+.0416666666666666)+d*d*(c*(c*-11359647557788195e-27+2.087572321298175e-9)+-2.7557314351390663e-7))-a*b))}function VN(a,b){var c=0,d=0;d=jb-16|0;jb=d;c=v[a+104>>2];a:{if(!c){break a}c=v[c>>2];if(!c){break a}v[a+76>>2]=c;v[a+88>>2]=v[a+88>>2]&-131|128;v[d+12>>2]=b<<8;v[d+8>>2]=c-1;b=c+(v[Jb(d+12|0,d+8|0)>>2]^-1)|0;v[a>>2]=0;v[a+4>>2]=b}jb=d+16|0}function kD(a){var b=0,c=0;a:{if(Rb(a,14132,4)){break a}if(Rb(a+8|0,14053,4)){break a}b=bc(w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24));if(!b){break a}c=(bc(w[a+12|0]|w[a+13|0]<<8|(w[a+14|0]<<16|w[a+15|0]<<24))|0)!=0&b>>>0>27}return c}function SK(a,b,c){var d=0,e=0;if(C(D(a))<C(0x8000000000000000)){d=~~a>>>0}else{d=0}e=d&-2147483648;d=e?0-d|0:d;while(1){if(!((d|0)<0|(b|0)<=0)){b=b-1|0;d=d<<1;continue}break}b=(d>>>31|0)+b<<31-c|(d&2147483647)>>>c;return C((e?b^-1|e:b)|0)}function iO(a,b){var c=0;c=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[a|0]=c;t[a+1|0]=c>>>8;t[a+2|0]=c>>>16;t[a+3|0]=c>>>24;b=w[b+3|0]|w[b+4|0]<<8|(w[b+5|0]<<16|w[b+6|0]<<24);t[a+3|0]=b;t[a+4|0]=b>>>8;t[a+5|0]=b>>>16;t[a+6|0]=b>>>24}function ge(a,b){var c=0,d=0;c=v[a+4>>2];d=c+b|0;v[a+4>>2]=d;if(v[a+8>>2]>=(d|0)){d=v[a>>2]+(c>>3)|0;a=c&7;c=w[d|0]&255>>>a;a=a+b|0;b=0;while(1){if((a|0)>=9){a=a-8|0;b=c<<a|b;c=w[d+1|0];d=d+1|0;continue}break}a=c>>>8-a|b}else{a=0}return a}function TQ(a){var b=0,c=0;a:{if(w[a+29|0]!=2){break a}b=w[a+28|0];if((b|0)!=26&(b|0)!=2|w[a+30|0]!=2){break a}b=w[a+31|0];if(b>>>0>21|!(1<<b&3146753)|w[a+33|0]>64){break a}b=w[a+34|0];if(b>>>0>=65&(b|0)!=88){break a}c=RQ(a+20|0)}return c}function P3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-32|0;jb=d;el(d,c);c=d+16|0;v[c>>2]=b;$c(c+4|0,d);v[23588]=0;R(1059,a+4|0,c|0);a=v[23588];v[23588]=0;if((a|0)!=1){Cs(d+16|0);yb(d);jb=d+32|0;return}a=P()|0;O()|0;Cs(d+16|0);yb(d);T(a|0);L()}function Nf(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Sb(a+8|0);v[23588]=0;U(244,a|0,b|0,c|0);c=v[23588];v[23588]=0;a:{if((c|0)!=1){a=v[a>>2];v[23588]=0;Q(188,b|0,a|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;hc(d);T(a|0);L()}}function Hia(a){a=a|0;var b=0,c=0,d=0;b=jb-32|0;jb=b;t[b+30|0]=0;u[b+28>>1]=0;c=gc(b+8|0,b+28|0,3);mc(b+16|0,v[a>>2],v[a+8>>2],v[c>>2],v[c+4>>2]);a:{if(v[b+20>>2]!=3){break a}if(Rb(b+28|0,14711,3)){break a}Zb(a,3);d=1}jb=b+32|0;return d|0}function Gea(a){a=a|0;var b=0,c=0,d=0;b=jb-32|0;jb=b;u[b+28>>1]=0;v[b+24>>2]=0;c=gc(b+8|0,b+24|0,6);mc(b+16|0,v[a>>2],v[a+8>>2],v[c>>2],v[c+4>>2]);a:{if(v[b+20>>2]!=6){break a}if(Rb(b+24|0,3856,6)){break a}Zb(a,6);d=1}jb=b+32|0;return d|0}function GE(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+12>>2]=c;c=e+12|0;wc(c,d);wc(c,65535);d=x[e+12>>1];ug(a,d);c=0;while(1){if((c|0)==(d|0)){jb=e+16|0}else{f=w[b+c|0];g=Il(v[a>>2],v[a+4>>2],c),h=f,u[g>>1]=h;c=c+1|0;continue}break}}function $M(a,b){a=XM(a);XM(a+368680|0);if(b){WM(a,1);return}if(!w[463224]){$M(94520,1);t[463224]=1}_n(225632,291168,a+131112|0);_n(291168,356704,a+196648|0);_n(356704,422240,a+262184|0);_n(94544,225632,a+24|0);tc(a+327720|0,422240,40960)}function aka(a,b){a=a|0;b=b|0;var c=0;b=jb-32|0;jb=b;c=-1;a:{if(!vB(a,b+16|0)){break a}c=0;if(!LU(b+16|0)){break a}if(!Rb(b+16|0,14118,4)){c=-1;if(!hd(a,4)){break a}}c=-1;if(!Qj(a,b+8|0)){break a}c=!Rb(b+8|0,14094,4)}jb=b+32|0;return c|0}function _v(a,b){var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;u[b>>1]=0;t[c+15|0]=0;Mh(a,c+15|0);d=w[c+15|0];e=d>>>1|0;f=d&1;d=0;while(1){u[b>>1]=e;if(d>>>0>=f>>>0){jb=c+16|0}else{t[c+15|0]=0;Mh(a,c+15|0);e=x[b>>1]|w[c+15|0]<<7;d=1;continue}break}}function Hf(a,b,c){var d=0;a:{if(y[b+8>>2]<c>>>0){v[23588]=0;X(1074,17347,9070,435,6384);a=v[23588];v[23588]=0;if((a|0)==1){break a}L()}d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;v[a+8>>2]=v[b+8>>2];v[a+12>>2]=c;return}V(0)|0;O()|0;Ub();L()}function TY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=jb-16|0;jb=e;if(d>>>0<4294967280){a:{if(El(d)){ce(a,c);break a}f=Mg(d)+1|0;d=sc(f);ud(a,d);bf(a,f);Fd(a,c);a=d}a=ve(a,b,c);t[e+15|0]=0;ie(a+c|0,e+15|0);jb=e+16|0;return}hf();L()}function BN(a,b){var c=0,d=0;a:{if(!(w[a+89|0]&16)){break a}c=v[a+656>>2];if(!c){break a}c=v[c>>2];b:{if(c){d=a;a=v[a+696>>2]-(c<<1)|0;a=(a|0)>0?a:0;v[d+696>>2]=a;a=(B(a,v[b>>2])|0)/65536|0;break b}if(v[a+696>>2]){break a}a=0}v[b>>2]=a}}function ki(a,b,c){var d=0,e=0,f=0,g=0;v[a+112>>2]=b;v[a+116>>2]=c;e=v[a+4>>2];d=v[a+44>>2]-e|0;v[a+120>>2]=d;v[a+124>>2]=d>>31;d=a;a=v[a+8>>2];f=a-e|0;g=f>>31;if(!(!(b|c)|((c|0)>=(g|0)&b>>>0>=f>>>0|(c|0)>(g|0)))){a=b+e|0}v[d+104>>2]=a}function hka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;xv(c+8|0,b);d=v[c+12>>2];mc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){Zb(a,v[c+12>>2])}jb=c+16|0;if((d|0)!=(e|0)){t[b+2|0]=0;t[b|0]=0;t[b+1|0]=0}}function eU(a){var b=0,c=0,d=0,e=0;b=w[a+3|0];c=Lka(b>>>0<3?48:64,0,Hb(w[a+196|0]|w[a+197|0]<<8),0);d=mb;e=c;c=Lka(Lka(Hb(w[a+198|0]|w[a+199|0]<<8),0,b>>>0<4?4:5,0),mb,Hb(w[a+200|0]|w[a+201|0]<<8),0);b=e+c|0;b=b+512|0;a=b;mb=0;return a}function UN(a,b){var c=0,d=0;a:{if(!(t[a+851|0]&1)){break a}c=v[a+104>>2];if(!c){break a}d=v[c>>2];if(!d){break a}v[a+76>>2]=d;v[a>>2]=0;v[a+4>>2]=d-1;c=v[a+88>>2];v[a+88>>2]=b?c|134:c&-135|128;if(!b){break a}v[a+84>>2]=d;v[a+80>>2]=0}}function P9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=b;d=jb-16|0;jb=d;b=qf(a,c);me(d,v[a+36>>2]);a:{b:{if(!b){Rc(d,a+32|0,5);c=-1;if(!Bb(v[v[d>>2]>>2],v[d+4>>2])){break b}break a}c=v[b+16>>2]}vz(v[a+36>>2],e,c);f=b}Xe(a,f);jb=d+16|0}function Vha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;while(1){a:{d=v[a>>2];if(uc(d,v[a+4>>2])>>>0>e>>>0){Ik(c,v[Db(d,e)>>2]+40|0);d=mq(c,b);zb(c);if(!d){break a}f=v[Db(v[a>>2],e)>>2]}jb=c+16|0;return f|0}e=e+1|0;continue}}function PN(a,b,c){var d=0,e=0;d=jb-16|0;jb=d;e=c&15;if(e){t[b+824|0]=e}c=c&240;if(c){t[b+823|0]=c>>>4}v[b+88>>2]=v[b+88>>2]|131072;Cb(d+8|0,a+1074312|0,80);if(!(!e|!Bb(v[v[d+8>>2]>>2],v[d+12>>2]))){t[b+824|0]=w[b+824|0]<<2}jb=d+16|0}function y8(a,b,c){a=a|0;b=b|0;c=c|0;a:{if(v[b+4>>2]!=8){break a}b=v[b>>2];if(Rb(b,9516,4)){break a}c=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[a+4228>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[a+4232>>2]=c;Ps(a)}}function o9(a,b,c){a=a|0;b=b|0;c=c|0;a:{if(v[b+4>>2]!=8){break a}b=v[b>>2];if(Rb(b,9516,4)){break a}c=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[a+4260>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[a+4264>>2]=c;Ts(a)}}function _i(a,b,c){c=v[c+4>>2]&176;if((c|0)==32){return b}a:{if((c|0)!=16){break a}b:{c:{c=w[a|0];switch(c-43|0){case 0:case 2:break c;default:break b}}return a+1|0}if((c|0)!=48|(b-a|0)<2|(w[a+1|0]|32)!=120){break a}a=a+2|0}return a}function NO(a,b){var c=0,d=0,e=0;v[a>>2]=0;v[a+4>>2]=0;Gc(a+8|0);if(b){FO(a,b);d=jb-16|0;jb=d;c=Et(d,a,b);b=v[c+4>>2];e=v[c+8>>2];while(1){if((b|0)==(e|0)){kc(c);jb=d+16|0}else{nl(b,0,0);b=b+16|0;v[c+4>>2]=b;continue}break}}return a}function Dia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;EA(c+8|0,b);d=v[c+12>>2];mc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){Zb(a,v[c+12>>2])}jb=c+16|0;a=(d|0)==(e|0);if(!a){Tb(b,0,4896)}return a|0}function J0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if(!w[a+44|0]){c=(c|0)>0?c:0;while(1){if((c|0)==(d|0)){break a}if((nb[v[v[a>>2]+52>>2]](a,v[b>>2])|0)==-1){return d|0}else{b=b+4|0;d=d+1|0;continue}}}c=vk(b,4,c,v[a+32>>2])}return c|0}function Aea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-32|0;jb=d;e=Af(v[b>>2],v[b+4>>2]);c=YP(d+8|0,c);v[23588]=0;X(727,a|0,b|0,e-1&65535,c|0);a=v[23588];v[23588]=0;if((a|0)!=1){Ve(c);jb=d+32|0;return}a=P()|0;O()|0;Ve(c);T(a|0);L()}function zM(a){var b=0,c=0,d=0;c=jb-544|0;jb=c;a:{if(!(w[a+480210|0]&128)|!v[a+24668>>2]){break a}d=a+1298224|0;b=a+1074992|0;a=Nz(c,v[a+24620>>2]);while(1){if((b|0)==(d|0)){break a}tc(b+112|0,a,538);b=b+872|0;continue}}jb=c+544|0}function xha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;CA(c+8|0,b);d=v[c+12>>2];mc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){Zb(a,v[c+12>>2])}jb=c+16|0;a=(d|0)==(e|0);if(!a){Tb(b,0,33)}return a|0}function Nz(a,b){var c=0,d=0,e=0,f=0;u[a+24>>1]=0;v[a+20>>2]=0;c=3546895/+(b>>>0);d=c*.25;a:{if(D(d)<2147483648){b=~~d;break a}b=-2147483648}v[a+16>>2]=b;v[a>>2]=0;v[a+4>>2]=0;e=a,f=sQ(c-+(b<<2)),v[e+8>>2]=f;v[a+12>>2]=mb;return a}function Jy(a,b,c){var d=0,e=0;d=Sd(a);a:{if(d){e=ic(a);while(1){a=d;d=w[a+16|0];if(Rn(c,d)){e=a;d=v[a>>2];if(d){continue}break a}if(!Rn(d,c)){break a}e=a+4|0;d=v[a+4>>2];if(d){continue}break}break a}a=ic(a);e=a}v[b>>2]=a;return e}function rW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;bv(c+8|0,b);d=v[c+12>>2];mc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){Zb(a,v[c+12>>2])}jb=c+16|0;a=(d|0)==(e|0);if(!a){Tb(b,0,65)}return a|0}function XD(a){var b=0;if(!(Rb(a,13261,8)|(w[a+8|0]|w[a+9|0]<<8)!=14|(!(w[a+12|0]|w[a+13|0]<<8)|(w[a+14|0]|w[a+15|0]<<8|(w[a+16|0]<<16|w[a+17|0]<<24))<=0))){b=(w[a+18|0]|w[a+19|0]<<8|(w[a+20|0]<<16|w[a+21|0]<<24))>>>0>23}return b}function Pfa(a,b){a=a|0;b=b|0;var c=0;b=jb-32|0;jb=b;c=-1;a:{if(!vB(a,b+16|0)){break a}c=0;if(!uR(b+16|0)){break a}c=-1;if(!Qj(a,b+8|0)){break a}c=0;if(!v[b+12>>2]){break a}a=v[b+8>>2];c=(a&2139062143)==(a|0)}jb=b+32|0;return c|0}function $D(){var a=0,b=0,c=0;b=jb-16|0;jb=b;a=Mc(b,15351);a:{if(!Gb(a)){break a}c=1;if((Dg(a,14600)|0)!=-1){break a}if((Dg(a,16764)|0)!=-1){break a}if((Dg(a,13662)|0)!=-1){break a}c=(Dg(a,13705)|0)!=-1}yb(a);jb=b+16|0;return c|0}function v3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=v[b>>2];d=v[b+8>>2];e=v[b+4>>2];a=0;a:while(1){if((a|0)!=(e|0)){f=(a<<2)+c|0;b=0;while(1)if((b|0)==(d|0)){a=a+1|0;continue a}else{v[v[f>>2]+(b<<2)>>2]=0;b=b+1|0;continue}}break}}function ig(a,b){var c=0,d=0,e=0,f=0;d=x[a+22>>1];e=d+x[a+20>>1]|0;c=x[a+24>>1]<<17;while(1){if((d|0)==(e|0)){a=(c|0)/32768|0}else{f=c;c=((d&127)<<2)+a|0;c=f-B(v[Db(b,x[c+28>>1])>>2],u[c+26>>1])|0;d=d+1|0;continue}break}return a}function hS(a,b,c){var d=0,e=0,f=0,g=0;while(1){if((b|0)!=(c|0)){e=v[a+4>>2];f=e>>>8|0;d=v[a>>2];e=(e&255)<<24|d>>>8;d=(((d^w[b|0])&255)<<3)+21640|0;g=v[d>>2];d=v[d+4>>2]^f;v[a>>2]=e^g;v[a+4>>2]=d;b=b+1|0;continue}break}return a}function RV(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=Pb(v[a>>2],v[a+8>>2],120);a:{if(!d){a=0;while(1){if((a|0)!=120){Ch(a+b|0);a=a+1|0;continue}break}break a}fc(c+8|0,b,120);td(c,a,v[c+8>>2],v[c+12>>2])}jb=c+16|0;return d|0}function Mja(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=Pb(v[a>>2],v[a+8>>2],64);a:{if(!d){a=0;while(1){if((a|0)!=32){Fo((a<<1)+b|0);a=a+1|0;continue}break}break a}Gu(c+8|0,b);td(c,a,v[c+8>>2],v[c+12>>2])}jb=c+16|0;return d|0}function wga(a){a=a|0;var b=0,c=0,d=0;b=jb-32|0;jb=b;u[b+30>>1]=0;c=gc(b+8|0,b+30|0,2);mc(b+16|0,v[a>>2],v[a+8>>2],v[c>>2],v[c+4>>2]);a:{if(v[b+20>>2]!=2){break a}if(Rb(b+30|0,13570,2)){break a}Zb(a,2);d=1}jb=b+32|0;return d|0}function ti(a){var b=0,c=0,d=0,e=0;e=Le(a);c=e&63;a:{if(!(e&64)){break a}b=6;while(1){d=Le(a);c=(d&127)<<b|c;if(!(d&128)){break a}d=b>>>0<25;b=b+7|0;if(d){continue}break}}a=e>>>7|0;b=a?-2147483648:c;return a?(c|0)>=0?0-c|0:b:b}function mM(a,b,c){var d=0,e=0,f=0,g=0,h=0;g=c;h=c>>31;c=0;while(1){if((b|0)!=(c|0)){d=v[a>>2];e=v[a+4>>2];f=(d+e|0)/2|0;d=d-e|0;d=Hc(Mka(Lka(d,d>>31,g,h),mb,256,0),mb);v[a+4>>2]=f-d;v[a>>2]=d+f;c=c+1|0;a=a+8|0;continue}break}}function Nq(a){var b=0,c=0,d=0,e=0;c=jb-16|0;jb=c;b=jb-16|0;jb=b;Xq(b+8|0,c+15|0);d=v[b+12>>2];ld(b,a,v[b+8>>2],v[b+12>>2]);e=v[b+4>>2];if((e|0)==(d|0)){hd(a,v[b+12>>2])}jb=b+16|0;jb=c+16|0;return((d|0)==(e|0)?w[c+15|0]:0)&255}function AB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=v[a>>2];f=xk(e,v[a+4>>2]);while(1){a:{c=d&65535;if(c>>>0>=f>>>0){break a}c=ag(e,c);if(!Ob(v[c>>2],v[c+4>>2])){break a}d=d+1|0;continue}break}return(oh(a,d&65535,b)?d:-1)&65535}function hw(a,b,c,d,e){var f=0,g=0,h=0;f=jb-16|0;jb=f;g=Cg(f+8|0,d);v[23588]=0;h=v[g+4>>2];v[f>>2]=v[g>>2];v[f+4>>2]=h;a=Eg(e,a,b,c,f);b=v[23588];v[23588]=0;if((b|0)!=1){le(d);jb=f+16|0;return a}a=P()|0;O()|0;le(d);T(a|0);L()}function _N(a,b,c){var d=0,e=0,f=0;d=jb-16|0;jb=d;a:{if(!c){break a}v[b+40>>2]=c;if(!c|v[a+480180>>2]!=256){break a}v[d+12>>2]=c>>>4;v[d+8>>2]=1;e=b,f=v[Yc(d+12|0,d+8|0)>>2],v[e+40>>2]=f;e=b,f=Vz(c&255),v[e+44>>2]=f}jb=d+16|0}function Yba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;QO(c+8|0,b);d=v[c+12>>2];mc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){Zb(a,v[c+12>>2])}jb=c+16|0;a=(d|0)==(e|0);if(!a){oz(b)}return a|0}function Mka(a,b,c,d){var e=0,f=0,g=0,h=0;f=b^d;g=f>>31;e=b>>31;a=a^e;h=a-e|0;e=(b^e)-((a>>>0<e>>>0)+e|0)|0;a=d>>31;b=c^a;f=f>>31;a=Oka(h,e,b-a|0,(a^d)-((a>>>0>b>>>0)+a|0)|0)^f;b=a-f|0;mb=(g^mb)-((a>>>0<f>>>0)+g|0)|0;return b}function Iu(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=jb-16|0;jb=f;if(b){e=ad(a);d=Gb(a);g=d+b|0;if(e-d>>>0<b>>>0){rm(a,e,g-e|0,d,d,0,0)}e=d;d=zc(a);zB(e+d|0,b,c);Qh(a,g);t[f+15|0]=0;ie(d+g|0,f+15|0)}jb=f+16|0;return a|0}function td(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;g=v[b+8>>2];f=v[b>>2];v[e+8>>2]=c;v[e+12>>2]=d;h=v[v[f>>2]+28>>2];v[e>>2]=c;v[e+4>>2]=d;nb[h|0](a,f,g,e);v[b+8>>2]=v[b+8>>2]+v[a+4>>2];jb=e+16|0}function pA(a,b){var c=0,d=0,e=0,f=0;c=a<<8;d=c&16711680;c=e;e=a<<24|d;f=c;d=b<<24|a>>>8;c=b<<8|a>>>24;a=f|(((b&255)<<24|a>>>8)&-16777216|((b&16777215)<<8|a>>>24)&16711680|(b>>>8&65280|b>>>24));mb=e|(d&65280|c&255);return a}
function Zu(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;kC(c+8|0,b);d=v[c+12>>2];mc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){Zb(a,v[c+12>>2])}jb=c+16|0;a=(d|0)==(e|0);if(!a){jC(b)}return a|0}function Vt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;vR(c+8|0,b);d=v[c+12>>2];mc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){Zb(a,v[c+12>>2])}jb=c+16|0;a=(d|0)==(e|0);if(!a){wR(b)}return a|0}function BC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;DC(c+8|0,b);d=v[c+12>>2];mc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){Zb(a,v[c+12>>2])}jb=c+16|0;a=(d|0)==(e|0);if(!a){CC(b)}return a|0}function bt(a,b){var c=0;a:{b:{c:{switch(b-2|0){default:c=43820;if((b|0)==16777216){break a}if((b|0)!=32){break b}c=43672;break a;case 2:c=43668;break a;case 1:break b;case 0:break c}}c=43664;break a}c=43660}v[a>>2]=v[c>>2]}function Qd(a,b){var c=0,d=0,e=0,f=0,g=0;d=x[a+22>>1];g=d+x[a+20>>1]|0;c=d;while(1){a:{if((c|0)!=(g|0)){e=((c&127)<<2)+a|0;f=x[e+28>>1]+b|0;u[e+28>>1]=f;if((f&65535)>>>0<2048){break a}u[a+20>>1]=c-d}return}c=c+1|0;continue}}function Yp(a,b,c){var d=0,e=0,f=0,g=0,h=0;f=131072/(A[b-8>>3]-A[a>>3]);b=0;while(1){if((b|0)!=2048){d=-we(f*A[af(a,b)>>3]);a:{if(D(d)<2147483648){e=~~d;break a}e=-2147483648}g=Db(c,b),h=e,v[g>>2]=h;b=b+1|0;continue}break}}function YG(a,b){var c=0,d=0;c=jb-16|0;jb=c;v[c>>2]=a;v[c+4>>2]=b;d=jb-16|0;jb=d;a=Yr(d+8|0,Mka(v[c>>2],v[c+4>>2],1e6,0),mb);b=v[a+4>>2];a=v[a>>2];jb=d+16|0;v[c+8>>2]=a;v[c+12>>2]=b;jb=c+16|0;mb=v[c+12>>2];return v[c+8>>2]}function Iia(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;v[a+480180>>2]=b;vq(c,wq(a));d=v[c+12>>2];b=a+1074320|0;v[b>>2]=v[c+8>>2];v[b+4>>2]=d;b=v[c+4>>2];v[a+1074312>>2]=v[c>>2];v[a+1074316>>2]=b;bt(a+8|0,wq(a));jb=c+16|0}function hga(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=Pb(v[a>>2],v[a+8>>2],6);a:{if(!d){a=0;while(1){if((a|0)!=6){Ch(a+b|0);a=a+1|0;continue}break}break a}oB(c+8|0,b);td(c,a,v[c+8>>2],v[c+12>>2])}jb=c+16|0;return d|0}function TN(a,b,c,d){var e=0;a=dd(Vn(a,x[c+70>>1],v[c+48>>2],b,0)-32768|0);a:{if(!d){break a}d=il(c)-v[c+16>>2]|0;if((d|0)<2){break a}e=a;a=u[(B(b,872)+c|0)+1390>>1];a=dd(((e-a|0)/(d|0)|0)+a|0)}u[(B(b,872)+c|0)+1390>>1]=a}function TA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=xl(a);e=yd(v[a+4>>2],w[a+11|0]);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=od(a);ve(d+e|0,b,c);b=c+e|0;sq(a,b);wd(b+d|0,0);return a|0}oq(a,d,(c+e|0)-d|0,e,e,0,c,b)}return a|0}function KE(a,b,c,d,e){var f=0;f=jb-32|0;jb=f;v[f+24>>2]=a;v[f+28>>2]=b;v[f+16>>2]=d;v[f+20>>2]=e;v[f+8>>2]=c;v[f+12>>2]=0;a=VB(f+24|0,f+8|0);b=f+16|0;a=zr(v[b>>2],v[b+4>>2],v[a>>2],v[a+4>>2])?a:b;jb=f+32|0;return v[a>>2]}function FJ(a,b){var c=0,d=0,e=0;v[a>>2]=0;v[a+4>>2]=0;Gc(a+8|0);if(b){Nl(a,b);d=jb-16|0;jb=d;b=Ok(d,a,b);c=v[b+4>>2];e=v[b+8>>2];while(1){if((c|0)==(e|0)){kc(b);jb=d+16|0}else{c=c+1|0;v[b+4>>2]=c;continue}break}}return a}function Tt(a,b){var c=0,d=0,e=0;if(v[a>>2]){rV(a);c=v[a>>2];IB(a);Mb(c);d=Fb(a),e=0,v[d>>2]=e;v[a>>2]=0;v[a+4>>2]=0}v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=Fb(b);d=Fb(a),e=v[c>>2],v[d>>2]=e;v[c>>2]=0;v[b>>2]=0;v[b+4>>2]=0}function uN(a,b){var c=0,d=0,e=0,f=0;v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=v[b+8>>2];d=Fb(a);c=ic(a);a:{if(!v[d>>2]){v[a>>2]=c;break a}v[v[c>>2]+8>>2]=c;c=ic(b);v[b>>2]=c;v[c>>2]=0;e=Fb(b),f=0,v[e>>2]=f}return a}function ps(a){var b=0;a:{b=w[a+1376|0];b:{if(!b){b=-1;if(v[a+1384>>2]){break b}if(!ix(a)){break b}b=w[a+1376|0];if(!b){break a}}t[a+1376|0]=b-1;v[a+1400>>2]=v[a+1400>>2]+1;b=_e(a)}return b}aa(15678,13110,1578,5432);L()}function d_(a){a=a|0;if(w[468448]){return v[117111]}if(!w[469608]){a=469584;while(1){a=Lb(a)+12|0;if((a|0)!=469608){continue}break}t[469608]=1}qd(469584,89760);qd(469596,89772);t[468448]=1;v[117111]=469584;return 469584}function VQ(a,b,c){var d=0;d=jb-16|0;jb=d;t[d+15|0]=a;a=0;if(!(c>>>0<25|b>>>0<25|(b>>>0>108|b>>>0>=c>>>0)|c>>>0>108)){t[d+14|0]=(x[(b<<1)+32622>>1]-x[(c<<1)+32622>>1]|0)/5;a=w[Wb(d+15|0,d+14|0)|0]}jb=d+16|0;return a&255}function RZ(a){a=a|0;if(w[468440]){return v[117109]}if(!w[469576]){a=469552;while(1){a=Lb(a)+12|0;if((a|0)!=469576){continue}break}t[469576]=1}pd(469552,13812);pd(469564,13791);t[468440]=1;v[117109]=469552;return 469552}function ys(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=jb-16|0;jb=c;d=v[b>>2];b=uc(d,v[b+4>>2]);a=0;while(1){if((a|0)==(b|0)){jb=c+16|0}else{v[c+8>>2]=0;e=Gc(c+8|0);f=Db(d,a),g=v[e>>2],v[f>>2]=g;a=a+1|0;continue}break}}function s8(a){a=a|0;var b=0;nb[v[v[a>>2]+132>>2]](a);Hx(a);v[a+4236>>2]=0;t[a+4202|0]=1;b=nb[v[v[a>>2]+196>>2]](a)|0;v[a+4328>>2]=0;v[a+4312>>2]=0;z[a+4240>>2]=b?C(.5):C(1);b=v[a+4256>>2];v[a+4324>>2]=b;v[a+4320>>2]=b}function nN(a,b,c,d){var e=0,f=0;e=v[(B(c,872)+b|0)+704>>2];a:{if(!(!(e&134218752)|(d|0)!=1)|e&67108864){break a}b=x[(B(c,872)+b|0)+1402>>1];b=(b?b-1|0:c)&65535;if(b>>>0>126){break a}f=w[((b<<5)+a|0)+480288|0]}return f}function di(a,b,c){var d=0,e=0,f=0;d=jb-16|0;jb=d;fc(d+8|0,b,c);e=v[d+12>>2];mc(d,v[a>>2],v[a+8>>2],v[d+8>>2],v[d+12>>2]);f=v[d+4>>2];if((f|0)==(e|0)){Zb(a,v[d+12>>2])}jb=d+16|0;a=(e|0)==(f|0);if(!a){Tb(b,0,c)}return a}function PS(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function Kha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;c=-1;a:{if(!Qj(a,d+8|0)){break a}e=v[d+12>>2];c=0;if(!(v[d+8>>2]==(Tm(8938)|0)&e>>>0>255&e>>>0<260)){break a}c=Ae(a,b,e>>>0<259?80:76,0)}jb=d+16|0;return c|0}function aq(a,b,c){var d=0;d=jb-16|0;jb=d;Cb(d+8|0,c+1074312|0,102);a:{if(!Bb(v[v[d+8>>2]>>2],v[d+12>>2])){break a}c=x[a+692>>1]+1|0;u[a+784>>1]=c;if(!(t[a+89|0]&1)){break a}u[a+784>>1]=c|32768}v[a+692>>2]=b;jb=d+16|0}function YO(a,b){a:{if(w[a+76|0]==(b|0)){break a}t[a+76|0]=b;if(b){b=0;if(x[a+24>>1]==15){u[a+20>>1]=0;b=1}v[a+8>>2]=0;v[a+16>>2]=b;return}b:{switch(v[a+16>>2]+1|0){case 0:case 4:break a;default:break b}}v[a+16>>2]=3}}function Lka(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=c>>>16|0;f=a>>>16|0;j=B(e,f);g=c&65535;h=a&65535;i=B(g,h);f=(i>>>16|0)+B(f,g)|0;e=(f&65535)+B(e,h)|0;mb=(B(b,c)+j|0)+B(a,d)+(f>>>16)+(e>>>16)|0;return i&65535|e<<16}function AT(a){var b=0;a:{b:{if(Rb(a,13789,4)){if(Rb(a,16245,4)){break a}if((w[a+34|0]|w[a+35|0]<<8)>>>0<=255){break b}break a}if((w[a+34|0]|w[a+35|0]<<8)>>>0>255){break a}}b=(w[a+36|0]|w[a+37|0]<<8)>>>0<4e3}return b}function yL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;og(a+12|0,d);if(b){if(b>>>0>=2097152){Lg();L()}d=sc(b<<11)}else{d=0}v[a>>2]=d;c=d+(c<<11)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=Bc(a),f=d+(b<<11)|0,v[e>>2]=f;return a|0}function uq(a,b,c){var d=0,e=0;e=x[a+480192>>1];a:{if(e){if(!_c(b)|c>>>0>e>>>0){break a}c=v[((c<<2)+a|0)+900380>>2];if(!c){break a}d=x[cc(c+236|0,b-1|0)>>1];break a}d=c}return(x[a+480190>>1]<(d&65535)>>>0?0:d)&65535}function gx(a){var b=0;a:{b:{while(1){if(v[a+1380>>2]!=-1){break b}b=0;if(!os(a)){break a}if(!(t[a+1375|0]&1)){continue}break}dc(a,32);return 0}v[a+1396>>2]=0;v[a+1400>>2]=0;v[a+1384>>2]=0;t[a+1376|0]=0;b=1}return b}function WH(a,b){var c=0,d=0,e=0;c=jb-256|0;jb=c;if((b|0)>=2){v[(b<<2)+a>>2]=c;tc(c,v[a>>2],4);while(1){e=(d<<2)+a|0;d=d+1|0;tc(v[e>>2],v[(d<<2)+a>>2],4);v[e>>2]=v[e>>2]+4;if((b|0)!=(d|0)){continue}break}}jb=c+256|0}function wu(a,b,c){var d=0,e=0,f=0;d=jb-16|0;jb=d;if(c>>>0<4294967280){a:{if(El(c)){ce(a,c);break a}e=Mg(c)+1|0;f=sc(e);ud(a,f);bf(a,e);Fd(a,c);a=f}a=ve(a,b,c);t[d+15|0]=0;ie(a+c|0,d+15|0);jb=d+16|0;return}hf();L()}function vz(a,b,c){var d=0;a:{switch(c+1|0){case 0:case 3:bP(a,b);return;default:break a}}d=jb-32|0;jb=d;v[d+28>>2]=c;u[d+24>>1]=0;v[d+12>>2]=2;tw(d+16|0,a,d+24|0,v[Jb(d+28|0,d+12|0)>>2]);Jj(b,x[d+24>>1]);jb=d+32|0}function GO(a,b){var c=0,d=0,e=0,f=0;e=A[a+48>>3];c=A[a+40>>3];A[a+48>>3]=c;f=A[a+64>>3];d=A[a+56>>3];A[a+64>>3]=d;A[a+40>>3]=b;b=e*A[a+16>>3]+(A[a>>3]*b+c*A[a+8>>3])-d*A[a+24>>3]-f*A[a+32>>3];A[a+56>>3]=b;return b}function yP(a){var b=0;b=u[a+784>>1];if(b){v[a+692>>2]=(b&32767)-1;if((b|0)<0){v[a+88>>2]=v[a+88>>2]|256}u[a+784>>1]=0}b=w[a+795|0];if(b){t[a+795|0]=0;t[a+838|0]=b-1}b=w[a+796|0];if(b){t[a+796|0]=0;t[a+837|0]=b-1}}function Y_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=tn(a);e=Gb(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=zc(a);li(d+(e<<2)|0,b,c);b=c+e|0;Qh(a,b);ud(d+(b<<2)|0,0);return a|0}wF(a,d,(c+e|0)-d|0,e,e,0,c,b)}return a|0}function Rp(a,b){a=tc(a,b,88);v[a+88>>2]=v[b+88>>2];tc(a+92|0,b+92|0,576);v[a+668>>2]=v[b+668>>2];tc(a+672|0,b+672|0,52);My(a+724|0,b+724|0);My(a+732|0,b+732|0);My(a+740|0,b+740|0);tc(a+748|0,b+748|0,123);return a}function En(a,b){var c=0,d=0,e=0;c=a*a;d=c*a;e=c*c;a=d*e*(e*(c*.009465647849436732+.002974357433599673)+(c*.024528318116654728+.05338123784456704))+(d*(c*.13339200271297674+.3333313950307914)+a);return C(b?-1/a:a)}function qm(a,b){var c=C(0),d=0,e=0;c=C(1);d=u[a+28>>1];a:{if((d|0)>(b|0)){break a}e=v[a+4>>2];if((uc(e,v[a+8>>2])+d<<16)-65536>>16<(b|0)){break a}c=z[Db(e,b-d|0)>>2];c=c<=C(10000000036274937e-31)?C(1):c}return c}function cia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=jb-16|0;jb=e;c=qf(a,c);me(e,v[a+36>>2]);a:{if(!c){Rc(e,a+32|0,5);f=0;if(Bb(v[v[e>>2]>>2],v[e+4>>2])){break a}}sT(v[a+36>>2],b,d,0);f=c}Xe(a,f);jb=e+16|0}function hT(a,b,c){var d=0,e=0;d=jb-16|0;jb=d;v[d>>2]=v[a+8>>2];e=v[a+8>>2];v[d+8>>2]=a+8;v[d+4>>2]=B(b,6)+e;b=v[d>>2];while(1){if(v[d+4>>2]!=(b|0)){hu(b,c);b=v[d>>2]+6|0;v[d>>2]=b;continue}break}Td(d);jb=d+16|0}function Sba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=Sb(a);d=Xf(a+12|0);t[a+32|0]=c;v[a+28>>2]=0;v[a+24>>2]=b;v[23588]=0;R(765,a|0,1);b=v[23588];v[23588]=0;if((b|0)!=1){return a|0}b=P()|0;O()|0;AO(d);EO(a);T(b|0);L()}function nP(a,b,c,d){var e=0;e=jb-16|0;jb=e;a=_h(e,a,d);d=jb-16|0;jb=d;v[d+8>>2]=b;while(1){if(Ob(b,c)){Mi(v[a+4>>2],x[b>>1]);b=Re(d+8|0);v[a+4>>2]=v[a+4>>2]+2;b=v[b>>2];continue}break}jb=d+16|0;kc(a);jb=e+16|0}function jB(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;oU(c+8|0,b);d=v[c+12>>2];mc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){Zb(a,v[c+12>>2])}jb=c+16|0;a=(d|0)==(e|0);if(!a){pU(b)}return a}function bN(a,b){v[a+24>>2]=0;v[a+28>>2]=0;v[a+40>>2]=0;v[a+32>>2]=0;v[a+36>>2]=0;v[a+20>>2]=v[b>>2]-1900;v[a+16>>2]=v[b+4>>2]-1;v[a+12>>2]=v[b+8>>2];v[a+8>>2]=v[b+12>>2];v[a+4>>2]=v[b+16>>2];v[a>>2]=v[b+24>>2]}function TC(a,b){var c=0,d=0;c=jb-16|0;jb=c;a:{if(b>>>0<2){b:{if(!b){break b}if(!Pb(v[a>>2],v[a+8>>2],1)){break b}t[c+15|0]=0;zg(a,c+15|0);d=t[c+15|0]}jb=c+16|0;a=d;break a}aa(11143,9039,136,14156);L()}return a}function Haa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-32|0;jb=c;a:{if(Uh(a)>>>0<b>>>0){if(sh(1073741823)>>>0<b>>>0){break a}d=Fb(a);e=a;a=Uf(c+8|0,b,uc(v[a>>2],v[a+4>>2]),d);Dd(e,a);Tf(a)}jb=c+32|0;return}bd();L()}function GS(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;IS(c+8|0,b);d=v[c+12>>2];mc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){Zb(a,v[c+12>>2])}jb=c+16|0;a=(d|0)==(e|0);if(!a){HS(b)}return a}function Ck(a){wc(a+16|0,v[a>>2]);wc(a+8|0,v[a>>2]);if(y[a+12>>2]>=y[a+16>>2]){v[a+12>>2]=0;v[a+16>>2]=0;u[a+34>>1]=x[a+34>>1]&65511}if(y[a+4>>2]>=y[a+8>>2]){v[a+4>>2]=0;v[a+8>>2]=0;u[a+34>>1]=x[a+34>>1]&65529}}function py(a,b){var c=0,d=0;c=v[b+4>>2];v[a+24648>>2]=v[b>>2];v[a+24652>>2]=c;d=v[b+20>>2];c=a+24664|0;v[c>>2]=v[b+16>>2];v[c+4>>2]=d;d=v[b+12>>2];c=a+24656|0;v[c>>2]=v[b+8>>2];v[c+4>>2]=d;tM(a+24648|0);zM(a)}function mH(a,b){a=a|0;b=b|0;var c=0,d=0;c=v[a>>2];a:{if(!c){break a}d=v[c+24>>2];b:{if((d|0)==v[c+28>>2]){b=nb[v[v[c>>2]+52>>2]](c,b)|0;break b}v[c+24>>2]=d+4;v[d>>2]=b}if(!Cn(b)){break a}v[a>>2]=0}return a|0}function ffa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-32|0;jb=c;a:{if(Vj(a)>>>0<b>>>0){if(sh(357913941)>>>0<b>>>0){break a}d=Fb(a);e=a;a=Hk(c+8|0,b,xd(v[a>>2],v[a+4>>2]),d);HQ(e,a);GQ(a)}jb=c+32|0;return}bd();L()}function Uba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;v[a>>2]=0;v[a+4>>2]=0;Gc(a+8|0);c=Ug(v[b>>2],v[b+4>>2]);if(c){mz(a,c);d=jb-16|0;jb=d;e=v[b>>2];f=v[b+4>>2];b=kr(d,a,c);iu(e,f,b+4|0);kc(b);jb=d+16|0}return a|0}function S9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=jb-16|0;jb=e;c=qf(a,c);me(e,v[a+36>>2]);a:{if(!c){Rc(e,a+32|0,5);f=0;if(Bb(v[v[e>>2]>>2],v[e+4>>2])){break a}}FL(d,v[a+36>>2],b);f=c}Xe(a,f);jb=e+16|0}function Rba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-32|0;jb=c;a:{if(gn(a)>>>0<b>>>0){if(sh(536870911)>>>0<b>>>0){break a}d=Fb(a);e=a;a=mr(c+8|0,b,Ug(v[a>>2],v[a+4>>2]),d);Dd(e,a);lr(a)}jb=c+32|0;return}bd();L()}function Jaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-32|0;jb=c;a:{if(Vj(a)>>>0<b>>>0){if(sh(357913941)>>>0<b>>>0){break a}d=Fb(a);e=a;a=Hk(c+8|0,b,xd(v[a>>2],v[a+4>>2]),d);yr(e,a);fO(a)}jb=c+32|0;return}bd();L()}function Iba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-32|0;jb=c;a:{if(ez(a)>>>0<b>>>0){if(sh(613566756)>>>0<b>>>0){break a}d=Fb(a);e=a;a=lO(c+8|0,b,dz(v[a>>2],v[a+4>>2]),d);kO(e,a);jO(a)}jb=c+32|0;return}bd();L()}function CS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-32|0;jb=c;a:{if(Xm(a)>>>0<b>>>0){if(sh(2147483647)>>>0<b>>>0){break a}d=Fb(a);e=a;a=Mj(c+8|0,b,Qc(v[a>>2],v[a+4>>2]),d);Dd(e,a);Ni(a)}jb=c+32|0;return}bd();L()}function Aaa(a,b){a=a|0;b=b|0;var c=0;b=jb-16|0;jb=b;c=-1;a:{if(!Qj(a,b+8|0)){break a}c=0;if(!cM(v[b+8>>2],v[b+12>>2])){break a}a=XQ(a,b);if(!a){Nm(b)}c=-1;if(!a){break a}c=bM(v[b>>2])}a=c;jb=b+16|0;return a|0}function yr(a,b){var c=0,d=0,e=0;e=v[a>>2];c=v[a+4>>2];d=b+4|0;while(1){if((c|0)!=(e|0)){c=c-12|0;$o(v[d>>2]-12|0,c);v[d>>2]=v[d>>2]-12;continue}break}pc(a,d);pc(a+4|0,b+8|0);pc(Fb(a),Bc(b));v[b>>2]=v[b+4>>2]}function wD(a,b){var c=0,d=0,e=0;e=v[a>>2];c=v[a+4>>2];d=b+4|0;while(1){if((c|0)!=(e|0)){c=c-36|0;zv(v[d>>2]-36|0,c);v[d>>2]=v[d>>2]-36;continue}break}pc(a,d);pc(a+4|0,b+8|0);pc(Fb(a),Bc(b));v[b>>2]=v[b+4>>2]}function mw(a,b,c){var d=0;d=v[a+16>>2];if(!d){v[a+36>>2]=1;v[a+24>>2]=c;v[a+16>>2]=b;return}a:{if((b|0)==(d|0)){if(v[a+24>>2]!=2){break a}v[a+24>>2]=c;return}t[a+54|0]=1;v[a+24>>2]=2;v[a+36>>2]=v[a+36>>2]+1}}function kB(a,b){var c=0,d=0,e=0;e=v[a>>2];c=v[a+4>>2];d=b+4|0;while(1){if((c|0)!=(e|0)){c=c-20|0;nB(v[d>>2]-20|0,c);v[d>>2]=v[d>>2]-20;continue}break}pc(a,d);pc(a+4|0,b+8|0);pc(Fb(a),Bc(b));v[b>>2]=v[b+4>>2]}function hn(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;a:{if(c){Mc(d,c);break a}Lb(d)}v[23588]=0;U(11,a|0,b|0,d|0);a=v[23588];v[23588]=0;if((a|0)!=1){yb(d);jb=d+16|0;return}a=P()|0;O()|0;yb(d);T(a|0);L()}function cP(a,b){var c=0,d=0,e=0;e=v[a>>2];c=v[a+4>>2];d=b+4|0;while(1){if((c|0)!=(e|0)){c=c-32|0;xz(v[d>>2]-32|0,c);v[d>>2]=v[d>>2]-32;continue}break}pc(a,d);pc(a+4|0,b+8|0);pc(Fb(a),Bc(b));v[b>>2]=v[b+4>>2]}function c9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;a=kj(a);if(a){d=v[b+4>>2];b=v[b>>2];v[c+8>>2]=b;v[c+12>>2]=d;e=v[v[a>>2]+72>>2];v[c>>2]=b;v[c+4>>2]=d;a=nb[e|0](a,c)|0}else{a=1}jb=c+16|0;return a|0}function sQ(a){a=a*4294967296;if(D(a)<0x8000000000000000){mb=D(a)>=1?~~(a>0?F(H(a*2.3283064365386963e-10),4294967295):I((a-+(~~a>>>0>>>0))*2.3283064365386963e-10))>>>0:0;return~~a>>>0}mb=-2147483648;return 0}function ry(a,b){var c=0;c=v[b+24>>2];v[a+24628>>2]=c?c>>>0<512?c:512:1;a:{if(!(v[b+16>>2]!=v[a+24620>>2]|v[b+20>>2]!=v[a+24624>>2])){c=0;if(v[b+12>>2]==v[a+24616>>2]){break a}}c=1}tc(a+24604|0,b,40);uM(a,c)}function gA(a,b){var c=0,d=0,e=0,f=0;d=b?224:240;e=LD(a);a:while(1){if((a|0)!=(e|0)){f=vd(a);b=a;while(1)if((b|0)==(f|0)){a=a+16|0;continue a}else{c=((w[Kb(b,0)|0]&d)!=0)+c|0;b=b+4|0;continue}}break}return c}function MW(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-48|0;jb=c;d=-1;a:{if(!lD(a,c+8|0)){break a}d=0;if(!kD(c+8|0)){break a}if(b){a=v[b>>2];if(!v[b+4>>2]&a>>>0<bc(v[c+12>>2])-8>>>0){break a}}d=1}jb=c+48|0;return d|0}function $aa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;b=(b-a|0)/160|0;while(1){if((b|0)>0){b=b-1|0;v[a>>2]=v[c>>2];d=a+4|0;if((d|0)!=(c+4|0)){ty(d,v[c+4>>2],v[c+8>>2])}tc(a+16|0,c+16|0,144);a=a+160|0;continue}break}}function kN(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;c=v[b+28>>2];v[a+24>>2]=v[b+24>>2];v[a+28>>2]=c;c=v[b+20>>2];v[a+16>>2]=v[b+16>>2];v[a+20>>2]=c;c=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=c}function Su(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+16|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function Bd(a,b){var c=0,d=0;c=jb-16|0;jb=c;a:{if(b>>>0<2){b:{if(!b){break b}if(!Pb(v[a>>2],v[a+8>>2],1)){break b}t[c+15|0]=0;zg(a,c+15|0);d=w[c+15|0]}jb=c+16|0;break a}aa(11143,9039,136,14156);L()}return d}function $s(a){var b=0;v[23588]=0;a=S(812,a|0)|0;b=v[23588];v[23588]=0;a:{if((b|0)==1){a=V(0)|0;O()|0;_(a|0)|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;a=0;if((b|0)==1){break a}}return a}V(0)|0;O()|0;Ub();L()}function w1(a,b){a=a|0;b=b|0;var c=0;a=Hs(a);v[a>>2]=77440;c=Lb(a+32|0);v[a+44>>2]=0;v[a+48>>2]=8;v[23588]=0;R(92,a|0,b|0);b=v[23588];v[23588]=0;if((b|0)!=1){return a|0}b=P()|0;O()|0;yb(c);Kn(a);T(b|0);L()}function ei(a,b,c){var d=0,e=0,f=0;d=jb-16|0;jb=d;fc(d+8|0,b,c);e=v[d+12>>2];mc(d,v[a>>2],v[a+8>>2],v[d+8>>2],v[d+12>>2]);f=v[d+4>>2];if((f|0)==(e|0)){Zb(a,v[d+12>>2])}jb=d+16|0;if((e|0)!=(f|0)){Tb(b,0,c)}}function mka(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{if(!Pb(v[a>>2],v[a+8>>2],64)){a=0;while(1){if((a|0)!=64){Ch(a+b|0);a=a+1|0;continue}break}break a}Gu(c+8|0,b);td(c,a,v[c+8>>2],v[c+12>>2])}jb=c+16|0}function mea(a){a=a|0;var b=0;b=jb-16|0;jb=b;a:{if(xq(a,10215)){NJ(b,17538,a);a=Lc(b);v[23588]=0;R(41,44,a|0);a=v[23588];v[23588]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(b);T(a|0);L()}jb=b+16|0;return}L()}function _k(a){a=a|0;var b=0;v[a>>2]=78636;v[23588]=0;R(70,a|0,0);b=v[23588];v[23588]=0;if((b|0)!=1){$b(a+28|0);Mb(v[a+32>>2]);Mb(v[a+36>>2]);Mb(v[a+48>>2]);Mb(v[a+60>>2]);return a|0}V(0)|0;O()|0;Ub();L()}function _O(a){var b=0,c=0,d=0;b=x[a+20>>1];u[a+28>>1]=x[a+22>>1]<<1|(w[v[a+16>>2]+3842|0]?b>>>9|0:b>>>8&1);b=0;while(1){if((b|0)!=4){c=(b<<2)+a|0;d=v[c>>2];if(d){co(d);ZO(v[c>>2])}b=b+1|0;continue}break}}function Xba(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{if(!Pb(v[a>>2],v[a+8>>2],27)){a=0;while(1){if((a|0)!=27){Ch(a+b|0);a=a+1|0;continue}break}break a}QO(c+8|0,b);td(c,a,v[c+8>>2],v[c+12>>2])}jb=c+16|0}function N3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;WJ(d,c);a=v[a+1298464>>2];v[23588]=0;U(376,a|0,b|0,d|0);a=v[23588];v[23588]=0;if((a|0)!=1){zb(d);jb=d+16|0;return}a=P()|0;O()|0;zb(d);T(a|0);L()}function $ea(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;Am(a,b);b=Eb(v[a>>2]);v[c+8>>2]=b;a=Eb(v[a+4>>2]);while(1){if(Ob(b,a)){d=w[b|0]+(d&255)|0;t[b|0]=d;b=v[Ge(c+8|0)>>2];continue}else{jb=c+16|0}break}}function NR(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{if(!Pb(v[a>>2],v[a+8>>2],32)){a=0;while(1){if((a|0)!=32){Ch(a+b|0);a=a+1|0;continue}break}break a}KR(c+8|0,b);td(c,a,v[c+8>>2],v[c+12>>2])}jb=c+16|0}function Gf(a,b,c,d,e){var f=0;f=jb-256|0;jb=f;if(!(e&73728|(c|0)<=(d|0))){d=c-d|0;c=d>>>0<256;Tb(f,b&255,c?d:256);if(!c){while(1){sf(a,f,256);d=d-256|0;if(d>>>0>255){continue}break}}sf(a,f,d)}jb=f+256|0}function xea(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;if((b|0)>=0){d=2147483647;a=Ct(a);if(a>>>0<=1073741822){v[c+12>>2]=a<<1;v[c+8>>2]=b+31&-32;d=v[Yc(c+12|0,c+8|0)>>2]}jb=c+16|0;return d|0}bd();L()}function jU(a){var b=0;a:{if(Rb(a,3873,4)|w[a+68|0]!=13|(w[a+69|0]!=10|w[a+70|0]!=26)){break a}if(Rb(a+71|0,13650,4)|w[a+75|0]!=1|w[a+76|0]){break a}b=((w[a+116|0]|w[a+117|0]<<8)-1&65535)>>>0<9}return b}function fe(a,b){var c=0,d=0,e=0;b=b+7&-8;v[a+8>>2]=b+v[a+8>>2];d=v[a+80>>2];a:{if(d){c=b;b=v[a+88>>2];e=c+b|0;c=0;if((e|0)>v[a+92>>2]){break a}v[a+88>>2]=e;return b+d|0}if(!b){return 0}c=Od(b)}return c}function daa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;c=qf(a,c);me(d,v[a+36>>2]);a:{if(!c){Rc(d,a+32|0,5);e=0;if(Bb(v[v[d>>2]>>2],v[d+4>>2])){break a}}vT(v[a+36>>2],b,a);e=c}Xe(a,e);jb=d+16|0}function MS(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;oB(c+8|0,b);b=v[c+12>>2];mc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);d=v[c+4>>2];if((b|0)==(d|0)){Zb(a,v[c+12>>2])}jb=c+16|0;return(b|0)==(d|0)|0}function Hh(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;an(c+8|0,b);b=v[c+12>>2];mc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);d=v[c+4>>2];if((b|0)==(d|0)){Zb(a,v[c+12>>2])}jb=c+16|0;return(b|0)==(d|0)|0}function A7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=jb-16|0;jb=f;b=Hc(Mka(Lka(d,d>>31,b,0),mb,1e3,0),mb);v[a+16>>2]=0;v[a+12>>2]=b+c;KK(a,e);b=v[a+12>>2];v[f+12>>2]=0;IL(a,b,f+12|0);jb=f+16|0}function $6(a,b){a=a|0;b=b|0;var c=0,d=0;a:{c=v[b+52>>2];if(c&16){d=v[b+48>>2];c=v[b+28>>2];if(d>>>0<c>>>0){v[b+48>>2]=c;d=c}Th(a,v[b+24>>2],d);break a}if(c&8){Th(a,v[b+12>>2],v[b+20>>2]);break a}Lb(a)}}function yV(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{if(!Pb(v[a>>2],v[a+8>>2],8)){a=0;while(1){if((a|0)!=8){Ch(a+b|0);a=a+1|0;continue}break}break a}an(c+8|0,b);td(c,a,v[c+8>>2],v[c+12>>2])}jb=c+16|0}function qn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-32|0;jb=c;a:{if(jp(a)>>>0<b>>>0){if(sh(-1)>>>0<b>>>0){break a}d=Fb(a);e=a;a=Yl(c+8|0,b,ed(v[a>>2],v[a+4>>2]),d);Dd(e,a);Xl(a)}jb=c+32|0;return}bd();L()}function fG(a,b,c,d,e,f){var g=0,h=0,i=0;g=jb-16|0;jb=g;t[g+15|0]=0;t[g+14|0]=f;t[g+13|0]=e;t[g+12|0]=37;if(f){Ii(g+13|0,g+14|0)}h=c,i=(cb(b|0,ed(b,v[c>>2])|0,g+12|0,d|0,a|0)|0)+b|0,v[h>>2]=i;jb=g+16|0}function ch(a){var b=0,c=0,d=0,e=0;b=jb-16|0;jb=b;c=2;if(a>>>0>=2){v[b+12>>2]=a>>>1;v[b+8>>2]=a^-1;d=b,e=v[Jb(b+12|0,b+8|0)>>2]+a|0,v[d+12>>2]=e;v[b+8>>2]=-1;c=v[Jb(b+12|0,b+8|0)>>2]}jb=b+16|0;return c}function _ga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[a>>2]=0;v[a+4>>2]=0;Gc(a+8|0);if(b){if(sh(1073741823)>>>0<b>>>0){bd();L()}c=XC(b);v[a>>2]=c;v[a+4>>2]=c;d=Fb(a),e=(b<<2)+c|0,v[d>>2]=e;DA(a,b)}return a|0}function pW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[a>>2]=0;v[a+4>>2]=0;Gc(a+8|0);if(b){if(sh(214748364)>>>0<b>>>0){bd();L()}c=tC(b);v[a>>2]=c;v[a+4>>2]=c;d=Fb(a),e=B(b,20)+c|0,v[d>>2]=e;wC(a,b)}return a|0}function eY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;f=v[v[b>>2]+20>>2];e=v[c+12>>2];v[d+8>>2]=v[c+8>>2];v[d+12>>2]=e;e=v[c+4>>2];v[d>>2]=v[c>>2];v[d+4>>2]=e;nb[f|0](a,b,d,8);jb=d+16|0}function dh(a,b){var c=0,d=0,e=0;c=Gb(a);a:{if((c|0)!=(Gb(b)|0)){break a}d=Lc(a);b=Lc(b);if(!ef(a)){while(1){e=!c;if(!c|w[d|0]!=w[b|0]){break a}b=b+1|0;d=d+1|0;c=c-1|0;continue}}e=!Lp(d,b,c)}return e}function OR(a,b){a=a|0;b=b|0;var c=0,d=0;d=v[a>>2];c=65535;a:{if(!xe(d,v[a+4>>2],b)){break a}d=AB(a,v[ag(d,b)+12>>2]);c=65535;if((d|0)==65535){break a}c=v[a>>2];a=ag(c,b);VL(ag(c,d),a);c=d}return c|0}function xK(a){var b=0,c=0,d=C(0);if(!a){return C(1)}if((a|0)>=-99999){b=+(a|0)*3.321928094887362/2e3;c=b+.5;a:{if(D(c)<2147483648){a=~~c;break a}a=-2147483648}d=C(mi(b-+(a|0)))}else{d=C(0)}return d}function dR(a){var b=0,c=0,d=0;d=w[a+32|0]|w[a+33|0]<<8;b=w[a+34|0]|w[a+35|0]<<8;a=b+(w[a+36|0]|w[a+37|0]<<8)|0;c=a>>>0<b>>>0?1:c;b=a;a=c<<1|a>>>31;b=b<<1;c=d+b|0;a=c>>>0<b>>>0?a+1|0:a;mb=a;return c}function UX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;v[e+12>>2]=d;d=yd(v[b+4>>2],w[b+11|0]);if(d>>>0<c>>>0){rk();L()}b=od(b);v[e+8>>2]=d-c;OD(a,b+c|0,v[Jb(e+12|0,e+8|0)>>2]);jb=e+16|0}function RP(a){var b=0,c=0,d=0;d=w[a+64|0]|w[a+65|0]<<8;b=w[a+70|0]|w[a+71|0]<<8;a=b+(w[a+72|0]|w[a+73|0]<<8)|0;c=a>>>0<b>>>0?1:c;b=a;a=c<<2|a>>>30;b=b<<2;c=d+b|0;a=c>>>0<b>>>0?a+1|0:a;mb=a;return c}function QB(a,b){var c=0;c=jb-16|0;jb=c;a:{if(!Pb(v[a>>2],v[a+8>>2],512)){a=0;while(1){if((a|0)!=128){Nm((a<<2)+b|0);a=a+1|0;continue}break}break a}Lu(c+8|0,b);td(c,a,v[c+8>>2],v[c+12>>2])}jb=c+16|0}function M8(a){a=a|0;var b=0,c=0,d=0;b=jb-32|0;jb=b;a:{if(Uh(a)>>>0<=12){if(sh(1073741823)>>>0<=12){break a}c=Fb(a);d=a;a=Uf(b+8|0,13,uc(v[a>>2],v[a+4>>2]),c);Dd(d,a);Tf(a)}jb=b+32|0;return}bd();L()}function ev(a,b){var c=0;c=jb-16|0;jb=c;a:{if(!Pb(v[a>>2],v[a+8>>2],256)){a=0;while(1){if((a|0)!=256){Ch(a+b|0);a=a+1|0;continue}break}break a}fc(c+8|0,b,256);td(c,a,v[c+8>>2],v[c+12>>2])}jb=c+16|0}function $R(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;fS(c+8|0,b);d=v[c+12>>2];mc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){Zb(a,v[c+12>>2])}jb=c+16|0;if((d|0)!=(e|0)){gS(b)}}function nU(a){var b=0,c=0,d=0;a:{if(Rb(a,21608,11)){break a}c=a+215|0;a=a+63|0;while(1){b=(a|0)==(c|0);if(b|w[a+16|0]>3|w[a+17|0]>3){break a}d=a;a=a+19|0;if(w[d+18|0]<16){continue}break}}return b}function UJ(){var a=0,b=0,c=0,d=0;a=jb-16|0;jb=a;b=sc(1298472);v[23588]=0;c=S(1062,b|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){b=v[Lf(a+8|0,c)>>2];jb=a+16|0;return b|0}a=P()|0;O()|0;Mb(b);T(a|0);L()}function Rd(a,b){var c=0,d=0,e=0;d=x[a+24>>1];if((d|0)!=(b&65535)){c=x[a+22>>1]-1&127;u[a+22>>1]=c;e=x[a+20>>1];if(e>>>0<=127){u[a+20>>1]=e+1}c=(c<<2)+a|0;u[c+26>>1]=b-d;u[c+28>>1]=0;u[a+24>>1]=b}}function HO(a,b,c,d,e,f){v[a+40>>2]=0;v[a+44>>2]=0;A[a+32>>3]=f;A[a+24>>3]=e;A[a+16>>3]=d;A[a+8>>3]=c;A[a>>3]=b;v[a+48>>2]=0;v[a+52>>2]=0;v[a+56>>2]=0;v[a+60>>2]=0;a=a- -64|0;v[a>>2]=0;v[a+4>>2]=0}function hj(a){var b=0;b=32767;a:{if(a>=C(32766.5)){break a}b=32768;if(a<=C(-32767.5)){break a}a=C(a+C(.5));b:{if(C(D(a))<C(2147483648)){b=~~a;break b}b=-2147483648}b=b+(b>>15)|0}return b<<16>>16}function Dr(a,b,c,d){var e=0,f=0,g=0;e=b+4|0;g=c;f=v[a>>2];c=v[a+4>>2]-f|0;d=v[e>>2]+B(g,(c|0)/(d|0)|0)|0;v[e>>2]=d;if((c|0)>0){tc(d,f,c)}pc(a,e);pc(a+4|0,b+8|0);pc(Fb(a),Bc(b));v[b>>2]=v[b+4>>2]}function zR(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;vR(c+8|0,b);d=v[c+12>>2];ld(c,a,v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){hd(a,v[c+12>>2])}jb=c+16|0;a=(d|0)==(e|0);if(!a){wR(b)}return a}function vB(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;Cq(c+8|0,b);d=v[c+12>>2];ld(c,a,v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){hd(a,v[c+12>>2])}jb=c+16|0;a=(d|0)==(e|0);if(!a){KU(b)}return a}function lD(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;er(c+8|0,b);d=v[c+12>>2];ld(c,a,v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){hd(a,v[c+12>>2])}jb=c+16|0;a=(d|0)==(e|0);if(!a){fr(b)}return a}function iS(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;fS(c+8|0,b);d=v[c+12>>2];ld(c,a,v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){hd(a,v[c+12>>2])}jb=c+16|0;a=(d|0)==(e|0);if(!a){gS(b)}return a}function gG(a,b,c,d){var e=0,f=0;e=jb-16|0;jb=e;cG(e+8|0,b);f=c;Uk(v[e+12>>2],c,d);b=jb-16|0;jb=b;v[b+12>>2]=v[v[e+12>>2]+4>>2];v[b+8>>2]=0;c=v[Oe(b+8|0,b+12|0)>>2];jb=b+16|0;fc(a,f,c);jb=e+16|0}function fV(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;Fu(c+8|0,b);d=v[c+12>>2];ld(c,a,v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){hd(a,v[c+12>>2])}jb=c+16|0;a=(d|0)==(e|0);if(!a){EB(b)}return a}function YD(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;WD(c+8|0,b);d=v[c+12>>2];ld(c,a,v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){hd(a,v[c+12>>2])}jb=c+16|0;a=(d|0)==(e|0);if(!a){Nv(b)}return a}function Y3(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;WJ(c,b);a=v[a+1298464>>2];v[23588]=0;U(376,a|0,1,c|0);a=v[23588];v[23588]=0;if((a|0)!=1){zb(c);jb=c+16|0;return}a=P()|0;O()|0;zb(c);T(a|0);L()}function UQ(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;oU(c+8|0,b);d=v[c+12>>2];ld(c,a,v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){hd(a,v[c+12>>2])}jb=c+16|0;a=(d|0)==(e|0);if(!a){pU(b)}return a}function Qj(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;an(c+8|0,b);d=v[c+12>>2];ld(c,a,v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){hd(a,v[c+12>>2])}jb=c+16|0;a=(d|0)==(e|0);if(!a){Sj(b)}return a}function OH(a){var b=0,c=0,d=0;d=v[a>>2];while(1){c=t[d|0];if($j(c)){d=d+1|0;v[a>>2]=d;if(b>>>0<=214748364){c=c-48|0;b=B(b,10);b=(c|0)>(2147483647-b|0)?-1:c+b|0}else{b=-1}continue}break}return b}function Du(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function CM(a){var b=0,c=0;a=a+906300|0;c=ek(a);while(1){if((a|0)!=(c|0)){b=v[a>>2];a:{if(!b){break a}if(!(nb[v[v[b>>2]+120>>2]](b)|0)){break a}nb[v[v[b>>2]+100>>2]](b)}a=a+160|0;continue}break}}function xB(a,b){var c=0;c=jb-16|0;jb=c;v[c+12>>2]=1;v[c+8>>2]=a>>>4;b=Xb(128/(B(v[Oe(c+12|0,c+8|0)>>2],b)|0)|0,1,15);t[c+7|0]=1;t[c+6|0]=a&15;a=w[jf(c+7|0,c+6|0)|0];jb=c+16|0;return a|b<<4&240}function iP(a){a=a|0;var b=0,c=0;b=jb-32|0;jb=b;t[a+16|0]=0;c=Bz(b,v[a+12>>2]);v[23588]=0;R(753,a|0,c|0);a=v[23588];v[23588]=0;if((a|0)!=1){ql(c);jb=b+32|0;return}a=P()|0;O()|0;ql(c);T(a|0);L()}function Ou(a,b,c){var d=0;a=(a&65535)>>>B(c,3)|0;d=a>>>2&1|w[b+12|0]&-8;t[b+12|0]=d|a<<1&6;if(!(!(a>>>9-(c<<1)&1)|(a&3)!=1)){a=w[b+13|0]|w[b+14|0]<<8;t[b+15|0]=a;t[b+16|0]=a>>>8;t[b+12|0]=d|4}}function xR(a){var b=0,c=0,d=0,e=0;mb=0;d=w[a+4|0];e=w[a+92|0];c=w[a+94|0]|w[a+95|0]<<8;b=c+w[a+93|0]|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=e+b|0;a=b>>>0<c>>>0?a+1|0:a;c=b<<2;b=d+c|0;b=b-96|0;return b}function wK(a,b){var c=0,d=0,e=0,f=0;if(a>C(.9999989867210388)){d=0}else{a=C(a*a);c=+a;e=32768/(1-c);f=c;c=$e(31415.926535897932/+b);d=yl(e*(1-(f*c+K(+C(a+a)*(1-c)-+C(a*a)*(1-c*c)))))}return d}function vT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;Vf(a,d+14|0);e=x[d+14>>1];IM(b,e);c=0;while(1){if((c|0)==(e|0)){uy(b);jb=d+16|0}else{ok(a,Db(v[b>>2],c));c=c+1|0;continue}break}}function rI(a,b){var c=0,d=0,e=0,f=C(0),g=C(0),h=0;b=(b|0)>0?b:0;h=a+2304|0;while(1){if((b|0)!=(d|0)){c=d<<2;e=c+a|0;f=z[e>>2];c=c+h|0;g=z[c>>2];z[e>>2]=f+g;z[c>>2]=f-g;d=d+1|0;continue}break}}function QT(a,b,c){var d=0,e=0;d=jb-16|0;jb=d;a=Ah(d,a,b);b=v[a+4>>2];e=v[a+8>>2];while(1){if((b|0)==(e|0)){kc(a);jb=d+16|0}else{Hm(b,x[c>>1]|x[c+2>>1]<<16);b=b+4|0;v[a+4>>2]=b;continue}break}}function Dh(a,b){var c=0;c=v[a>>2];a=Vd(b);b=v[c+8>>2];if(uc(b,v[c+12>>2])>>>0>a>>>0){c=v[Db(b,a)>>2]!=0}else{c=0}if(!c){a=km(ba(4)|0);v[a>>2]=93404;ha(a|0,93540,1107);L()}return v[Db(b,a)>>2]}function wg(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb+-64|0;jb=c;d=_x(c+8|0,a);v[23588]=0;U(201,a|0,b|0,d|0);a=v[23588];v[23588]=0;if((a|0)!=1){gl(d);jb=c- -64|0;return}a=P()|0;O()|0;gl(d);T(a|0);L()}function sy(a,b){var c=0;a=zQ(a,b);t[a+12|0]=w[b+12|0];c=w[b+13|0]|w[b+14|0]<<8|(w[b+15|0]<<16|w[b+16|0]<<24);t[a+13|0]=c;t[a+14|0]=c>>>8;t[a+15|0]=c>>>16;t[a+16|0]=c>>>24;t[a+17|0]=w[b+17|0]}function bp(a,b,c,d,e,f){var g=0,h=0;og(a+12|0,d);if(b){if(b>>>0>=f>>>0){Lg();L()}d=sc(B(b,e))}else{d=0}v[a>>2]=d;c=d+B(c,e)|0;v[a+8>>2]=c;v[a+4>>2]=c;g=Bc(a),h=d+B(b,e)|0,v[g>>2]=h;return a}
function yF(a){a=a|0;var b=0,c=0,d=0;v[a>>2]=83224;d=a+8|0;while(1){b=v[a+8>>2];if(uc(b,v[a+12>>2])>>>0>c>>>0){b=v[Db(b,c)>>2];if(b){fn(b)}c=c+1|0;continue}break}yb(a+152|0);TF(d);return a|0}function qj(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;a:{d=ol(a,b);if((d|0)==255){break a}hk(a,b);_p(a,b,0,0);if(!c){break a}e=cc(a+26|0,d),f=65535,u[e>>1]=f;a=Kb(a+62|0,b);t[a|0]=w[a|0]|128}}function pg(a,b){var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=b;d=b;b=sh(1073741823);if(d>>>0<=b>>>0){a=Uh(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Yc(c+8|0,c+12|0)>>2]}jb=c+16|0;return b}bd();L()}function Nj(a,b){var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=b;d=b;b=sh(2147483647);if(d>>>0<=b>>>0){a=Xm(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Yc(c+8|0,c+12|0)>>2]}jb=c+16|0;return b}bd();L()}function yD(a,b){var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=b;d=b;b=sh(119304647);if(d>>>0<=b>>>0){a=Av(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Yc(c+8|0,c+12|0)>>2]}jb=c+16|0;return b}bd();L()}function pE(a,b){var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=b;d=b;b=sh(178956970);if(d>>>0<=b>>>0){a=Ar(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Yc(c+8|0,c+12|0)>>2]}jb=c+16|0;return b}bd();L()}function nr(a,b){var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=b;d=b;b=sh(536870911);if(d>>>0<=b>>>0){a=gn(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Yc(c+8|0,c+12|0)>>2]}jb=c+16|0;return b}bd();L()}function mB(a,b){var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=b;d=b;b=sh(214748364);if(d>>>0<=b>>>0){a=vC(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Yc(c+8|0,c+12|0)>>2]}jb=c+16|0;return b}bd();L()}function lA(a,b,c,d){var e=0,f=0,g=0;e=jb-16|0;jb=e;f=v[b+12>>2];v[e+8>>2]=c;v[e+12>>2]=d;g=v[v[b>>2]+28>>2];v[e>>2]=c;v[e+4>>2]=d;nb[g|0](a,b,f,e);v[b+12>>2]=v[b+12>>2]+v[a+4>>2];jb=e+16|0}function jn(a,b){var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=b;d=b;b=sh(357913941);if(d>>>0<=b>>>0){a=Vj(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Yc(c+8|0,c+12|0)>>2]}jb=c+16|0;return b}bd();L()}function gQ(a,b){var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=b;d=b;b=sh(268435455);if(d>>>0<=b>>>0){a=Mt(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Yc(c+8|0,c+12|0)>>2]}jb=c+16|0;return b}bd();L()}function cq(a,b){var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=b;d=b;b=sh(134217727);if(d>>>0<=b>>>0){a=ko(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Yc(c+8|0,c+12|0)>>2]}jb=c+16|0;return b}bd();L()}function aB(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;d=c,e=(zp(b)+-4.8737671609324025)*(a&32768?28.85390081777927:34.624680981335125),A[d+8>>3]=e;eO(c+8|0,127);a=sk(A[c+8>>3]);jb=c+16|0;return a}function Raa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;e=x[a+28>>1];u[d+8>>1]=e;f=d,g=(uc(v[a+4>>2],v[a+8>>2])+e|0)-1|0,u[f+10>>1]=g;a=LL(a,b,c,d+8|0);jb=d+16|0;return a|0}function IA(a,b){var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=b;d=b;b=sh(715827882);if(d>>>0<=b>>>0){a=Cu(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Yc(c+8|0,c+12|0)>>2]}jb=c+16|0;return b}bd();L()}function Gn(a){var b=0,c=0;b=jb-16|0;jb=b;a:{if(!IJ(w[a+20|0])){v[23588]=0;R(1067,b+8|0,a|0);c=v[23588];v[23588]=0;if((c|0)==1){break a}}t[a+20|0]=255;jb=b+16|0;return}V(0)|0;O()|0;Ub();L()}function zg(a,b){var c=0,d=0;c=jb-16|0;jb=c;Xq(c+8|0,b);b=v[c+12>>2];mc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);d=v[c+4>>2];if((b|0)==(d|0)){Zb(a,v[c+12>>2])}jb=c+16|0;return(b|0)==(d|0)}function uD(a,b){var c=0,d=0;c=jb-16|0;jb=c;WD(c+8|0,b);b=v[c+12>>2];mc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);d=v[c+4>>2];if((b|0)==(d|0)){Zb(a,v[c+12>>2])}jb=c+16|0;return(b|0)==(d|0)}function qh(a,b,c){a:{if(b>>>0<=c>>>0){a=ba(8)|0;v[23588]=0;b=S(193,a|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break a}b=P()|0;O()|0;ca(a|0);T(b|0);L()}return w[a+c|0]}ha(b|0,26056,168);L()}function oC(a){var b=0;b=v[a+72>>2];v[a+72>>2]=b-1|b;b=v[a>>2];if(b&8){v[a>>2]=b|32;return-1}v[a+4>>2]=0;v[a+8>>2]=0;b=v[a+44>>2];v[a+28>>2]=b;v[a+20>>2]=b;v[a+16>>2]=b+v[a+48>>2];return 0}function mN(a,b,c){var d=0,e=0;d=jb-16|0;jb=d;a=kr(d,a,b);b=v[a+4>>2];e=v[a+8>>2];while(1){if((b|0)==(e|0)){kc(a);jb=d+16|0}else{lN(b,v[c>>2],v[c+4>>2]);b=b+8|0;v[a+4>>2]=b;continue}break}}function mD(a,b){var c=0,d=0;c=jb-16|0;jb=c;er(c+8|0,b);b=v[c+12>>2];mc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);d=v[c+4>>2];if((b|0)==(d|0)){Zb(a,v[c+12>>2])}jb=c+16|0;return(b|0)==(d|0)}function dC(a,b){var c=0,d=0;c=jb-16|0;jb=c;cC(c+8|0,b);b=v[c+12>>2];mc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);d=v[c+4>>2];if((b|0)==(d|0)){Zb(a,v[c+12>>2])}jb=c+16|0;return(b|0)==(d|0)}function bT(a,b){var c=0,d=0;c=jb-16|0;jb=c;aT(c+8|0,b);b=v[c+12>>2];mc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);d=v[c+4>>2];if((b|0)==(d|0)){Zb(a,v[c+12>>2])}jb=c+16|0;return(b|0)==(d|0)}function _R(a,b){var c=0,d=0;c=jb-16|0;jb=c;ZR(c+8|0,b);b=v[c+12>>2];mc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);d=v[c+4>>2];if((b|0)==(d|0)){Zb(a,v[c+12>>2])}jb=c+16|0;return(b|0)==(d|0)}function XU(a,b){var c=0,d=0;c=jb-16|0;jb=c;av(c+8|0,b);b=v[c+12>>2];mc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);d=v[c+4>>2];if((b|0)==(d|0)){Zb(a,v[c+12>>2])}jb=c+16|0;return(b|0)==(d|0)}function SL(a,b){var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=b;d=b;b=sh(82595524);if(d>>>0<=b>>>0){a=ct(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Yc(c+8|0,c+12|0)>>2]}jb=c+16|0;return b}bd();L()}function Ro(a,b){var c=0,d=0;c=jb-16|0;jb=c;Jh(c+8|0,b);b=v[c+12>>2];mc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);d=v[c+4>>2];if((b|0)==(d|0)){Zb(a,v[c+12>>2])}jb=c+16|0;return(b|0)==(d|0)}function RG(a,b,c,d){a:{if(!a){break a}b:{switch(b+2|0){case 0:t[a|0]=c;return;case 1:u[a>>1]=c;return;case 2:case 3:v[a>>2]=c;return;case 5:break b;default:break a}}v[a>>2]=c;v[a+4>>2]=d}}function Oo(a,b){var c=0,d=0;c=jb-16|0;jb=c;Wm(c+8|0,b);b=v[c+12>>2];mc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);d=v[c+4>>2];if((b|0)==(d|0)){Zb(a,v[c+12>>2])}jb=c+16|0;return(b|0)==(d|0)}function Nu(a,b){var c=0,d=0;c=jb-16|0;jb=c;Do(c+8|0,b);b=v[c+12>>2];mc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);d=v[c+4>>2];if((b|0)==(d|0)){Zb(a,v[c+12>>2])}jb=c+16|0;return(b|0)==(d|0)}function NU(a,b){var c=0,d=0;c=jb-16|0;jb=c;Fu(c+8|0,b);b=v[c+12>>2];mc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);d=v[c+4>>2];if((b|0)==(d|0)){Zb(a,v[c+12>>2])}jb=c+16|0;return(b|0)==(d|0)}function Mu(a,b){var c=0,d=0;c=jb-16|0;jb=c;Eo(c+8|0,b);b=v[c+12>>2];mc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);d=v[c+4>>2];if((b|0)==(d|0)){Zb(a,v[c+12>>2])}jb=c+16|0;return(b|0)==(d|0)}function Kt(a){var b=0;a:{if(Rb(a,13505,4)|w[a+4|0]){break a}if(Hb(w[a+6|0]|w[a+7|0]<<8)>>>0>1){break a}if(Hb(w[a+12|0]|w[a+13|0]<<8)){break a}b=(Hb(w[a+16|0]|w[a+17|0]<<8)|0)==20}return b}function IU(a,b){var c=0,d=0;c=jb-16|0;jb=c;Gu(c+8|0,b);b=v[c+12>>2];mc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);d=v[c+4>>2];if((b|0)==(d|0)){Zb(a,v[c+12>>2])}jb=c+16|0;return(b|0)==(d|0)}function HU(a,b){var c=0,d=0;c=jb-16|0;jb=c;Cq(c+8|0,b);b=v[c+12>>2];mc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);d=v[c+4>>2];if((b|0)==(d|0)){Zb(a,v[c+12>>2])}jb=c+16|0;return(b|0)==(d|0)}function Gr(a,b,c){var d=0;d=jb-16|0;jb=d;fc(d+8|0,b,c);b=v[d+12>>2];mc(d,v[a>>2],v[a+8>>2],v[d+8>>2],v[d+12>>2]);c=v[d+4>>2];if((b|0)==(c|0)){Zb(a,v[d+12>>2])}jb=d+16|0;return(b|0)==(c|0)}function ER(a,b){var c=0,d=0;c=jb-16|0;jb=c;uA(c+8|0,b);b=v[c+12>>2];mc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);d=v[c+4>>2];if((b|0)==(d|0)){Zb(a,v[c+12>>2])}jb=c+16|0;return(b|0)==(d|0)}function kA(a,b){var c=0,d=0;d=jb-32|0;jb=d;c=Fb(a);c=Uf(d+8|0,pg(a,uc(v[a>>2],v[a+4>>2])+1|0),uc(v[a>>2],v[a+4>>2]),c);fq(v[c+8>>2],v[b>>2]);v[c+8>>2]=v[c+8>>2]+4;Dd(a,c);Tf(c);jb=d+32|0}function Mw(a,b,c){b=(b+9|0)%12|0;a=((b<<24>>24)/-10<<24>>24)+a|0;return(((((((a|0)/4|0)+c|0)+B(a,365)|0)+((a|0)/-100|0)|0)+((a|0)/400|0)|0)+((B(b,20054016)+327680>>16)/10<<16>>16)|0)-1|0}function Lx(a,b,c,d,e,f,g,h,i){var j=0;j=jb-16|0;jb=j;Fg(j,b,c,d,e,f,g,h,i^-2147483648);d=v[j>>2];c=v[j+4>>2];b=v[j+12>>2];v[a+8>>2]=v[j+8>>2];v[a+12>>2]=b;v[a>>2]=d;v[a+4>>2]=c;jb=j+16|0}function xF(a,b){var c=0,d=0;d=jb-32|0;jb=d;c=Fb(a);c=Yl(d+8|0,Wl(a,ed(v[a>>2],v[a+4>>2])+1|0),ed(v[a>>2],v[a+4>>2]),c);wd(v[c+8>>2],w[b|0]);v[c+8>>2]=v[c+8>>2]+1;Dd(a,c);Xl(c);jb=d+32|0}function rn(a,b){var c=0,d=0,e=0;a:{c=KG(b);if(c>>>0<1073741808){b:{if(Ur(c)){ce(a,c);break b}d=bm(c)+1|0;e=Bi(d);ud(a,e);bf(a,d);Fd(a,c);a=e}li(a,b,c);ud((c<<2)+a|0,0);break a}hf();L()}}function g0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;if(d>>>0<4294967280){a:{if(El(d)){ce(a,c);break a}e=Mg(d)+1|0;d=sc(e);ud(a,d);bf(a,e);Fd(a,c);a=d}wd(ve(a,b,c)+c|0,0);return}hf();L()}function LP(a){var b=0,c=0;a:{b:{c=a&240;if((c|0)!=192){if((c|0)==240){break b}b=3;if((c|0)!=208){break a}}b=2;break a}a=a+15&255;b=1;if(a>>>0>2){break a}b=131842>>>(a<<3)|0}return b&255}function vi(a,b){var c=0,d=0;c=w[a|0];d=w[b|0];a:{if(!c|(d|0)!=(c|0)){break a}while(1){d=w[b+1|0];c=w[a+1|0];if(!c){break a}b=b+1|0;a=a+1|0;if((c|0)==(d|0)){continue}break}}return c-d|0}function v0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=v[a+84>>2];d=c+256|0;f=Vs(e,0,d);d=f?f-e|0:d;c=c>>>0>d>>>0?d:c;tc(b,e,c);b=e+d|0;v[a+84>>2]=b;v[a+8>>2]=b;v[a+4>>2]=c+e;return c|0}function jT(a,b,c,d){var e=0;e=jb-16|0;jb=e;v[e+12>>2]=b;v[e+8>>2]=d;c=Lp(a,c,v[Jb(e+12|0,e+8|0)>>2]);a:{if(c){break a}c=0;if((b|0)==(d|0)){break a}c=b>>>0<d>>>0?-1:1}jb=e+16|0;return c}function x$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=jb-16|0;jb=g;v[g+8>>2]=624576549;v[g+12>>2]=1394948685;h=a;a=g+16|0;b=Zj(h,b,c,d,e,f,g+8|0,a);jb=a;return b|0}function Mx(a){var b=0,c=0,d=0;A[a+4272>>3]=A[a+4280>>3];c=a;d=a+4296|0;a=0;while(1){if(a>>>0<32){a=a+15|0;b=Sn(d)|b<<15;continue}break}A[c+4280>>3]=C(C(b|0)*C(-4.656612873077393e-10))}function K6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=jb-16|0;jb=f;v[f+8>>2]=v[a+8>>2];g=v[a+4>>2];v[f>>2]=v[a>>2];v[f+4>>2]=g;a=oK(f,b,c,d,0,0,0,0,e);jb=f+16|0;return a|0}function vs(a){var b=0,c=0,d=0;c=1;while(1){if(c){c=0;b=v[a+4>>2];d=((b<<2)+(nv(v[a>>2],1)^270549120)|0)+2019860093|0;v[a>>2]=d;b=b+B(nv(d,16),5)|0;v[a+4>>2]=b;continue}break}return b}function Aia(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=Pb(v[a>>2],v[a+8>>2],12);a:{if(!d){t[c|0]=0;bi(b,12,c);break a}Cq(c+8|0,b);td(c,a,v[c+8>>2],v[c+12>>2])}jb=c+16|0;return d|0}function A3(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=v[14447];v[c+8>>2]=v[14446];v[c+12>>2]=d;d=v[14445];v[c>>2]=v[14444];v[c+4>>2]=d;nb[v[vp(c,bk(w[b+20|0]))>>2]](a,b);jb=c+16|0}function Wl(a,b){var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=b;d=b;b=sh(-1);if(d>>>0<=b>>>0){a=jp(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Yc(c+8|0,c+12|0)>>2]}jb=c+16|0;return b}bd();L()}function Sh(a){var b=0;a=Vh(a);b=2147483647;a:{if(a>=C(2147483648)){break a}b=-2147483648;if(a<=C(-2147483648)){break a}b=~~a;if(C(D(a))<C(2147483648)){break a}b=-2147483648}return b}function uK(a,b,c,d,e){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;var f=0,g=0;f=jb-16|0;jb=f;v[f+8>>2]=v[a+8>>2];g=v[a+4>>2];v[f>>2]=v[a>>2];v[f+4>>2]=g;c=tK(f,b,c,d,e,0,0,0,0);jb=f+16|0;return+c}function Zl(a,b){v[a+28>>2]=0;u[a+24>>1]=65535;v[a+16>>2]=0;v[a+20>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;t[a|0]=0;v[a+32>>2]=11;v[a+36>>2]=b;Sb(a+40|0);Sb(a+52|0);Tb(a- -64|0,0,48);return a}function Uf(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;og(a+12|0,d);if(b){d=Bi(b)}else{d=0}v[a>>2]=d;c=d+(c<<2)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=Bc(a),f=d+(b<<2)|0,v[e>>2]=f;return a|0}function Js(a){var b=0;b=v[a+24>>2];v[23588]=0;Y(813,b|0);b=v[23588];v[23588]=0;if((b|0)!=1){We(a+68|0);Wf(a+36|0);As(a+32|0);jj(a+24|0);ij(a+4|0);return De(a)}V(0)|0;O()|0;Ub();L()}function Fia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;YS(b,c);c=Pb(v[a>>2],v[a+8>>2],c<<2);if(c){XS(d+8|0,v[b>>2],v[b+4>>2]);td(d,a,v[d+8>>2],v[d+12>>2])}jb=d+16|0;return c|0}function Fea(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=Pb(v[a>>2],v[a+8>>2],4);a:{if(!d){t[c|0]=0;rD(b,4,c);break a}Jh(c+8|0,b);td(c,a,v[c+8>>2],v[c+12>>2])}jb=c+16|0;return d|0}function ws(a){var b=0,c=0,d=0;b=jb-16|0;jb=b;v[b+12>>2]=12;while(1){v[b+8>>2]=32;if(y[Jb(b+12|0,b+8|0)>>2]<=c>>>0){jb=b+16|0;a=d&4095}else{c=c+15|0;d=Sn(a);continue}break}return a}function uX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;FD(b,c);c=Pb(v[a>>2],v[a+8>>2],c<<3);if(c){ED(d+8|0,v[b>>2],v[b+4>>2]);td(d,a,v[d+8>>2],v[d+12>>2])}jb=d+16|0;return c|0}function jz(a){var b=0,c=0;b=v[a>>2];c=v[b>>2];a:{if(!c){while(1){c=Bh(b);b=v[b+8>>2];if(c){continue}break}break a}while(1){b=c;c=v[b+4>>2];if(c){continue}break}}v[a>>2]=b;return a}function jX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;c=0;a=nb[v[v[a>>2]+24>>2]](a)|0;if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Jb(d+12|0,d+8|0)>>2]}jb=d+16|0;return c|0}function Qv(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;v[e+12>>2]=d;d=Gb(b);if(d>>>0<c>>>0){rk();L()}b=Lc(b);v[e+8>>2]=d-c;wu(a,b+c|0,v[Jb(e+12|0,e+8|0)>>2]);jb=e+16|0}function HM(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;FM(c,b+80|0);v[23588]=0;U(11,a|0,0,c|0);a=v[23588];v[23588]=0;if((a|0)!=1){yb(c);jb=c+16|0;return}a=P()|0;O()|0;yb(c);T(a|0);L()}function tX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;d=!b|(b>>>0>d>>>0|a>>>0>=d>>>0|d-a>>>0<b>>>0);a:{if(d){break a}a=a+b|0;if(ed(v[c>>2],v[c+4>>2])>>>0>=a>>>0){break a}Ri(c,a)}return!d|0}function XN(a,b,c,d){a:{if((a|0)!=67108864){break a}a=B(d,872)+c|0;v[a+704>>2]=v[a+704>>2]&-129;a=d^1;if(a>>>0>=(b&65535)>>>0){break a}a=B(a,872)+c|0;v[a+704>>2]=v[a+704>>2]&-129}}function Iea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;yQ(b,c);if(Pb(v[a>>2],v[a+8>>2],c<<8)){c=v[b>>2];fc(d+8|0,c,zh(c,v[b+4>>2])<<8);td(d,a,v[d+8>>2],v[d+12>>2])}jb=d+16|0}function xC(a,b,c){var d=0,e=0;d=jb-16|0;jb=d;a=Ah(d,a,b);b=v[a+4>>2];e=v[a+8>>2];while(1){if((b|0)==(e|0)){kc(a);jb=d+16|0}else{fq(b,v[c>>2]);b=b+4|0;v[a+4>>2]=b;continue}break}}function ue(a,b){var c=0;a:{c=xg(b);if((c|0)==(Gb(a)|0)){v[23588]=0;a=W(361,a|0,b|0,c|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break a}a=!a}else{a=0}return a}V(0)|0;O()|0;Ub();L()}function oM(a){var b=0,c=0,d=0;b=jb-16|0;jb=b;while(1){v[b+12>>2]=7;v[b+8>>2]=32;if(y[Jb(b+12|0,b+8|0)>>2]<=c>>>0){jb=b+16|0;a=d&127}else{c=c+15|0;d=Sn(a);continue}break}return a}function hu(a,b){var c=0;c=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[a|0]=c;t[a+1|0]=c>>>8;t[a+2|0]=c>>>16;t[a+3|0]=c>>>24;b=w[b+4|0]|w[b+5|0]<<8;t[a+4|0]=b;t[a+5|0]=b>>>8}function Yx(a,b,c){var d=0,e=0;d=jb-16|0;jb=d;a=Ah(d,a,b);b=v[a+4>>2];e=v[a+8>>2];while(1){if((b|0)==(e|0)){kc(a);jb=d+16|0}else{dk(b,z[c>>2]);b=b+4|0;v[a+4>>2]=b;continue}break}}function Go(a,b,c){var d=0,e=0;d=jb-16|0;jb=d;a=_h(d,a,b);b=v[a+4>>2];e=v[a+8>>2];while(1){if((b|0)==(e|0)){kc(a);jb=d+16|0}else{Mi(b,x[c>>1]);b=b+2|0;v[a+4>>2]=b;continue}break}}function vl(a,b){var c=0,d=0,e=0;v[a>>2]=0;v[a+4>>2]=0;Gc(a+8|0);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=Fb(b);d=Fb(a),e=v[c>>2],v[d>>2]=e;v[c>>2]=0;v[b>>2]=0;v[b+4>>2]=0;return a}function sia(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;v[c+24>>2]=0;v[c+28>>2]=0;v[c+16>>2]=0;v[c+20>>2]=0;v[c+8>>2]=0;v[c+12>>2]=0;v[c>>2]=0;v[c+4>>2]=0;uT(b,c);tT(a,c);jb=c+32|0}function maa(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-32|0;jb=d;c=-1;a:{if(!YD(a,d+8|0)){break a}c=0;if(!_L(d+8|0)|(v[d+16>>2]!=v[b>>2]|v[b+4>>2]?b:0)){break a}c=1}jb=d+32|0;return c|0}function mZ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){a=v[b>>2];if(a>>>0<=127){a=v[(a<<2)+83296>>2]}else{a=0}v[d>>2]=a;d=d+4|0;b=b+4|0;continue}break}return c|0}function Zha(){var a=0,b=0,c=0;a=jb-16|0;jb=a;b=sc(1);v[23588]=0;Z(32);c=v[23588];v[23588]=0;if((c|0)!=1){b=v[Lf(a+8|0,b)>>2];jb=a+16|0;return b|0}a=P()|0;O()|0;Mb(b);T(a|0);L()}function Mo(a,b,c){var d=0,e=0;d=jb-16|0;jb=d;a=Ok(d,a,b);b=v[a+4>>2];e=v[a+8>>2];while(1){if((b|0)==(e|0)){kc(a);jb=d+16|0}else{wd(b,w[c|0]);b=b+1|0;v[a+4>>2]=b;continue}break}}function EC(a){var b=0,c=0;a:{if(Rb(a,14128,3)){break a}b=w[a+3|0];b:{if(b>>>0<=7){if((b|0)==1){break b}break a}if(b>>>0>14){break a}}c=(w[a+40|0]-1&255)>>>0<32|b>>>0<9}return c}function Ac(a,b){var c=0,d=0;c=jb-16|0;jb=c;if(ef(a)){Mb(v[a>>2])}d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;v[a+8>>2]=v[b+8>>2];ce(b,0);t[c+15|0]=0;ie(b,c+15|0);jb=c+16|0;return a}function tO(a,b,c,d){var e=0,f=0;e=jb-16|0;jb=e;while(1){if(c){f=ll(x[c+16>>1],v[c+20>>2],a,b);d=f?d:c;c=v[(f?c+4|0:c)>>2];continue}break}a=v[ec(e+8|0,d)>>2];jb=e+16|0;return a}function t7(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0,f=C(0);if(b>>>0<=12){c=Xd(c,C(0));d=a+4208|0;if((b|0)==12){c=C(Vh(C(c*C(3)))/C(3));b=12}e=Db(d,b),f=c,z[e>>2]=f;t[a+5046|0]=1}}function eE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=xl(a);d=yd(v[a+4>>2],w[a+11|0]);e=d+1|0;if((c|0)==(d|0)){Oy(a,c,e-c|0,c,c,0)}c=od(a);mI(c+d|0,1,b);sq(a,e);wd(c+e|0,0);return a|0}function bE(a){var b=0;a:{b:{if(a>>>0>=18285141){if(a>>>0>18350591){break b}b=1;if((a|0)!=18350080){break a}}return 0}b=0;if((a|0)==18350592){break a}b=(a&-256)!=(a|0)}return b}function VX(a){a=a|0;var b=0,c=0;b=jb-16|0;jb=b;VD(b,0,a);v[23588]=0;a=S(125,b|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){yb(b);jb=b+16|0;return a|0}a=P()|0;O()|0;yb(b);T(a|0);L()}function jw(a,b,c,d,e){var f=0;a:{f=$s(4332);if(f){v[23588]=0;ja(e|0,f|0,a|0,b|0,c|0,d|0)|0;a=v[23588];v[23588]=0;if((a|0)==1){break a}}return f}a=P()|0;O()|0;Mb(f);T(a|0);L()}function hF(a,b,c){var d=0;a:{if(!a){a=ba(8)|0;v[23588]=0;c=S(c|0,a|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){break a}b=P()|0;O()|0;ca(a|0);T(b|0);L()}return}ha(c|0,b|0,956);L()}function Q2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;qx(a,b,c);c=0;a=v[a+16>>2];if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Jb(d+8|0,d+12|0)>>2]}jb=d+16|0;return c|0}function Lja(a,b){a=a|0;b=b|0;if(!HU(a,b)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0}}function hba(a,b){a=a|0;b=b|0;var c=0;a=Xf(a);c=Fi(v[b>>2]);b=wf(b);v[23588]=0;U(807,a|0,c|0,b|0);b=v[23588];v[23588]=0;if((b|0)!=1){return a|0}b=P()|0;O()|0;yN(a);T(b|0);L()}function cfa(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;b=-1;a:{if(!Qj(a,c+8|0)){break a}b=0;if(!AQ(c+8|0)){break a}b=-1;if(!eg(a,4)){break a}b=YQ(a)>>>31|0}jb=c+16|0;return b|0}function RY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;nb[v[v[a>>2]+12>>2]](d+8|0,a,b);a=v[d+8>>2];b=v[c>>2];a=oc(v[d+12>>2],v[c+4>>2])&(a|0)==(b|0);jb=d+16|0;return a|0}function qp(a){var b=0,c=0;b=v[23509];c=a+3&-4;a=b+c|0;a:{if(a>>>0<=b>>>0?c:0){break a}if(_w()>>>0<a>>>0){if(!(ya(a|0)|0)){break a}}v[23509]=a;return b}v[116064]=48;return-1}function Gq(a,b){a=a|0;b=b|0;var c=0,d=0;c=v[a>>2];d=v[a+4>>2];if(Qc(c,d)>>>0>b>>>0){a=v[a+24>>2];b=Il(c,d,b);a=xe(v[a+484344>>2],v[a+484348>>2],x[b>>1])}else{a=0}return a|0}function Yu(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;Ri(b,c);if(Pb(v[a>>2],v[a+8>>2],c)){c=v[b>>2];fc(d+8|0,c,ed(c,v[b+4>>2]));td(d,a,v[d+8>>2],v[d+12>>2])}jb=d+16|0}function XQ(a,b){var c=0,d=0;c=jb-16|0;jb=c;Jh(c+8|0,b);b=v[c+12>>2];ld(c,a,v[c+8>>2],v[c+12>>2]);d=v[c+4>>2];if((b|0)==(d|0)){hd(a,v[c+12>>2])}jb=c+16|0;return(b|0)==(d|0)}function NA(a,b,c){var d=0,e=0;d=jb-16|0;jb=d;a=Fq(d,a,b);b=v[a+4>>2];e=v[a+8>>2];while(1){if((b|0)==(e|0)){kc(a);jb=d+16|0}else{hu(b,c);b=b+6|0;v[a+4>>2]=b;continue}break}}function Bga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d+8>>2]=b;while(1){if(Ob(b,c)){v[d+4>>2]=v[b>>2];zA(a,d+4|0);b=v[Ke(d+8|0)>>2];continue}else{jb=d+16|0}break}}function Ag(a,b,c,d){var e=0;a=((b|0)/8|0)+a|0;e=qh(v[d>>2],v[d+4>>2],a);return((qh(v[d>>2],v[d+4>>2],a+1|0)<<8|e<<16|qh(v[d>>2],v[d+4>>2],a+2|0))<<(b&7)&16777215)>>>24-c|0}function AU(a){var b=0;a:{if(Rb(a,16682,4)){break a}if(bc(w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24))-257>>>0<4294967053){break a}b=!Hb(w[a+8|0]|w[a+9|0]<<8)}return b}function Yl(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;og(a+12|0,d);if(b){d=sc(b)}else{d=0}v[a>>2]=d;c=c+d|0;v[a+8>>2]=c;v[a+4>>2]=c;e=Bc(a),f=b+d|0,v[e>>2]=f;return a|0}function Mh(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;t[c+24|0]=0;Yi(c+8|0,c+24|0);vn(c+16|0,a,v[c+8>>2],v[c+12>>2]);a=v[c+20>>2];t[b|0]=w[c+24|0];jb=c+32|0;return(a|0)==1|0}function J9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;f=v[c>>2];if(f>>>0<ed(a,b)>>>0){a=Lk(e,Kb(a,f),x[c+20>>1]);g=cw(d,a);_b(a)}jb=e+16|0;return g|0}function kZ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a:{while(1){if((c|0)==(d|0)){break a}a=v[c>>2];if(!(a>>>0>127|!(v[(a<<2)+83296>>2]&b))){c=c+4|0;continue}break}d=c}return d|0}function ika(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;an(c+8|0,b);b=v[c+12>>2];mc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);if((b|0)==v[c+4>>2]){Zb(a,v[c+12>>2])}jb=c+16|0}function gf(a,b,c){var d=0,e=0,f=0;d=jb-16|0;jb=d;v[d+8>>2]=c;v[d+4>>2]=31;e=d,f=qV(b,c),v[e+12>>2]=f;c=b;b=JB(d+4|0);ph(c,c+b|0,a);e=Kb(a,b),f=0,t[e|0]=f;sV(a);jb=d+16|0}function DD(a,b,c){var d=0,e=0;a:{b:{if(El(c)){ce(a,c);break b}if(c>>>0>=4294967280){break a}d=Mg(c)+1|0;e=sc(d);ud(a,e);bf(a,d);Fd(a,c);a=e}ve(a,b,c+1|0);return}hf();L()}function vba(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=Pb(v[a>>2],v[a+8>>2],16);a:{if(!d){pC(b);break a}av(c+8|0,b);td(c,a,v[c+8>>2],v[c+12>>2])}jb=c+16|0;return d|0}function kX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=nb[v[v[a>>2]+24>>2]](a)|0;a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function gm(a){a=a<<8&16711680|a<<24|(a>>>8&65280|a>>>24);a=a>>>4&252645135|(a&252645135)<<4;a=a>>>2&858993459|(a&858993459)<<2;return a>>>1&1431655765|(a&1431655765)<<1}function fja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;a:{if(a){nb[v[v[a>>2]+8>>2]](a,b,c);break a}if((b|0)>=6){break a}MM(d,9113,10812,140,42);oE(d,b,c)}jb=d+16|0}function Lha(){var a=0,b=0,c=0;a=jb-16|0;jb=a;b=Mc(a,10215);v[23588]=0;Y(36,b|0);c=v[23588];v[23588]=0;if((c|0)!=1){yb(b);jb=a+16|0;return}a=P()|0;O()|0;yb(b);T(a|0);L()}function sC(a,b){var c=0,d=0;c=jb-16|0;jb=c;a=_h(c,a,b);b=v[a+4>>2];d=v[a+8>>2];while(1){if((b|0)==(d|0)){kc(a);jb=c+16|0}else{rC(b);b=b+2|0;v[a+4>>2]=b;continue}break}}function rE(a,b){var c=0,d=0;c=jb-16|0;jb=c;a=Ok(c,a,b);b=v[a+4>>2];d=v[a+8>>2];while(1){if((b|0)==(d|0)){kc(a);jb=c+16|0}else{qE(b);b=b+1|0;v[a+4>>2]=b;continue}break}}function lZ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){a:{if((c|0)!=(d|0)){a=v[c>>2];if(a>>>0>127|!(v[(a<<2)+83296>>2]&b)){break a}}else{c=d}return c|0}c=c+4|0;continue}}function DA(a,b){var c=0,d=0;c=jb-16|0;jb=c;a=Ah(c,a,b);b=v[a+4>>2];d=v[a+8>>2];while(1){if((b|0)==(d|0)){kc(a);jb=c+16|0}else{Nm(b);b=b+4|0;v[a+4>>2]=b;continue}break}}function Bt(a,b){var c=0,d=0;c=jb-16|0;jb=c;a=Ah(c,a,b);b=v[a+4>>2];d=v[a+8>>2];while(1){if((b|0)==(d|0)){kc(a);jb=c+16|0}else{OP(b);b=b+4|0;v[a+4>>2]=b;continue}break}}function sI(a){var b=0,c=0;a:{if(w[a|0]!=255){break a}b=w[a+1|0];if((b&240)!=240&(b&254)!=226|!(b&6)){break a}a=w[a+2|0];if((a&240)==240){break a}c=(a&12)!=12}return c}function no(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=Pb(v[a>>2],v[a+8>>2],4);a:{if(!d){_S(b);break a}Jh(c+8|0,b);td(c,a,v[c+8>>2],v[c+12>>2])}jb=c+16|0;return d|0}function Wt(a){var b=0,c=0,d=0,e=0;while(1){a:{if((b|0)==32){e=c;break a}d=w[a+b|0];if((d-1&255)>>>0<31|((c^1)&1?0:d)){break a}b=b+1|0;c=!d|c;continue}break}return e&1}function ofa(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-48|0;jb=c;d=-1;a:{if(!UQ(a,c)){break a}d=0;if(!TQ(c)){break a}d=Ae(a,b,SQ(w[c+31|0],w[c+33|0]),mb)}jb=c+48|0;return d|0}function lga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;FD(b,c);if(Pb(v[a>>2],v[a+8>>2],c<<3)){ED(d+8|0,v[b>>2],v[b+4>>2]);td(d,a,v[d+8>>2],v[d+12>>2])}jb=d+16|0}function Rb(a,b,c){var d=0,e=0,f=0;a:{if(!c){break a}while(1){d=w[a|0];e=w[b|0];if((d|0)==(e|0)){b=b+1|0;a=a+1|0;c=c-1|0;if(c){continue}break a}break}f=d-e|0}return f}function KC(a,b,c){var d=0;d=jb-16|0;jb=d;a=No(d,a+8|0,b);b=v[a>>2];while(1){if((b|0)!=v[a+4>>2]){Mi(b,x[c>>1]);b=v[a>>2]+2|0;v[a>>2]=b;continue}break}Td(a);jb=d+16|0}function yA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;YS(b,c);if(Pb(v[a>>2],v[a+8>>2],c<<2)){XS(d+8|0,v[b>>2],v[b+4>>2]);td(d,a,v[d+8>>2],v[d+12>>2])}jb=d+16|0}function hk(a,b){var c=0,d=0,e=0;a:{c=ol(a,b);if((c|0)==255){break a}if(ik(v[a>>2])){break a}d=Kb(a+8|0,c);e=w[d|0]&223;t[d|0]=e;gh(v[a>>2],v[a+4>>2],b,yt(c)|176,e)}}function dT(a,b,c){var d=0;d=jb-16|0;jb=d;a=Xv(d,a+8|0,b);b=v[a>>2];while(1){if((b|0)!=v[a+4>>2]){wd(b,w[c|0]);b=v[a>>2]+1|0;v[a>>2]=b;continue}break}Td(a);jb=d+16|0}function Zba(a,b){a=a|0;b=b|0;a=Gc(a);t[a+534|0]=0;v[a+4>>2]=0;v[23588]=0;R(758,a|0,b|0);b=v[23588];v[23588]=0;if((b|0)!=1){return a|0}b=P()|0;O()|0;yj(a);T(b|0);L()}function ZW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;c=0;a=v[a+16>>2];if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Jb(d+12|0,d+8|0)>>2]}jb=d+16|0;return c|0}function WQ(a,b){var c=0;c=jb-32|0;jb=c;DR(c+24|0,a);Fe(c+16|0,b);a=v[c+20>>2];v[c+8>>2]=v[c+16>>2];v[c+12>>2]=a;a=Pc(v[c+24>>2],v[c+28>>2],c+8|0);jb=c+32|0;return a}function Ql(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=or(b);d=xl(a);if(c>>>0<=d>>>0){bB(a,Wh(od(a),b,c),c);break a}e=a;a=yd(v[a+4>>2],w[a+11|0]);oq(e,d,c-d|0,a,0,a,c,b)}}function Oga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=Sb(a+8|0);v[23588]=0;U(244,a|0,b|0,c|0);a=v[23588];v[23588]=0;if((a|0)!=1){break a}a=P()|0;O()|0;hc(d);T(a|0);L()}}function M6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=a;a=b+28|0;d=wp(d,a);fK(a,c);v[23588]=0;R(70,b|0,1);a=v[23588];v[23588]=0;if((a|0)==1){a=P()|0;O()|0;$b(d);T(a|0);L()}}function zA(a,b){a=a|0;b=b|0;var c=0;if(y[a+4>>2]<y[Fb(a)>>2]){c=jb-16|0;jb=c;a=Ah(c,a,1);fq(v[a+4>>2],v[b>>2]);v[a+4>>2]=v[a+4>>2]+4;kc(a);jb=c+16|0;return}kA(a,b)}function q$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=a;h=b;a=nb[v[v[a+8>>2]+20>>2]](a+8|0)|0;b=zc(a);return Yj(g,h,c,d,e,f,b,b+(Gb(a)<<2)|0)|0}function nT(a,b,c){var d=0,e=0,f=0;d=jb-16|0;jb=d;b=ic(b);a=lh(a,sc(32),mh(d+8|0,b));b=v[a>>2]+16|0;u[b>>1]=x[v[c>>2]>>1];Lb(b+4|0);e=ic(a),f=1,t[e+4|0]=f;jb=d+16|0}function lX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;c=0;a=v[a+8>>2];if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Jb(d+12|0,d+8|0)>>2]}jb=d+16|0;return c|0}function kja(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{if(!Pb(v[b>>2],v[b+8>>2],12)){u[c>>1]=0;HT(a,6,c);break a}Cq(c+8|0,a);td(c,b,v[c+8>>2],v[c+12>>2])}jb=c+16|0}function R2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;qx(a,b,c);a=v[a+16>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function OD(a,b,c){var d=0,e=0;if(c>>>0<4294967280){a:{if(El(c)){ce(a,c);break a}d=Mg(c)+1|0;e=sc(d);ud(a,e);bf(a,d);Fd(a,c);a=e}wd(ve(a,b,c)+c|0,0);return}hf();L()}function KP(a){var b=0,c=0;a:{if(w[a|0]!=255){break a}b=w[a+1|0];if((b&224)!=224|(b&24)==8|!(b&6)){break a}a=w[a+2|0];if((a&12)==12){break a}c=(a&240)!=240}return c}function D1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;a=bx(Ta(v[a+60>>2],b|0,c|0,d&255,e+8|0)|0);jb=e+16|0;mb=a?-1:v[e+12>>2];return(a?-1:v[e+8>>2])|0}function xH(a,b){var c=0,d=0,e=0,f=0;c=v[a+24>>2];if((c|0)==v[a+28>>2]){return e=a,f=yf(b),d=v[v[a>>2]+52>>2],nb[d](e|0,f|0)|0}v[a+24>>2]=c+1;t[c|0]=b;return yf(b)}function Yfa(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{if(!Pb(v[b>>2],v[b+8>>2],8)){u[c>>1]=0;HT(a,4,c);break a}an(c+8|0,a);td(c,b,v[c+8>>2],v[c+12>>2])}jb=c+16|0}function iQ(a){v[a>>2]=0;v[a+4>>2]=0;v[a+88>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;Nz(a+112|0,48e3);v[a+668>>2]=0;Mz(a+724|0);Mz(a+732|0);Mz(a+740|0);tg(a+788|0);return a}function Ze(a,b){var c=0;c=v[a>>2];v[a>>2]=b;a:{if(c){a=v[ic(a)>>2];v[23588]=0;Y(a|0,c|0);a=v[23588];v[23588]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Ub();L()}function Qfa(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{if(!Pb(v[b>>2],v[b+8>>2],5)){t[c|0]=0;bi(a,5,c);break a}Do(c+8|0,a);td(c,b,v[c+8>>2],v[c+12>>2])}jb=c+16|0}function Hja(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{if(!Pb(v[b>>2],v[b+8>>2],6)){t[c|0]=0;bi(a,6,c);break a}oB(c+8|0,a);td(c,b,v[c+8>>2],v[c+12>>2])}jb=c+16|0}function zY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d+12>>2]=v[c>>2];a=nb[v[v[a>>2]+16>>2]](a,b,d+12|0)|0;if(a){v[c>>2]=v[d+12>>2]}jb=d+16|0;return a|0}function kca(a,b){a=a|0;b=b|0;a=Sb(a);t[a+16|0]=0;v[a+12>>2]=b;v[23588]=0;Y(752,a|0);b=v[23588];v[23588]=0;if((b|0)!=1){return a|0}b=P()|0;O()|0;zz(a);T(b|0);L()}function bq(a){v[a+8>>2]=0;v[a+12>>2]=0;v[a>>2]=128;v[a+4>>2]=256;v[a+32>>2]=363;v[a+36>>2]=952;v[a+16>>2]=48e3;v[a+20>>2]=2;v[a+24>>2]=128;v[a+28>>2]=0;return a}function Sm(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{if(!Pb(v[b>>2],v[b+8>>2],4)){t[c|0]=0;bi(a,4,c);break a}Jh(c+8|0,a);td(c,b,v[c+8>>2],v[c+12>>2])}jb=c+16|0}function Qaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=c,e=Ei(b),v[d+12>>2]=e;v[c+8>>2]=0;d=a,e=v[Ij(c+12|0,c+8|0,43824)>>2],v[d+36>>2]=e;Ep(a);jb=c+16|0}function O0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;v[e>>2]=c;v[e+4>>2]=d;v[e+8>>2]=c;v[e+12>>2]=d;a=gH(a,e,b);v[a>>2]=78316;jb=e+16|0;return a|0}function JB(a){var b=0,c=0;a:{c=Db(a,3);if((c|0)==(a|0)){break a}b=a;while(1){b=b+4|0;if((c|0)==(b|0)){break a}a=po(v[b>>2],v[a>>2])?b:a;continue}}return v[a>>2]}function Ik(a,b){a=a|0;b=b|0;var c=0;if(!ff(w[b+11|0])){c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2];return a|0}DD(a,v[b>>2],v[b+4>>2]);return a|0}function rq(a){var b=0,c=0,d=0,e=0;b=v[a+4>>2];c=v[b>>2];v[a+4>>2]=c;if(c){lm(c,a)}v[b+8>>2]=v[a+8>>2];d=v[a+8>>2]+(Bh(a)?0:4)|0,e=b,v[d>>2]=e;v[b>>2]=a;lm(a,b)}function qq(a){var b=0,c=0,d=0,e=0;b=v[a>>2];c=v[b+4>>2];v[a>>2]=c;if(c){lm(c,a)}v[b+8>>2]=v[a+8>>2];d=v[a+8>>2]+(Bh(a)?0:4)|0,e=b,v[d>>2]=e;v[b+4>>2]=a;lm(a,b)}function gga(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-80|0;jb=d;c=-1;a:{if(!fV(a,d+8|0)){break a}c=0;if(!JR(d+8|0)){break a}c=Ae(a,b,IR(d+8|0),mb)}jb=d+80|0;return c|0}function dB(a){var b=0,c=0;b=jb-16|0;jb=b;u[b+14>>1]=a;Ef(b+14|0,4095);a=x[b+14>>1];c=aU(mi(+((a&255)>>>0)*.00390625)*32768);jb=b+16|0;return c>>>15-(a>>>8|0)|0}function Ti(a,b,c,d,e){a:{e=$s(e);if(e){v[23588]=0;fa(d|0,e|0,a|0,b|0,c|0)|0;a=v[23588];v[23588]=0;if((a|0)==1){break a}}return e}a=P()|0;O()|0;Mb(e);T(a|0);L()}function OM(a){var b=0,c=0,d=0;b=v[a+112>>2];if((b|0)>=11){c=378;while(1){if(c|d){NM(a);b=c;c=b-1|0;d=d-!b|0;continue}break}b=0}v[a+112>>2]=b+1;a=NM(a);return a}function NP(a,b){var c=0;c=v[a+4>>2];a:{if((b|0)>=0){b=b+c|0;c=v[a>>2]+(b>>>3&536870908)|0;break a}b=b+c|0;c=v[a>>2]+((b-31|0)/32<<2)|0}v[a>>2]=c;v[a+4>>2]=b&31}function w$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=a;h=b;a=nb[v[v[a+8>>2]+20>>2]](a+8|0)|0;b=Lc(a);return Zj(g,h,c,d,e,f,b,Gb(a)+b|0)|0}function os(a){var b=0;a:{if((_e(a)|0)!=79){break a}if((_e(a)|0)!=103){break a}if((_e(a)|0)!=103){break a}b=(_e(a)|0)==83}if(!b){dc(a,30);return 0}return kI(a)}function dv(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{if(!Pb(v[b>>2],v[b+8>>2],2)){t[c|0]=0;qC(a,c);break a}Wm(c+8|0,a);td(c,b,v[c+8>>2],v[c+12>>2])}jb=c+16|0}function aJ(a,b){var c=0,d=0;d=a+4|0;c=ed(v[d>>2],v[a+8>>2]);a=v[a+16>>2]+b|0;if(c>>>0<a>>>0){a:{if(c){b=ch(c);if(a>>>0<=b>>>0){break a}}b=bJ(a,65536)}Ri(d,b)}}function ok(a,b){var c=0;c=jb-32|0;jb=c;v[c+24>>2]=0;Vv(c+8|0,c+24|0);vn(c+16|0,a,v[c+8>>2],v[c+12>>2]);a=v[c+20>>2];_l(b,v[c+24>>2]);jb=c+32|0;return(a|0)==4}function iC(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=-1;if(zg(a,c+8|0)){v[c+4>>2]=w[c+8|0];d=bC(a,b,v[Jb(c+4|0,c+12|0)>>2])}jb=c+16|0;return d|0}function g9(a){a=a|0;var b=0,c=0,d=0;b=jb-16|0;jb=b;nL(b+8|0,a,0);c=v[b+12>>2];if(c){a=v[a+20>>2];v[a+148>>2]=-1;d=a+4|0;a=v[b+8>>2];ty(d,a,Kb(a,c))}jb=b+16|0}function Xd(a,b){var c=0,d=0,e=C(0);c=jb-16|0;jb=c;v[c+8>>2]=1065353216;z[c+12>>2]=b;d=c,e=Jf(a),z[d+4>>2]=e;a=z[kq(c+4|0,c+12|0,c+8|0)>>2];jb=c+16|0;return a}function VJ(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;c=v[b+20>>2];v[a+16>>2]=v[b+16>>2];v[a+20>>2]=c;c=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=c}function Im(a){var b=0;b=2147483647;a:{if(a>=2147483647){break a}b=-2147483648;if(a<=-2147483648){break a}if(D(a)<2147483648){return~~a}b=-2147483648}return b}function GU(a){var b=0;if(!(Rb(a,17813,8)|w[a+8|0]>1|((w[a+9|0]-1&255)>>>0>7|(w[a+10|0]|w[a+11|0]<<8)>>>0>4096))){b=(w[a+12|0]|w[a+13|0]<<8)>>>0<4097}return b}function FT(a,b){var c=0;c=Lka(b&65535,0,384,0);b=a&65535;a=b>>>30|0;b=b<<2;c=c+b|0;a=a+mb|0;a=b>>>0>c>>>0?a+1|0:a;b=c+256|0;a=b>>>0<256?a+1|0:a;mb=a;return b}function $V(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=-1;if(zg(a,c+8|0)){v[c+4>>2]=w[c+8|0];d=eC(a,b,v[Jb(c+4|0,c+12|0)>>2])}jb=c+16|0;return d|0}function tD(a){var b=0;if(!(Rb(a,15492,4)|(w[a+4|0]-16&255)>>>0<249|((w[a+5|0]-16&255)>>>0<249|(w[a+6|0]-16&255)>>>0<249))){b=(w[a+7|0]-9&255)>>>0<7}return b}function n0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;while(1){if((b|0)!=(c|0)){a=v[b>>2]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+4|0;continue}break}return a|0}function ld(a,b,c,d){var e=0,f=0,g=0;e=jb-16|0;jb=e;f=v[b+12>>2];v[e+8>>2]=c;v[e+12>>2]=d;g=v[v[b>>2]+28>>2];v[e>>2]=c;v[e+4>>2]=d;nb[g|0](a,b,f,e);jb=e+16|0}function lB(a,b,c,d){var e=0,f=0;og(a+12|0,d);if(b){d=tC(b)}else{d=0}v[a>>2]=d;c=d+B(c,20)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=Bc(a),f=d+B(b,20)|0,v[e>>2]=f;return a}function Qz(a){var b=0;a=we(a);b=32767;a:{if(a>=32767){break a}b=32768;if(a<=-32768){break a}b=~~a;if(D(a)<2147483648){break a}b=-2147483648}return b<<16>>16}function Hk(a,b,c,d){var e=0,f=0;og(a+12|0,d);if(b){d=cE(b)}else{d=0}v[a>>2]=d;c=d+B(c,12)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=Bc(a),f=d+B(b,12)|0,v[e>>2]=f;return a}function DK(a){a=a|0;var b=0;v[a+4240>>2]=0;v[a+4244>>2]=0;b=a+4264|0;v[b>>2]=0;v[b+4>>2]=0;b=a+4256|0;v[b>>2]=0;v[b+4>>2]=0;a=a+4248|0;v[a>>2]=0;v[a+4>>2]=0}function q0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;while(1){if((b|0)!=(c|0)){a=t[b|0]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+1|0;continue}break}return a|0}function gw(a,b,c,d){var e=0;e=ba(8)|0;v[23588]=0;a=Q(d|0,e|0,a|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){ha(a|0,c|0,b|0);L()}a=P()|0;O()|0;ca(e|0);T(a|0);L()}function Zb(a,b){a=a|0;b=b|0;var c=0;c=Pb(v[a>>2],v[a+8>>2],b);a:{if(c){b=v[a+8>>2]+b|0;break a}b=v[a>>2];b=nb[v[v[b>>2]+24>>2]](b)|0}v[a+8>>2]=b;return c|0}function Q3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;while(1){if((a|0)!=(b|0)){d=v[c>>2];v[d>>2]=v[a>>2];xh(d+4|0,a+4|0);v[c>>2]=v[c>>2]+16;a=a+16|0;continue}break}}function MR(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;while(1){if((b|0)==(c|0)){jb=d+16|0}else{v[d+12>>2]=v[b>>2];zA(a,d+12|0);b=b+4|0;continue}break}}function ML(a,b){var c=0;c=jb-16|0;jb=c;a=Vm(c,a+8|0,b);b=v[a>>2];while(1){if((b|0)!=v[a+4>>2]){OP(b);b=v[a>>2]+4|0;v[a>>2]=b;continue}break}Td(a);jb=c+16|0}function Dea(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-48|0;jb=d;c=-1;a:{if(!UQ(a,d)){break a}c=0;if(!_P(d)){break a}c=Ae(a,b,ZP(w[d+47|0]),mb)}jb=d+48|0;return c|0}function sc(a){a=a|0;var b=0;a=a?a:1;a:{while(1){b=Od(a);if(b){break a}b=v[117529];if(b){nb[b|0]();continue}break}ha(mm(ba(4)|0)|0,92948,26);L()}return b|0}function mr(a,b,c,d){var e=0,f=0;og(a+12|0,d);if(b){d=CD(b)}else{d=0}v[a>>2]=d;c=d+(c<<3)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=Bc(a),f=d+(b<<3)|0,v[e>>2]=f;return a}function iT(a,b,c,d){var e=0,f=0;og(a+12|0,d);if(b){d=eT(b)}else{d=0}v[a>>2]=d;c=d+B(c,6)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=Bc(a),f=d+B(b,6)|0,v[e>>2]=f;return a}function fQ(a,b,c,d){var e=0,f=0;og(a+12|0,d);if(b){d=dQ(b)}else{d=0}v[a>>2]=d;c=d+(c<<4)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=Bc(a),f=d+(b<<4)|0,v[e>>2]=f;return a}function et(a,b){var c=0,d=0,e=C(0);c=jb-16|0;jb=c;z[c+12>>2]=b;v[c+8>>2]=0;v[c+4>>2]=1065353216;d=a,e=z[kq(c+12|0,c+8|0,c+4|0)>>2],z[d+144>>2]=e;jb=c+16|0}function cA(a,b,c){var d=0;d=jb-16|0;jb=d;v[d+8>>2]=a;c=c&65535;while(1){if(!(!Ob(a,b)|(c|0)==x[a>>1])){a=v[Re(d+8|0)>>2];continue}break}jb=d+16|0;return a}function UM(){var a=0,b=0,c=0,d=0;a=jb-16|0;jb=a;b=a+8|0;while(1){if(c>>>0<32){c=c+48|0;d=xy(94392);continue}break}v[b>>2]=d;Sn(b);jb=a+16|0;return v[b>>2]}function Mj(a,b,c,d){var e=0,f=0;og(a+12|0,d);if(b){d=$C(b)}else{d=0}v[a>>2]=d;c=d+(c<<1)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=Bc(a),f=d+(b<<1)|0,v[e>>2]=f;return a}function Dt(a,b,c,d){var e=0,f=0;og(a+12|0,d);if(b){d=$P(b)}else{d=0}v[a>>2]=d;c=d+(c<<5)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=Bc(a),f=d+(b<<5)|0,v[e>>2]=f;return a}function xp(a,b){var c=0,d=0;a:{if(!a){break a}c=Lka(a,0,b,0);d=mb;if((a|b)>>>0<65536){break a}c=d?-1:c}a=Od(c);if(!(!a|!(w[a-4|0]&3))){Tb(a,0,c)}return a}function wV(a,b,c){var d=0;b=b-a>>2;while(1){if((b|0)>0){d=v[c>>2];t[a|0]=d;t[a+1|0]=d>>>8;t[a+2|0]=d>>>16;t[a+3|0]=d>>>24;b=b-1|0;a=a+4|0;continue}break}}function v2(a,b,c){a=a|0;b=b|0;c=c|0;a:{a=xh(a,b);v[23588]=0;Q(54,a+12|0,c|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break a}b=P()|0;O()|0;yb(a);T(b|0);L()}}function sD(a,b){a=a|0;b=b|0;var c=0,d=0;c=a;a=v[b>>2];d=(nb[v[v[a>>2]+20>>2]](a)|0)+v[b+8>>2]|0;a=v[b>>2];gc(c,d,(nb[v[v[a>>2]+24>>2]](a)|0)-v[b+8>>2]|0)}function mj(a,b,c,d){var e=0;e=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=e;e=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=e;A[a>>3]=A[a>>3]-c;A[a+8>>3]=A[a+8>>3]-d}function gi(a){var b=0,c=0;b=a*a;c=b*a;return C(c*(b*b)*(b*2718311493989822e-21+-.00019839334836096632)+(c*(b*.008333329385889463+-.16666666641626524)+a))}function _W(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=v[a+16>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function xh(a,b){a=a|0;b=b|0;var c=0;if(!ef(b)){c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2];return a|0}DD(a,v[b>>2],v[b+4>>2]);return a|0}function mX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=v[a+8>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function lx(a,b){var c=0;while(1){c=(b|0)<120?b:120;a=C(a*C(z[((c&3)<<2)+65808>>2]*C(1073741824>>>(c>>2)|0)));b=b-c|0;if((b|0)>0){continue}break}return a}function h7(a){a=a|0;var b=0,c=C(0);t[a+4202|0]=1;b=a,c=az(C(C(C(C(y[v[a+16>>2]+24620>>2])/C(3))+C(-80))/C(15920)),C(0),C(1)),z[b+4272>>2]=c;EK(a);DK(a)}function Kg(a){var b=0,c=0;b=v[a>>2];c=v[b+4>>2];a:{if(!c){while(1){if(!Bh(b)){b=v[b+8>>2];continue}break}b=v[b+8>>2];break a}b=LT(c)}v[a>>2]=b;return a}function Fn(a,b){var c=0,d=0;b=b+7&-8;d=v[a+80>>2];a:{if(d){b=v[a+92>>2]-b|0;c=0;if((b|0)<v[a+88>>2]){break a}v[a+92>>2]=b;return b+d|0}c=Od(b)}return c}function zQ(a,b){var c=0,d=0,e=0;ou(a);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=Fb(b);d=Fb(a),e=v[c>>2],v[d>>2]=e;v[c>>2]=0;v[b>>2]=0;v[b+4>>2]=0;return a}function yG(a,b,c){var d=0;d=jb-32|0;jb=d;v[d+28>>2]=c;v[d+24>>2]=0;v[d+12>>2]=4;tw(d+16|0,a,d+24|0,v[Jb(d+28|0,d+12|0)>>2]);_l(b,v[d+24>>2]);jb=d+32|0}function vx(a){var b=0,c=0;if(v[a>>2]){c=v[a>>2];b=v[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-16|0;Cs(b);continue}break}v[a+4>>2]=c;b=v[a>>2];Mt(a);Mb(b)}}function vD(a){a=a|0;var b=0;a=Lb(a);v[23588]=0;S(174,a+12|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){Gc(a+32|0);return a|0}b=P()|0;O()|0;zb(a);T(b|0);L()}function sS(a){var b=0,c=0;if(v[a>>2]){c=v[a>>2];b=v[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-24|0;Ab(b);continue}break}v[a+4>>2]=c;b=v[a>>2];Ar(a);Mb(b)}}function sR(a){var b=0,c=0;if(v[a>>2]){c=v[a>>2];b=v[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-56|0;St(b);continue}break}v[a+4>>2]=c;b=v[a>>2];qR(a);Mb(b)}}function dZ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;while(1){if((b|0)!=(c|0)){a=v[b>>2];t[e|0]=a>>>0<128?a:d;e=e+1|0;b=b+4|0;continue}break}return c|0}function cd(a,b){a=a|0;b=b|0;var c=0,d=0;a:{if(y[a+8>>2]<b>>>0){d=v[a>>2];c=0;if(nb[v[v[d>>2]+24>>2]](d)>>>0<b>>>0){break a}}v[a+8>>2]=b;c=1}return c|0}function We(a){var b=0,c=0;if(v[a>>2]){c=v[a>>2];b=v[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-12|0;_b(b);continue}break}v[a+4>>2]=c;b=v[a>>2];Vj(a);Mb(b)}}function Rl(a){var b=0,c=0;if(v[a>>2]){c=v[a>>2];b=v[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-12|0;ac(b);continue}break}v[a+4>>2]=c;b=v[a>>2];Vj(a);Mb(b)}}function L9(a){a=a|0;var b=0;b=jb-16|0;jb=b;Rc(b,a+32|0,4);if(!Bb(v[v[b>>2]>>2],v[b+4>>2])){Yv(a)}a=v[ec(b+8|0,Eb(v[a+52>>2]))>>2];jb=b+16|0;return a|0}function Km(a,b){var c=0,d=0,e=0;rB(a);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=Fb(b);d=Fb(a),e=v[c>>2],v[d>>2]=e;v[c>>2]=0;v[b>>2]=0;v[b+4>>2]=0;return a}function K9(a){a=a|0;var b=0;b=jb-16|0;jb=b;Rc(b,a+32|0,4);if(!Bb(v[v[b>>2]>>2],v[b+4>>2])){Yv(a)}a=v[ec(b+8|0,Eb(v[a+56>>2]))>>2];jb=b+16|0;return a|0}function H0(a,b){a=a|0;b=b|0;var c=0,d=0;b=Iw(b);v[a+36>>2]=b;c=a,d=Vg(b),v[c+44>>2]=d;c=a,d=zn(v[a+36>>2]),t[c+53|0]=d;if(v[a+44>>2]>=9){Xr(5566);L()}}function A0(a,b){a=a|0;b=b|0;var c=0,d=0;b=Nw(b);v[a+36>>2]=b;c=a,d=Vg(b),v[c+44>>2]=d;c=a,d=zn(v[a+36>>2]),t[c+53|0]=d;if(v[a+44>>2]>=9){Xr(5566);L()}}function mU(a,b){var c=0;c=Lka(b&255,0,9,0);b=a&255;a=b>>>31|0;b=b<<1;c=c+b|0;a=a+mb|0;a=b>>>0>c>>>0?a+1|0:a;b=c+11|0;a=b>>>0<11?a+1|0:a;mb=a;return b}function lT(a,b,c){var d=0;d=jb-32|0;jb=d;v[d+28>>2]=c;t[d+24|0]=0;v[d+12>>2]=1;tw(d+16|0,a,d+24|0,v[Jb(d+28|0,d+12|0)>>2]);t[b|0]=w[d+24|0];jb=d+32|0}function Op(a,b,c){var d=0;a:{if(b&134218752){break a}if(!pj(c)){break a}b=w[c+34|0];if((b+5&255)>>>0<6){break a}d=v[Ld(a+906300|0,b-1|0)>>2]}return d}function Jn(a,b){v[a+20>>2]=0;v[a+24>>2]=b;v[a+12>>2]=0;v[a+4>>2]=4098;v[a+8>>2]=6;v[a+16>>2]=!b;Tb(a+32|0,0,40);DH(a+28|0);v[a+72>>2]=0;v[a+76>>2]=-1}function I4(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=jb-32|0;jb=h;i=h+8|0;YI(i,b,c,d,e,f,g);$c(a,h+20|0);wm(i);jb=h+32|0}function yv(a,b){var c=0;c=jb-16|0;jb=c;a:{if(!Pb(v[b>>2],v[b+8>>2],3)){t[c|0]=0;bi(a,3,c);break a}xv(c+8|0,a);td(c,b,v[c+8>>2],v[c+12>>2])}jb=c+16|0}function jE(a){v[a>>2]=0;v[a+4>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;u[a+20>>1]=0;v[a+16>>2]=-1;v[a+8>>2]=0;v[a+12>>2]=0;v[a>>2]=0}function RN(a,b,c){var d=0,e=0;v[b+56>>2]=0;d=b,e=Vn(a,x[b+70>>1],v[b+48>>2],c,0),u[d+68>>1]=e;if(!(!(w[a+480180|0]&5)|v[b+60>>2]==-1)){v[b+60>>2]=0}}function vfa(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-96|0;jb=d;c=-1;a:{if(!zR(a,d)){break a}c=0;if(!eR(d)){break a}c=Ae(a,b,dR(d),mb)}jb=d+96|0;return c|0}function tv(a,b,c,d,e){var f=0;while(1){if((d|0)!=(f|0)){z[b>>2]=C(v[a>>2])*e;z[c>>2]=C(v[a+4>>2])*e;f=f+1|0;c=c+4|0;a=a+8|0;b=b+4|0;continue}break}}function _f(a){var b=0,c=0;b=jb-16|0;jb=b;a:{if(ef(a)){c=v[a>>2];t[b+15|0]=0;ie(c,b+15|0);Fd(a,0);break a}t[b+14|0]=0;ie(a,b+14|0);ce(a,0)}jb=b+16|0}function XY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;while(1){if((b|0)!=(c|0)){a=t[b|0];t[e|0]=(a|0)<0?d:a;e=e+1|0;b=b+1|0;continue}break}return c|0}function Ufa(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-96|0;jb=d;c=-1;a:{if(!zR(a,d)){break a}c=0;if(!yR(d)){break a}c=Ae(a,b,xR(d),mb)}jb=d+96|0;return c|0}function wz(a){var b=0,c=0;c=v[a+4>>2];while(1){b=v[a+8>>2];if((b|0)!=(c|0)){b=b-32|0;v[a+8>>2]=b;ql(b);continue}break}c=v[a>>2];if(c){_o(a);Mb(c)}}function vu(a){var b=0,c=0;c=v[a+4>>2];while(1){b=v[a+8>>2];if((b|0)!=(c|0)){b=b-20|0;v[a+8>>2]=b;Ab(b);continue}break}c=v[a>>2];if(c){Bc(a);Mb(c)}}function sK(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-16|0;jb=d;c=XJ(sc(12));v[c+8>>2]=b;v[c+4>>2]=a;v[c>>2]=49020;a=v[Lf(d+8|0,c)>>2];jb=d+16|0;return a|0}function pR(a){var b=0,c=0;c=v[a+4>>2];while(1){b=v[a+8>>2];if((b|0)!=(c|0)){b=b-56|0;v[a+8>>2]=b;St(b);continue}break}c=v[a>>2];if(c){Bc(a);Mb(c)}}function kV(a){var b=0,c=0;c=v[a+4>>2];while(1){b=v[a+8>>2];if((b|0)!=(c|0)){b=b-28|0;v[a+8>>2]=b;zd(b);continue}break}c=v[a>>2];if(c){Bc(a);Mb(c)}}function fO(a){var b=0,c=0;c=v[a+4>>2];while(1){b=v[a+8>>2];if((b|0)!=(c|0)){b=b-12|0;v[a+8>>2]=b;_b(b);continue}break}c=v[a>>2];if(c){_o(a);Mb(c)}}function Sv(a){var b=0,c=0;c=v[a+4>>2];while(1){b=v[a+8>>2];if((b|0)!=(c|0)){b=b-12|0;v[a+8>>2]=b;ac(b);continue}break}c=v[a>>2];if(c){_o(a);Mb(c)}}function QL(a){var b=0,c=0;c=v[a+4>>2];while(1){b=v[a+8>>2];if((b|0)!=(c|0)){b=b-52|0;v[a+8>>2]=b;gl(b);continue}break}c=v[a>>2];if(c){Bc(a);Mb(c)}}function IY(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(Zg(a,v[b+8>>2],f)){ow(b,c,d,e);return}a=v[a+8>>2];nb[v[v[a>>2]+20>>2]](a,b,c,d,e,f)}function EM(a){if(w[a+480224|0]==2){return+y[a+1074420>>2]/1e4}return+y[a+24620>>2]/(+y[a+1074404>>2]*+(B(v[a+1074408>>2],v[a+1074416>>2])>>>0))*60}function Bv(a){var b=0,c=0;c=v[a+4>>2];while(1){b=v[a+8>>2];if((b|0)!=(c|0)){b=b-36|0;v[a+8>>2]=b;ir(b);continue}break}c=v[a>>2];if(c){Bc(a);Mb(c)}}function tp(a,b){var c=0;a:{if(!sI(b)|(w[b+1|0]^w[a+1|0])>>>0>1){break a}b=w[b+2|0];a=w[a+2|0];if((b^a)&12){break a}c=!(b&240)^(a&240)!=0}return c}function sz(a,b,c){var d=0,e=0,f=0;d=ol(a,b);if((d|0)!=255){e=cc(a+26|0,d),f=c,u[e>>1]=f;a=a+62|0;e=Kb(a,b),f=255,t[e|0]=f;e=Kb(a,c),f=d,t[e|0]=f}}function pF(a){var b=0,c=0;c=a>>>23&255;b=0;a:{if(c>>>0<127){break a}b=2;if(c>>>0>150){break a}c=1<<150-c;b=0;if(c-1&a){break a}b=a&c?1:2}return b}function Xe(a,b){var c=0;c=jb-16|0;jb=c;a:{if(!b){Rc(c+8|0,a+32|0,5);if(Bb(v[v[c+8>>2]>>2],v[c+12>>2])){break a}}v[a+28>>2]=v[a+28>>2]+1}jb=c+16|0}function SO(a){var b=0,c=0,d=0;d=w[a+26|0];b=d+27|0;while(1){if((c|0)==(d|0)){a=b&65535}else{b=w[(a+c|0)+27|0]+b|0;c=c+1|0;continue}break}return a}function Nka(a,b,c){var d=0;d=b>>31;a=a^d;Jka(a-d|0,(b^d)-((a>>>0<d>>>0)+d|0)|0,c,0);mb=lb;a=d^kb;b=a-d|0;mb=(d^mb)-((a>>>0<d>>>0)+d|0)|0;return b}function N0(a,b){a=a|0;b=b|0;var c=0,d=0;c=v[a+40>>2];while(1){if(c){c=c-1|0;d=c<<2;nb[v[v[a+32>>2]+d>>2]](b,a,v[d+v[a+36>>2]>>2]);continue}break}}function KU(a){t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0}function $x(a,b,c,d){var e=0;e=jb-16|0;jb=e;a=Fq(e,a,d);c=c-b|0;if((c|0)>0){tc(v[a+4>>2],b,c);v[a+4>>2]=v[a+4>>2]+B((c>>>0)/6|0,6)}kc(a);jb=e+16|0}function jC(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+7|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0}function hL(a,b){var c=0;c=v[b+4>>2];if(v[a>>2]==(b|0)){v[a>>2]=c}if(c){v[c+8>>2]=v[b+8>>2]}a=v[b+8>>2];if(a){v[a+4>>2]=c}v[b+4>>2]=0;v[b+8>>2]=0}function G7(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0,f=C(0);if(b>>>0<=1){c=Xd(c,C(0));if((b|0)==1){d=1;c=Vh(c)}e=Db(a+4208|0,d),f=c,z[e>>2]=f;LK(a)}}function G5(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=jb-32|0;jb=h;i=h+8|0;YI(i,b,c,d,e,f,g);$c(a,i);wm(i);jb=h+32|0}function aca(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-32|0;jb=c;t[c+24|0]=b;b=c+24|0;Xq(c+16|0,b);d=v[c+16>>2];Xq(c+8|0,b);Lk(a,d,v[c+12>>2]);jb=c+32|0}function W9(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-32|0;jb=c;u[c+24>>1]=b;b=c+24|0;Wm(c+16|0,b);d=v[c+16>>2];Wm(c+8|0,b);Lk(a,d,v[c+12>>2]);jb=c+32|0}function Lw(a){var b=0,c=0;b=jb-16|0;jb=b;c=-1;a:{if(Xw(a)){break a}if((nb[v[a+32>>2]](a,b+15|0,1)|0)!=1){break a}c=w[b+15|0]}jb=b+16|0;return c}function GL(a){var b=0;b=jb-16|0;jb=b;z[b+12>>2]=D(a);v[b+8>>2]=646978941;v[b+4>>2]=1259902592;a=z[kq(b+12|0,b+8|0,b+4|0)>>2];jb=b+16|0;return a}function DH(a){var b=0,c=0;v[23588]=0;c=ga(1096)|0;b=v[23588];v[23588]=0;if((b|0)!=1){b=a;a=v[c>>2];v[b>>2]=a;bn(a);return}V(0)|0;O()|0;Ub();L()}function vk(a,b,c,d){var e=0;e=B(b,c);a:{if(v[d+76>>2]<0){a=NB(a,e,d);break a}a=NB(a,e,d)}if((e|0)==(a|0)){return b?c:0}return(a>>>0)/(b>>>0)|0}function gj(a,b,c){if(a>>>0<b>>>0){tc(a,b,c);return}if(c){a=a+c|0;b=b+c|0;while(1){a=a-1|0;b=b-1|0;t[a|0]=w[b|0];c=c-1|0;if(c){continue}break}}}function Wz(a,b){a=a|0;b=b|0;var c=0;v[a>>2]=0;v[a+4>>2]=0;Gc(a+8|0);c=ed(v[b>>2],v[b+4>>2]);if(c){Nl(a,c);ju(a,v[b>>2],v[b+4>>2],c)}return a|0}function P6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(!b){Ax(a,0,0,0,0,0,0,c,d);return}Ax(a,v[b>>2],v[b+4>>2],v[b+8>>2],v[b+12>>2],v[b+24>>2],b,c,d)}
function JN(a,b){t[a+840|0]=b;t[a+812|0]=b;t[a+811|0]=b;t[a+809|0]=b;t[a+807|0]=b;t[a+806|0]=b;t[a+833|0]=b;t[a+826|0]=b>>>4;t[a+827|0]=b<<2&60}function $9(a,b){a=a|0;b=b|0;var c=0;v[a>>2]=0;v[a+4>>2]=0;Gc(a+8|0);c=uc(v[b>>2],v[b+4>>2]);if(c){Ak(a,c);tA(a,v[b>>2],v[b+4>>2],c)}return a|0}function yS(a){var b=0;if(!(Rb(a,14984,3)|(w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24))-2147483647>>>0<2147484072)){b=w[a+3|0]<6}return b}function oga(a,b){a=a|0;b=b|0;a:{if(a>>>0>=515){a=Bg(b);Bg(b);break a}a=Rg(b);Rg(b)}while(1){if(a){if(a&1){Zb(b,260)}a=a>>>1|0;continue}break}}function nj(a){var b=0,c=0;b=jb-16|0;jb=b;Cb(b+8|0,a+1074312|0,7);if(Bb(v[v[b+8>>2]>>2],v[b+12>>2])){c=Jm(v[a+480180>>2])^1}jb=b+16|0;return c}function mc(a,b,c,d,e){var f=0,g=0;f=jb-16|0;jb=f;v[f+8>>2]=d;v[f+12>>2]=e;g=v[v[b>>2]+28>>2];v[f>>2]=d;v[f+4>>2]=e;nb[g|0](a,b,c,f);jb=f+16|0}function hz(a){var b=0,c=0;b=jb-16|0;jb=b;v[b+8>>2]=a;c=b+8|0;a=1;while(1){if((a|0)>0){Kg(c);a=a-1|0;continue}break}jb=b+16|0;return v[b+8>>2]}function aR(a,b,c,d){var e=0;e=c&4;a:{b:{if(!(e|(b&255)!=4)){if(c&2){break b}Zc(a,8,1,0,10);return}b=16;if(e){break a}}b=8}Zc(a,b,c&2|1,0,d^1)}function aI(a,b,c,d,e,f){var g=0,h=0;g=v[a+32>>2];if(!w[a+23|0]){v[(c<<2)+g>>2]=b;return}h=g;g=d<<2;v[h+g>>2]=b;t[v[a+8>>2]+d|0]=e;v[f+g>>2]=c}function Vf(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;u[c+24>>1]=0;Wj(c+8|0,c+24|0);vn(c+16|0,a,v[c+8>>2],v[c+12>>2]);Jj(b,x[c+24>>1]);jb=c+32|0}function Tl(a,b){var c=0,d=0;d=v[a+4>>2];c=v[a+8>>2];while(1){if((c|0)!=(d|0)){c=c-b|0;v[a+8>>2]=c;continue}break}b=v[a>>2];if(b){Bc(a);Mb(b)}}function Bka(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;v[c+12>>2]=-1;if(zg(a,c+8|0)){v[c+4>>2]=w[c+8|0];tV(a,b,v[Jb(c+4|0,c+12|0)>>2])}jb=c+16|0}function tt(a,b){var c=0,d=0;d=Af(a,b);while(1){a:{c=d;if(!(c&65535)){c=0;break a}d=c-1|0;if(!xe(a,b,d&65535)){continue}}break}return c&65535}function fi(a){var b=0;a=a*a;b=a*a;return C(a*b*(a*2439044879627741e-20+-.001388676377460993)+(b*.04166662332373906+(a*-.499999997251031+1)))}function eW(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;v[c+12>>2]=-1;if(zg(a,c+8|0)){v[c+4>>2]=w[c+8|0];gC(a,b,v[Jb(c+4|0,c+12|0)>>2])}jb=c+16|0}function cQ(a){var b=0,c=0;c=v[a+4>>2];b=v[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-32|0;v[a+8>>2]=b;continue}break}b=v[a>>2];if(b){_o(a);Mb(b)}}function If(a){a=a|0;var b=0;v[a>>2]=44312;v[v[a+20>>2]>>2]=0;b=v[a+16>>2];v[b+946300>>2]=v[b+946300>>2]-1;v[a+20>>2]=0;kL(a+44|0);return a|0}function GQ(a){var b=0,c=0;c=v[a+4>>2];b=v[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-12|0;v[a+8>>2]=b;continue}break}b=v[a>>2];if(b){_o(a);Mb(b)}}function $m(a,b){var c=0;a=dn(a);v[a>>2]=62268;c=v[b+8>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=c;t[a+16|0]=w[b+16|0];v[a+12>>2]=v[b+12>>2];return a}function pz(a,b,c){var d=0;while(1){if((b|0)!=(c|0)){d=v[a>>2];v[a>>2]=d<<8^v[((w[b|0]^d>>>24)<<2)+29196>>2];b=b+1|0;continue}break}return a}function jba(a,b){a=a|0;b=b|0;a=Ly(a);v[23588]=0;R(804,a|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){b=P()|0;O()|0;Sp(a);T(b|0);L()}return a|0}function G4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=jb-32|0;jb=g;h=g+8|0;ZI(h,b,c,d,e,f);$c(a,g+20|0);wm(h);jb=g+32|0}function CB(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;u[c+14>>1]=1;d=c,e=Dl(a,b),u[d+12>>1]=e;a=x[ke(c+14|0,c+12|0)>>1];jb=c+16|0;return a-1&65535}function jv(a,b){var c=0;a:{if(!b){break a}if(!Pb(v[a>>2],v[a+8>>2],b)){break a}if(b>>>0<=1){c=RC(a,1);break a}c=Rg(a);Zb(a,b-2|0)}return c}function _T(a){var b=0,c=0,d=0;b=jb-16|0;jb=b;c=b,d=bc(a),v[c+12>>2]=d;v[b+8>>2]=236;a=v[Yc(b+12|0,b+8|0)>>2];jb=b+16|0;mb=0;return a-216|0}function Ne(a,b,c){t[a+11|0]=c;t[a+10|0]=b;t[a+12|0]=w[a+12|0]&251;u[a+8>>1]=65535;v[a>>2]=0;v[a+4>>2]=0;t[a+12|0]=w[a+12|0]&252|1;return a}function Nb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;if(b>>>0>=118){tq(12062);L()}e=d+8|0;Cb(e,a,b);Ye(e,c);jb=d+16|0;return a|0}function Io(a,b){var c=0;a:{if(!b){break a}if(!Pb(v[a>>2],v[a+8>>2],b)){break a}if(b>>>0<=3){c=SC(a,b);break a}c=Bg(a);Zb(a,b-4|0)}return c}function Ib(a,b){var c=0;if(ff(w[a+11|0])){Mb(v[a>>2])}c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2];ce(b,0);wd(b,0);return a}function tF(a,b,c,d,e){var f=0;f=c;c=0;a:{if(!d){break a}c=b>>8;if(!(b&1)){break a}c=lw(v[d>>2],c)}nb[v[v[a>>2]+28>>2]](a,f,c+d|0,b&2?e:2)}function oZ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=jb-16|0;jb=a;v[a+12>>2]=e;v[a+8>>2]=d-c;b=Jb(a+12|0,a+8|0);jb=a+16|0;return v[b>>2]}function il(a){var b=0,c=0,d=0;b=jb-16|0;jb=b;c=v[a+24>>2];d=v[a+40>>2];v[b+12>>2]=1;a=v[Yc(a+20|0,b+12|0)>>2];jb=b+16|0;return B(a,c+d|0)}function dd(a){var b=0;b=jb-16|0;jb=b;v[b+12>>2]=a;v[b+8>>2]=-32768;v[b+4>>2]=32767;a=u[Oe(b+8|0,sd(b+12|0,b+4|0))>>1];jb=b+16|0;return a}function Xz(a,b){var c=0,d=0;v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=v[b+8>>2];v[b>>2]=0;v[b+4>>2]=0;c=Fb(b),d=0,v[c>>2]=d;return a}function Vz(a){a=50-(B(w[(a>>>4|0)+31536|0],a&15)>>>4|0)|0;a=a>>>0>23863?65536:23863/(a>>>0)|0;return Hc((a+119315e4>>>0)/(a<<1>>>0)|0,0)}function Lj(a,b,c){var d=0,e=0,f=0;d=jb-16|0;jb=d;t[d+15|0]=b;t[d+14|0]=127;e=a,f=w[Wb(d+15|0,d+14|0)|0]|(c?-128:0),t[e+21|0]=f;jb=d+16|0}function Kj(a,b,c){var d=0,e=0,f=0;d=jb-16|0;jb=d;t[d+15|0]=b;t[d+14|0]=127;e=a,f=w[Wb(d+15|0,d+14|0)|0]|(c?-128:0),t[e+22|0]=f;jb=d+16|0}function Eba(a){a=a|0;var b=0;b=v[a>>2];if(nb[v[v[b>>2]+32>>2]](b,0,32)|0){a=v[a>>2];a=nb[v[v[a>>2]+32>>2]](a,32,1)^1}else{a=0}return a|0}function f9(a,b){a=a|0;b=b|0;var c=0;b=jb-16|0;jb=b;c=v[a+20>>2];re(b,v[c+4>>2],v[c+8>>2]);mL(a,gc(b+8|0,v[b>>2],v[b+4>>2]),0);jb=b+16|0}function Yw(a,b){var c=0;if(b>>>0<=99){return KH(a,b)}if(b>>>0<=999){c=a;a=(b>>>0)/100|0;return js(JH(c,a),B(a,-100)+b|0)}return dj(a,b)}function PE(a,b,c){var d=0;while(1){if((a|0)!=(b|0)){d=v[a>>2];if(d>>>0<=127){d=v[(d<<2)+c>>2]}v[a>>2]=d;a=a+4|0;continue}break}return b}function EU(a){var b=0,c=0,d=0;c=jb-16|0;jb=c;b=c+8|0;yv(b,a);a=w[Kb(b,0)|0];d=w[Kb(b,1)|0];b=w[Kb(b,2)|0];jb=c+16|0;return a|d<<8|b<<16}function mA(a){var b=0;b=Hb(w[a+26|0]|w[a+27|0]<<8);return((w[a+24|0]>15)+(w[a+25|0]>64)|0)+(Hb(w[a+22|0]|w[a+23|0]<<8)<<1>>>0<b>>>0)|0}function hd(a,b){var c=0,d=0,e=0;c=eg(a,b);if(c){v[a+12>>2]=v[a+12>>2]+b;return c}d=a,e=nb[v[v[a>>2]+24>>2]](a)|0,v[d+12>>2]=e;return c}function eN(a,b,c,d){var e=0;e=a+1074376|0;Ty(a,e,b,c,d);e=0-w[(B(b,872)+e|0)+1428|0]|0;if(d){c=0}else{c=ft(v[a+480180>>2])}Pn(a,b,e,c)}function Zq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if((b|0)<0){bd();L()}b=(b-1>>>5|0)+1|0;c=XC(b);v[a+4>>2]=0;v[a>>2]=c;d=Fb(a),e=b,v[d>>2]=e}function E5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=jb-32|0;jb=g;h=g+8|0;ZI(h,b,c,d,e,f);$c(a,h);wm(h);jb=g+32|0}function A1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=b;b=v[b>>2]+7&-8;v[c>>2]=b+16;d=a,e=Hw(v[b>>2],v[b+4>>2],v[b+8>>2],v[b+12>>2]),A[d>>3]=e}function ns(a,b){var c=0,d=0;a:{if(b>>>0<=31){d=v[a+4>>2];c=a;break a}b=b-32|0;c=a+4|0}c=v[c>>2];v[a+4>>2]=d>>>b;v[a>>2]=d<<32-b|c>>>b}function Xl(a){var b=0,c=0;c=v[a+4>>2];b=v[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-1|0;v[a+8>>2]=b;continue}break}a=v[a>>2];if(a){Mb(a)}}function u2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Cx(v[a+32>>2],b,c,d,2);if(a>>>0<=15){a=w[a+43728|0]}else{a=0}return(a>>>0<5?a+1|0:0)|0}function Z8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(!(!d|!_c(c&255))){pL(a,8,C(0))}a=kj(a);if(a){nb[v[v[a>>2]+96>>2]](a,b,c,d,e)}}function JE(a,b,c,d){a=Sb(a);v[23588]=0;U(d|0,a|0,b|0,c|0);b=v[23588];v[23588]=0;if((b|0)!=1){return a}b=P()|0;O()|0;vc(a);T(b|0);L()}function nS(a){var b=0;b=jb-16|0;jb=b;v[b+12>>2]=a;v[b+8>>2]=-128;v[b+4>>2]=127;a=t[Oe(b+8|0,sd(b+12|0,b+4|0))|0];jb=b+16|0;return a}function Yh(a,b,c){t[a|0]=b;t[a+1|0]=b>>>8;t[a+2|0]=b>>>16;t[a+3|0]=b>>>24;t[a+4|0]=c;t[a+5|0]=c>>>8;t[a+6|0]=c>>>16;t[a+7|0]=c>>>24}function Vi(a,b){var c=0;if(ef(a)){c=v[a>>2];Kl(a);Mb(c)}c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2];ce(b,0);ud(b,0)}function OE(a,b,c){var d=0;while(1){if((a|0)!=(b|0)){d=t[a|0];if((d|0)>=0){d=v[(d<<2)+c>>2]}t[a|0]=d;a=a+1|0;continue}break}return b}function Hba(a,b){a=a|0;b=b|0;a=Mu(a,b);if(!a){t[b+6|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b|0]=0;t[b+1|0]=0}return a|0}function ls(a,b){var c=0,d=0;a:{if(b>>>0<=31){d=v[a>>2];c=a+4|0;break a}b=b-32|0;c=a}c=v[c>>2];v[a>>2]=d<<b;v[a+4>>2]=c<<b|d>>>32-b}function kj(a){var b=0,c=0;b=Ym(v[v[a+20>>2]+28>>2]);if(!(b>>>0>249|w[a+4200|0]>=b>>>0)){c=v[Ld(v[a+16>>2]+906300|0,b)>>2]}return c}function hq(a,b){var c=0,d=0,e=0;if(sh(2147483647)>>>0<b>>>0){bd();L()}c=$C(b);v[a>>2]=c;v[a+4>>2]=c;d=Fb(a),e=(b<<1)+c|0,v[d>>2]=e}function fN(a,b,c,d){var e=0;e=a+1074376|0;Uy(a,e,b,c,d);e=w[(B(b,872)+e|0)+1427|0];if(d){c=0}else{c=ft(v[a+480180>>2])}Pn(a,b,e,c)}function _D(a){a=a|0;var b=0;a=Lb(a);v[23588]=0;R(136,a|0,13608);b=v[23588];v[23588]=0;if((b|0)==1){b=P()|0;O()|0;zb(a);T(b|0);L()}}function Zf(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;if(b>>>0>=118){tq(12027);L()}d=c+8|0;Cb(d,a,b);Ye(d,0);jb=c+16|0;return a|0}function W7(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;if(b>>>0<=4){c=Xd(c,C(0));d=((b<<2)+a|0)+4220|0;if((b|0)==4){c=Vh(c)}z[d>>2]=c;NK(a)}}function Tw(a){a=a|0;var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return nb[v[v[a>>2]+40>>2]](a)|0}v[a+12>>2]=b+1;return yf(t[b|0])|0}function Ph(a,b){var c=0,d=0;c=v[a>>2];d=v[a+4>>2];b=v[a+16>>2]+b|0;a=v[a+12>>2];b=(b|0)%(a|0)|0;return z[Oc(c,d,(b>>31&a)+b|0)>>2]}function Ak(a,b){var c=0,d=0,e=0;if(sh(1073741823)>>>0<b>>>0){bd();L()}c=Bi(b);v[a>>2]=c;v[a+4>>2]=c;d=Fb(a),e=(b<<2)+c|0,v[d>>2]=e}function u1(a){a=a|0;var b=0;if((nb[v[v[a>>2]+36>>2]](a)|0)!=-1){b=a;a=v[a+12>>2];v[b+12>>2]=a+1;a=yf(t[a|0])}else{a=-1}return a|0}function nba(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;if(b>>>0>=250){tq(12062);L()}d=c+8|0;Cb(d,a,b);oo(d);jb=c+16|0;return a|0}function mz(a,b){var c=0,d=0,e=0;if(sh(536870911)>>>0<b>>>0){bd();L()}c=CD(b);v[a>>2]=c;v[a+4>>2]=c;d=Fb(a),e=(b<<3)+c|0,v[d>>2]=e}function lu(a,b){var c=0,d=0,e=0;if(sh(715827882)>>>0<b>>>0){bd();L()}c=eT(b);v[a>>2]=c;v[a+4>>2]=c;d=Fb(a),e=B(b,6)+c|0,v[d>>2]=e}function FO(a,b){var c=0,d=0,e=0;if(sh(268435455)>>>0<b>>>0){bd();L()}c=dQ(b);v[a>>2]=c;v[a+4>>2]=c;d=Fb(a),e=(b<<4)+c|0,v[d>>2]=e}function $H(a,b){a:{if(a&255){a=1;if((b|0)!=255){break a}aa(14180,13110,1180,5737);L()}if((b|0)==255){return 0}a=b>>>0>10}return a}function sg(a){var b=0;b=jb-16|0;jb=b;v[b+12>>2]=a;v[b+8>>2]=0;v[b+4>>2]=255;a=w[Oe(b+8|0,sd(b+12|0,b+4|0))|0];jb=b+16|0;return a}function PC(a,b){var c=0;c=Lka(b&255,0,1536,0);b=mb;a=Lka(a&255,0,25,0);c=a+c|0;b=mb+b|0;b=a>>>0>c>>>0?b+1|0:b;a=c;mb=b;return a}function tW(a,b){a=a|0;b=b|0;v[a+4>>2]=b;t[a|0]=0;b=v[v[b>>2]-12>>2]+b|0;if(Yg(b)){b=v[b+72>>2];if(b){$q(b)}t[a|0]=1}return a|0}function mq(a,b){var c=0;c=yd(v[a+4>>2],w[a+11|0]);if((c|0)==(yd(v[b+4>>2],w[b+11|0])|0)){a=Rv(od(a),od(b),c)}else{a=1}return!a}function lz(a,b){var c=0;c=v[a+484360>>2];b=b&255;if(rj(c,v[a+484364>>2])>>>0<=b>>>0){return Vb(c,w[a+484376|0])}return xj(c,b)}function le(a){var b=0;a=v[a+4>>2];if(a){if(fn(a)){a:{b=a+8|0;if(v[b>>2]){if((Fv(b)|0)!=-1){break a}}nb[v[v[a>>2]+16>>2]](a)}}}}function lG(a,b,c,d,e,f){a=nb[v[v[a+8>>2]+4>>2]](a+8|0)|0;a=Tr(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){v[b>>2]=((a|0)/12|0)%12}}function iG(a,b,c,d,e,f){a=nb[v[v[a+8>>2]+4>>2]](a+8|0)|0;a=Rr(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){v[b>>2]=((a|0)/12|0)%12}}function hx(a,b,c){var d=0;d=v[a+32>>2];if(y[a+40>>2]<d+c>>>0){v[a+96>>2]=1;return 0}tc(b,d,c);v[a+32>>2]=v[a+32>>2]+c;return 1}function g1(a){a=a|0;var b=0;if((nb[v[v[a>>2]+36>>2]](a)|0)!=-1){b=a;a=v[a+12>>2];v[b+12>>2]=a+4;a=v[a>>2]}else{a=-1}return a|0}function fZ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){v[d>>2]=t[b|0];d=d+4|0;b=b+1|0;continue}break}return c|0}function d1(a,b){a=a|0;b=b|0;v[a+4>>2]=b;t[a|0]=0;b=v[v[b>>2]-12>>2]+b|0;if(Yg(b)){b=v[b+72>>2];if(b){rH(b)}t[a|0]=1}return a|0}function QN(a,b,c,d){a:{if(d>>>0>=64){d=-1;if(w[a+480180|0]&2){break a}}v[b+56>>2]=0;d=Vn(a,x[b+70>>1],v[b+48>>2],c,0)}return d}function ME(a,b,c){var d=0;d=jb-16|0;jb=d;v[d+8>>2]=a;v[d+12>>2]=b;v[d>>2]=c;v[d+4>>2]=0;a=Yq(d+8|0,d);jb=d+16|0;return v[a>>2]}function zq(a){var b=0;b=-1;a:{if(a>=4294967295){break a}b=0;if(a<=0){break a}if(a<4294967296&a>=0){return~~a>>>0}b=0}return b}function zE(a,b,c){a=Vh(a);a:{if(a>=b){break a}c=0;if(a<=C(0)){break a}if(a<C(4294967296)&a>=C(0)){c=~~a>>>0;break a}}return c}function rZ(a){a=a|0;var b=0;b=jb-16|0;jb=b;ii(ji(b+8|0,v[a+8>>2]));jb=b+16|0;a=v[a+8>>2];if(!a){return 1}return(DF(a)|0)==1|0}function hC(a,b){var c=0;c=v[b+4>>2];if(c){fc(a,c,v[b>>2]);return}c=v[b+8>>2];b=v[b+12>>2];if(!oc(c,b)){re(a,c,b);return}ee(a)}function aP(a,b,c,d,e){v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;if(b){Fd(b,a)}if(c){Fd(c,a)}if(d){Fd(d,a)}if(e){Fd(e,a)}}function aE(){var a=0,b=0,c=0;a=jb-16|0;jb=a;b=Mc(a,15351);if(Gb(b)){c=(Dg(b,13813)|0)!=-1}else{c=0}yb(b);jb=a+16|0;return c|0}function ZY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){t[d|0]=w[b|0];d=d+1|0;b=b+1|0;continue}break}return c|0}function TJ(a){a=a|0;var b=0,c=0;b=jb-16|0;jb=b;c=CJ(sc(8));v[c+4>>2]=a;v[c>>2]=57800;a=v[Lf(b+8|0,c)>>2];jb=b+16|0;return a|0}function Rs(a){var b=0;b=A[a+4248>>3]/+y[v[a+16>>2]+24620>>2];A[a+4264>>3]=b;if(w[a+4240|0]){A[a+4264>>3]=b*(A[a+4288>>3]/60)}}function wl(a,b){var c=0;a:{if(y[a+12>>2]<b>>>0){c=0;if(nb[v[v[a>>2]+24>>2]](a)>>>0<b>>>0){break a}}v[a+12>>2]=b;c=1}return c}function pw(a,b){var c=0,d=0,e=0,f=0;c=xg(b);d=sc(c+13|0);v[d+8>>2]=0;v[d+4>>2]=c;v[d>>2]=c;e=a,f=tc(Bc(d),b,c+1|0),v[e>>2]=f}function Rq(a,b){return po(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24),w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))?b:a}function OS(a,b){var c=0;c=jb-16|0;jb=c;a=Ah(c,a,1);Hm(v[a+4>>2],x[b>>1]|x[b+2>>1]<<16);v[a+4>>2]=v[a+4>>2]+4;kc(a);jb=c+16|0}function GY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(Zg(a,v[b+8>>2],0)){mw(b,c,d);return}a=v[a+8>>2];nb[v[v[a>>2]+28>>2]](a,b,c,d)}function vU(a){var b=0;a:{if(Rb(a,3863,4)){break a}if(Rb(a+44|0,17805,3)){break a}b=(w[a+47|0]|w[a+48|0]<<8)>>>0>97}return b}function mG(a,b,c,d,e,f){a=nb[v[v[a+8>>2]>>2]](a+8|0)|0;a=Tr(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){v[b>>2]=((a|0)/12|0)%7}}function jg(a,b,c){var d=0;d=4;a:{b:{switch(b-1|0){case 0:d=c;break a;case 1:break b;default:break a}}d=c?3:2}return ao(a,d)}function jG(a,b,c,d,e,f){a=nb[v[v[a+8>>2]>>2]](a+8|0)|0;a=Rr(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){v[b>>2]=((a|0)/12|0)%7}}function fl(a,b,c,d){var e=0;e=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=e;e=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=e;cy(a,c,d)}function cO(a){Xy(a);v[a>>2]=0;v[a+4>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;a=Xf(a);Xf(a+12|0);t[a+24|0]=1}function Xc(a,b,c){var d=0;d=a;a=c&31;if((c&63)>>>0>=32){c=b>>31;a=b>>a}else{c=b>>a;a=((1<<a)-1&b)<<32-a|d>>>a}mb=c;return a}function DS(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;u[c+14>>1]=b;if((Dl(v[a>>2],v[a+4>>2])|0)!=65535){YB(a,c+14|0)}jb=c+16|0}function rc(a,b){var c=0;a=km(a);v[a+4>>2]=0;v[a>>2]=49120;c=Od(Gb(b)+1|0);v[a+4>>2]=c;if(c){tc(c,Lc(b),Gb(b)+1|0)}return a}function hH(a,b){var c=0;c=jb-32|0;jb=c;a=rl(c+24|0,_G(c+16|0,Yr(c+8|0,a,b)));b=v[a+4>>2];a=v[a>>2];jb=c+32|0;mb=b;return a}function JK(a){a=a|0;var b=0,c=0;b=a+4960|0;c=a+4504|0;while(1){b=vc(b-24|0);if((c|0)!=(b|0)){continue}break}return If(a)|0}function z9(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0;if(b>>>0<=3){d=(a+b|0)+4264|0,e=jh(C(Xd(c,C(0))*C(255))),t[d|0]=e;Ts(a)}}function xo(a){v[a+32>>2]=0;v[a+24>>2]=0;v[a+28>>2]=0;v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[a+16>>2]=0;return a}function nu(a,b,c){c=c&255;while(1){a:{if(!b){a=0;break a}if(oc(w[a|0],c)){break a}b=b-1|0;a=a+1|0;continue}break}return a}function hM(a,b){var c=0;if(!(w[a|0]!=w[b|0]|A[a+8>>3]!=A[b+8>>3]|w[a+16|0]!=w[b+16|0])){c=v[a+20>>2]==v[b+20>>2]}return c}function Yha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;v[a>>2]=0;v[a+4>>2]=0;Gc(a+8|0);d=b+c|0;c=Rh(b,d);if(c){Nl(a,c);ju(a,b,d,c)}}function RQ(a){var b=0,c=0;while(1){b=c;if((b|0)!=8){c=b+1|0;if((w[a+b|0]-127&255)>>>0>160){continue}}break}return(b|0)==8}function F8(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0;if(b>>>0<=2){d=(a+b|0)+4232|0,e=jh(C(Xd(c,C(0))*C(127))),t[d|0]=e;Ps(a)}}function AE(a,b){v[a>>2]=b;DH(a+4|0);v[a+24>>2]=0;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function $z(a){v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function oe(a,b,c){var d=0;a:{if((b|0)>(c|0)){break a}d=v[a>>2];if((d|0)>=(b|0)){b=c;if((d|0)<=(b|0)){break a}}v[a>>2]=b}}function Po(a,b,c){var d=0;a:{if(b>>>0>c>>>0){break a}d=v[a>>2];if(d>>>0>=b>>>0){b=c;if(d>>>0<=b>>>0){break a}}v[a>>2]=b}}function uL(a,b,c){var d=0,e=0;d=ad(a);if(d>>>0>=c>>>0){Vx(a,Wh(zc(a),b,c),c);return}e=a;a=Gb(a);hp(e,d,c-d|0,a,0,a,c,b)}function sP(a,b,c,d,e,f,g){t[a+17|0]=g;t[a+16|0]=f;v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;if(d){oP(a,1);oP(a,0)}}function rP(a,b,c,d,e,f,g){t[a+17|0]=g;t[a+16|0]=f;v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;if(d){qP(a,1);qP(a,0)}}function oQ(a){var b=0;if(!(w[a+35|0]&2)){a=a+68|0;b=9;while(1){if(b){v[a>>2]=268435456;b=b-1|0;a=a+4|0;continue}break}}}function nH(a){var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return nb[v[v[a>>2]+40>>2]](a)|0}v[a+12>>2]=b+4;return v[b>>2]}function lS(a,b){var c=0;c=jb-16|0;jb=c;a:{if(!eg(a,4)){_S(b);break a}Jh(c+8|0,b);lA(c,a,v[c+8>>2],v[c+12>>2])}jb=c+16|0}function C2(a,b,c){a=a|0;b=b|0;c=c|0;while(1){if((a|0)!=(b|0)){xh(v[c>>2],a);v[c>>2]=v[c>>2]+12;a=a+12|0;continue}break}}function $g(a,b,c,d,e){var f=0;f=jb-16|0;jb=f;v[f+12>>2]=e;c=ji(f+8|0,c);a=Vr(a,b,d,v[f+12>>2]);ii(c);jb=f+16|0;return a}function wi(a,b,c){c=w[c|0];while(1){a:{if((a|0)!=(b|0)){if((c|0)!=w[a|0]){break a}}else{a=b}return a}a=a+1|0;continue}}function vt(a){var b=0,c=0,d=0;d=a*a;a=0;b=1;c=1;while(1){a=a+2;c=d*c/(a*a);b=b+c;if(b*1e-7<c){continue}break}return b}function jY(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=b;b=0;return nb[a|0](h|b,c,d,e,b|f,g)|0}function _e(a){var b=0;b=v[a+32>>2];a:{if(b>>>0>=y[a+40>>2]){v[a+96>>2]=1;a=0;break a}v[a+32>>2]=b+1;a=w[b|0]}return a}function Nl(a,b){var c=0,d=0,e=0;if(sh(-1)>>>0<b>>>0){bd();L()}c=sc(b);v[a>>2]=c;v[a+4>>2]=c;d=Fb(a),e=b+c|0,v[d>>2]=e}function JR(a){var b=0;if(!(Rb(a,13765,3)|w[a+3|0]>31|(t[a+27|0]<0|w[a+32|0]>64))){b=(w[a+33|0]-1&255)>>>0<32}return b}function HT(a,b,c){var d=0;while(1){if(b){d=w[c|0]|w[c+1|0]<<8;t[a|0]=d;t[a+1|0]=d>>>8;b=b-1|0;a=a+2|0;continue}break}}function FN(a,b,c,d){var e=0,f=0;if(c&255){e=a,f=Xb(v[a>>2]+((B((d^-1|-256)+b|0,c<<24>>24)|0)/2|0)|0,0,256),v[e>>2]=f}}function qG(a,b,c){var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;b=ji(d+8|0,b);a=QG(a,9222,v[d+12>>2]);ii(b);jb=d+16|0;return a}function Ji(a){var b=0;while(1){a:{if((b|0)!=46){if(w[b+43760|0]!=(a|0)){break a}}else{b=0}return b}b=b+1|0;continue}}function DE(a,b,c){a=we(a);a:{if(a>=b){break a}c=0;if(a<=0){break a}if(a<4294967296&a>=0){c=~~a>>>0;break a}}return c}function zP(a){v[a+700>>2]=0;u[a+842>>1]=0;v[a+688>>2]=0;v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[a+16>>2]=0}function rV(a){var b=0,c=0;c=v[a>>2];b=v[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-28|0;zd(b);continue}break}v[a+4>>2]=c}function l7(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=C(0);if(b>>>0<=2){c=Xd(c,C(0));d=Db(a+4208|0,b),e=c,z[d>>2]=e;EK(a)}}function i8(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=C(0);if(b>>>0<=5){c=Xd(c,C(0));d=Db(a+4208|0,b),e=c,z[d>>2]=e;TK(a)}}function i0(a){a=a|0;var b=0,c=0;c=v[a+4>>2];b=v[a>>2];a=v[a+8>>2];b=b+(a>>1)|0;if(a&1){c=v[c+v[b>>2]>>2]}nb[c|0](b)}function d7(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=C(0);if(b>>>0<=3){c=Xd(c,C(0));d=Db(a+4208|0,b),e=c,z[d>>2]=e;CK(a)}}function b8(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=C(0);if(b>>>0<=4){c=Xd(c,C(0));d=Db(a+4208|0,b),e=c,z[d>>2]=e;PK(a)}}function Wo(a){var b=0,c=0;c=v[a>>2];b=v[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-36|0;ir(b);continue}break}v[a+4>>2]=c}function Ng(a){var b=0;Dm(a);b=Jt(v[a>>2],Ek(x[a+34>>1]));v[a+20>>2]=b;if(!b){return 0}return Hj(v[a>>2],x[a+34>>1])}function vO(a){var b=0,c=0,d=0;if(v[a>>2]){Kc(a);b=v[a>>2];gn(a);Mb(b);c=Fb(a),d=0,v[c>>2]=d;v[a>>2]=0;v[a+4>>2]=0}}function sh(a){var b=0;b=jb-16|0;jb=b;v[b+12>>2]=a;v[b+8>>2]=2147483647;a=Jb(b+12|0,b+8|0);jb=b+16|0;return v[a>>2]}function ou(a){var b=0,c=0,d=0;if(v[a>>2]){Kc(a);b=v[a>>2];Uh(a);Mb(b);c=Fb(a),d=0,v[c>>2]=d;v[a>>2]=0;v[a+4>>2]=0}}function mP(a){var b=0,c=0,d=0;if(v[a>>2]){Kc(a);b=v[a>>2];Xm(a);Mb(b);c=Fb(a),d=0,v[c>>2]=d;v[a>>2]=0;v[a+4>>2]=0}}function WL(a){var b=0,c=0,d=0;if(v[a>>2]){Kc(a);b=v[a>>2];Cu(a);Mb(b);c=Fb(a),d=0,v[c>>2]=d;v[a>>2]=0;v[a+4>>2]=0}}function VG(a,b,c,d,e,f,g,h,i){v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=d;v[a+12>>2]=e&65535|(i>>>16&32768|e>>>16&32767)<<16}function Hu(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;Sm(d+8|0,b);v[d+4>>2]=v[d+8>>2];xu(a,d+4|0,c);jb=d+16|0}function Ei(a){var b=0;b=jb-16|0;jb=b;v[b+12>>2]=a;v[b+8>>2]=2147483647;a=v[Jb(b+12|0,b+8|0)>>2];jb=b+16|0;return a}function vV(a,b,c,d,e){t[a+4|0]=b;t[a|0]=69;t[a+1|0]=99;t[a+2|0]=104;t[a+3|0]=111;t[a+7|0]=e;t[a+6|0]=d;t[a+5|0]=c}function tc(a,b,c){var d=0;if(c){d=a;while(1){t[d|0]=w[b|0];d=d+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}return a}function eR(a){var b=0;if(!(Rb(a+44|0,13774,4)|w[a+29|0]!=16)){b=((w[a+42|0]|w[a+43|0]<<8)-1&65535)>>>0<2}return b}function ZH(a,b,c){var d=0,e=0,f=0;e=c*c;A[a>>3]=e;f=c;d=c*134217729;c=d+(c-d);d=f-c;A[b>>3]=d*d+((c+c)*d+(c*c-e))}function Dd(a,b){var c=0;c=b+4|0;dq(v[a>>2],v[a+4>>2],c);pc(a,c);pc(a+4|0,b+8|0);pc(Fb(a),Bc(b));v[b>>2]=v[b+4>>2]}function tH(a,b){a=a|0;b=b|0;var c=0;c=v[a>>2];a:{if(!c){break a}if(!oc(xH(c,b),-1)){break a}v[a>>2]=0}return a|0}function lM(a,b){var c=0,d=0;c=v[a+4>>2];d=v[b+4>>2];if((c|0)==(d|0)){a=aN(v[a>>2],c,v[b>>2],d)}else{a=1}return!a}function hl(a,b){var c=0;c=b&15;if(c){t[a+824|0]=c<<2}b=b&240;if(b){t[a+823|0]=b>>>4}v[a+88>>2]=v[a+88>>2]|131072}function Sr(a,b){a:{if((a|0)==(b|0)){break a}while(1){b=b-4|0;if(b>>>0<=a>>>0){break a}pc(a,b);a=a+4|0;continue}}}function ON(a,b){var c=0;c=b&15;if(c){t[a+827|0]=c<<2}b=b&240;if(b){t[a+826|0]=b>>>4}v[a+88>>2]=v[a+88>>2]|262144}function OK(a){a=a|0;v[a+4244>>2]=0;v[a+4248>>2]=0;v[a+4228>>2]=0;v[a+4232>>2]=0;a=a+4252|0;v[a>>2]=0;v[a+4>>2]=0}function $l(a,b){a:{if((a|0)==(b|0)){break a}while(1){b=b-1|0;if(b>>>0<=a>>>0){break a}Ii(a,b);a=a+1|0;continue}}}function eQ(a){var b=0,c=0;c=v[a+4>>2];b=v[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-4|0;v[a+8>>2]=b;continue}break}}function X3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(a){c=a;a=nb[v[v[b>>2]+8>>2]](b)|0;d=c,e=fg(a?a:21619),v[d>>2]=e}}function AQ(a){if(Rb(a,13747,4)){a=0}else{a=(bc(w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24))|0)==1}return a}function ww(a,b,c){while(1){a:{if((a|0)!=(b|0)){if(v[a>>2]!=(c|0)){break a}}else{a=b}return a}a=a+4|0;continue}}function vm(a,b){var c=0;c=1;a:{switch((b&255)-4|0){default:c=(a&255)==11;break;case 0:case 2:break a}}return c}function bj(a){a:{a=v[a+4>>2]&74;if(a){if((a|0)==64){return 8}if((a|0)!=8){break a}return 16}return 0}return 10}function Tm(a){a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);return a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)}function K0(a,b){a=a|0;b=b|0;var c=0,d=0;nb[v[v[a>>2]+24>>2]](a)|0;b=Iw(b);v[a+36>>2]=b;c=a,d=zn(b),t[c+44|0]=d}function D0(a,b){a=a|0;b=b|0;var c=0,d=0;nb[v[v[a>>2]+24>>2]](a)|0;b=Nw(b);v[a+36>>2]=b;c=a,d=zn(b),t[c+44|0]=d}function zF(a,b){var c=0;c=jb-16|0;jb=c;a=Ok(c,a,1);wd(v[a+4>>2],w[b|0]);v[a+4>>2]=v[a+4>>2]+1;kc(a);jb=c+16|0}function Zg(a,b,c){if(!c){return v[a+4>>2]==v[b+4>>2]}if((a|0)==(b|0)){return 1}return!vi(v[a+4>>2],v[b+4>>2])}function Ye(a,b){var c=0;c=v[a+4>>2];if(b){a=v[a>>2];v[a>>2]=v[a>>2]|c;return}a=v[a>>2];v[a>>2]=v[a>>2]&(c^-1)}function SQ(a,b){var c=0;c=b&255;b=c>>>24|0;a=a&255?1120:1056;c=a+(c<<8)|0;b=a>>>0>c>>>0?b+1|0:b;mb=b;return c}function OL(a){var b=0;b=jb-16|0;jb=b;v[b+12>>2]=a;v[b+8>>2]=32767;a=u[Jb(b+12|0,b+8|0)>>1];jb=b+16|0;return a}function NE(a,b){var c=0,d=0;c=a+68|0;a=0;while(1){if((a|0)!=9){d=Db(c,a);a=a+1|0;v[d>>2]=a<<b;continue}break}}function Eu(a,b){var c=0;c=jb-16|0;jb=c;v[c+12>>2]=(B(a,b)>>>0)/255;oe(c+12|0,0,15);jb=c+16|0;return w[c+12|0]}function Cl(a){var b=0;b=jb-16|0;jb=b;v[b+12>>2]=a;v[b+8>>2]=65535;a=x[Jb(b+12|0,b+8|0)>>1];jb=b+16|0;return a}function nM(a,b){a:{switch(b-1|0){default:return a+724|0;case 0:return a+732|0;case 1:break a}}return a+740|0}function kw(a,b,c,d,e,f,g){var h=0;h=b>>8;if(b&1){h=lw(v[e>>2],h)}nb[v[v[a>>2]+20>>2]](a,c,d,e+h|0,b&2?f:2,g)}function jl(a,b,c,d){var e=0;e=jb-16|0;jb=e;v[e+12>>2]=d;v[e+8>>2]=c;gc(a,b,v[Jb(e+12|0,e+8|0)>>2]);jb=e+16|0}function GM(a,b){var c=0;c=jb-16|0;jb=c;a=Iz(c,a);fq(v[a+4>>2],v[b>>2]);v[a+4>>2]=v[a+4>>2]+4;kc(a);jb=c+16|0}function Dp(a,b){var c=0;c=jb-32|0;jb=c;Jh(c+16|0,b);vn(c+24|0,a,v[c+16>>2],v[c+20>>2]);Jh(c+8|0,b);jb=c+32|0}function Au(a){var b=0;b=jb-16|0;jb=b;u[b+14>>1]=a;u[b+12>>1]=255;a=w[Vc(b+14|0,b+12|0)|0];jb=b+16|0;return a}function zH(a){var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return nb[v[v[a>>2]+36>>2]](a)|0}return yf(t[b|0])}function kG(a,b,c,d,e){b=Xi(b,c,d,e,4);if(!(w[d|0]&4)){v[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)-1900}}function hG(a,b,c,d,e){b=Wi(b,c,d,e,4);if(!(w[d|0]&4)){v[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)-1900}}function ada(){var a=0;a=jb-16|0;jb=a;if(bb(a+12|0,4)|0){is(v[116064],12562);L()}jb=a+16|0;return v[a+12>>2]}function Zw(a,b){var c=0;if(b>>>0<=9999){return Yw(a,b)}c=a;a=(b>>>0)/1e4|0;return dj(Yw(c,a),B(a,-1e4)+b|0)}function ZO(a){var b=0;b=v[a+4>>2];u[a+70>>1]=w[((x[b+20>>1]>>>6|x[b+22>>1]<<4)&65535)+29056|0]>>>x[a+68>>1]}function ym(a,b){var c=0;c=jb-16|0;jb=c;v[c+8>>2]=a;a=c+8|0;v[a>>2]=v[a>>2]+(b<<2);jb=c+16|0;return v[a>>2]}function qha(a,b){a=a|0;b=b|0;if(!MS(a,b)){t[b+4|0]=0;t[b+5|0]=0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0}}function oI(a,b,c,d){z[d+4>>2]=a+c;a=C(a+C(c*C(-.5)));b=C(b*C(.8660253882408142));z[d+8>>2]=a-b;z[d>>2]=b+a}function ll(a,b,c,d){a=a&65535;c=c&65535;a=(a|0)==(c|0)?0:a>>>0<c>>>0?-1:1;if(wj(a)){a=uO(b,d)}return ff(a)}function aS(a,b){t[a+6|0]=255;v[a+16>>2]=0;u[a+4>>1]=0;v[a>>2]=0;if(b>=0){A[a+8>>3]=b;v[a+16>>2]=3}return a}function _x(a,b){a=Sb(a);v[a+20>>2]=0;v[a+12>>2]=0;v[a+16>>2]=0;Sb(a+24|0);Lb(a+36|0);v[a+48>>2]=b;return a}function Ll(a){var b=0;b=jb-16|0;jb=b;v[b+12>>2]=a;v[b+8>>2]=255;a=w[Jb(b+12|0,b+8|0)|0];jb=b+16|0;return a}function yR(a){var b=0;if(!(Rb(a,17800,4)|w[a+5|0]!=16|(w[a+54|0]-33&255)>>>0<224)){b=w[a+4|0]>95}return b}function o4(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return aF(a,b,c,d,e,f,g,12897,1040)|0}function lt(a){var b=0,c=0;while(1){if(b>>>0>=8){a=c<<24>>24}else{b=b+15|0;c=Sn(a);continue}break}return a}function kka(a,b){a=a|0;b=b|0;var c=0;b=jb-80|0;jb=b;c=-1;if(fV(a,b+8|0)){c=eV(b+8|0)}jb=b+80|0;return c|0}function iv(a,b){a:{switch(b-1|0){default:return a+48|0;case 0:return a+68|0;case 1:break a}}return a+88|0}function hha(a,b){a=a|0;b=b|0;var c=0;b=jb-16|0;jb=b;c=-1;if(Qj(a,b+8|0)){c=yS(b+8|0)}jb=b+16|0;return c|0}function gr(a){var b=0;b=jb-16|0;jb=b;a=v[ec(b+8|0,od(a)+yd(v[a+4>>2],w[a+11|0])|0)>>2];jb=b+16|0;return a}function C4(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return aF(a,b,c,d,e,f,g,12829,1033)|0}function Xk(a){var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return nb[v[v[a>>2]+36>>2]](a)|0}return v[b>>2]}function Jr(a,b,c,d,e,f){var g=0;g=b>>8;if(b&1){g=lw(v[d>>2],g)}nb[v[v[a>>2]+24>>2]](a,c,d+g|0,b&2?e:2,f)}function JV(a,b){a=a|0;b=b|0;var c=0;b=jb-16|0;jb=b;c=-1;if(Qj(a,b+8|0)){c=OB(b+8|0)}jb=b+16|0;return c|0}function DO(a,b){var c=0;c=v[a+484344>>2];if(xe(c,v[a+484348>>2],b)){a=v[Yb(c,b)+12>>2]}else{a=1}return a}function CF(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;v[e>>2]=c;v[h>>2]=f;return 3}function yO(a,b){var c=0;c=v[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-12|0;Ve(c);continue}break}v[a+4>>2]=b}function uC(a,b){var c=0;c=v[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-20|0;Ab(c);continue}break}v[a+4>>2]=b}function qga(a,b,c){a=a|0;b=b|0;c=c|0;v[a>>2]=0;v[a+4>>2]=0;Gc(a+8|0);if(b){hq(a,b);Go(a,b,c)}return a|0}function je(a,b){a=Pl(a,v[b>>2],v[b+4>>2]);v[a+8>>2]=v[b+8>>2];Pl(a+12|0,v[b+12>>2],v[b+16>>2]);return a}function gP(a,b){var c=0;c=v[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-32|0;ql(c);continue}break}v[a+4>>2]=b}function Qb(a,b,c){var d=0;c=v[a+4>>2]+c|0;d=b;b=v[a>>2]+b|0;c=d>>>0>b>>>0?c+1|0:c;v[a>>2]=b;v[a+4>>2]=c}function PM(a,b){var c=0;c=v[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-52|0;gl(c);continue}break}v[a+4>>2]=b}function FQ(a,b){var c=0;c=v[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-12|0;EQ(c);continue}break}v[a+4>>2]=b}function xT(a,b,c){a=a|0;b=b|0;c=c|0;v[a>>2]=0;v[a+4>>2]=0;Gc(a+8|0);if(b){lu(a,b);NA(a,b,c)}return a|0}function qW(a,b,c){a=a|0;b=b|0;c=c|0;v[a>>2]=0;v[a+4>>2]=0;Gc(a+8|0);if(b){Ak(a,b);xC(a,b,c)}return a|0}function eO(a,b){var c=0,d=0;a:{if(b<0){break a}c=A[a>>3];if(!(c<0)){d=b;if(!(b<c)){break a}}A[a>>3]=d}}function VY(){if(w[468316]){return v[117078]}wp(468308,IK());t[468316]=1;v[117078]=468308;return 468308}function Om(a,b,c){a=a|0;b=b|0;c=c|0;v[a>>2]=0;v[a+4>>2]=0;Gc(a+8|0);if(b){Nl(a,b);Mo(a,b,c)}return a|0}function LU(a){a:{if(Rb(a,14137,4)){break a}if(Rb(a+8|0,14118,4)){break a}return 1}return!Rb(a,14118,4)}function DF(a){var b=0,c=0;b=jb-16|0;jb=b;a=ji(b+8|0,a);c=v[v[116090]>>2];ii(a);jb=b+16|0;return c?4:1}function yX(a){a=a|0;var b=0,c=0;b=jb-32|0;jb=b;c=-1;if(YD(a,b+8|0)){c=XD(b+8|0)}jb=b+32|0;return c|0}function tB(a,b){if(b>>>0<=126){df(((b<<5)+a|0)+480280|0);eo((B(b,872)+a|0)+1074992|0,a,b,134217728)}}function rB(a){var b=0,c=0;if(v[a>>2]){Kc(a);Mb(v[a>>2]);b=Fb(a),c=0,v[b>>2]=c;v[a>>2]=0;v[a+4>>2]=0}}function cB(a){a=a|0;var b=0;u[a+34>>1]=0;b=a+43|0;om(b,b+22|0,62364);v[a+20>>2]=0;md(a,0);return a|0}function Tb(a,b,c){var d=0;if(c){d=a;while(1){t[d|0]=b;d=d+1|0;c=c-1|0;if(c){continue}break}}return a}function TW(a){a=a|0;var b=0,c=0;b=jb-16|0;jb=b;c=-1;if(Qj(a,b+8|0)){c=tD(b+8|0)}jb=b+16|0;return c|0}function SP(a){if(((w[a+68|0]|w[a+69|0]<<8)-128&65535)>>>0>=65409){a=Rb(a,17648,17)}else{a=1}return!a}function Qq(a,b,c){var d=0;d=jb-16|0;jb=d;if(b){t[d+15|0]=0;pM(a+36|0,b,wi(b,b+c|0,d+15|0))}jb=d+16|0}function IT(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;d=c,e=Hb(b&65535),u[d+14>>1]=e;ZJ(a,c+14|0);jb=c+16|0}function x2(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;fC(c+8|0,b);ar(a,v[c+8>>2],v[c+12>>2]);jb=c+16|0}function qT(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){oT(c+52|0);zb(c+40|0);vc(c+16|0);vc(c+4|0);Mb(c)}}function kS(a){u[a+10>>1]=0;u[a+12>>1]=0;u[a+8>>1]=1084;v[a>>2]=0;v[a+4>>2]=40;u[a+14>>1]=0;return a}function XM(a){v[a+20>>2]=0;t[a+16|0]=7;v[a+8>>2]=1889785610;v[a+12>>2]=1072630333;t[a|0]=3;return a}function UP(a){Yd(a+140|0);Ab(a+120|0);Ab(a+100|0);Ab(a+80|0);Ab(a+60|0);Ab(a+40|0);Ab(a+20|0);Ab(a)}function Sj(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0}function Ru(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0}function Gj(a){a=a|0;var b=0,c=0;b=jb-16|0;jb=b;if(Oo(a,b+8|0)){c=Hb(x[b+8>>1])}jb=b+16|0;return c|0}function EW(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;Um(c+8|0,b);ar(a,v[c+8>>2],v[c+12>>2]);jb=c+16|0}function DW(a,b){a=a|0;b=b|0;v[a>>2]=0;v[a+4>>2]=0;nk(a+8|0,0);Zq(a,127);YC(a,127,w[b|0]);return a|0}function Bo(a){a=a|0;var b=0,c=0;b=jb-16|0;jb=b;if(Ro(a,b+8|0)){c=bc(v[b+8>>2])}jb=b+16|0;return c|0}function t2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Jz(Cx(v[a+32>>2],b,c,d,3));return(a>>>0<5?a+1|0:0)|0}function fT(a,b,c){var d=0;d=c;b=b-a|0;c=v[c>>2]+B((b|0)/-6|0,6)|0;v[d>>2]=c;if((b|0)>0){tc(c,a,b)}}function AM(a,b){if(b>>>0<=255){a=v[((b<<2)+a|0)+900380>>2];a=a?a+492|0:21619}else{a=21619}return a}function $c(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2];sE(b);return a}function $8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=kj(a);if(a){nb[v[v[a>>2]+88>>2]](a,b,c,d,e)}}function yga(a,b){a=a|0;b=b|0;var c=0;b=jb-16|0;jb=b;c=-1;if(vB(a,b)){c=TR(b)}jb=b+16|0;return c|0}function lg(a,b,c){var d=0;d=c;c=v[a>>2];d=v[a+4>>2]-(d+(c>>>0<b>>>0)|0)|0;v[a>>2]=c-b;v[a+4>>2]=d}function kv(a){a=a|0;var b=0;b=jb-16|0;jb=b;a=zg(a,b+15|0);jb=b+16|0;return(a?w[b+15|0]:0)<<24>>24}function X8(a,b,c){a=a|0;b=b|0;c=c|0;a=kj(a);if(!a){return 0}return nb[v[v[a>>2]+104>>2]](a,b,c)|0}function Vga(a){a=a|0;var b=0;b=jb-16|0;jb=b;a=Oo(a,b+8|0);jb=b+16|0;return(a?x[b+8>>1]:0)<<16>>16}function U3(a,b){a=a|0;b=b|0;var c=0;b=Lc(b);c=v[a+4>>2];if(c){nb[c|0](b,v[a+8>>2]);return}Ns(b,a)}function EF(a,b,c,d,e){var f=0;f=jb-16|0;jb=f;e=ji(f+8|0,e);a=Wr(a,b,c,d);ii(e);jb=f+16|0;return a}function BO(a,b,c){var d=0;d=jb-16|0;jb=d;a=v[ec(d+8|0,tO(b,c,Sd(a),ic(a)))>>2];jb=d+16|0;return a}function ox(a,b,c){b=(B(B(mx(a),nx(a,b)),125)>>>0)/(vI(a,b)>>>0)|0;a=(a&6)==6?b&-4:b;return a?a:c}function H6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;nb[v[v[b>>2]+8>>2]](b,c);d=a;a=b+4|0;wp(d,a);fK(a,c)}function vn(a,b,c,d){var e=0;e=jb-16|0;jb=e;_g(e+8|0,c,d);gG(a,b,v[e+8>>2],v[e+12>>2]);jb=e+16|0}function tw(a,b,c,d){var e=0;e=jb-16|0;jb=e;fc(e+8|0,c,d);gG(a,b,v[e+8>>2],v[e+12>>2]);jb=e+16|0}function q1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;nb[v[v[a>>2]+12>>2]](a,b,c,d,e,f)|0}function o1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;nb[v[v[a>>2]+24>>2]](a,b,c,d,e,f)|0}function n1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;nb[v[v[a>>2]+16>>2]](a,b,c,d,e,f)|0}function m1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;nb[v[v[a>>2]+28>>2]](a,b,c,d,e,f)|0}function li(a,b,c){if(c){while(1){v[a>>2]=v[b>>2];a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}}function l1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;nb[v[v[a>>2]+20>>2]](a,b,c,d,e,f)|0}function k1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;nb[v[v[a>>2]+44>>2]](a,b,c,d,e,f)|0}function Zz(a,b,c){b=b-a>>2;while(1){if((b|0)>0){v[a>>2]=v[c>>2];b=b-1|0;a=a+4|0;continue}break}}function YE(a,b,c){var d=0;d=jb-16|0;jb=d;c=Mc(d,c);a=rc(a,c);yb(c);v[a>>2]=b;jb=d+16|0;return a}function J4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return gF(a,b,c,d,e,f,10569,1030)|0}function H5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return gF(a,b,c,d,e,f,10614,1004)|0}function Fp(a,b){var c=0;c=jb-16|0;jb=c;v[c+8>>2]=v[a>>2];a=v[fB(c+8|0,b)>>2];jb=c+16|0;return a}function uv(a,b){a=nD(a,v[b>>2],v[b+4>>2]);v[a+8>>2]=v[b+8>>2];nD(a+12|0,v[b+12>>2],v[b+16>>2])}function jW(a){a=a|0;var b=0;b=v[a+76>>2];if(oc(-1,b)){b=_C(a,32);v[a+76>>2]=b}return b<<24>>24}function XB(a,b){a=a|0;b=b|0;if(!Nu(a,b)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0}}function V0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;nb[v[v[b>>2]+16>>2]](a,b,v[c+8>>2],v[c+12>>2],0,d)}function PV(a,b){a=a|0;b=b|0;if(!Nu(a,b)){t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b|0]=0}}function Mha(a){a=a|0;var b=0;b=jb-16|0;jb=b;a=Ro(a,b+8|0);jb=b+16|0;return C(a?z[b+8>>2]:C(0))}function LR(a){var b=0,c=0;b=1;c=v[a>>2];a:{if((c|0)>0){b=120;if(c>>>0<121){break a}}v[a>>2]=b}}function Iaa(a,b){a=a|0;b=b|0;ti(a);ti(a);a:{if(b>>>0>=60){Zb(a,4);break a}ti(a)}return ti(a)|0}function C3(a){a=a|0;var b=0;b=jb-16|0;jb=b;a=v[Lf(b+8|0,vl(sc(12),a))>>2];jb=b+16|0;return a|0}function At(a,b){b=Lka(a,a>>31,b,b>>31)+5e5|0;a=mb;return Hc(Mka(b,b>>>0<5e5?a+1|0:a,1e6,0),mb)}function AY(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(Zg(a,v[b+8>>2],f)){ow(b,c,d,e)}}function oea(a,b){a=a|0;b=b|0;v[a>>2]=0;v[a+4>>2]=0;Gc(a+8|0);if(b){Ak(a,b);Bt(a,b)}return a|0}function jV(a){var b=0;if(!(Rb(a,26324,20)|(w[a+25|0]-9&255)>>>0<248)){b=t[a+47|0]>=0}return b}function hB(a,b){var c=0;c=jb-16|0;jb=c;v[c+8>>2]=a;a=v[kU(c+8|0,0-b|0)>>2];jb=c+16|0;return a}function fw(a,b,c,d){var e=0;v[a>>2]=v[b>>2];e=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=(c<<d)+e;return a}function bI(a){var b=0;b=+((a&2097151)>>>0);return C(Uj(+C((a|0)<0?-b:b),(a>>>21&1023)-788|0))}function _U(a,b){return(Xb((B(a>>>4|0,b)>>>0)/15|0,1,15)<<4|Xb((B(a&15,b)>>>0)/15|0,1,15))&255}function JG(a){var b=0;b=v[116090];if(a){v[116090]=(a|0)==-1?468100:a}return(b|0)==468100?-1:b}function sB(a,b){a=a|0;b=b|0;v[a>>2]=0;v[a+4>>2]=0;Gc(a+8|0);if(b){Nl(a,b);rE(a,b)}return a|0}function om(a,b,c){b=b-a|0;while(1){if((b|0)>0){t[a|0]=w[c|0];b=b-1|0;a=a+1|0;continue}break}}function Tk(a){var b=0;b=jb-16|0;jb=b;a=v[ec(b+8|0,zc(a)+(Gb(a)<<2)|0)>>2];jb=b+16|0;return a}function Rf(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=a;a=xc(c,b);$c(d,a);zb(a);jb=c+16|0}function Pc(a,b,c){var d=0;d=v[c+4>>2];if((d|0)==(b|0)){a=jT(a,b,v[c>>2],d)}else{a=1}return!a}function Ju(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=a;a=Mc(c,b);$c(d,a);yb(a);jb=c+16|0}function IC(a){var b=0;b=a&255;a=b>>>21|0;b=(b<<11)+2624|0;a=b>>>0<2624?a+1|0:a;mb=a;return b}function CQ(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=B(c,12)+d;return a}function i1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;return nb[v[v[a>>2]+32>>2]](a,b,c,d,e)|0}function eB(a){var b=0,c=0;b=jb-16|0;jb=b;if(Oo(a,b+8|0)){c=pe(u[b+8>>1])}jb=b+16|0;return c}function YQ(a){var b=0,c=0;b=jb-16|0;jb=b;if(XQ(a,b+8|0)){c=bc(v[b+8>>2])}jb=b+16|0;return c}function KG(a){var b=0,c=0;c=a;while(1){b=c;c=b+4|0;if(v[b>>2]){continue}break}return b-a>>2}function Gga(a){a=a|0;var b=0,c=0;b=jb-32|0;jb=b;c=a;a=Ih(b+8|0);wS(c,a,0,0);Ab(a);jb=b+32|0}function BW(a){a=a|0;var b=0;b=jb-16|0;jb=b;a=zg(a,b+8|0);jb=b+16|0;return(a?w[b+8|0]:0)&255}function AF(a){a=a|0;var b=0;v[a>>2]=83244;b=v[a+8>>2];if(!(!b|!w[a+12|0])){Mb(b)}return a|0}function uR(a){a:{if(Rb(a,17593,4)){break a}if(Rb(a+8|0,14175,4)){break a}return 1}return 0}function nx(a,b){a=a&255;return w[(B(a>>>1&3,15)+B(a>>>3&1,45)+((b&240)>>>4)|0)+64705|0]<<1}function iga(a){a=a|0;var b=0;b=jb-16|0;jb=b;a=Hh(a,b+8|0);jb=b+16|0;return+(a?A[b+8>>3]:0)}function Wy(a){var b=0;v[a+84>>2]=0;v[a+88>>2]=0;b=v[a+80>>2];v[a+92>>2]=b;v[a+96>>2]=b<<12}function WC(a,b){if((a&4088)>>>0>=520){b=nv(0-Pka(b^1230262859,25)|0,4)^1247037516}return b}function AJ(a,b,c,d,e){if(!((b|0)==(c|0)|(d|0)>=0)){t[b|0]=45;d=$K(d);b=b+1|0}fJ(a,b,c,d,e)}function $f(a){var b=0,c=0;while(1){c=b&65535;if(c>>>0<127){tB(a,c);b=b+1|0;continue}break}}function yH(a){var b=0;b=v[a>>2];if(b){if(!oc(zH(b),-1)){return!v[a>>2]}v[a>>2]=0}return 1}function qw(a,b,c){var d=0;d=jb-16|0;jb=d;c=ji(d+8|0,c);a=$w(a,b);ii(c);jb=d+16|0;return a}function nD(a,b,c){var d=0;d=jb-16|0;jb=d;b=Pl(d+8|0,b,c);RD(b,a);le(b);jb=d+16|0;return a}function ZP(a){var b=0;b=a&255;a=b>>>27|0;b=(b<<5)+259|0;a=b>>>0<259?a+1|0:a;mb=a;return b}function Z6(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;Ax(a,b,c,d,e,0,0,f,g)}function Wv(a,b){a=a|0;b=b|0;b=b-1|0;if(b>>>0<=4){b=v[(b<<2)+21620>>2]}else{b=9692}xc(a,b)}function Vl(a,b,c){var d=C(0);if(b>>>0<=c>>>0){d=z[Db(a+4208|0,b)>>2]}else{d=C(0)}return d}function Qf(a,b){var c=0;c=jb-16|0;jb=c;v[c+8>>2]=a;a=v[fB(c+8|0,b)>>2];jb=c+16|0;return a}function Mg(a){var b=0;if(a>>>0>=11){b=a+16&-16;a=b-1|0;a=(a|0)==11?b:a}else{a=10}return a}function KK(a,b){var c=0;c=v[a+12>>2];if((c|0)>0){v[a+20>>2]=(v[a+16>>2]+(b+c|0)|0)%(c|0)}}function or(a){var b=0;while(1){if(!oc(w[a|0],0)){a=a+1|0;b=b+1|0;continue}break}return b}function gL(a,b){a=a|0;b=b|0;var c=0;c=Gb(a);if(c>>>0<b>>>0){Iu(a,b-c|0,0);return}EL(a,b)}function b9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=kj(a);if(a){nb[v[v[a>>2]+76>>2]](a,b,c,d)}}function a9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=kj(a);if(a){nb[v[v[a>>2]+84>>2]](a,b,c,d)}}function _8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=kj(a);if(a){nb[v[v[a>>2]+92>>2]](a,b,c,d)}}function YJ(a){a=a|0;var b=0;v[a>>2]=49120;b=v[a+4>>2];if(b){Mb(b);v[a+4>>2]=0}return a|0}function VU(a,b,c){var d=0;d=jb-16|0;jb=d;Yh(d+8|0,b,c);jb=d+16|0;return v[d+8>>2]==(a|0)}function Rg(a){var b=0;b=jb-16|0;jb=b;a=Oo(a,b+8|0);jb=b+16|0;return(a?x[b+8>>1]:0)&65535}function Pka(a,b){var c=0,d=0;c=b&31;d=(-1>>>c&a)<<c;c=a;a=0-b&31;return d|(c&-1<<a)>>>a}
function Jp(a,b,c){a=a+1074992|0;return v[(a+B(b,872)|0)+680>>2]>v[(a+B(c,872)|0)+680>>2]}function Gw(a,b,c,d){var e=0;e=jb-16|0;jb=e;v[e+12>>2]=d;a=Vr(a,b,c,d);jb=e+16|0;return a}function zs(a){if(IJ(a)){a=ba(4)|0;v[a>>2]=0;a=km(a);v[a>>2]=92472;ha(a|0,92508,26);L()}}function yh(a){var b=0;b=jb-16|0;jb=b;a=v[ec(b+8|0,zc(a)+Gb(a)|0)>>2];jb=b+16|0;return a}function xz(a,b){a=vl(a,b);$c(a+12|0,b+12|0);u[a+28>>1]=x[b+28>>1];v[a+24>>2]=v[b+24>>2]}function sN(a,b){var c=0;c=w[a+851|0];if(c&1){t[a+851|0]=c|64;v[a+852>>2]=v[a+852>>2]+b}}function pt(a){var b=0;b=jb-16|0;jb=b;a=v[ec(b+8|0,Lc(a)+Gb(a)|0)>>2];jb=b+16|0;return a}function _M(a){a=Lb(a);Lb(a+12|0);Lb(a+24|0);Lb(a+36|0);Lb(a+48|0);v[a+60>>2]=0;return a}function Zs(a,b){var c=0;c=Lc(a);if(c>>>0<=b>>>0){a=Gb(a)+c>>>0>=b>>>0}else{a=0}return a}function YM(a){var b=0;b=a+4e4|0;while(1){b=yy(b-160|0);if((b|0)!=(a|0)){continue}break}}function Vx(a,b,c){var d=0;d=jb-16|0;jb=d;Qh(a,c);t[d+15|0]=0;ie(b+c|0,d+15|0);jb=d+16|0}function Lv(){var a=0,b=0;a=jb-16|0;jb=a;b=Lf(a+8|0,Sb(sc(12)));jb=a+16|0;return v[b>>2]}function Le(a){var b=0;b=jb-16|0;jb=b;a=zg(a,b+15|0);jb=b+16|0;return(a?w[b+15|0]:0)&255}function DR(a,b){var c=0;c=jb-16|0;jb=c;Um(c+8|0,b);kT(a,v[c+8>>2],v[c+12>>2]);jb=c+16|0}function tg(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;return a}function oH(a){var b=0;b=v[a>>2];if(b){if(!Cn(Xk(b))){return!v[a>>2]}v[a>>2]=0}return 1}function kq(a,b,c){var d=C(0);d=z[a>>2];if(!fu(d,z[b>>2])){b=fu(z[c>>2],d)?c:a}return b}function fn(a){var b=0;b=Fv(a+4|0);if((b|0)==-1){nb[v[v[a>>2]+8>>2]](a)}return(b|0)==-1}function d9(a,b){a=a|0;b=b|0;a=kj(a);if(!a){return 1}return nb[v[v[a>>2]+68>>2]](a,b)|0}function bX(a){a=a|0;var b=0;b=v[a+4>>2];return(nb[v[v[b>>2]+20>>2]](b)|0)+v[a+12>>2]|0}function Xv(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=c+d;return a}function XL(a,b,c){var d=0;d=b-a|0;if((a|0)!=(b|0)){gj(c,a,d)}return B((d|0)/6|0,6)+c|0}function UA(a){var b=0;b=Hz(a);while(1){if((a|0)!=(b|0)){sV(a);a=a+32|0;continue}break}}function Qp(a,b,c){a=il(a)-v[a+16>>2]|0;if(a>>>0>=2){c=C(C(C(c-b)/C(a>>>0))+b)}return c}function PG(a,b){var c=0;c=jb-16|0;jb=c;v[c+12>>2]=b;a=QG(a,11096,b);jb=c+16|0;return a}function Kx(a,b,c,d){if(!((b|0)==(c|0)|(d|0)>=0)){t[b|0]=45;d=$K(d);b=b+1|0}Gx(a,b,c,d)}function vI(a,b){a=a&255;return v[(b&12)+64708>>2]>>>((a>>>3^-1)&1)>>>((a>>>4^-1)&1)|0}function mS(a){var b=0;b=a+24|0;while(1){b=yb(b-12|0);if((b|0)!=(a|0)){continue}break}}function lQ(a){var b=0;b=a+36|0;while(1){b=yb(b-12|0);if((b|0)!=(a|0)){continue}break}}function TO(a,b){return(a>>>0<=62?63-(B((b^-1)&63,(a?a+1|0:0)&255)>>>6|0)|b&192:b)&255}function SD(a,b){var c=0;c=jb-16|0;jb=c;b=Cg(c+8|0,b);RD(b,a);le(b);jb=c+16|0;return a}function PB(a,b,c){t[a+2|0]=1;b=b&15;if(c){b=w[b+26272|0]}else{b=(b<<2)+4|0}t[a+4|0]=b}function JX(){var a=0;a:{if(bE(19988498)){break a}if(aE()){break a}a=$D()^1}return a|0}function H4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return fF(a,b,c,d,e,12285,1031)|0}function F5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return fF(a,b,c,d,e,12385,1005)|0}function E$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return QE(b,c,d,e,f,1)|0}
function Cc(a,b){var c=0,d=0;c=jb-16|0;jb=c;d=c+8|0;Um(d,a);Ml(d,b);jb=c+16|0;return a}function $u(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;t[c+15|0]=b;dK(a,c+15|0);jb=c+16|0}function tA(a,b,c,d){var e=0;e=jb-16|0;jb=e;a=Ah(e,a,d);iu(b,c,a+4|0);kc(a);jb=e+16|0}function sE(a){var b=0;while(1){if((b|0)!=3){v[(b<<2)+a>>2]=0;b=b+1|0;continue}break}}function m4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return $E(a,b,c,d,e,9648,1041)|0}function ju(a,b,c,d){var e=0;e=jb-16|0;jb=e;a=Ok(e,a,d);iu(b,c,a+4|0);kc(a);jb=e+16|0}function jt(a,b){if(!(t[b+851|0]&1&v[a+480180>>2]==8)){ny(a,b,0);ny(a,b,1);ny(a,b,2)}}function eP(a,b,c,d){var e=0;e=jb-16|0;jb=e;a=_h(e,a,d);iu(b,c,a+4|0);kc(a);jb=e+16|0}function du(a,b){var c=0;c=jb-16|0;jb=c;u[c+14>>1]=b;$t(a+236|0,128,c+14|0);jb=c+16|0}function dq(a,b,c){var d=0;d=c;b=b-a|0;c=v[c>>2]-b|0;v[d>>2]=c;if((b|0)>0){tc(c,a,b)}}function bm(a){var b=0;if(a>>>0>=2){b=a+4&-4;a=b-1|0;a=(a|0)==2?b:a}else{a=1}return a}function bZ(a,b){a=a|0;b=b|0;if((b|0)>=0){b=v[((b&255)<<2)+81744>>2]}return b<<24>>24}function _F(a,b){var c=0,d=0;Ze(a,be(b));b=ic(b);c=ic(a),d=v[b>>2],v[c>>2]=d;return a}function WZ(a){a=a|0;a=469608;while(1){a=Fc(a-12|0);if((a|0)!=469584){continue}break}}function VZ(a){a=a|0;a=469536;while(1){a=Fc(a-12|0);if((a|0)!=469248){continue}break}}function UZ(a){a=a|0;a=468936;while(1){a=Fc(a-12|0);if((a|0)!=468768){continue}break}}function Rt(a,b){a:{if(b){break a}if(a>>>0<=3){a=a|-16;break a}a=a>>>2|0}return a&255}function O$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return SE(b,c,d,e,f,1)|0}function Ns(a,b){a=a|0;b=b|0;b=jb-16|0;jb=b;v[b>>2]=a;pK(17822,b);Ls(93888);jb=b+16|0}function M$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return SE(b,c,d,e,f,0)|0}function J1(a,b){a=a|0;b=b|0;a=x[a>>1];b=x[b>>1];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function Il(a,b,c){a=a|0;b=b|0;c=c|0;if(Qc(a,b)>>>0<=c>>>0){fv();L()}return(c<<1)+a|0}function IZ(a){a=a|0;a=469576;while(1){a=yb(a-12|0);if((a|0)!=469552){continue}break}}function HZ(a){a=a|0;a=469232;while(1){a=yb(a-12|0);if((a|0)!=468944){continue}break}}function H1(a,b){a=a|0;b=b|0;a=v[a>>2];b=v[b>>2];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function GZ(a){a=a|0;a=468760;while(1){a=yb(a-12|0);if((a|0)!=468592){continue}break}}function C$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return QE(b,c,d,e,f,0)|0}function A4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return $E(a,b,c,d,e,9576,1034)|0}function $Y(a,b){a=a|0;b=b|0;if((b|0)>=0){b=v[((b&255)<<2)+80208>>2]}return b<<24>>24}function xe(a,b,c){if(Qm(a,b,c)){a=ag(a,c);a=Ob(v[a>>2],v[a+4>>2])}else{a=0}return a}function jQ(a,b,c,d,e,f){a=ec(a,b);ec(a+4|0,c);ec(a+8|0,d);ec(a+12|0,e);ec(a+16|0,f)}function ew(a,b){var c=0;while(1){if((b|0)!=(c|0)){Ch(a+c|0);c=c+1|0;continue}break}}function cf(a){a=a|0;var b=0;b=v[a>>2];return(nb[v[v[b>>2]+24>>2]](b)|0)-v[a+8>>2]|0}function Tz(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2]}function Sn(a){var b=0;b=a;a=v[a>>2];v[b>>2]=B(a,214013)+2531011;return a>>>16&32767}function QF(a,b){a:{if(!(w[a+120|0]|b>>>0>30)){t[a+120|0]=1;break a}a=Bi(b)}return a}function Ij(a,b,c){var d=0;d=v[a>>2];if(!kp(d,v[b>>2])){b=kp(v[c>>2],d)?c:a}return b}function Gg(a,b,c){var d=0;d=A[a>>3];if(!TP(d,A[b>>3])){b=TP(A[c>>3],d)?c:a}return b}function Ej(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;tg(a)}function yp(a){a=a|0;v[a+56>>2]=77976;v[a>>2]=77956;Is(a+4|0);_k(a+56|0);return a|0}function y9(a,b){a=a|0;b=b|0;return C(b>>>0<=3?C(C(w[(a+b|0)+4264|0])/C(255)):C(0))}function wO(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){if(w[ic(a)+4|0]){xO(b+16|0)}Mb(b)}}function rf(a){a=a|0;v[a+60>>2]=78140;v[a>>2]=78120;Is(a+8|0);_k(a+60|0);return a|0}function mT(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){if(w[ic(a)+4|0]){KA(b+16|0)}Mb(b)}}function lY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=nb[a|0](b,c,d)|0;sa(mb|0);return a|0}function iM(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){if(w[ic(a)+4|0]){ac(b+16|0)}Mb(b)}}function Wd(a){var b=0;b=jb-16|0;jb=b;v[b+12>>2]=49288;ho(a,49184,b+12|0);jb=b+16|0}function MG(a){return(a|0)!=0&(a|0)!=89968&(a|0)!=89992&(a|0)!=468016&(a|0)!=468040}function G6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return nK(a,b,c,d,0,0,0,0,e)|0}function FF(a){a=a|0;v[a>>2]=84328;if(v[a+8>>2]!=(Gd()|0)){LG(v[a+8>>2])}return a|0}function E8(a,b){a=a|0;b=b|0;return C(b>>>0<=2?C(C(w[(a+b|0)+4232|0])/C(127)):C(0))}function Cg(a,b){v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];v[b>>2]=0;v[b+4>>2]=0;return a}function Al(a,b){var c=0,d=0,e=0;c=v[a+24>>2];d=a,e=Pe(mi(b)*+(c>>>0)),v[d+24>>2]=e}function xy(a){var b=0;b=jb-16|0;jb=b;ec(b+8|0,a+116|0);a=OM(a);jb=b+16|0;return a}function q9(a){a=a|0;t[a+4202|0]=1;v[a+4232>>2]=v[v[a+16>>2]+24620>>2];Ts(a);rL(a)}function eI(a,b){b=v[a+32>>2]+b|0;v[a+32>>2]=b;if(b>>>0>=y[a+40>>2]){v[a+96>>2]=1}}function dp(a,b,c,d){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<d);return a}function ap(a,b,c,d){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,d);return a}function T7(a){a=a|0;t[a+4202|0]=1;v[a+4256>>2]=v[v[a+16>>2]+24620>>2];NK(a);MK(a)}function MN(a,b){var c=0;c=b&15;if(c){t[a+830|0]=c}b=b&240;if(b){t[a+829|0]=b>>>4}}function Ft(a,b){a=Hb(a&65535);b=Hb(b&65535);return(a|0)==(b|0)?0:a>>>0<b>>>0?-1:1}function Bg(a){var b=0;b=jb-16|0;jb=b;a=Ro(a,b+8|0);jb=b+16|0;return a?v[b+8>>2]:0}function jo(a,b){a=tc(a,b,34);u[a+34>>1]=x[b+34>>1];tc(a+36|0,b+36|0,68);return a}function _P(a){if((w[a+14|0]-53&255)>>>0>=252){a=Rb(a,15539,14)}else{a=1}return!a}function HL(a,b,c){while(1){if(b){z[a>>2]=z[c>>2];b=b-1|0;a=a+4|0;continue}break}}function $t(a,b,c){while(1){if(b){u[a>>1]=x[c>>1];b=b-1|0;a=a+2|0;continue}break}}function wk(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;jc(a+8|0,b+8|0)}function wf(a){var b=0;b=jb-16|0;jb=b;a=v[ec(b+8|0,Yf(a))>>2];jb=b+16|0;return a}function qt(a){var b=0;b=jb-16|0;jb=b;a=v[ec(b+8|0,Lc(a))>>2];jb=b+16|0;return a}function pK(a,b){var c=0;c=jb-16|0;jb=c;v[c+12>>2]=b;QH(93888,a,b,0,0);jb=c+16|0}function he(a){var b=0;b=jb-16|0;jb=b;a=v[ec(b+8|0,zc(a))>>2];jb=b+16|0;return a}function Yf(a){var b=0;b=jb-16|0;jb=b;a=v[ec(b+8|0,ic(a))>>2];jb=b+16|0;return a}function Oi(a){var b=0;b=jb-16|0;jb=b;a=v[ec(b+8|0,od(a))>>2];jb=b+16|0;return a}function Fi(a){var b=0;b=jb-16|0;jb=b;a=v[ec(b+8|0,Eb(a))>>2];jb=b+16|0;return a}function rD(a,b,c){while(1){if(b){t[a|0]=w[c|0];b=b-1|0;a=a+1|0;continue}break}}function nZ(a,b,c){a=a|0;b=b|0;c=c|0;return(v[(c<<2)+83296>>2]&b)!=0&c>>>0<=127}function kY(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;nb[a|0](b,c,d,e,f)}function Xf(a){var b=0,c=0;Gc(a+4|0);nk(a+8|0,0);b=a,c=ic(a),v[b>>2]=c;return a}function I_(){var a=0,b=0,c=0;a=Ud(469664);v[a>>2]=84328;b=a,c=Gd(),v[b+8>>2]=c}function $v(a,b){b=a+b|0;while(1){b=zb(b-12|0);if((b|0)!=(a|0)){continue}break}}function $h(a){return(Pj(v[a>>2],v[a+4>>2])|0)!=(0-Pj(v[a+12>>2],v[a+16>>2])|0)}function io(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0}function hY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return nb[a|0](b,c,d,e)|0}function gy(a,b){a=a|0;b=b|0;if(v[a+4>>2]!=v[Fb(a)>>2]){GM(a,b);return}kA(a,b)}function fY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;nb[v[v[b>>2]+16>>2]](a,b,c,d,1,8)}function c_(a){a=a|0;if(!w[468544]){rn(468532,84564);t[468544]=1}return 468532}function a_(a){a=a|0;if(!w[468576]){rn(468564,84648);t[468576]=1}return 468564}function a2(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;return EI(a-88|0,b,c,d,e)|0}function _Z(a){a=a|0;if(!w[468480]){rn(468468,84492);t[468480]=1}return 468468}function YZ(a){a=a|0;if(!w[468512]){rn(468500,84528);t[468512]=1}return 468500}function Xu(a,b){return Pe(mi((+(a|0)*128+ +(b|0))*.0006510416666666666)*8363)}function Xaa(a,b){a=a|0;b=b|0;if(y[a+4>>2]<y[Fb(a)>>2]){GM(a,b);return}kA(a,b)}function QZ(a){a=a|0;if(!w[468528]){Mc(468516,13401);t[468528]=1}return 468516}function KZ(a){a=a|0;if(!w[468496]){Mc(468484,13655);t[468496]=1}return 468484}function BU(a,b){a=a|0;b=b|0;if(v[a+4>>2]!=v[Fb(a)>>2]){zF(a,b);return}xF(a,b)}function oO(a){v[a>>2]=0;v[a+4>>2]=0;v[a>>2]=-2078137563;v[a+4>>2]=-873292572}function nA(a){if(ff(w[a+11|0])){wd(v[a>>2],0);Fd(a,0);return}wd(a,0);ce(a,0)}function ej(a,b,c){if(v[a+80>>2]){v[a+92>>2]=v[a+92>>2]+(c+7&-8);return}Mb(b)}function dj(a,b){var c=0;c=a;a=(b>>>0)/100|0;return js(js(c,a),B(a,-100)+b|0)}function YP(a,b){a=oR(a,b);t[a+16|0]=w[b+16|0];v[a+12>>2]=v[b+12>>2];return a}function Wx(a,b){if((a|0)>=0){return(a|0)/(b|0)|0}return((a+1|0)/(b|0)|0)-1|0}function On(a,b){if((a|0)>=0){return(a|0)%(b|0)|0}return((a^-1)%(b|0)^-1)+b|0}function OZ(a){a=a|0;if(!w[468560]){Mc(468548,9213);t[468560]=1}return 468548}function NY(a,b,c){a=a|0;b=b|0;c=c|0;if(!w[470112]){t[470112]=1}gc(a,c,94340)}function MZ(a){a=a|0;if(!w[468464]){Mc(468452,5268);t[468464]=1}return 468452}function Gl(a,b){var c=0,d=0;c=jb-16|0;jb=c;d=c+8|0;fC(d,a);Ml(d,b);jb=c+16|0}function FY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(Zg(a,v[b+8>>2],0)){mw(b,c,d)}}function Be(a,b){var c=0,d=0;c=jb-16|0;jb=c;d=c+8|0;ov(d,a);Ml(d,b);jb=c+16|0}function $y(a){var b=0;if(!(w[a+2|0]|(w[a|0]|w[a+1|0]))){b=!w[a+3|0]}return b}function zj(a){var b=0;b=jb-16|0;jb=b;a=v[Lf(b+8|0,a)>>2];jb=b+16|0;return a}function y4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return mn(a,b,c,d,12786,1035)|0}function u4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return mn(a,b,c,d,12860,1037)|0}function tG(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;nb[v[v[a>>2]+32>>2]](a,b,c,d)|0}function pG(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;nb[v[v[a>>2]+48>>2]](a,b,c,d)|0}function oN(a,b,c){var d=0;return!b|!(w[a+35|0]&4?!a|(c|0)!=1:1)?d:w[b+34|0]}function VF(a){var b=0;b=jb-16|0;jb=b;v[b+8>>2]=a;jb=b+16|0;return v[b+8>>2]}function V7(a,b){a=a|0;b=b|0;return C(b>>>0<=4?z[((b<<2)+a|0)+4220>>2]:C(0))}function UY(a,b){a=a|0;b=b|0;a=km(a);v[a>>2]=93e3;pw(a+4|0,Lc(b));return a|0}function Ie(a){var b=0;b=jb-16|0;jb=b;Tu(b+8|0,a);jb=b+16|0;return v[b+8>>2]}function Eb(a){var b=0;b=jb-16|0;jb=b;a=v[ec(b+8|0,a)>>2];jb=b+16|0;return a}function $d(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=v[b+8>>2];Zb(b,c);Iv(a,b,d,c)}function w4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return mn(a,b,c,d,9531,1036)|0}function s4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return mn(a,b,c,d,9609,1038)|0}function q4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return mn(a,b,c,d,9411,1039)|0}function lH(a,b,c,d,e,f,g,h){return nb[v[v[a>>2]+16>>2]](a,b,c,d,e,f,g,h)|0}function jZ(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=v[(b<<2)+81744>>2]}return b|0}function hZ(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=v[(b<<2)+80208>>2]}return b|0}function cL(a){a=a|0;v[a>>2]=46284;vc(a+4276|0);vc(a+4264|0);return If(a)|0}function Rz(a,b){return(+(a>>>0)+ +(b|0)*4294967296)*2.3283064365386963e-10}function Q$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return TE(b,c,d,e,1)|0}function P0(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)!=1){iH(a,c);return}Mc(a,7880)}function Ok(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+c;return a}function OO(a,b){b=1/(1/(b*6.283185307179586/3546895)+1);HO(a,b,0,0,b+-1,0)}function N$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return TE(b,c,d,e,0)|0}function LT(a){var b=0;while(1){b=a;a=v[a>>2];if(a){continue}break}return b}function G$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return RE(b,c,d,e,1)|0}function E4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return mn(a,b,c,d,9380,1032)|0}function D$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return RE(b,c,d,e,0)|0}function $r(a,b,c,d,e,f,g,h){return nb[v[v[a>>2]+12>>2]](a,b,c,d,e,f,g,h)|0}function yg(a,b){var c=0;c=a;a=v[a+8>>2];b=a-b|0;v[c+8>>2]=a>>>0<b>>>0?0:b}function kk(a){var b=0;b=x[a+172>>1];a=x[a+156>>1];return(VP(a)?b:a)&65535}function js(a,b){b=x[(b<<1)+77104>>1];t[a|0]=b;t[a+1|0]=b>>>8;return a+2|0}function Xg(a,b,c){v[a+8>>2]=b;v[a+12>>2]=c;v[a>>2]=0;v[a+4>>2]=0;return a}function QY(a,b,c){a=a|0;b=b|0;c=c|0;return oc(a,v[b+4>>2])&v[b>>2]==(c|0)}function Ev(a,b,c){var d=0;d=b-a|0;if((a|0)!=(b|0)){gj(c,a,d)}return c+d|0}function rl(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;return a}function od(a){var b=0,c=0,d=0;return b=v[a>>2],c=a,d=ff(w[a+11|0]),d?b:c}function kia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=Io(a,b),v[d>>2]=e}function jia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=jv(a,b),u[d>>1]=e}function iu(a,b,c){b=b-a|0;if((b|0)>0){tc(v[c>>2],a,b);v[c>>2]=b+v[c>>2]}}function gd(a,b){a=SD(a,b);v[a+8>>2]=v[b+8>>2];SD(a+12|0,b+12|0);return a}function cG(a,b){var c=0,d=0;c=ec(a,v[v[b>>2]-12>>2]+b|0),d=b,v[c+4>>2]=d}function bS(a,b){t[a+6|0]=255;v[a+16>>2]=b;u[a+4>>1]=0;v[a>>2]=0;return a}function Zc(a,b,c,d,e){t[a+3|0]=e;t[a+2|0]=d;t[a+1|0]=c;t[a|0]=b;return a}function Wk(a,b,c){a=a|0;b=b|0;c=c|0;return nb[v[v[a>>2]+12>>2]](a,b,c)|0}function R8(a,b){a=a|0;b=b|0;a=v[a+20>>2];t[a+24|0]=w[a+24|0]&253|(b?2:0)}function Pm(a,b,c){a=a|0;b=b|0;c=c|0;return nb[v[v[a>>2]+48>>2]](a,b,c)|0}function Pb(a,b,c){a=a|0;b=b|0;c=c|0;return nb[v[v[a>>2]+32>>2]](a,b,c)|0}function ID(a,b){a=Cg(a,b);v[a+8>>2]=v[b+8>>2];Cg(a+12|0,b+12|0);return a}function _l(a,b){t[a|0]=b;t[a+1|0]=b>>>8;t[a+2|0]=b>>>16;t[a+3|0]=b>>>24}function Nia(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;CE(a,b,c,d,e,113)}
function Kw(a,b){var c=0;c=Ms(a+4|0);v[a>>2]=78768;v[c>>2]=78788;Jn(c,b)}function Jw(a,b){var c=0;c=aH(a+4|0);v[a>>2]=79136;v[c>>2]=79156;Jn(c,b)}function JD(a,b){a=a|0;b=b|0;a=km(a);v[a>>2]=93e3;pw(a+4|0,b);return a|0}function GH(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;Xg(a,-1,-1)}function yB(a,b,c){var d=0;d=(b|0)/(c|0)|0;v[a>>2]=d;v[a+4>>2]=b-B(c,d)}function xl(a){if(ff(w[a+11|0])){a=uu(v[a+8>>2])-1|0}else{a=10}return a}function vc(a){var b=0;if(v[a>>2]){Kc(a);b=v[a>>2];Uh(a);Mb(b)}return a}function sfa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;CE(a,b,c,d,e,139)}function qc(a,b){var c=0,d=0;v[a>>2]=b;c=a,d=xg(b),v[c+4>>2]=d;return a}function ip(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;v[e>>2]=c;return 3}function ex(a){return((vh(a)+(vh(a)<<8)|0)+(vh(a)<<16)|0)+(vh(a)<<24)|0}function YK(a){a=a|0;return C(C(C(z[Db(a+4208|0,5)>>2]*C(198))+C(-99)))}function Wf(a){var b=0;if(v[a>>2]){Kc(a);b=v[a>>2];Ar(a);Mb(b)}return a}function WU(a,b,c){a=a&255;return a>>>0>=(b&255)>>>0&a>>>0<=(c&255)>>>0}function Uc(a){var b=0;if(v[a>>2]){uC(a,v[a>>2]);b=v[a>>2];vC(a);Mb(b)}}function UO(a){if(a>>>0<=8){return w[a+29184|0]}return w[a+29175|0]|256}function NI(a){a=a|0;return+(+y[v[a+32>>2]+480240>>2]*152587890625e-16)}function IQ(a){var b=0;if(v[a>>2]){FQ(a,v[a>>2]);b=v[a>>2];Vj(a);Mb(b)}}function $O(a,b){v[a+4>>2]=0;v[a+8>>2]=0;v[a>>2]=b?b:49716;v[a+12>>2]=0}function ol(a,b){a=w[Kb(a+62|0,b)|0];return(a<<24>>24>=0?a&127:-1)&255}function nw(a,b,c){if(!(v[a+28>>2]==1|v[a+4>>2]!=(b|0))){v[a+28>>2]=c}}function hr(a){v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function fy(a,b){if(b){fy(a,v[b>>2]);fy(a,v[b+4>>2]);ac(b+16|0);Mb(b)}}function dha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return hw(a,b,c,d,571)|0}function cz(a,b){if(b){cz(a,v[b>>2]);cz(a,v[b+4>>2]);wm(b+16|0);Mb(b)}}function YV(a){a=a|0;v[a+16>>2]=v[a+16>>2]|1;if(t[a+20|0]&1){wa();L()}}function Wp(a,b){if(b){Wp(a,v[b>>2]);Wp(a,v[b+4>>2]);xO(b+16|0);Mb(b)}}function TR(a){if(Rb(a,13769,4)){a=1}else{a=Rb(a+8|0,13822,4)}return!a}function Sk(a,b){a=a|0;b=b|0;t[a|0]=2;t[a+1|0]=3;t[a+2|0]=0;t[a+3|0]=4}function My(a,b){v[a>>2]=v[b>>2];u[a+4>>1]=x[b+4>>1];t[a+6|0]=w[b+6|0]}function Lg(){var a=0;a=mm(ba(4)|0);v[a>>2]=92884;ha(a|0,92960,26);L()}function LA(a,b){if(b){LA(a,v[b>>2]);LA(a,v[b+4>>2]);KA(b+16|0);Mb(b)}}function JA(a,b){if(b){JA(a,v[b>>2]);JA(a,v[b+4>>2]);KA(b+16|0);Mb(b)}}function Ht(a,b){a=a&255;b=b&255;return(a|0)==(b|0)?0:a>>>0<b>>>0?-1:1}function Bz(a,b){a=Sb(a);Lb(a+12|0);u[a+28>>1]=0;v[a+24>>2]=b;return a}function yY(a){a=a|0;if(!a){return 0}return(Ky(a,92556,92700)|0)!=0|0}function rw(a){a=a|0;if(v[a+8>>2]!=(Gd()|0)){LG(v[a+8>>2])}return a|0}function pr(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return hw(a,b,c,d,169)|0}function mY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;nb[a|0](b,c,d,e)}function kQ(a,b,c,d,e){a=ec(a,b);ec(a+4|0,c);ec(a+8|0,d);ec(a+12|0,e)}function RJ(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){Gn(c+120|0);Mb(c)}}function MM(a,b,c,d,e){v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b}function FU(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return hw(a,b,c,d,333)|0}function j0(a){a=a|0;var b=0;b=v[117080]+1|0;v[117080]=b;v[a+4>>2]=b}function iY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return nb[a|0](b,c,d)|0}function cm(a,b){return b?a<<8&16711680|a<<24|(a>>>8&65280|a>>>24):a}function WP(a,b){a=Xz(a,b);t[a+16|0]=w[b+16|0];v[a+12>>2]=v[b+12>>2]}function P_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;xh(a,f)}function LS(a,b){v[a>>2]=v[b>>2];u[a+4>>1]=x[b+4>>1];jc(a+8|0,b+8|0)}function Ku(a,b){var c=0;c=jb-16|0;jb=c;VC(c,a,64);ZC(c,b);jb=c+16|0}function KB(a,b){var c=0;c=jb-16|0;jb=c;VC(c,a,32);ZC(c,b);jb=c+16|0}function x4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return _E(a,b,c,d,4)|0}function v4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return _E(a,b,c,d,2)|0}function t4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return ZE(a,b,c,d,4)|0}function rN(a,b){v[a+852>>2]=v[a+852>>2]+b;t[a+851|0]=w[a+851|0]|64}function r4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return ZE(a,b,c,d,2)|0}function iE(a,b){return v[b+8>>2]==v[a+8>>2]&v[a+12>>2]==v[b+12>>2]}function Yq(a,b){return mv(v[b>>2],v[b+4>>2],v[a>>2],v[a+4>>2])?b:a}function VS(a){t[a+4|0]=0;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0}function VB(a,b){return zr(v[b>>2],v[b+4>>2],v[a>>2],v[a+4>>2])?b:a}function Oc(a,b,c){if(uc(a,b)>>>0<=c>>>0){fv();L()}return(c<<2)+a|0}function FM(a,b){var c=0;c=jb-16|0;jb=c;aA(c,1,b);Ec(a,c);jb=c+16|0}function tP(a,b){var c=0,d=0;c=ec(a,v[b>>2]),d=w[b+4|0],t[c+4|0]=d}function eZ(a,b,c){a=a|0;b=b|0;c=c|0;return(b>>>0<128?b:c)<<24>>24}function UL(a,b){if((a|0)!=(b|0)){zS(a,v[b>>2],v[b+4>>2])}return a}function SF(a,b,c){a:{if((a|0)==(b|0)){t[b+120|0]=0;break a}Mb(b)}}function Paa(a,b){a=a|0;b=b|0;if(!v[23588]){v[23589]=b;v[23588]=a}}function wS(a,b,c,d){a=je(a,b);u[a+22>>1]=d;u[a+20>>1]=c;return a}function sr(a,b){a=a|0;b=b|0;return nb[v[v[a>>2]+32>>2]](a,0,b)|0}function pn(a,b){if(y[a+4>>2]<y[Fb(a)>>2]){zF(a,b);return}xF(a,b)}function oJ(a,b,c){a=a|0;b=b|0;c=c|0;return kJ(a,b,Lc(c),Gb(c))|0}function lh(a,b,c){a=ec(a,b);NT(a+4|0,v[c>>2],v[c+4>>2]);return a}function g7(a,b,c){a=a|0;b=b|0;c=c|0;return Ti(a,b,c,931,86224)|0}function dX(a){a=a|0;a=v[a+4>>2];return nb[v[v[a>>2]+12>>2]](a)|0}function cX(a){a=a|0;a=v[a+4>>2];return nb[v[v[a>>2]+16>>2]](a)|0}function XH(a,b){a=VH(a-1|0);if(!a){a=VH(b);a=a?a+32|0:0}return a}function Rm(a,b){v[a>>2]=v[(v[v[b>>2]-12>>2]+b|0)+24>>2];return a}function Lc(a){var b=0,c=0,d=0;return b=v[a>>2],c=a,d=ef(a),d?b:c}function LI(a){a=a|0;return+(+v[v[a+32>>2]+1074456>>2]*.00390625)}function Fj(a,b){if(qg(v[a>>2],v[a+4>>2])>>>0>b>>>0){t[a+16|0]=b}}function Dv(a,b,c){a=Cg(a,b);v[a+8>>2]=0;Cg(a+12|0,c);le(c);le(b)}function zr(a,b,c,d){return a>>>0<c>>>0&(b|0)<=(d|0)|(b|0)<(d|0)}function z7(a,b,c){a=a|0;b=b|0;c=c|0;return Ti(a,b,c,928,5048)|0}function o7(a,b,c){a=a|0;b=b|0;c=c|0;return Ti(a,b,c,930,4276)|0}function n9(a,b,c){a=a|0;b=b|0;c=c|0;return Ti(a,b,c,904,4304)|0}function n8(a,b,c){a=a|0;b=b|0;c=c|0;return Ti(a,b,c,923,4280)|0}function jd(a){a=(a|0)<32767?a:32767;return(a|0)>-32768?a:-32768}function iq(a,b,c){a=Hb(a&65535);return(a|0)>=(b|0)&(a|0)<=(c|0)}function eX(a){a=a|0;a=v[a+4>>2];return nb[v[v[a>>2]+8>>2]](a)|0}function e8(a,b,c){a=a|0;b=b|0;c=c|0;return Ti(a,b,c,924,4276)|0}function Z7(a,b,c){a=a|0;b=b|0;c=c|0;return Ti(a,b,c,925,4268)|0}function Rja(a,b){a=a|0;b=b|0;a=yu(a,b);v[a>>2]=93156;return a|0}function Qia(a,b){a=a|0;b=b|0;a=yu(a,b);v[a>>2]=93208;return a|0}function PD(a,b,c){a=dn(a);v[a+8>>2]=c;v[a+4>>2]=b;v[a>>2]=62268}function J7(a,b,c){a=a|0;b=b|0;c=c|0;return Ti(a,b,c,927,4228)|0}function H8(a,b,c){a=a|0;b=b|0;c=c|0;return Ti(a,b,c,920,4236)|0}function FK(a){return C(C(z[Db(a+4208|0,11)>>2]*C(19980))+C(20))}function D9(a,b,c){a=a|0;b=b|0;c=c|0;return Ti(a,b,c,896,4268)|0}function Cy(a){zb(a+48|0);zb(a+36|0);zb(a+24|0);zb(a+12|0);zb(a)}function zz(a){var b=0;if(v[a>>2]){hP(a);b=v[a>>2];ko(a);Mb(b)}}function wQ(a){var b=0;if(v[a>>2]){Kc(a);b=v[a>>2];Av(a);Mb(b)}}function uk(a){var b=0;if(v[a>>2]){Kc(a);b=v[a>>2];Cu(a);Mb(b)}}function tC(a){if(a>>>0>=214748365){Lg();L()}return sc(B(a,20))}function qe(a){var b=0;if(v[a>>2]){Kc(a);b=v[a>>2];gn(a);Mb(b)}}function pZ(a){a=a|0;a=v[a+8>>2];if(!a){return 1}return DF(a)|0}function nd(a){var b=0;if(v[a>>2]){Kc(a);b=v[a>>2];Xm(a);Mb(b)}}function mv(a,b,c,d){return(b|0)==(d|0)&a>>>0<c>>>0|b>>>0<d>>>0}function mO(a){var b=0;if(v[a>>2]){Kc(a);b=v[a>>2];ez(a);Mb(b)}}function lo(a){var b=0;if(v[a>>2]){Kc(a);b=v[a>>2];SS(a);Mb(b)}}function eja(a,b){a=a|0;b=b|0;a=KT(a,b);if(!a){JT(b)}return a|0}function cE(a){if(a>>>0>=357913942){Lg();L()}return sc(B(a,12))}function _r(a,b){a=a|0;b=b|0;return nb[v[v[a>>2]+44>>2]](a,b)|0}function ZM(a){var b=0;if(v[a>>2]){Kc(a);b=v[a>>2];OU(a);Mb(b)}}function Yd(a){var b=0;if(v[a>>2]){rV(a);b=v[a>>2];IB(a);Mb(b)}}function X6(a,b){a=a|0;b=b|0;if(!b){return 3}v[b>>2]=a;return 0}function VO(a,b){a=a|0;b=b|0;a=yu(a,b);v[a>>2]=93020;return a|0}function TH(a){var b=0;b=jb-16|0;z[b+12>>2]=a;return z[b+12>>2]}function Qt(a){var b=0;if(v[a>>2]){Kc(a);b=v[a>>2];Fb(a);Mb(b)}}function Qs(a){var b=0;if(v[a>>2]){Kc(a);b=v[a>>2];Sx(a);Mb(b)}}function Qn(a,b,c,d){a=Ht(a,c);if(wj(a)){a=uO(b,d)}return ff(a)}function QM(a){var b=0;if(v[a>>2]){dt(a);b=v[a>>2];ct(a);Mb(b)}}function Ot(a){var b=0;if(v[a>>2]){Kc(a);b=v[a>>2];Sz(a);Mb(b)}}function Jl(a,b){a=a|0;b=b|0;return nb[v[v[a>>2]+28>>2]](a,b)|0}function Jba(a,b){a=a|0;b=b|0;a=QS(a,b);if(!a){PS(b)}return a|0}function JM(a){var b=0;if(v[a>>2]){Wo(a);b=v[a>>2];Av(a);Mb(b)}}function Ir(a){var b=0;b=jb-16|0;A[b+8>>3]=a;return A[b+8>>3]*a}function GK(a){return C(C(z[Db(a+4208|0,0)>>2]*C(1e4))+C(-1e4))}function Fc(a){var b=0;if(ef(a)){b=v[a>>2];Kl(a);Mb(b)}return a}function EQ(a){var b=0;if(v[a>>2]){Kc(a);b=v[a>>2];Vj(a);Mb(b)}}function EO(a){var b=0;if(v[a>>2]){zO(a);b=v[a>>2];Vj(a);Mb(b)}}function Di(a){var b=0;if(v[a>>2]){Kc(a);b=v[a>>2];ko(a);Mb(b)}}function De(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){Us(b)}return a}function Cp(a,b,c){if(!b){return 0}return Vs(a,yf(c<<24>>24),b)}function Bw(a,b){a=a|0;b=b|0;return nb[v[v[a>>2]+12>>2]](a,b)|0}function Bm(a){var b=0;if(v[a>>2]){Kc(a);b=v[a>>2];Mt(a);Mb(b)}}function zv(a,b){a=$c(a,b);jc(a+12|0,b+12|0);dg(a+32|0,b+32|0)}function wv(a,b){a=a|0;b=b|0;a=mD(a,b);if(!a){fr(b)}return a|0}function wA(a,b){a=a|0;b=b|0;a=Ro(a,b);if(!a){Nm(b)}return a|0}function vM(a,b,c,d){u[a+4>>1]=c;t[a+6|0]=b;v[a>>2]=d;return a}function uo(a,b){a=a|0;b=b|0;a=HU(a,b);if(!a){KU(b)}return a|0}function tr(a,b){a=a|0;b=b|0;a=uD(a,b);if(!a){Nv(b)}return a|0}function qV(a,b){if(!b){return-1}b=Cp(a,b,0);return b?b-a|0:-1}function hO(a,b){a=a|0;b=b|0;a=XU(a,b);if(!a){Du(b)}return a|0}function g$(a,b){a=a|0;b=b|0;pN(a,Tw(v[b>>2])<<24>>24,v[b>>2])}function eg(a,b){return nb[v[v[a>>2]+32>>2]](a,v[a+12>>2],b)|0}function eT(a){if(a>>>0>=715827883){Lg();L()}return sc(B(a,6))}function cr(a,b){var c=0;c=b+1|0;v[a>>2]=v[a>>2]>(c|0)?c:b+2|0}function ci(a,b){a=a|0;b=b|0;a=Hh(a,b);if(!a){Sj(b)}return a|0}function bc(a){return a<<8&16711680|a<<24|(a>>>8&65280|a>>>24)}function bR(a){return w[a+15|0]<<12|w[a+14|0]<<4|w[a+13|0]<<20}function ar(a,b,c){a=a|0;b=b|0;c=c|0;Th(a,b,wi(b,b+c|0,62364))}function _B(a,b){a=a|0;b=b|0;a=Mu(a,b);if(!a){Ru(b)}return a|0}function Yt(a,b){a=a|0;b=b|0;a=IU(a,b);if(!a){Bu(b)}return a|0}function WK(a){a=a|0;return jk(C(z[Db(a+4208|0,4)>>2]*C(4)))|0}function SA(a,b){a=a|0;b=b|0;a=bT(a,b);if(!a){FA(b)}return a|0}function RL(a){if(a>>>0>=82595525){Lg();L()}return sc(B(a,52))}function M3(a,b,c){a=a|0;b=b|0;c=c|0;BP(a,0,v[b+1298404>>2],c)}function Jv(a,b){a=a|0;b=b|0;a=BD(a,b);if(!a){AD(b)}return a|0}function yia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;HE(a,b,c,d,113)}function x8(a,b,c){a=a|0;b=b|0;c=c|0;return jw(a,b,c,0,922)|0}function wia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;EE(a,b,c,d,462)}function uh(a,b,c){return(v[((c&255)<<2)+a>>2]&b)!=0&(c|0)>=0}function qk(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){ic(a);Mb(b)}}function nka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;HE(a,b,c,d,139)}function bJ(a,b){a=(a+b|0)-1|0;return a-((a>>>0)%(b>>>0)|0)|0}function TD(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){Mb(hc(c))}}function S7(a,b,c){a=a|0;b=b|0;c=c|0;return jw(a,b,c,0,926)|0}function RM(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){Mb(yj(c))}}function Pl(a,b,c){v[a+4>>2]=c;v[a>>2]=b;if(c){bn(c)}return a}function K7(a,b,c){a=a|0;b=b|0;c=c|0;return jw(a,b,c,1,926)|0}function Fja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;EE(a,b,c,d,355)}function Bi(a){if(a>>>0>=1073741824){Lg();L()}return sc(a<<2)}function BM(a,b){return b>>>0<4e3?((b<<5)+a|0)+946304|0:21619}function pc(a,b){var c=0;c=v[a>>2];v[a>>2]=v[b>>2];v[b>>2]=c}function o8(a){a=a|0;return C(C(z[Db(a+4208|0,6)>>2]*C(20)))}function mF(a,b,c){b=Pa(961,a|0,b|0,c|0)|0;mb=O()|0;return b}function ly(a,b){var c=0;c=x[a>>1];u[a>>1]=x[b>>1];u[b>>1]=c}function dQ(a){if(a>>>0>=268435456){Lg();L()}return sc(a<<4)}function bba(a){a=a|0;a=yu(a,21619);v[a>>2]=93100;return a|0}function Y8(a){a=a|0;a=kj(a);if(a){nb[v[v[a>>2]+100>>2]](a)}}function XW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;fc(a,v[d>>2],0)}function XK(a){a=a|0;return C(C(z[Db(a+4208|0,2)>>2]*C(10)))}function VM(a){v[a>>2]=0;Sb(a+4|0);Tb(a+16|0,0,144);return a}function VH(a){return t[(B(0-a&a,124511785)>>>27|0)+73744|0]}function Sg(a,b,c,d){mb=b-((a>>>0<c>>>0)+d|0)|0;return a-c|0}function PI(a){a=a|0;return+(65536/+y[v[a+32>>2]+480244>>2])}function Nx(a){a=a|0;v[a+32>>2]=0;v[a+28>>2]=v[a+28>>2]&-7|2}function Is(a){a=a|0;v[a>>2]=77440;yb(a+32|0);return Kn(a)|0}function CD(a){if(a>>>0>=536870912){Lg();L()}return sc(a<<3)}function $P(a){if(a>>>0>=134217728){Lg();L()}return sc(a<<5)}function zN(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){Mb(Ny(b))}}function z5(a,b){a=a|0;b=b|0;return C(dF(a,b,6232,1075834))}function yu(a,b){a=km(a);v[a>>2]=92980;pw(a+4|0,b);return a}function x5(a,b){a=a|0;b=b|0;return C(cF(a,b,6275,1075834))}function wI(a,b){a=a|0;b=+b;VE(a,b,1e4,1074420,9323,512,32)}function w5(a,b){a=a|0;b=b|0;return C(cF(a,b,6177,1075835))}function vA(a,b){if(b){vA(a,v[b>>2]);vA(a,v[b+4>>2]);Mb(b)}}function v5(a,b){a=a|0;b=b|0;return C(dF(a,b,6133,1075835))}function ux(a,b,c,d,e,f){return XE(a,b,c,d,e,f,57860,58656)}function uS(a){var b=0;b=v[a+100>>2];v[a+100>>2]=0;return b}function tx(a,b,c,d,e,f){return XE(a,b,c,d,e,f,58736,59500)}function nY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;nb[a|0](b,c,d)}function mha(a,b,c){a=a|0;b=b|0;c=c|0;return JE(a,b,c,37)|0}function ji(a,b){var c=0,d=0;c=a,d=JG(b),v[c>>2]=d;return a}function it(a,b){if(b){it(a,v[b>>2]);it(a,v[b+4>>2]);Mb(b)}}function iZ(a,b,c){a=a|0;b=b|0;c=c|0;return PE(b,c,81744)|0}function ht(a,b){if(b){ht(a,v[b>>2]);ht(a,v[b+4>>2]);Mb(b)}}function gZ(a,b,c){a=a|0;b=b|0;c=c|0;return PE(b,c,80208)|0}function eV(a){return!Rb(a,14123,4)&(w[a+4|0]-1&255)>>>0<10}function al(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){Mb(Wf(b))}}function aZ(a,b,c){a=a|0;b=b|0;c=c|0;return OE(b,c,81744)|0}function _Y(a,b,c){a=a|0;b=b|0;c=c|0;return OE(b,c,80208)|0}function _A(a,b){if(b){_A(a,v[b>>2]);_A(a,v[b+4>>2]);Mb(b)}}function Pz(a,b){if(b){Pz(a,v[b>>2]);Pz(a,v[b+4>>2]);Mb(b)}}function Oz(a,b){if(b){Oz(a,v[b>>2]);Oz(a,v[b+4>>2]);Mb(b)}}function MD(a,b){return TA(a,od(b),yd(v[b+4>>2],w[b+11|0]))}function Ln(a,b){return(((a<<12&b>>31)+b|0)/4096|0)%(a|0)|0}function L7(a){a=a|0;return C(C(z[Db(a+4208|0,6)>>2]*C(4)))}function KH(a,b){if(b>>>0<=9){return JH(a,b)}return js(a,b)}function JW(a){a=a|0;a=KD(a,13238);v[a>>2]=26076;return a|0}function Fv(a){var b=0;b=a;a=v[a>>2]-1|0;v[b>>2]=a;return a}function EJ(a,b){a=a|0;b=b|0;return Rh(v[b>>2],v[b+4>>2])|0}function Dq(a){return v[a+20>>2]+(v[a+8>>2]-v[a+24>>2]|0)|0}function DJ(a,b){a=a|0;b=b|0;return _d(v[b>>2],v[b+4>>2])|0}function $A(a,b){if(b){$A(a,v[b>>2]);$A(a,v[b+4>>2]);Mb(b)}}function qX(a){a=a|0;a=KD(a,8664);v[a>>2]=30500;return a|0}function oo(a){var b=0;b=v[a>>2];v[b>>2]=v[b>>2]|v[a+4>>2]}function cy(a,b,c){A[a>>3]=A[a>>3]+b;A[a+8>>3]=A[a+8>>3]+c}function YY(a,b,c){a=a|0;b=b|0;c=c|0;return((b|0)<0?c:b)|0}function YX(a){a=a|0;a=VO(a,7916);v[a>>2]=41832;return a|0}function S3(a,b,c){a=a|0;b=b|0;c=c|0;$c(a,kJ(c,0,b,xg(b)))}function M0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;mb=0;return 0}function K3(a){a=a|0;$J(a,2,100);Fj(v[a+24>>2]+484360|0,0)}function Gb(a){if(ef(a)){return v[a+4>>2]}return w[a+11|0]}function GR(a){var b=0;a=a+8|0;b=a>>>0<8?1:b;mb=b;return a}function Aq(a,b,c){if((a|0)!=(b|0)){b=b-a|0;gj(c-b|0,a,b)}}function An(a,b,c,d){v[a+16>>2]=d;v[a+12>>2]=c;v[a+8>>2]=b}function tE(a,b,c){a=a|0;b=b|0;c=c|0;wu(a,b,c);return a|0}function sq(a,b){if(ff(w[a+11|0])){Fd(a,b);return}ce(a,b)}function oV(a,b){t[a|0]=w[b|0];t[a+1|0]=w[b+1|0];return a}function jx(a,b){return v[((a>>>24^b)<<2)+463232>>2]^a<<8}function jI(a){while(1){if((ps(a)|0)!=-1){continue}break}}function hia(a,b,c){a=a|0;b=b|0;c=c|0;Th(a,b,ed(b,c)+b|0)}function go(a){v[a>>2]=0;v[a+4>>2]=0;nk(a+8|0,0);return a}function To(a){a=QD(a);v[a+8>>2]=0;v[a>>2]=89892;return a}function Tf(a){var b=0;eQ(a);b=v[a>>2];if(b){Kz(a);Mb(b)}}function TF(a){if(v[a>>2]){Kc(a);SF(sw(a),v[a>>2],Uh(a))}}function QJ(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){Us(c)}}function Pw(a,b,c){v[a+28>>2]=c;v[a+20>>2]=b;v[a+24>>2]=b}function Pp(a){return((a-65&255)>>>0<26?a+32|0:a)<<24>>24}function MI(a,b){a=a|0;b=+b;VE(a,b,256,1074456,11672,1,0)}function Hc(a,b){return KE(a,b,2147483647,-2147483648,-1)}function HA(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){Mb(c)}}function vN(a,b){a=uN(a,b);uN(a+12|0,b+12|0);t[a+24|0]=1}function th(a,b,c){t[a|0]=w[a|0]|b;v[a+4>>2]=v[a+4>>2]|c}function sX(a,b,c){a=a|0;b=b|0;c=c|0;Iv(a,b,v[b+8>>2],c)}function pB(a,b){t[v[a>>2]]=w[b|0];t[v[a+4>>2]]=w[b+1|0]}function nz(a,b){A[a>>3]=A[a>>3]*b;A[a+8>>3]=A[a+8>>3]*b}function k5(a,b){a=a|0;b=b|0;return nn(a,b,11702,1013)|0}function i5(a,b){a=a|0;b=b|0;return iF(a,b,13210,1014)|0}function fj(a){return _e(a)|_e(a)<<8|_e(a)<<16|_e(a)<<24}function fK(a,b){bn(v[b>>2]);fn(v[a>>2]);v[a>>2]=v[b>>2]}function cu(a){vc(a+88|0);vc(a+68|0);vc(a+48|0);return a}function _I(a){a=a|0;v[a>>2]=61612;hc(a+12|0);return a|0}function Z4(a,b){a=a|0;b=b|0;return nn(a,b,11737,1021)|0}function W4(a,b){a=a|0;b=b|0;return nn(a,b,11767,1023)|0}function O4(a,b){a=a|0;b=b|0;return nn(a,b,11863,1026)|0}function O1(a,b,c){a=a|0;b=b|0;c=c|0;return Od(B(b,c))|0}function Nm(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0}function NF(a){a=a|0;v[a>>2]=84416;yb(a+16|0);return a|0}function MF(a){a=a|0;v[a>>2]=84376;yb(a+12|0);return a|0}function Lt(a,b){pc(a,b);pc(a+4|0,b+4|0);pc(Fb(a),Fb(b))}function L4(a,b){a=a|0;b=b|0;return nn(a,b,11831,1027)|0}function Ii(a,b){var c=0;c=w[a|0];t[a|0]=w[b|0];t[b|0]=c}function FH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Xg(a,-1,-1)}function D5(a,b){a=a|0;b=b|0;return nn(a,b,11799,1006)|0}function yU(a){a=a|0;v[a>>2]=92980;sF(a+4|0);return a|0}function xs(a){a=a|0;v[a>>2]=49332;vx(a+4|0);return a|0}function xaa(a,b,c){a=a|0;b=b|0;c=c|0;vE(a,b,c,867,866)}function uI(a,b,c){v[a+4>>2]=0;v[a>>2]=b;v[a+8>>2]=c<<3}function sF(a){a=px(v[a>>2]);if((Fv(a+8|0)|0)<0){Mb(a)}}function q8(a){a=a|0;return z[Db(a+4208|0,3)>>2]<C(1)|0}function kF(a,b,c,d,e){return Ia(a|0,b|0,c|0,d|0,e|0)|0}function ho(a,b,c){v[a>>2]=b;v[a+4>>2]=v[c>>2];return a}function gB(a){a=a&255;return _c(a)^1|(a-49&255)>>>0<36}function ds(a){a=a|0;v[a>>2]=77376;$b(a+4|0);return a|0}function dJ(a){a=a|0;v[a>>2]=62076;hc(a+4|0);return a|0}function bM(a){return(a|0)==1179012417|(a|0)==538987841}function ad(a){if(ef(a)){a=Kl(a)-1|0}else{a=10}return a}function Vo(a){var b=0;b=v[a+8>>2];v[a+8>>2]=0;return b}function Sb(a){v[a>>2]=0;v[a+4>>2]=0;Gc(a+8|0);return a}function RF(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){fn(b)}}function N7(a){a=a|0;return z[Db(a+4208|0,1)>>2]<C(1)|0}function Kn(a){a=a|0;v[a>>2]=77312;$b(a+4|0);return a|0}function HD(a){a=a|0;v[a>>2]=43104;le(a+4|0);return a|0}function Eg(a,b,c,d,e){return Ra(a|0,b|0,c|0,d|0,e|0)|0}function DG(a,b,c){a=ec(a,b);ec(a+4|0,v[c>>2]);return a}function Cd(a,b,c){return a>>>0<b>>>0?b:a>>>0<c>>>0?a:c}function Cba(a,b,c){a=a|0;b=b|0;c=c|0;vE(a,b,c,796,795)}function C7(a){a=a|0;LK(a);t[a+4202|0]=1;v[a+4224>>2]=0}function xfa(a,b){a=a|0;b=b|0;Ul(a,b,259,1042,-1332,2)}function wH(a){a=a|0;return es(v[v[a>>2]-12>>2]+a|0)|0}function vh(a){var b=0;b=ps(a);v[a+1396>>2]=0;return b}function uO(a,b){return(a|0)==(b|0)?0:a>>>0<b>>>0?-1:1}function tn(a){if(ef(a)){a=Kl(a)-1|0}else{a=1}return a}function sp(a){return w[a+2|0]&2?(w[a+1|0]&6)==6?4:1:0}function r0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Th(a,c,d)}function oia(a,b){a=a|0;b=b|0;Ul(a,b,101,1042,-1332,2)}function oY(a){a=a|0;a=nb[a|0]()|0;sa(mb|0);return a|0}function o0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;GG(a,c,d)}function mx(a){return(a&6)==6?384:1152>>>((a&14)==2)|0}function lea(a,b){a=a|0;b=b|0;if(!ER(a,b)){Tb(b,0,40)}}function gia(a,b){a=a|0;b=b|0;return Mc(a,b?b:21619)|0}function fM(a,b){return B(b&65535,a&65535)+7>>>3&65535}function dm(a,b){v[a+16>>2]=!v[a+24>>2]|(v[a+16>>2]|b)}function bh(a,b){a=a|0;b=b|0;nb[v[v[b>>2]+20>>2]](a,b)}function ZL(a,b){return(b>>>0<=15?t[a+b|0]:63)<<24>>24}function YL(a,b){return(b>>>0<=45?t[a+b|0]:63)<<24>>24}function Xb(a,b,c){return(a|0)<(b|0)?b:(a|0)<(c|0)?a:c}function U0(a){a=a|0;return yp(v[v[a>>2]-12>>2]+a|0)|0}function S0(a){a=a|0;return rf(v[v[a>>2]-12>>2]+a|0)|0}function Oh(a,b){a=a|0;b=b|0;nb[v[v[b>>2]+24>>2]](a,b)}function Nh(a,b){a=a|0;b=b|0;nb[v[v[b>>2]+28>>2]](a,b)}function Mia(a,b){a=a|0;b=b|0;Ul(a,b,405,1042,-1332,2)}function Hv(a){a=a|0;v[a>>2]=93e3;sF(a+4|0);return a|0}function E6(a,b){a=a|0;b=b|0;return iF(a,b,6435,954)|0}function CH(a){a=a|0;return fs(v[v[a>>2]-12>>2]+a|0)|0}function $_(a,b){a=a|0;b=b|0;gc(a,nH(v[b>>2]),v[b>>2])}function zb(a){if(ff(w[a+11|0])){Mb(v[a>>2])}return a}function z8(a,b,c){a=a|0;b=b|0;c=c|0;gc(a,b+4228|0,7)}function xc(a,b){a=a|0;b=b|0;OD(a,b,or(b));return a|0}function wn(a,b){return nb[v[v[a>>2]+36>>2]](a,b,0)|0}function wB(a,b){a=je(a,b);Tb(a+20|0,0,1040);return a}function w0(a,b){a=a|0;b=b|0;Ul(a,b,101,1025,-1284,4)}function un(a,b){return nb[v[v[a>>2]+52>>2]](a,b,0)|0}function t0(a,b){a=a|0;b=b|0;Ul(a,b,101,1025,-1284,2)}function qr(a,b){a=jc(a,b);Tb(a+20|0,0,1040);return a}function pf(a,b,c,d){t[a+8|0]=d;v[a+4>>2]=c;v[a>>2]=b}function p9(a,b,c){a=a|0;b=b|0;c=c|0;gc(a,b+4260|0,8)}function oha(a,b,c){a=a|0;b=b|0;c=c|0;zS(a,b,Db(b,c))}function kL(a){vc(a+36|0);vc(a+24|0);Qs(a+12|0);Qs(a)}function iha(a,b,c){a=a|0;b=b|0;c=c|0;$c(a,oJ(c,0,b))}function hc(a){if(v[a>>2]){Kc(a);Mb(v[a>>2])}return a}function aj(a){a=a|0;return nb[v[v[a>>2]+16>>2]](a)|0}function a3(a,b){a=a|0;b=b|0;gO(v[a>>2],b);return a|0}function Vg(a){a=a|0;return nb[v[v[a>>2]+24>>2]](a)|0}function SV(a,b){a=a|0;b=b|0;Ul(a,b,259,1025,-1284,2)}function Pf(a,b,c,d){b=b+d|0;mb=a+c>>>0<c>>>0?b+1|0:b}function Ny(a){Sp(a+223860|0);hc(a+223848|0);return a}function Mc(a,b){a=a|0;b=b|0;wu(a,b,xg(b));return a|0}function Cv(a,b,c){v[a+4>>2]=c;v[a>>2]=b;if(c){bn(c)}}function BG(a,b,c){a=HG(a,b,c,0,-2147483648);return a}function $i(a){a=a|0;return nb[v[v[a>>2]+12>>2]](a)|0}function xD(a,b,c,d){return bp(a,b,c,d,36,119304648)}function vv(a){a=a|0;return nb[v[v[a>>2]+8>>2]](a)|0}function vga(a,b,c){a=a|0;b=b|0;c=c|0;BE(a,b,c,14,2)}function sL(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0}function nE(a,b,c,d){return bp(a,b,c,d,24,178956971)}function lV(a,b,c,d){return bp(a,b,c,d,28,153391690)}function gD(a,b){return(w[b+34|0]&8)>>>3&(a&2050)==2}function de(a,b,c){t[a|0]=b;t[a+1|0]=w[c|0];return a}function cY(a,b){a=a|0;b=b|0;Ul(a,b,12,1058,-1332,2)}function _s(a){a=a|0;a=Ih(a);v[a+20>>2]=0;return a|0}function W8(a){a=a|0;t[a+4202|0]=1;Rs(a);Mx(a);lL(a)}function RU(a,b,c,d){return bp(a,b,c,d,40,107374183)}function Kka(a){if(a){return 31-E(a-1^a)|0}return 32}function Ez(a){a=Sb(a);v[a+12>>2]=0;u[a+16>>1]=65280}function Bq(a,b,c,d,e){gc(a,b+d|0,(e|0)==-1?c-d|0:e)}function wp(a,b){b=v[b>>2];v[a>>2]=b;bn(b);return a}function vj(a){if(!a){return 0}return v[a+44>>2]!=0}function sn(a,b,c){v[a>>2]=b;v[a+4>>2]=c-b;return a}function pj(a){if(!a){return 0}return uj(w[a+31|0])}function p8(a){a=a|0;return C(z[Db(a+4208|0,1)>>2])}function m_(){Ud(469896);PF(469904);v[117474]=87264}function lha(a,b,c){a=a|0;b=b|0;c=c|0;GE(a,b,c,256)}function lO(a,b,c,d){return bp(a,b,c,d,7,613566757)}function k_(){Ud(469912);PF(469920);v[117478]=87420}function jga(a,b){a=a|0;b=b|0;return di(a,b,1030)|0}function hs(a,b){v[a>>2]=b;v[a+4>>2]=b>>31;return a}function fia(a){a=a|0;yj(94384);yj(94376);yb(94364)}function fD(a){return UH(a,C(2524354896707238e-44))}function e2(a,b,c){a=a|0;b=b|0;c=c|0;II(a-88|0,b,c)}function c2(a,b,c){a=a|0;b=b|0;c=c|0;GI(a-88|0,b,c)}function bx(a){if(!a){return 0}v[116064]=a;return-1}function be(a){var b=0;b=v[a>>2];v[a>>2]=0;return b}function aga(a,b){a=a|0;b=b|0;return Gr(a,b,1100)|0}function ZK(a){a=a|0;return C(z[Db(a+4208|0,0)>>2])}function Ve(a){var b=0;b=v[a>>2];if(b){Fb(a);Mb(b)}}function VC(a,b,c){t[a+8|0]=1;v[a+4>>2]=c;v[a>>2]=b}function T3(a){a=a|0;a=v[a+4>>2];return(a?a:5014)|0}function So(a){a=a|0;a=Bc(a);nb[v[v[a>>2]>>2]](a)|0}function Pv(a,b){a=a|0;b=b|0;return TA(a,b,or(b))|0}function Mz(a){t[a+6|0]=0;u[a+4>>1]=65535;v[a>>2]=0}function MO(a,b){v[a+8>>2]=0;v[a+12>>2]=0;A[a>>3]=b}function M7(a){a=a|0;return C(z[Db(a+4208|0,3)>>2])}function Lp(a,b,c){if(!c){return 0}return Rb(a,b,c)}function Lo(a,b,c){gc(a,(c>>>3&536870908)+b|0,c&31)}function Lga(a,b,c){a=a|0;b=b|0;c=c|0;BE(a,b,c,5,3)}function Hka(a,b){a=a|0;b=b|0;aw(a,b,259,274,-1332)}function GD(a){return UH(a,C(15845632502852868e13))}function Cb(a,b,c){gc(a,(c>>>3&536870908)+b|0,1<<c)}function Bea(a,b,c){a=a|0;b=b|0;c=c|0;$c(a,Pv(b,c))}function $C(a){if((a|0)<0){Lg();L()}return sc(a<<1)}function uka(a,b,c){a=a|0;b=b|0;c=c|0;Er(a,b,c,80)}function uaa(a,b){a=a|0;b=b|0;return di(a,b,225)|0}function tm(a){oj(a+724|0);oj(a+732|0);oj(a+740|0)}function raa(a,b){a=a|0;b=b|0;return di(a,b,326)|0}function g2(a,b,c){a=a|0;b=b|0;c=+c;KI(a-88|0,b,c)}function fE(a,b,c){a=a|0;b=b|0;c=c|0;$c(a,MD(b,c))}function e1(a,b){a=a|0;b=b|0;return cp(a,b,1103)|0}function d2(a,b){a=a|0;b=b|0;return HI(a-88|0,b)|0}function cja(a,b){a=a|0;b=b|0;return di(a,b,308)|0}function cha(a,b){a=a|0;b=b|0;return di(a,b,422)|0}function b2(a,b){a=a|0;b=b|0;return FI(a-88|0,b)|0}function b1(a,b){a=a|0;b=b|0;return cp(a,b,1101)|0}function _n(a,b,c){if((a|0)!=(b|0)){gj(c,a,b-a|0)}}function _0(a,b){a=a|0;b=b|0;return cp(a,b,1102)|0}function Zga(a,b){a=a|0;b=b|0;return di(a,b,826)|0}function V1(a,b,c){a=a|0;b=b|0;c=+c;AI(a-92|0,b,c)}function T1(a,b,c){a=a|0;b=b|0;c=+c;yI(a-92|0,b,c)}function Lia(a,b,c){a=a|0;b=b|0;c=c|0;Cr(a,b,c,85)}function Iga(a,b,c){a=a|0;b=b|0;c=c|0;Er(a,b,c,79)}function Hga(a,b,c){a=a|0;b=b|0;c=c|0;Er(a,b,c,78)}function Dk(a,b){return(a&65535)>>>0<(b&65535)>>>0}function D3(a,b){a=a|0;b=b|0;return cp(a,b,1098)|0}function C1(a,b){a=a|0;b=b|0;return cp(a,b,1099)|0}function Bl(a){a=(a|0)<120?a:120;return(a|0)>1?a:1}function AS(a,b,c){a=a|0;b=b|0;c=c|0;$c(a,nF(b,c))}function y2(a,b,c){a=a|0;b=b|0;c=c|0;wE(a,b,c,61)}function xm(a,b,c){v[a+4>>2]=c;u[a>>1]=b;return a}function waa(a,b){a=a|0;b=b|0;return di(a,b,73)|0}function w2(a,b,c){a=a|0;b=b|0;c=c|0;Er(a,b,c,74)}function vC(a){return(v[Fb(a)>>2]-v[a>>2]|0)/20|0}function sga(a,b){a=a|0;b=b|0;if(!Mu(a,b)){Ru(b)}}function s7(a,b){a=a|0;b=b|0;return C(Vl(a,b,12))}function s2(a,b,c){a=a|0;b=b|0;c=c|0;yE(a,b,c,72)}function qR(a){return(v[Fb(a)>>2]-v[a>>2]|0)/56|0}function qF(a){return(a<<1)+16777216>>>0<16777217}function paa(a,b){a=a|0;b=b|0;return di(a,b,60)|0}function p5(a){a=a|0;return iw(a,12717,1074416)|0}function nl(a,b,c){A[a+8>>3]=c;A[a>>3]=b;return a}function k0(a,b,c){a=a|0;b=b|0;c=c|0;Cr(a,b,c,86)}function jja(a,b){a=a|0;b=b|0;if(!KT(a,b)){JT(b)}}function ija(a,b){a=a|0;b=b|0;return di(a,b,78)|0}function gc(a,b,c){v[a+4>>2]=c;v[a>>2]=b;return a}function eka(a,b){a=a|0;b=b|0;if(!XU(a,b)){Du(b)}}function dY(a,b){a=a|0;b=b|0;aw(a,b,12,290,-1332)}function ct(a){return(v[Fb(a)>>2]-v[a>>2]|0)/52|0}function cM(a,b){return(a|0)==1179011410&b>>>0>80}function Yr(a,b,c){v[a>>2]=b;v[a+4>>2]=c;return a}function X2(a,b,c){a=a|0;b=b|0;c=c|0;yE(a,b,c,61)}function WG(a){return($j(a)|0)!=0|(a|32)-97>>>0<6}function Vj(a){return(v[Fb(a)>>2]-v[a>>2]|0)/12|0}function Up(a,b){v[a+4>>2]=256;v[a>>2]=b;return a}function Sfa(a,b){a=a|0;b=b|0;return di(a,b,71)|0}function SS(a){return(v[Fb(a)>>2]-v[a>>2]|0)/33|0}function Qh(a,b){if(ef(a)){Fd(a,b);return}ce(a,b)}function QD(a){v[a+4>>2]=0;v[a>>2]=92452;return a}function OU(a){return(v[Fb(a)>>2]-v[a>>2]|0)/40|0}function NV(a,b,c){a=a|0;b=b|0;c=c|0;Cr(a,b,c,81)}function KD(a,b){a=JD(a,b);v[a>>2]=93260;return a}function K1(a,b,c){a=a|0;b=b|0;c=c|0;xE(a,b,c,72)}function JC(a){return!Rb(a,26160,25)&w[a+34|0]<65}function J2(a,b,c){a=a|0;b=b|0;c=c|0;xE(a,b,c,61)}function IX(a,b){a=a|0;b=b|0;aw(a,b,12,257,-1284)}function IW(a,b,c){a=a|0;b=b|0;c=c|0;Cr(a,b,c,87)}function IB(a){return(v[Fb(a)>>2]-v[a>>2]|0)/28|0}function I1(a,b,c){a=a|0;b=b|0;c=c|0;wE(a,b,c,72)}function Fha(a,b){a=a|0;b=b|0;return di(a,b,91)|0}function Caa(a,b){a=a|0;b=b|0;if(!uD(a,b)){Nv(b)}}function CT(a){if(!(a&255)){return 1}return _c(a)}function Av(a){return(v[Fb(a)>>2]-v[a>>2]|0)/36|0}function Ar(a){return(v[Fb(a)>>2]-v[a>>2]|0)/24|0}function Aha(a,b){a=a|0;b=b|0;if(!QS(a,b)){PS(b)}}function zl(a,b,c){t[a+2|0]=c;u[a>>1]=b;return a}function yx(a,b){v[a>>2]=v[b>>2];$c(a+4|0,b+4|0)}function wo(a,b){a=a|0;b=b|0;if(!Hh(a,b)){Sj(b)}}function uJ(a,b){a=a|0;b=b|0;Mk(a,b,58696,58704)}function u8(a,b){a=a|0;b=b|0;return C(Vl(a,b,6))}function tz(a){v[a+24>>2]=x[a+20>>1]<<x[a+22>>1]}function tJ(a,b){a=a|0;b=b|0;Mk(a,b,58712,58720)}function t5(a){a=a|0;return bF(a,8756,1074448)|0}function rka(a,b){a=a|0;b=b|0;return Iu(a,1,b)|0}function qL(a){a=a|0;hc(a+4208|0);return If(a)|0}function q5(a){a=a|0;return iw(a,5322,1074424)|0}function pN(a,b,c){v[a+4>>2]=c;t[a|0]=b;return a}function pJ(a,b){a=a|0;b=b|0;Mk(a,b,59516,59524)}function nJ(a,b){a=a|0;b=b|0;Mk(a,b,59532,59540)}function mJ(a,b){a=a|0;b=b|0;Mk(a,b,60344,60352)}function lP(a,b){v[a>>2]=v[a>>2]+(b<<1);return a}function lJ(a,b){a=a|0;b=b|0;Mk(a,b,60360,60368)}function lF(a,b,c,d,e){Oa(a|0,b|0,c|0,d|0,e|0,1)}function kU(a,b){v[a>>2]=v[a>>2]+B(b,6);return a}function kT(a,b,c){gc(a,b,wi(b,b+c|0,62364)-b|0)}function k7(a,b){a=a|0;b=b|0;return C(Vl(a,b,2))}function id(a,b,c,d){return Hd(a,B(Pg(b),c)+d|0)}function hJ(a,b){a=a|0;b=b|0;Mk(a,b,61172,61180)}function h8(a,b){a=a|0;b=b|0;return C(Vl(a,b,5))}function gJ(a,b){a=a|0;b=b|0;Mk(a,b,61188,61196)}function f2(a,b){a=a|0;b=b|0;return+JI(a-88|0,b)}function ez(a){return(v[Fb(a)>>2]-v[a>>2]|0)/7|0}function dV(a,b){a=NU(a,b);if(!a){EB(b)}return a}function cga(a,b){a=a|0;b=b|0;ep(a,b,623,622,8)}
function c7(a,b){a=a|0;b=b|0;return C(Vl(a,b,3))}function a8(a,b){a=a|0;b=b|0;return C(Vl(a,b,4))}function _g(a,b,c){var d=0;d=a;a=b;sn(d,a,a+c|0)}function _V(a,b){a=a|0;b=b|0;if(!dC(a,b)){Su(b)}}function ZB(a,b){a=a|0;b=b|0;if(!BD(a,b)){AD(b)}}function Wu(a,b){a=a|0;b=b|0;if(!Oo(a,b)){Fo(b)}}function Ws(a){a=a|0;vc(a+4208|0);return If(a)|0}function Uo(a,b,c){a=ee(a);v[a+4>>2]=c;v[a>>2]=b}function UK(a){a=a|0;vc(a+4256|0);return If(a)|0}function U1(a,b){a=a|0;b=b|0;return+zI(a-92|0,b)}function TT(a,b){a=a|0;b=b|0;if(!mD(a,b)){fr(b)}}function S1(a,b){a=a|0;b=b|0;return+xI(a-92|0,b)}function JU(a,b){a=a|0;b=b|0;if(!IU(a,b)){Bu(b)}}function E7(a,b){a=a|0;b=b|0;return C(Vl(a,b,1))}function Cu(a){return(v[Fb(a)>>2]-v[a>>2]|0)/6|0}function AA(a,b){a=a|0;b=b|0;if(!bT(a,b)){FA(b)}}function zn(a){return nb[v[v[a>>2]+28>>2]](a)|0}function zB(a,b,c){if(b){Tb(a,yf(c),b)}return a}function sd(a,b){return kp(v[b>>2],v[a>>2])?b:a}function r5(a){a=a|0;return bF(a,7113,480214)|0}function qS(a){var b=0;b=v[a>>2];Ge(a);return b}function nm(a,b){return fu(z[b>>2],z[a>>2])?b:a}function laa(a,b,c){a=a|0;b=b|0;c=c|0;uL(a,b,c)}function ke(a,b){return Dk(x[a>>1],x[b>>1])?b:a}function gu(a,b){a=a|0;b=b|0;return Pb(a,b,1)^1}function aC(a,b){return(b&255)==2&(a&255)>>>0<3}function Yc(a,b){return po(v[a>>2],v[b>>2])?b:a}function Xy(a){if(w[a+24|0]){AN(a);t[a+24|0]=0}}function WS(a){return!Rb(a,13827,4)&w[a+4|0]<32}function W3(a){a=a|0;return YE(a,49080,12441)|0}function Vc(a,b){return Dk(x[b>>1],x[a>>1])?b:a}function Pk(a){return nb[v[v[a>>2]+36>>2]](a)|0}function PF(a){var b=0,c=0;b=a,c=Gd(),v[b>>2]=c}function P4(a){a=a|0;return iw(a,5819,480272)|0}function Oe(a,b){return kp(v[a>>2],v[b>>2])?b:a}function Nja(a,b){a=a|0;b=b|0;ep(a,b,354,353,8)}function Mfa(a,b){a=a|0;b=b|0;ep(a,b,654,653,8)}function MH(a,b){if(!a){return 0}return $w(a,b)}function Kh(a,b,c){return Ja(966,a|0,b|0,c|0)|0}function Jx(a,b){return fu(z[a>>2],z[b>>2])?b:a}function Jb(a,b){return po(v[b>>2],v[a>>2])?b:a}function Hha(a,b){a=a|0;b=b|0;ep(a,b,505,504,6)}function HH(a,b,c){a=a|0;b=b|0;c=c|0;return a|0}function AW(a,b){a=a|0;b=b|0;Xp(a,b);return a|0}function yt(a){return(a>>>0<9?a:a-9|256)&65535}function sf(a,b,c){if(!(w[a|0]&32)){NB(b,c,a)}}function q7(a){a=a|0;HK(a);Ex(a);t[a+4202|0]=1}function mh(a,b){t[a+4|0]=0;v[a>>2]=b;return a}function kg(a,b,c){a=Mka(a,b,c,c>>31);return a}function f8(a){a=a|0;t[a+4202|0]=1;RK(a);TK(a)}function caa(a,b){a=a|0;b=b|0;uy(UL(a+24|0,b))}function bga(a,b){a=a|0;b=b|0;return ER(a,b)|0}function bV(a,b,c){a=a|0;b=b|0;c=c|0;eC(a,b,c)}function _7(a){a=a|0;t[a+4202|0]=1;PK(a);OK(a)}function V3(a){a=a|0;return YE(a,49100,8151)|0}function SY(a,b,c){a=a|0;b=b|0;c=c|0;gc(a,c,b)}function RO(a){oz(a);Tb(a+27|0,0,255);return a}function OB(a){return!Rb(a,15443,4)&w[a+4|0]<4}function OA(a,b,c){a=a|0;b=b|0;c=c|0;bC(a,b,c)}function Nk(a,b,c,d,e){Sa(a|0,b|0,c|0,d|0,e|0)}function MB(a,b,c){a=a|0;b=b|0;c=c|0;tV(a,b,c)}function Kr(a,b){return(a&255)>>>0<(b&255)>>>0}function Jz(a){return a>>>0<=45?w[a+43680|0]:0}function HV(a,b){a=a|0;b=b|0;ep(a,b,295,294,8)}function Gi(a,b){return(B(b,104)+a|0)+484380|0}function EP(a){v[a>>2]=0;v[a+4>>2]=-1;return a}function E3(a,b){a=a|0;b=b|0;$c(a,_J(b,17608))}function yb(a){if(ef(a)){Mb(v[a>>2])}return a}function wc(a,b){if(y[a>>2]>b>>>0){v[a>>2]=b}}function vH(a){a=a|0;Sw(v[v[a>>2]-12>>2]+a|0)}function uU(a){mb=0;a=(a&65535)-98|0;return a}function tl(a,b,c,d){return(b-d|0)+(a-c<<3)|0}function qka(a,b){a=a|0;b=b|0;IE(a,b,301,300)}function qK(a,b){a=a|0;b=b|0;return _J(a,b)|0}function pV(a,b){a=a|0;b=b|0;return nF(a,b)|0}function op(a,b){a=a|0;b=b|0;return AH(a,b)^1}function mm(a){a=km(a);v[a>>2]=92864;return a}function ku(a,b){a=a|0;b=b|0;return Ik(a,b)|0}function jf(a,b){return Kr(w[a|0],w[b|0])?b:a}function iX(a){a=a|0;v[a>>2]=62132;return a|0}function hR(a){a=Lka(a&65535,0,80,0);return a}function g5(a){a=a|0;return eF(a,6594,1018)|0}function ee(a){v[a>>2]=0;v[a+4>>2]=0;return a}function cs(a,b){a=a|0;b=b|0;return pH(a,b)^1}function cj(a,b){a=a|0;b=b|0;return AH(a,b)|0}function ai(a,b){if(v[a>>2]>(b|0)){v[a>>2]=b}}function aV(a){t[a+12|0]=w[a+12|0]|2;return a}function _j(a,b){a=a|0;b=b|0;return pH(a,b)|0}function _ia(a,b){a=a|0;b=b|0;dw(a,b,17,3,16)}function ZX(a,b){a=a|0;b=b|0;return eE(a,b)|0}function Ym(a){return(a>>>0>127?a^128:-1)&255}function YW(a){a=a|0;v[a>>2]=42968;return a|0}function XJ(a){a=a|0;v[a>>2]=49164;return a|0}function Wb(a,b){return Kr(w[b|0],w[a|0])?b:a}function WW(a){a=a|0;v[a>>2]=42728;return a|0}function Ud(a){a=QD(a);v[a>>2]=84704;return a}function UF(a,b,c){a=a|0;b=b|0;c=c|0;return-1}function T0(a){a=a|0;kH(v[v[a>>2]-12>>2]+a|0)}function Sx(a){return v[Fb(a)>>2]-v[a>>2]>>11}function R0(a){a=a|0;jH(v[v[a>>2]-12>>2]+a|0)}function Oka(a,b,c,d){a=Jka(a,b,c,d);return a}function OG(a,b){a=a|0;b=b|0;return MD(a,b)|0}function N2(a){a=a|0;v[a>>2]=61712;return a|0}function Ms(a){a=eK(a);v[a>>2]=78608;return a}function LX(a,b){a=a|0;b=b|0;return Pv(a,b)|0}function JQ(a){return Pe(443250/+(a>>>0)*1e4)}function Gka(a,b){a=a|0;b=b|0;dw(a,b,44,2,44)}function FV(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function F2(a){a=a|0;v[a>>2]=61212;return a|0}function Ef(a,b){if(x[a>>1]>b>>>0){u[a>>1]=b}}function Cja(a,b){a=a|0;b=b|0;IE(a,b,358,357)}function BH(a){a=a|0;Uw(v[v[a>>2]-12>>2]+a|0)}function B5(a){a=a|0;return eF(a,7057,1010)|0}function Aw(a,b,c){a=HG(a,b,c,-1,-1);return a}function z_(a){a=a|0;ae(a,469776,Vd(468152))}function yd(a,b){if(!ff(b)){a=yf(b)}return a}function y_(a){a=a|0;ae(a,469784,Vd(468160))}function x_(a){a=a|0;ae(a,469792,Vd(468168))}function w_(a){a=a|0;ae(a,469800,Vd(468208))}function v_(a){a=a|0;ae(a,469808,Vd(468216))}function vF(a,b,c){a=a|0;b=b|0;c=c|0;iH(a,c)}function u_(a){a=a|0;ae(a,469816,Vd(468224))}function t_(a){a=a|0;ae(a,469824,Vd(468232))}function s_(a){a=a|0;ae(a,469832,Vd(468240))}function r_(a){a=a|0;ae(a,469840,Vd(468248))}function q_(a){a=a|0;ae(a,469848,Vd(468256))}function p_(a){a=a|0;ae(a,469856,Vd(468264))}function o_(a){a=a|0;ae(a,469864,Vd(468176))}function n_(a){a=a|0;ae(a,469880,Vd(468184))}function l_(a){a=a|0;ae(a,469896,Vd(468192))}function ko(a){return v[Fb(a)>>2]-v[a>>2]>>5}function jk(a){return zE(a,C(4294967296),-1)}function j_(a){a=a|0;ae(a,469912,Vd(468200))}function jF(a){a=Ga(a|0)|0;mb=O()|0;return a}function i_(a){a=a|0;ae(a,469928,Vd(468272))}function h_(a){a=a|0;ae(a,469936,Vd(468280))}function gn(a){return v[Fb(a)>>2]-v[a>>2]>>3}function bk(a){a=a&255;return(a|0)==255?-1:a}function aH(a){a=eK(a);v[a>>2]=79e3;return a}function Xm(a){return v[Fb(a)>>2]-v[a>>2]>>1}function Uh(a){return v[Fb(a)>>2]-v[a>>2]>>2}function T2(a){a=a|0;cJ(a);return v[a+16>>2]}function Sz(a){return v[Fb(a)>>2]-v[a>>2]>>8}function Qo(a,b,c,d){a=Mka(a,b,c,d);return a}function Ox(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0}function N_(a){a=a|0;ae(a,469616,Vd(468128))}function Mt(a){return v[Fb(a)>>2]-v[a>>2]>>4}function M_(a){a=a|0;ae(a,469624,Vd(468136))}function Ly(a){t[a+24|0]=0;t[a|0]=0;return a}function L_(a){a=a|0;ae(a,469632,Vd(468332))}function Kz(a){return v[Bc(a)>>2]-v[a>>2]>>2}function K_(a){a=a|0;ae(a,469648,Vd(468324))}function J_(a){a=a|0;ae(a,469656,Vd(468340))}function H_(a){a=a|0;ae(a,469664,Vd(468348))}function G_(a){a=a|0;ae(a,469680,Vd(468356))}function Fx(a){return C(C(a*C(7900))+C(100))}function F_(a){a=a|0;ae(a,469688,Vd(468372))}function F1(a){a=a|0;return ib(v[a+60>>2])|0}function E_(a){a=a|0;ae(a,469696,Vd(468364))}function D_(a){a=a|0;ae(a,469704,Vd(468380))}function Cw(){ha(mm(ba(4)|0)|0,92948,26);L()}function C_(a){a=a|0;ae(a,469712,Vd(468388))}function Bh(a){return v[v[a+8>>2]>>2]==(a|0)}function B_(a){a=a|0;ae(a,469736,Vd(468396))}function A_(a){a=a|0;ae(a,469768,Vd(468144))}function zc(a){if(ef(a)){a=v[a>>2]}return a}function yka(a,b){a=a|0;b=b|0;Fr(a,b,293,2)}function xJ(a){t[a+4|0]=0;t[a|0]=0;return a}function vf(a,b){if(w[a|0]>b>>>0){t[a|0]=b}}function ve(a,b,c){if(c){tc(a,b,c)}return a}function vK(a){return Sh(C(xK(a)*C(32768)))}function sl(a,b){return a<<24>>24<b<<24>>24}function qi(a,b){a=a|0;b=b|0;return C(C(0))}function mk(a,b){return a<<16>>16<b<<16>>16}function jp(a){return v[Fb(a)>>2]-v[a>>2]|0}function fB(a,b){v[a>>2]=v[a>>2]+b;return a}function em(a){a=a|0;Tw(v[a>>2]);return a|0}function eea(a,b){a=a|0;b=b|0;Fr(a,b,572,3)}function Wh(a,b,c){if(c){gj(a,b,c)}return a}function WF(a,b,c){return Ev(VF(a),VF(b),c)}function Us(a){a=a|0;nb[v[v[a>>2]+4>>2]](a)}function U2(a){a=a|0;cJ(a);return v[a+4>>2]}function Qm(a,b,c){return Af(a,b)>>>0>c>>>0}function Hm(a,b){u[a>>1]=b;u[a+2>>1]=b>>>16}function Bn(a){a=a|0;nH(v[a>>2]);return a|0}function xw(a){a=a|0;return Dh(a,468396)|0}function uQ(a,b,c,d){gc(a,b,(d|0)==-1?c:d)}function t9(a,b){a=a|0;b=b|0;t[a+4201|0]=b}function ss(a){return(a|0)<=65535&(a|0)>=0}function sA(a,b){a=a|0;b=b|0;Fr(a,b,572,2)}function r1(a){a=a|0;return Dh(a,468144)|0}function qN(a,b){return ME(a,b,2147483647)}function pd(a,b){a=a|0;b=b|0;uL(a,b,xg(b))}function oX(a){a=a|0;return v[a+4>>2]!=0|0}function lq(a){v[a>>2]=v[a>>2]+12;return a}function kf(a,b,c){a=Lka(c,0,a,b);return a}function j1(a){a=a|0;return Dh(a,468160)|0}function ir(a){rr(a+32|0);Ab(a+12|0);zb(a)}function hv(a){a=a|0;return Dh(a,468332)|0}function hfa(a,b){a=a|0;b=b|0;FE(a,b,2,31)}function gl(a){yb(a+36|0);vc(a+24|0);uk(a)}function eq(a){v[a>>2]=v[a>>2]+16;return a}function _t(a,b){a=a|0;b=b|0;Fr(a,b,573,2)}function UH(a,b){return C(TH(a?C(-b):b)*b)}function St(a){Ve(a+24|0);hc(a+12|0);hc(a)}function Saa(a,b){a=a|0;b=b|0;Yo(a+40|0,b)}function Rk(a,b){nb[v[v[b>>2]+44>>2]](a,b)}function Qw(a){a=a|0;return Dh(a,468324)|0}function Qk(a,b){nb[v[v[b>>2]+32>>2]](a,b)}function Q8(a,b,c){a=a|0;b=b|0;c=c|0;ee(a)}function Nw(a){a=a|0;return Dh(a,468340)|0}function Mm(a){v[a>>2]=v[a>>2]+28;return a}function Mf(a){v[a>>2]=v[a>>2]+20;return a}function Lr(a,b){nb[v[v[b>>2]+40>>2]](a,b)}function LM(a){v[a>>2]=v[a>>2]+52;return a}function Kl(a){return v[a+8>>2]&2147483647}function Iw(a){a=a|0;return Dh(a,468348)|0}function Eka(a,b){a=a|0;b=b|0;Yo(a+12|0,b)}function Dw(a){a=a|0;return Dh(a,468388)|0}function Dm(a){Cz(v[a+20>>2]);v[a+20>>2]=0}function Az(a){v[a>>2]=v[a>>2]+32;return a}function Aka(a,b){a=a|0;b=b|0;Mq(a+36|0,b)}function AK(a){return C(C(a*C(96))+C(-96))}function zt(a){om(a,fo(a),62364);return a}function zf(a){a=a|0;Ih(a+8|0);return a|0}function z2(a,b){a=a|0;b=b|0;Ik(a,b+12|0)}function yZ(a,b){a=a|0;b=b|0;xh(a,b+12|0)}function wka(a,b){a=a|0;b=b|0;ei(a,b,136)}function ut(a){v[a>>2]=v[a>>2]+8;return a}function up(a){a=a|0;Js(a+8|0);return a|0}function rga(a,b){a=a|0;b=b|0;ei(a,b,274)}function pe(a){return Hb(a&65535)<<16>>16}function p2(a,b){a=a|0;b=b|0;SI(a-88|0,b)}function o2(a,b){a=a|0;b=b|0;RI(a-88|0,b)}function nF(a,b){return Hr(a,Lc(b),Gb(b))}function mga(a,b){a=a|0;b=b|0;ei(a,b,106)}function lj(a,b){v[a>>2]=v[b>>2];return a}function kP(a){v[a>>2]=v[a>>2]-2;return a}function fs(a){a=a|0;_k(a+8|0);return a|0}function es(a){a=a|0;_k(a+4|0);return a|0}function dO(a,b){if(z[a>>2]>b){z[a>>2]=b}}function cka(a,b){a=a|0;b=b|0;FE(a,b,3,8)}function Yk(a){a=a|0;return zH(a)<<24>>24}function Yia(a,b){a=a|0;b=b|0;ei(a,b,282)}function Xr(a){a=a|0;gw(a,168,93308,1007)}function X9(a,b){a=a|0;b=b|0;xh(a,b+36|0)}function X1(a,b){a=a|0;b=b|0;CI(a-92|0,b)}function W1(a,b){a=a|0;b=b|0;BI(a-92|0,b)}function Re(a){v[a>>2]=v[a>>2]+2;return a}function Nn(a,b){return v[a>>2]-v[b>>2]|0}function Ke(a){v[a>>2]=v[a>>2]+4;return a}function JH(a,b){t[a|0]=b+48;return a+1|0}function Ge(a){v[a>>2]=v[a>>2]+1;return a}function EZ(a,b){a=a|0;b=b|0;xh(a,b+16|0)}function CI(a,b){a=a|0;b=b|0;UE(a,b,2048)}function Bk(a){v[a>>2]=v[a>>2]+6;return a}function BK(a){a=a|0;Tb(a+4296|0,0,81928)}function BI(a,b){a=a|0;b=b|0;UE(a,b,4096)}function $1(a,b){a=a|0;b=b|0;DI(a-88|0,b)}function yi(a,b){return v[a>>2]!=v[b>>2]}function xZ(a,b){a=a|0;b=b|0;Mc(a,11200)}function wZ(a,b){a=a|0;b=b|0;Mc(a,11317)}function v7(a){a=a|0;return v[a+4260>>2]}function r2(a){a=a|0;return up(a-88|0)|0}function oj(a){u[a+4>>1]=65535;v[a>>2]=0}function n2(a,b){a=a|0;b=+b;QI(a-88|0,b)}function l2(a,b){a=a|0;b=+b;OI(a-88|0,b)}function kha(a,b){a=a|0;b=b|0;ei(a,b,42)}function kga(a,b){a=a|0;b=b|0;ei(a,b,72)}function kc(a){v[v[a>>2]+4>>2]=v[a+4>>2]}function j2(a,b){a=a|0;b=+b;MI(a-88|0,b)}function bs(a,b){v[a+24>>2]=v[a+24>>2]+b}function bf(a,b){v[a+8>>2]=b|-2147483648}function _1(a){a=a|0;return up(a-92|0)|0}function Zia(a,b){a=a|0;b=b|0;Qq(a,b,17)}function Zd(a,b){return(b|0)!=0&(a|0)!=0}function Vk(a){return(a|0)==32|a-9>>>0<5}function Sf(a,b){a=Mka(0,a,b,0);return a}function RD(a,b){pc(a,b);pc(a+4|0,b+4|0)}function R1(a){a=a|0;return up(a-96|0)|0}function PJ(a){return(zc(a)+Gb(a)|0)-1|0}function P1(a,b){a=a|0;b=+b;wI(a-96|0,b)}function NT(a,b,c){v[a>>2]=b;v[a+4>>2]=c}function Jj(a,b){t[a|0]=b;t[a+1|0]=b>>>8}function Ija(a,b){a=a|0;b=b|0;ei(a,b,34)}function FS(a,b){a=a|0;b=b|0;ei(a,b,284)}function Ek(a){return B(Zm(a),Kd(a))&255}function DZ(a,b){a=a|0;b=b|0;rn(a,84448)}function CZ(a,b){a=a|0;b=b|0;rn(a,84468)}function A8(a){a=a|0;t[a+4202|0]=1;eL(a)}function zha(a,b){a=a|0;b=b|0;gC(a,b,8)}function tT(a,b){a=a|0;b=b|0;Qq(a,b,32)}function su(a,b,c){return a<b?b:a>c?c:a}function s9(a){a=a|0;return w[a+4201|0]}function r9(a){a=a|0;return w[a+4202|0]}function oW(a,b){a=a|0;b=b|0;ei(a,b,59)}function mR(a,b,c,d){return tl(c,d,a,b)}function jN(a,b){return(ol(a,b)|0)!=255}function gk(a,b){return Vy(a&255,b&255)}function en(a){a=v[a+8>>2];if(a){Mb(a)}}function eG(a,b){a=a|0;b=b|0;of(a,1,45)}function dG(a,b){a=a|0;b=b|0;nG(a,1,45)}function cx(a){return(p(a),j(2))>>>20|0}function cW(a,b){a=a|0;b=b|0;Qq(a,b,11)}function az(a,b,c){return a<b?b:a>c?c:a}function aU(a){return DE(a,65535,65535)}function YH(a){v[a+4>>2]=v[a+4>>2]|8192}function Xh(a){return(a&65535)>>>0<3999}function V6(a){a=a|0;return(a|0)==277|0}function UV(a){a=a|0;return v[a+12>>2]}
function Ig(a,b,c){t[a+4|0]=c;v[a>>2]=b}function Hb(a){return(a<<8|a>>>8)&65535}function BV(a,b){a=a|0;b=b|0;ei(a,b,50)}function BF(a,b){a=a|0;b=b|0;return b|0}function zi(a,b){return zc(a)+(b<<2)|0}function vL(a){a=a|0;return 1869112133}function re(a,b,c){sn(a,b,ed(b,c)+b|0)}function m2(a){a=a|0;return+PI(a-88|0)}function kE(a,b,c){return ap(a,b,c,24)}function k2(a){a=a|0;return+NI(a-88|0)}function jh(a){return zE(a,C(255),255)}function i2(a){a=a|0;return+LI(a-88|0)}function e7(a){a=a|0;return-2013527448}function dea(a){a=a|0;cR(a);return a|0}function cv(a,b,c){return ap(a,b,c,20)}function bz(a,b){return KE(a,b,-1,0,0)}function bB(a,b,c){sq(a,c);wd(b+c|0,0)}function aX(a){a=a|0;return v[a+16>>2]}function Yi(a,b){v[a+4>>2]=1;v[a>>2]=b}function Wj(a,b){v[a+4>>2]=2;v[a>>2]=b}function Vv(a,b){v[a+4>>2]=4;v[a>>2]=b}function UU(a,b,c){return ap(a,b,c,40)}function Td(a){v[v[a+8>>2]>>2]=v[a>>2]}function Pt(a,b,c){return ap(a,b,c,12)}function Ov(a,b){v[a+4>>2]=3;v[a>>2]=b}function Mr(a){a=a|0;return 2147483647}function MT(a,b,c){zl(a,b&65535,c&255)}function MJ(a){return a?(a|0)==2?3:2:1}function HP(a,b,c){return JE(a,b,c,42)}function z0(a){a=a|0;return XG(a,0)|0}function y0(a){a=a|0;return XG(a,1)|0}function w8(a){a=a|0;return-270114148}function w7(a){a=a|0;return-275227023}function vo(a,b){u[a+8>>1]=b;return a}function vJ(a){v[a>>2]=58680;return a}function uj(a){return(a-1&255)>>>0<17}function tS(a){nI(a);Ce(v[a+80>>2],a)}function ska(a,b){a=a|0;b=b|0;xt(a,b)}function rK(a,b){a=a|0;b=b|0;return 0}function pH(a,b){return oH(a)^oH(b)^1}function oba(a,b){a=a|0;b=b|0;NN(a,b)}function ni(a,b,c){$c($c(a,b)+12|0,c)}function m7(a){a=a|0;return 302837129}function kr(a,b,c){return dp(a,b,c,3)}function km(a){v[a>>2]=93560;return a}function k8(a){a=a|0;return-285139079}function j9(a){a=a|0;return 542066252}function ii(a){a=v[a>>2];if(a){JG(a)}}function gs(a,b){a=a|0;b=b|0;return-1}function ef(a){return w[a+11|0]>>>7|0}function eK(a){v[a>>2]=78636;return a}function dn(a){v[a>>2]=61664;return a}function c8(a){a=a|0;return-284078960}function bQ(a,b,c){return fw(a,b,c,5)}function aM(a,b){Zc(a,b&4?16:8,1,0,0)}function _h(a,b,c){return dp(a,b,c,1)}function _J(a,b){return Hr(a,b,xg(b))}function ZN(a,b){return(0-b|0)!=(a|0)}function Y6(a,b){a=a|0;b=b|0;return 3}function XS(a,b,c){fc(a,b,uc(b,c)<<2)}function X7(a){a=a|0;return-281111764}function WI(a){v[a>>2]=62976;return a}function W6(a,b){a=a|0;b=b|0;return 2}function Vm(a,b,c){return fw(a,b,c,2)}function VP(a){return(a&65535)==65534}function Uq(a){a=a|0;return v[a+4>>2]}function UI(a){v[a>>2]=63080;return a}function Te(a,b){v[a+4>>2]=b;return a}function TI(a){v[a>>2]=63120;return a}function Q7(a){a=a|0;return-271958638}function Px(a,b){a=a|0;b=b|0;return 1}function P2(a){a=a|0;return w[a+40|0]}function No(a,b,c){return fw(a,b,c,1)}function ND(a){a=a|0;return v[a+8>>2]}function Lz(a,b,c){return dp(a,b,c,5)}function LJ(a){a=C(a-a);return C(a/a)}function Jm(a){return(a&740327453)!=0}function H7(a){a=a|0;return-620920304}function G0(a){a=a|0;return ZG(a,0)|0}function Fq(a,b,c){return ap(a,b,c,6)}function F0(a){a=a|0;return ZG(a,1)|0}function Et(a,b,c){return dp(a,b,c,4)}function ED(a,b,c){fc(a,b,Ug(b,c)<<3)}function Cf(a,b,c){return id(a,b,c,0)}function CJ(a){v[a>>2]=49412;return a}function Ah(a,b,c){return dp(a,b,c,2)}function Af(a,b){return xk(a,b)&65535}function AH(a,b){return yH(a)^yH(b)^1}function zZ(a){a=a|0;return t[a+9|0]}function yK(a){v[a>>2]=0;v[a+4>>2]=0}function wX(a){a=a|0;aD(Lc(a),Gb(a))}function uba(a){a=a|0;return Vg(a)|0}function tu(a,b){return w[a+b|0]!=63}function tQ(a,b){return B(b,872)+a|0}function tL(a,b,c){a=a|0;b=b|0;c=c|0}function rja(a){a=a|0;return eB(a)|0}function qB(a,b,c){ec(ec(a,b)+4|0,c)}function pT(a,b){a=a|0;b=b|0;ku(a,b)}function oi(a,b){a=a|0;b=b|0;xh(a,b)}function oL(a,b){a=a|0;b=b|0;oi(a,b)}function mK(a){a=a|0;hF(a,48944,955)}function ln(a,b){a=a|0;b=b|0;cK(a,b)}function kh(a){Wf(a+52|0);hc(a+40|0)}function eS(a,b){if(!_R(a,b)){eA(b)}}function cK(a,b){a=a|0;b=b|0;Ds(a,b)}function bn(a){v[a+4>>2]=v[a+4>>2]+1}function _X(a,b){a=a|0;b=b|0;EN(a,b)}function ZQ(a){return(a&255)>>>0<129}function Wq(a,b){a=a|0;b=b|0;yv(a,b)}function Wja(a){a=a|0;return EU(a)|0}function VI(a){v[a>>2]=63e3;return a}function QP(a,b,c,d){NP(gc(a,b,c),d)}function Pg(a){return x[a+480188>>1]}function Ld(a,b){return B(b,160)+a|0}function Laa(a){a=a|0;return ti(a)|0}function Ki(a,b){a=a|0;b=b|0;EV(a,b)}function KX(a,b){a=a|0;b=b|0;hE(a,b)}function K2(a){a=a|0;return w[a+8|0]}function Jea(a){a=a|0;return Bi(a)|0}function Ix(a,b){a=a|0;b=b|0;gL(a,b)}function Iq(a,b){a=a|0;b=b|0;oL(a,b)}function HN(a){return(a+5&255)>>>0<2}function Gs(a){return x[a+480192>>1]}function GA(a,b){a=a|0;b=b|0;ZJ(a,b)}function Fs(a){return x[a+480190>>1]}function Ds(a,b){a=a|0;b=b|0;Ik(a,b)}function Ct(a){return v[Fb(a)>>2]<<5}function AZ(a){a=a|0;return t[a+8|0]}function $Q(a){return(a|0)<120?a:120}function xk(a,b){return(b-a|0)/52|0}function xd(a,b){return(b-a|0)/12|0}function vX(a){a=a|0;return Bg(a)|0}function sk(a){return DE(a,255,255)}function se(a,b,c){return DG(a,b,c)}function rj(a,b){return qg(a,b)&255}function rS(a,b){return Qf(a,0-b|0)}function qv(a){t[a+2|0]=0;u[a>>1]=0}function po(a,b){return a>>>0<b>>>0}function oc(a,b){return(a|0)==(b|0)}function nq(a){return(a&255)==1?1:2}function ng(a){return C(D(a))==C(N)}function lf(a,b){return B(b,24)+a|0}function jr(a,b){return(b-a|0)/36|0}function jK(a){a=a|0;return _k(a)|0}function gq(a,b){return(b-a|0)/56|0}function fx(a){return!Rb(a,93876,6)}function ft(a){return!(a&204473357)}function fH(a){a=a|0;return Hv(a)|0}function eu(a,b){return(b-a|0)/33|0}function ec(a,b){v[a>>2]=b;return a}function dg(a,b){return nk(a,be(b))}function dD(a){a=a|0;return Rg(a)|0}function by(a,b){return B(b,28)+a|0}function ag(a,b){return B(b,52)+a|0}function a1(a){a=a|0;return Xk(a)|0}function Yz(a,b){return B(b,56)+a|0}function Vb(a,b){return ye(a,b&255)}function VW(a){a=a|0;vD(Tb(a,0,36))}function VA(a,b,c){return Vs(a,b,c)}function UW(a){a=a|0;return Ih(a)|0}function TS(a,b){return B(b,33)+a|0}function Sp(a){if(w[a+24|0]){AN(a)}}function Rv(a,b,c){return Rb(a,b,c)}function Qi(a,b){return(b-a|0)/24|0}function Pq(a){a=a|0;return Le(a)|0}function Pi(a,b,c){return Ev(a,b,c)}function Og(a,b){return B(b,20)+a|0}function Nt(a,b){return B(b,36)+a|0}function Md(a,b){return B(b,12)+a|0}function Lk(a,b,c){return tE(a,b,c)}function Kp(a){return WU(a,251,255)}function Jq(a,b){return(b-a|0)/28|0}function FB(a){a=a|0;return sc(a)|0}function Eq(a,b){return(b-a|0)/40|0}function EV(a,b){DV(a,v[a+16>>2]|b)}function Dx(a){a=a|0;hF(a,49e3,957)}function Dl(a,b){return Cl(Qc(a,b))}function CV(a){a=a|0;return vv(a)|0}function Bf(a,b){return(b-a|0)/20|0}function B7(a){a=a|0;v[a+4224>>2]=0}function zD(a,b){return Ok(a,b,36)}function uu(a){return a&2147483647}function pm(a){return C(D(a))<C(N)}function pk(a,b){return(b-a|0)/6|0}function pi(a){a=a|0;t[a+4202|0]=0}function nV(a,b){return Ok(a,b,28)}function kp(a,b){return(a|0)<(b|0)}function gU(a){return w[a+1|0]!=63}function ff(a){return(a&128)>>>7|0}function dz(a,b){return(b-a|0)/7|0}function dr(a,b){return(b<<11)+a|0}function cl(a,b){return(a+b|0)-1|0}function bK(a,b,c,d){bw(a,b,c,d,2)}function ao(a,b){return(b<<13)+a|0}function aG(a){return Dh(a,468216)}function Zv(a,b){return!(b>>>31|0)}function ZF(a){return Dh(a,468232)}function Z9(a){a=a|0;Qq(a,21619,1)}function Ys(a,b){return(a-b|0)/6|0}function YF(a){return Dh(a,468224)}function Tv(a,b){return Ok(a,b,12)}function QS(a,b){return Gr(a,b,18)}function PX(a){a=a|0;hn(a,1,13360)}function Ow(a){return oc(a,-1)?0:a}function N1(a,b){a=a|0;b=b|0;Mb(b)}function Lh(a,b){a=a|0;b=b|0;Lb(a)}function Kk(a){return(a&255)>>>0>1}function KT(a,b){return Gr(a,b,56)}function IN(a){qe(a+8|0);zN(a+4|0)}function IJ(a){return(bk(a)|0)==-1}function Hn(a,b){v[a+1298464>>2]=b}function Hj(a,b){return B(Ek(b),a)}function Hd(a,b){return B(b,6)+a|0}function HJ(a,b){a=a|0;b=b|0;hc(b)}function Gx(a,b,c,d){bw(a,b,c,d,9)}function GJ(a,b){a=a|0;b=b|0;Fm(b)}function Fo(a){t[a|0]=0;t[a+1|0]=0}function Fe(a,b){gc(a,Lc(b),Gb(b))}function Dc(a,b){return ME(a,b,-1)}function Bx(a,b,c,d){bw(a,b,c,d,4)}function BD(a,b){return Gr(a,b,20)}function $ia(a){a=a|0;return+uH(a)}function $F(a){return Dh(a,468208)}function zm(a,b){return(b<<8)+a|0}function zk(a){u[a>>1]=0;return a}function yy(a){hc(a+4|0);return a}function ye(a,b){return(b<<5)+a|0}function xx(a,b){return hM(a,b)^1}function xq(a,b){return ue(a,b)^1}function xia(a){a=a|0;Rf(a,16153)}function wY(a){a=a|0;return 12944}function vY(a){a=a|0;return 10730}function sH(a){return AE(a,77376)}function qO(a,b){return Ok(a,b,8)}function ne(a,b){return!Rb(a,b,4)}function lw(a,b){return v[a+b>>2]}function gg(a,b){return Lc(a)+b|0}function eD(a){return(a&16)>>>4|0}function cc(a,b){return(b<<1)+a|0}function af(a,b){return(b<<3)+a|0}function _c(a){return WU(a,1,120)}function Waa(a){a=a|0;ug(a,sj(a))}function Ux(a){v[a>>2]=v[a>>2]+24}function Tn(a){return a+1074328|0}function Sd(a){return v[ic(a)>>2]}function Sc(a,b){return zc(a)+b|0}function Q0(a){a=a|0;return 10356}function PY(a){a=a|0;return 13058}function Ob(a,b){return oc(a,b)^1}function OY(a){a=a|0;return 10236}function Lm(a){v[a>>2]=2;return a}function Kfa(a){a=a|0;DS(a,65535)}function Jga(a){a=a|0;Rf(a,16784)}function Jf(a){return a!=a?C(0):a}function Jd(a,b){return(b<<4)+a|0}function Iz(a,b){return Ok(a,b,4)}function Hs(a){return AE(a,77312)}function Gc(a){v[a>>2]=0;return a}function Eh(a){v[a>>2]=1;return a}function EG(a,b){return DG(a,0,b)}function Db(a,b){return(b<<2)+a|0}function Cz(a){if(a){Mb(a+-64|0)}}function $j(a){return a-48>>>0<10}function xY(a){a=a|0;return 9795}function uia(a){a=a|0;Rf(a,4487)}function uY(a){a=a|0;return 5723}function uV(a){gw(a,25,93188,24)}function tq(a){gw(a,25,93240,27)}function tfa(a){a=a|0;Rf(a,4168)}function qU(a,b,c){LE(a,b,c,256)}function og(a,b){ec(Gc(a)+4|0,b)}function nv(a,b){return Pka(a,b)}function nia(a){a=a|0;Rf(a,4381)}function iL(a){return(a&8)>>>3|0}function gv(a,b,c){LE(a,b,c,128)}function dH(a){v[a+72>>2]=467144}function bha(a){a=a|0;Ju(a,3883)}function bg(a,b,c,d){pf(a,c,d,b)}function bH(a){v[a+72>>2]=467228}function Yg(a){return!v[a+16>>2]}function XI(a,b){return Ug(a,b)}
function Sja(a){a=a|0;Rf(a,3892)}function LY(a){a=a|0;return 6869}function LC(a){om(a,Xo(a),62364)}function Kga(a){a=a|0;Rf(a,3988)}function Hq(a,b,c){GE(a,b,c,128)}function EX(a){a=a|0;Rf(a,16811)}function ES(a,b){tc(a,b+4|0,256)}function Br(a){t[a|0]=0;return a}function AX(a){a=a|0;aD(a,xg(a))}function $ga(a){a=a|0;Ju(a,4890)}function yl(a){return Im(we(a))}function yj(a){HA(a,0);return a}function xj(a,b){return ye(a,b)}function xi(a,b){return(a|b)!=0}function xf(a){a=a|0;return a|0}function wm(a){yb(a+12|0);yb(a)}function vp(a,b){return Db(a,b)}function tk(a,b,c){pf(a,c,12,b)}function sw(a){return Fb(a+8|0)}function rh(a,b){return!yd(a,b)}function qy(a){u[a+480214>>1]=0}function ql(a){zb(a+12|0);nd(a)}function qM(a,b){return nM(a,b)}function q2(a){a=a|0;rs(a-88|0)}function pp(a){return a<<24>>24}function nk(a,b){return ec(a,b)}function nf(a,b){return zg(a,b)}function mt(a){AO(a+12|0);EO(a)}function mo(a,b){return Dk(a,b)}function mg(a){return Ai(a)?0:a}function mE(a,b){Dr(a,b,24,-24)}function mC(a){return(a&255)==1}function lv(a,b){return SC(a,b)}function jc(a,b){return ID(a,b)}function fz(a,b){return Qc(a,b)}function fh(a){return HN(a&255)}function dE(a,b){return $c(a,b)}function cw(a,b){return dh(a,b)}function b_(a){a=a|0;Fc(468532)}function aA(a,b,c){pf(a,c,64,b)}function _d(a,b){return uc(a,b)}function Zh(a,b,c){pf(a,c,13,b)}function ZZ(a){a=a|0;Fc(468468)}function Z1(a){a=a|0;rs(a-92|0)}function Yb(a,b){return ag(a,b)}function Xs(a,b){return mk(a,b)}function XZ(a){a=a|0;Fc(468500)}function XT(a,b,c){pf(a,c,24,b)}function UC(a,b){return RC(a,b)}function TV(a){a=a|0;Rf(a,4361)}function Si(a,b){return a>>>b&1}function Rn(a,b){return Kr(a,b)}function Rh(a,b){return ed(a,b)}function Rc(a,b,c){gc(a,b,1<<c)}function QU(a,b){Dr(a,b,40,-40)}function Q1(a){a=a|0;rs(a-96|0)}function Pj(a,b){return b-a>>11}function Pe(a){return zq(we(a))}function Pd(a){return(a&255)!=0}function PZ(a){a=a|0;yb(468516)}function OT(a,b){return po(a,b)}function Nr(a){a=a|0;return 127}function NZ(a){a=a|0;yb(468548)}function Me(a,b,c){pf(a,c,32,b)}function Lf(a,b){return nk(a,b)}function LZ(a){a=a|0;yb(468452)}function LG(a){if(MG(a)){Mb(a)}}function LB(a,b,c){pf(a,c,30,b)}function Jc(a,b){return dr(a,b)}function JZ(a){a=a|0;yb(468484)}function Hl(a,b,c){pf(a,c,22,b)}function Hi(a,b,c){pf(a,c,28,b)}function Hg(a,b){return Ob(a,b)}function HQ(a,b){Dr(a,b,12,-12)}function HB(a,b){return yo(b,a)}function Gh(a,b){return iv(a,b)}function Fk(a,b){return yd(a,b)}function FX(a){a=a|0;Rf(a,4535)}function FG(a,b){return xd(a,b)}function Df(a){zb(a+20|0);zb(a)}function DU(a,b){return ro(b,a)}function Cj(a,b,c){pf(a,c,20,b)}function Bb(a,b){return(a&b)!=0}function Ab(a){le(a+12|0);le(a)}function AN(a){yN(a+12|0);xN(a)}function $Z(a){a=a|0;Fc(468564)}function zx(a){a=a|0;Mb(YJ(a))}function zh(a,b){return b-a>>8}function yo(a,b){return a-b>>1}function x7(a){a=a|0;Mb(JK(a))}function w3(a){a=a|0;Mb(xs(a))}function vZ(a){a=a|0;Mb(FF(a))}function vQ(a){return a+4096|0}function uc(a,b){return b-a>>2}function u7(a){a=a|0;return 13}function rs(a){a=a|0;Mb(up(a))}function rR(a,b){dw(a,b,5,3,4)}function qg(a,b){return b-a>>5}function lk(a,b){return b-a>>4}function l8(a){a=a|0;Mb(UK(a))}function kn(a){a=a|0;Mb(yU(a))}function kH(a){a=a|0;Mb(yp(a))}function k9(a){a=a|0;Mb(qL(a))}function jH(a){a=a|0;Mb(rf(a))}function ie(a,b){t[a|0]=w[b|0]}function fX(a){a=a|0;Mb(HD(a))}function dc(a,b){v[a+100>>2]=b}function cn(a){a=a|0;Mb(Hv(a))}function cZ(a){a=a|0;Mb(AF(a))}function cT(a,b){sn(a,b,vd(b))}function bu(a,b){return a-b>>2}function bL(a){a=a|0;Mb(cL(a))}function XC(a){return sc(a<<2)}function Ww(a){a=a|0;Mb(_k(a))}function WY(a){a=a|0;Mb(yF(a))}function W0(a){a=a|0;Mb(Is(a))}function Vy(a,b){return a<<8|b}function Vw(a){a=a|0;Mb(Kn(a))}function V2(a){a=a|0;Mb(dJ(a))}function Uw(a){a=a|0;Mb(fs(a))}function Ut(a){return a>>>27^a}function Ug(a,b){return b-a>>3}function Sw(a){a=a|0;Mb(es(a))}function Rx(a){a=a|0;Mb(Ws(a))}function Rw(a){a=a|0;Mb(ds(a))}function Qc(a,b){return b-a>>1}function Os(a){a=a|0;Mb(If(a))}function OF(a){a=a|0;Mb(rw(a))}function LD(a){return a+1024|0}function L2(a){a=a|0;Mb(_I(a))}function Kd(a){return a&64?2:1}function IH(){return(gb()|0)>0}function Hz(a){return a+4896|0}function FZ(a){a=a|0;Mb(NF(a))}function El(a){return a>>>0<11}function EL(a,b){Vx(a,zc(a),b)}function Cn(a){return(a|0)==-1}function Ce(a,b){if(!a){Mb(b)}}function BZ(a){a=a|0;Mb(MF(a))}function yq(a){return a+256|0}function wj(a){return!(a&255)}function tR(a,b){pf(a,b,33,1)}function ro(a,b){return a-b|0}function rU(a,b){pf(a,b,40,2)}function mf(a){return D(a)==N}function lc(a){a=a|0;return 0}function kO(a,b){Dr(a,b,7,-7)}function j8(a){a=a|0;return 6}function ik(a){return Ed(a)^1}function i9(a){a=a|0;return 9}function gM(a,b,c){nl(a,b,-c)}function fd(a,b){wp(a,b+28|0)}function fL(a){a=a|0;return 3}function fA(a,b){fc(a,b,1024)}function ek(a){return a+4e4|0}function ed(a,b){return b-a|0}function dA(a){return a+128|0}function br(a,b){pf(a,b,26,3)}function bo(a,b){v[a+36>>2]=b}function aL(a){a=a|0;return 7}function _w(){return ob()<<16}function _u(a){return!v[a>>2]}function Zm(a){return a&1?2:1}function Zk(a){return(a&5)!=0}function ZS(a){xo(Tb(a,0,40))}function Ur(a){return a>>>0<2}function Ue(a,b){u[a+28>>1]=b}function T6(){return 19988498}function SB(a,b){fc(a,b,1954)}function QK(a){a=a|0;return 5}function Mn(a){a=a|0;return 4}function Lb(a){sE(a);return a}function Kb(a,b){return a+b|0}function Ho(a){return a>>>0<5}function He(a){a=a|0;return 1}function FR(a,b){fc(a,b,1108)}function Ee(a){a=a|0;return 2}function Ed(a){return(a|0)!=0}function EH(a){a=a|0;return-1}function EA(a,b){fc(a,b,4896)}function Bs(a,b){v[a+32>>2]=b}function zo(a,b){je(a,b+8|0)}function zO(a){yO(a,v[a>>2])}function wT(a){return a+36|0}function wM(a){return a-32|0}function vd(a){return a+16|0}function rQ(a,b){tc(a,b,128)}function rA(a,b){HA(a,be(b))}function qo(a){return a+14|0}function px(a){return a-12|0}function ph(a,b,c){Ev(a,b,c)}function pP(a,b,c){ml(a,c,b)}function pO(a,b,c){Yr(a,b,c)}function mI(a,b,c){Tb(a,c,b)}function lm(a,b){v[a+8>>2]=b}function lU(a,b){fc(a,b,218)}function lN(a,b,c){NT(a,b,c)}function kd(a,b){return a>>b}function kR(a,b){fc(a,b,146)}function jy(a,b){t[a+34|0]=b}function jq(a,b){return a<<b}function iy(a,b){t[a+32|0]=b}function iV(a,b){fc(a,b,610)}function iU(a,b){fc(a,b,157)}function iB(a,b){pf(a,b,8,2)}function hy(a,b){t[a+35|0]=b}function hP(a){gP(a,v[a>>2])}function gz(a){t[a+6152|0]=0}function gR(a,b){fc(a,b,608)}function fo(a){return a+32|0}function fc(a,b,c){gc(a,b,c)}function dt(a){PM(a,v[a>>2])}function dU(a,b){fc(a,b,206)}function dP(a,b,c){pl(a,c,b)}function ce(a,b){t[a+11|0]=b}function c1(a){a=a|0;EV(a,1)}function bi(a,b,c){rD(a,b,c)}function as(a,b){wp(a,b+4|0)}function ZT(a,b){fc(a,b,236)}function ZR(a,b){fc(a,b,130)}function ZA(a){return a-28|0}function Xo(a){return a+20|0}function XR(a,b){fc(a,b,600)}function VT(a){return a+10|0}function Tj(a){return a-36|0}function RT(a,b){fc(a,b,102)}function RR(a,b){fc(a,b,126)}function OC(a,b){fc(a,b,497)}function MP(a,b){fc(a,b,263)}function Lu(a,b){fc(a,b,512)}function Lq(a,b){fc(a,b,192)}function LQ(a,b){fc(a,b,204)}function Kv(a,b){TD(a,be(b))}function Kc(a){Fd(a,v[a>>2])}function Je(a,b){a=a|0;b=b|0}function JP(a){return a+48|0}function Ip(a,b){z[a+8>>2]=b}function Hp(a,b){z[a+4>>2]=b}function Gp(a,b){t[a+33|0]=b}function Fd(a,b){v[a+4>>2]=b}function ET(a,b){fc(a,b,576)}function Cm(a,b,c){Lo(a,b,c)}function Bc(a){return a+12|0}function BT(a,b){fc(a,b,674)}function $S(a,b){fc(a,b,128)}function zy(a){Tb(a,0,4096)}function zu(a,b){fc(a,b,22)}function yf(a){return a&255}function wL(a){Tb(a,0,2048)}function vR(a,b){fc(a,b,96)}function uA(a,b){fc(a,b,40)}function tU(a,b){fc(a,b,98)}function rk(){tq(10955);L()}function ov(a,b){gc(a,b,22)}function oU(a,b){fc(a,b,48)}function kC(a,b){fc(a,b,11)}function ic(a){return a+4|0}function hf(){uV(10955);L()}function fu(a,b){return a<b}function fS(a,b){fc(a,b,30)}function fC(a,b){gc(a,b,20)}function er(a,b){fc(a,b,36)}function cg(a,b){t[a+3|0]=b}function cC(a,b){fc(a,b,17)}function bv(a,b){fc(a,b,65)}function av(a,b){fc(a,b,16)}function aT(a,b){fc(a,b,80)}function _q(a){return a&127}function WT(a){return a+6|0}function WD(a,b){fc(a,b,24)}function Um(a,b){gc(a,b,32)}function TU(a,b){tc(a,b,40)}function TP(a,b){return a<b}function Se(a){return a+2|0}function S6(){return 458752}function RB(a){Tb(a,0,1954)}function Qe(a){return!Gb(a)}function QO(a,b){fc(a,b,27)}function Np(a){Tb(a,0,8192)}function Nc(a){return a+1|0}function Li(a){return a+3|0}function KR(a,b){fc(a,b,32)}function Jo(a,b){t[a+1|0]=b}function IS(a,b){fc(a,b,52)}function HC(a,b){fc(a,b,38)}function Gu(a,b){fc(a,b,64)}function Fu(a,b){fc(a,b,66)}function Fb(a){return a+8|0}function FC(a,b){ei(a,b,37)}function DC(a,b){fc(a,b,41)}function Cq(a,b){fc(a,b,12)}function Co(a){v[a+12>>2]=0}function CA(a,b){fc(a,b,33)}function Aj(a){return a-4|0}function $K(a){return 0-a|0}function yc(a){v[a+8>>2]=0}function yT(a){Tb(a,0,192)}function yN(a){ht(a,Sd(a))}function xv(a,b){fc(a,b,3)}function xN(a){it(a,Sd(a))}function wr(a){a=a|0;xr(a)}function ul(a,b){Lo(a,b,0)}function ud(a,b){v[a>>2]=b}function rT(a){JA(a,Sd(a))}function qu(a){_A(a,Sd(a))}function qba(a){a=a|0;jb=a}function qC(a,b){bi(a,2,b)}function oT(a){LA(a,Sd(a))}function oB(a,b){fc(a,b,6)}function nQ(a){Oz(a,Sd(a))}function mQ(a){Pz(a,Sd(a))}function kl(a){cz(a,Sd(a))}function kM(a){fy(a,Sd(a))}function jR(a){Tb(a,0,146)}function iW(a){a=a|0;Ih(a)}function hV(a){Tb(a,0,610)}function hU(a){Tb(a,0,157)}function hQ(a){Tb(a,0,256)}function fv(){tq(7678);L()}function fR(a){Tb(a,0,608)}function eA(a){Tb(a,0,130)}function dk(a,b){z[a>>2]=b}function cU(a){Tb(a,0,206)}function bd(){uV(7678);L()}function au(a){vA(a,Sd(a))}function an(a,b){fc(a,b,8)}function _K(a,b){HL(a,3,b)}function YT(a){Tb(a,0,236)}function Xq(a,b){fc(a,b,1)}function Wm(a,b){fc(a,b,2)}function WR(a){Tb(a,0,600)}function Tba(){return jb|0}function QR(a){Tb(a,0,126)}function PT(a){$A(a,Sd(a))}function NC(a){Tb(a,0,497)}function Mi(a,b){u[a>>1]=b}function KQ(a){Tb(a,0,204)}function Jh(a,b){fc(a,b,4)}function Ic(a){a=a|0;Mb(a)}function Eo(a,b){fc(a,b,7)}function Do(a,b){fc(a,b,5)}function DT(a){Tb(a,0,576)}function Ai(a){return a!=a}function AO(a){Wp(a,Sd(a))}function $b(a){fn(v[a>>2])}function xL(a){Tl(a,2048)}function wd(a,b){t[a|0]=b}function wR(a){Tb(a,0,96)}function sv(a){return a&1}function sU(a){Tb(a,0,98)}function pU(a){Tb(a,0,48)}function jm(a){yb(a+16|0)}function fr(a){Tb(a,0,36)}function Oj(a){zb(a+16|0)}function NS(a){Tb(a,0,33)}function JT(a){Tb(a,0,56)}function HS(a){Tb(a,0,52)}function GC(a){Tb(a,0,38)}function FA(a){Tb(a,0,80)}function EB(a){Tb(a,0,66)}function CC(a){Tb(a,0,41)}function Bu(a){Tb(a,0,64)}function $3(){return 2048}function zd(a){Ab(a+8|0)}function xO(a){qe(a+8|0)}function rt(a,b){yM(a,b)}function nB(a,b){jc(a,b)}function hi(a,b){Mh(a,b)}function fq(a,b){ec(a,b)}function fP(a,b){gP(a,b)}function bP(a,b){Vf(a,b)}function UR(a){ew(a,512)}function UB(a,b){dK(a,b)}function Tx(a,b){dg(a,b)}function Tu(a,b){hC(a,b)}function Tg(a){a=a|0;L()}function Tc(a){hc(a+8|0)}function TL(a,b){PM(a,b)}function Sl(a,b){DV(a,b)}function Nd(a,b){Fd(a,b)}function KA(a){zb(a+4|0)}function GB(a,b){wk(a,b)}function Cs(a){yb(a+4|0)}function BQ(a,b){vl(a,b)}function BA(a,b){LS(a,b)}function AR(a,b){je(a,b)}function $o(a,b){dE(a,b)}function vr(a){$v(a,36)}function to(a){NE(a,16)}function pC(a){ew(a,16)}function lE(a){Tl(a,24)}function gE(a){$v(a,48)}function Wg(a){$v(a,24)}function PU(a){Tl(a,40)}function Oha(){wa();L()}function Ko(a){NE(a,11)}function Ch(a){t[a|0]=0}function uF(){xa();L()}function tM(a){WM(a,0)}function rr(a){TD(a,0)}function rg(a){qT(a,0)}function lr(a){Tl(a,8)}function jj(a){SJ(a,0)}function jO(a){Tl(a,7)}function ij(a){QJ(a,0)}function gT(a){Tl(a,6)}function _S(a){ew(a,4)}function Wc(a){Ze(a,0)}function Ni(a){Tl(a,2)}function KY(){uF();L()}function By(a){SM(a,0)}function Ay(a){RM(a,0)}function As(a){RJ(a,0)}function xQ(a){Ke(a)}function wJ(a){Ge(a)}function tf(a){a=a|0}function sO(a){go(a)}function rC(a){zk(a)}function qE(a){Br(a)}function bA(a){Bk(a)}function ac(a){zb(a)}function _o(a){Bc(a)}function _b(a){yb(a)}function OP(a){Gc(a)}function Fm(a){vc(a)}function DQ(a){Sb(a)}
// EMSCRIPTEN_END_FUNCS
e=w;var nb=c([null,xc,fE,Ik,RX,hn,IX,AX,VD,wX,rX,iD,IW,tW,jW,Tq,Ki,YV,$,hv,Jl,tH,Vg,Pm,Rja,yU,xf,Qia,fia,Zha,Oha,Nha,Lha,zA,mha,gha,mea,Bga,MR,z1,y1,is,MR,ada,rca,VO,xt,Xp,Oba,Lba,oba,mba,FB,pM,xh,Mc,Naa,laa,oL,gL,Ix,oi,IK,p7,i7,$6,M6,H6,j1,i1,N0,cK,F4,EN,L3,F3,B3,oJ,X2,J2,y2,s2,h2,Y1,M1,L1,K1,I1,oi,G1,C1,w1,s1,p1,e1,b1,_0,w0,OG,t0,l0,k0,g0,TA,Tw,wa,Pb,fY,eY,dY,cY,bY,aY,ln,$X,_X,OG,ZX,YX,ha,WX,VX,UX,Ds,TX,SX,QX,aE,$D,PX,Qv,OX,Zo,LX,wr,Yo,Ql,Rf,HX,Zo,KX,JX,GX,NX,FX,ZD,EX,ZD,MX,_D,DX,CX,BX,ln,zX,cd,Pb,vX,Jv,uX,Vg,tX,UD,sX,Gk,UD,pr,qX,Hv,Gv,VW,pX,hX,gX,UW,Ri,PW,OW,vv,vD,NW,Jaa,Kaa,gO,Haa,Iaa,gy,_s,Zb,Laa,$d,sD,KW,JW,dD,GW,FW,dD,BW,kv,AW,_9,cf,Oga,vba,HW,Pq,Nf,MV,uba,bka,iaa,Z9,AC,zC,rW,qW,yC,pW,vg,oW,nW,Ec,mW,lW,wg,oh,kW,iW,fW,iC,eW,dW,cW,Yu,BP,MC,rJ,bW,aW,$V,_V,ZV,$u,XV,_B,Ad,Mq,TV,SV,Qu,Pu,RV,QV,PV,ZB,OV,YB,Zu,NV,dv,HV,Kq,Ika,Nb,Zf,Rf,Hka,MB,Gka,pd,Gj,Fka,Eka,Dka,CV,BV,md,Cka,Bo,Bka,Aka,zka,yV,xV,Ri,Ju,yka,xka,hca,wka,Qg,vka,uka,qka,Dj,tka,ska,pV,rka,Hh,zf,nka,mka,lka,cV,ika,Dj,Bj,hka,gka,Gq,fka,BB,bV,eka,dka,cka,MU,JU,_ja,Xja,qn,Vja,ug,gV,Wja,Yu,FU,Uja,Tja,uB,Sja,Gv,Qja,sB,BU,bU,Nja,Kq,so,Mja,Lja,BV,Kja,Jja,Ija,xU,Hja,Sm,Gja,Fja,Eja,Cja,Dj,wU,Dja,Hh,zf,AB,xja,uja,AC,qja,pja,oja,lja,Kq,kja,jja,wo,xU,ija,hja,Rf,gja,fja,eja,dja,cja,UT,bja,aja,tE,$ia,_ia,Zia,XB,TT,Yia,Xia,Wia,lca,Via,ST,Uia,ST,rja,Tia,Dj,Hh,zf,Fh,Nia,Mia,Lia,Iia,Hia,Gia,Fia,Eia,wo,Dia,Cia,Bia,SA,CW,Aia,zia,yia,xia,wia,zW,via,uia,tia,sia,sB,xT,ria,qia,Rf,pia,oia,DB,Oia,nia,mia,Pia,lia,kia,jia,PA,PA,OA,iia,hia,vT,PA,gia,gY,eia,dia,cia,bia,aia,$ha,_ha,sT,td,no,Mha,GA,Yha,L9,K9,J9,I9,H9,G9,Xha,Wha,Vf,Vha,Uha,Tha,Sha,fE,gca,eca,W9,gaa,haa,Rha,Qha,Pha,Uaa,E9,pT,cca,bca,aca,$ba,Hha,Gha,Fha,Eha,Dha,Cha,Bha,Aha,zha,yha,xha,vha,uha,wha,MS,zf,FS,AA,rha,yA,qha,pha,oha,nha,xA,lha,kv,yC,kha,DS,CS,ar,wA,jha,of,iha,AS,wo,Wu,wo,TT,Wq,Rf,cV,wo,qn,eha,dha,cha,bha,sA,_t,aha,$ga,_ga,Zga,Yga,Xga,BC,Wga,Vga,Uga,Tga,Sga,Rga,Qga,Pga,MA,Nga,Mga,Lga,Rf,uT,tT,WA,Kga,Jga,Qu,Gv,Iga,Hga,Nba,Iq,Gga,Om,Hu,Th,tba,Sba,st,nO,sba,rba,$N,nt,WN,pba,LN,WO,nba,qz,qj,ci,wga,vga,Yt,Ega,gu,sga,Om,rga,qga,OR,no,pga,oga,NR,nga,mga,lga,Xt,kga,jga,iga,hga,cga,_z,bga,aga,$fa,Dj,Hh,zf,ci,Yfa,Xfa,Wfa,Vfa,yA,Sfa,Rfa,Xt,Qfa,jaa,Nfa,Mfa,Bj,BR,_z,Zu,Lfa,Kfa,Jfa,Ifa,Vt,Hfa,Vt,Gfa,sr,DW,Dfa,Dj,Efa,Ffa,Wz,oR,Hh,zf,Yt,Afa,xfa,AA,wfa,tfa,sfa,cR,NR,SA,rfa,Qu,Rf,ifa,hfa,ZB,gfa,ffa,efa,dfa,cB,Bo,afa,$ea,_ea,Zea,Yea,Xea,Am,yQ,Wea,Vea,Uea,Tea,Sea,Rea,Qea,Pea,Oea,Nea,Mea,Lea,Kea,yA,Iea,Hea,Gea,gu,Fea,Eea,Kq,Eba,Jv,CV,Mba,Kba,Kq,Jba,ci,Jv,Iba,Hba,Gba,Bea,Aea,zea,yea,xea,wea,Zq,tea,sea,rea,qea,pea,oea,nea,lea,kea,jea,iea,XX,hE,hea,Rf,gea,fea,Il,Pba,mca,FB,iP,jca,ica,fca,dca,_ba,XO,Yba,Xba,PO,Wba,Vba,Uba,$n,CO,Rba,Qba,uo,Cba,Bj,hO,tr,Gaa,Faa,Eaa,lba,EW,Daa,wv,tr,_B,Caa,hO,Aba,Baa,Fba,Dj,Hh,zf,Dba,Dj,Hh,zf,Bba,Dj,Hh,zf,yba,pV,Iq,kba,jba,iba,hba,gba,fba,kca,dea,PP,eba,sc,cba,baa,bba,yX,TW,MW,RW,$aa,_aa,LW,SW,xX,QW,IM,Zaa,Yaa,Xaa,HM,wy,Waa,Vaa,Zba,Taa,Saa,Raa,Qaa,PL,U9,Pv,eE,oE,gy,Maa,pT,Iu,Sq,xba,zba,yaa,xaa,Bj,waa,_z,vaa,uaa,taa,Yt,saa,ci,raa,qaa,paa,oaa,naa,Dj,Hh,zf,zaa,faa,eaa,daa,caa,Mh,am,aaa,$9,Y9,S9,R9,Q9,P9,O9,LL,V9,Ep,KL,Jk,Mh,Vf,M9,F9,N9,T9,C9,B9,U8,A9,ck,yL,Uf,IL,m9,V8,Yl,P8,O8,M8,L8,K8,gy,N8,hh,ku,ku,ih,J8,I8,G8,ty,dL,m8,d8,Y7,R7,I7,y7,A7,n7,f7,sK,Ns,_6,Z6,Z2,$2,Q6,P6,N6,qK,Oaa,b3,J6,sK,I6,H3,x3,K3,F6,E2,mK,Dx,D6,W3,YJ,V3,NJ,B6,l9,y6,P7,z6,F7,w6,tE,S3,u6,E3,kK,AS,iK,hK,gK,k6,i6,mK,Dx,f6,e6,d6,c6,b6,a6,$5,_5,Z5,Y5,X5,W5,V5,U5,T5,S5,R5,Q5,P5,O5,N5,M5,L5,K5,J5,G5,E5,C5,JD,x2,M3,A5,l5,C3,j5,h5,el,A2,B2,f5,D2,_4,Y4,X9,V4,Dx,Q4,N4,K4,In,z2,I4,G4,D4,B4,z4,x4,v4,t4,r4,p4,n4,l4,aK,g4,e4,DM,Zt,$J,b4,a4,_3,Z3,Y3,X3,Ap,wba,ur,wN,Q3,O3,NN,J3,dba,G3,TY,Hr,D3,A3,y3,aba,I3,R3,N3,Wv,aa,a3,UJ,TJ,_2,eJ,Y2,W2,M2,C2,w2,v2,xM,eea,O1,N1,J1,H1,B1,A1,gH,fH,VY,r1,q1,o1,n1,m1,l1,k1,d1,Vg,c1,xf,MY,UY,O0,fH,L0,$q,rH,Nw,Iw,v0,u0,Dw,Oh,Nh,Tr,Mb,Cw,op,cj,Yk,Bw,em,j0,i0,aj,bh,tG,$i,Qw,xw,Oh,Nh,Rr,cs,_j,a1,Jl,Bn,aj,bh,pG,$i,P$,K$,mH,F$,_r,Pm,A$,Or,tf,i$,Xr,h$,g$,f$,bG,d$,b$,a$,Wk,$_,bG,Z_,Y_,W_,V_,S_,R_,N_,M_,L_,K_,J_,I_,H_,G_,F_,E_,D_,C_,B_,A_,z_,y_,x_,w_,v_,u_,t_,s_,r_,q_,p_,o_,n_,m_,l_,k_,j_,i_,h_,g_,UZ,VZ,WZ,b_,$Z,ZZ,XZ,GZ,HZ,IZ,PZ,NZ,LZ,JZ,FB,Jea,uF,cn,Uq,cea,bea,aea,$da,_da,Zda,Yda,Xda,Wda,Vda,Uda,Tda,Sda,Rda,Qda,Pda,Oda,Nda,Mda,Lda,Kda,Jda,Ida,Hda,Gda,Fda,Eda,Dda,Cda,Bda,Ada,zda,yda,xda,wda,vda,uda,tda,sda,rda,qda,pda,oda,nda,mda,lda,kda,jda,ida,hda,gda,fda,eda,dda,cda,bda,$ca,_ca,Zca,Yca,Xca,Wca,Vca,Uca,Tca,Sca,Rca,Qca,Pca,Oca,Nca,Mca,Lca,Kca,Jca,Ica,Hca,Gca,Fca,Eca,Dca,Cca,Bca,Aca,zca,yca,xca,wca,vca,uca,tca,sca,qca,pca,oca,nca,cn,vea,uea,Kia,Jia,vfa,ufa,ofa,nfa,tha,sha,gga,fga,Jha,Iha,JV,IV,Bja,Aja,hW,gW,WV,VV,_fa,Zfa,zfa,yfa,Dea,Cea,kka,jka,aka,$ja,wW,vW,uW,sW,Pfa,Ofa,Cfa,Bfa,uga,tga,Kha,FV,wja,vja,Sia,Ria,pka,oka,Pja,Oja,Ufa,Tfa,Aaa,maa,kaa,nja,mja,tja,sja,yga,xga,cfa,bfa,ega,dga,zja,yja,qfa,pfa,kfa,jfa,Zja,Yja,mfa,lfa,Fga,Aga,zga,yW,xW,LV,KV,hha,fha,Dga,Cga,kn,Uq,WW,Ic,So,rK,Ic,xf,Ic,lc,He,He,lc,lc,XW,kX,jX,YW,Ic,So,Ic,HD,fX,eX,dX,cX,bX,aX,$W,_W,ZW,Ws,Rx,Us,vL,lc,tf,lc,lc,lc,Je,Mn,z9,y9,x9,w9,v9,qi,Px,Px,Ox,tL,Ox,sL,Ox,sL,tf,FV,u9,t9,s9,r9,q9,pi,rL,R8,lc,lc,He,Nx,Ee,Ee,He,p9,o9,Je,tf,Je,tf,qL,k9,j9,lc,tf,lc,lc,lc,Je,i9,pL,h9,g9,f9,e9,qi,d9,c9,b9,a9,$8,_8,Z8,Y8,X8,W8,pi,lL,lc,lc,He,Ee,Ee,He,nL,mL,If,Tg,KY,T8,Qx,S8,lc,Q8,tL,x8,n8,e8,Z7,S7,J7,z7,o7,g7,K7,D9,n9,H8,Ws,Rx,vL,lc,tf,lc,lc,lc,Je,fL,F8,E8,D8,C8,B8,qi,A8,pi,eL,lc,lc,He,Ee,Ee,He,z8,y8,UK,l8,k8,lc,tf,lc,lc,lc,Je,j8,i8,h8,g8,qi,f8,pi,RK,lc,lc,He,Ee,Ee,Os,c8,lc,tf,lc,lc,lc,Je,QK,b8,a8,$7,qi,_7,pi,OK,lc,lc,He,Ee,Ee,Ws,Rx,X7,lc,tf,lc,lc,lc,Je,QK,W7,V7,U7,qi,T7,pi,MK,lc,lc,He,Ee,Ee,cL,bL,Q7,lc,tf,lc,lc,lc,Je,aL,O7,u8,t8,qi,s8,pi,r8,lc,lc,He,Ee,Ee,Je,tf,ZK,N7,M7,YK,L7,XK,WK,bL,w8,aL,v8,ZK,q8,p8,YK,o8,XK,WK,Os,H7,lc,tf,lc,lc,lc,Je,Ee,G7,E7,D7,qi,C7,pi,B7,lc,lc,He,Ee,Ee,JK,x7,w7,lc,tf,lc,lc,v7,Je,u7,t7,s7,r7,qi,q7,pi,Ex,lc,lc,He,Ee,Ee,Je,tf,Os,m7,lc,tf,lc,lc,lc,Je,fL,l7,k7,j7,qi,h7,pi,DK,lc,lc,He,Ee,Ee,Os,e7,lc,tf,lc,lc,lc,Je,Mn,d7,c7,b7,qi,a7,pi,BK,lc,lc,He,Ee,Ee,XJ,Ic,U3,zx,T3,zx,zx,Tg,xs,w3,P3,xf,Tg,xf,Ic,v3,u3,Tg,EJ,DJ,EJ,DJ,Je,ys,Je,ys,HJ,GJ,HJ,GJ,Ic,z3,xf,Ic,t3,s3,Ic,uJ,tJ,Tg,p3,qJ,o3,qJ,r3,sJ,q3,sJ,Ic,n3,m3,Ic,pJ,nJ,us,us,us,us,l3,sx,sx,sx,Ic,k3,j3,Ic,mJ,lJ,g3,iJ,f3,iJ,i3,jJ,h3,jJ,Ic,e3,d3,Ic,hJ,gJ,ts,ts,ts,ts,c3,rx,rx,rx,F2,Ic,So,Ic,_I,L2,He,He,K2,I2,Uq,H2,G2,Tg,Tg,N2,Ic,So,Ic,dJ,V2,He,lc,He,U2,T2,S2,R2,Q2,P2,O2,Tg,iX,Ic,So,Ic,Ic,oX,He,He,Uq,ND,nX,mX,lX,Je,ys,Je,ys,up,rs,u2,t2,SI,RI,QI,PI,OI,NI,MI,LI,KI,JI,II,HI,GI,FI,EI,DI,CI,BI,AI,zI,yI,xI,wI,r2,q2,p2,o2,n2,m2,l2,k2,j2,i2,g2,f2,e2,d2,c2,b2,a2,$1,_1,Z1,X1,W1,V1,U1,T1,S1,R1,Q1,P1,xf,Tg,xf,Tg,xf,Tg,xf,Tg,F1,E1,D1,Kn,Vw,Je,HH,GH,FH,lc,lc,v1,EH,u1,gs,t1,gs,ds,Rw,Je,HH,GH,FH,lc,lc,h1,EH,g1,gs,f1,gs,Is,W0,X0,V0,$0,Z0,Y0,yp,kH,U0,T0,es,Sw,wH,vH,rf,jH,S0,R0,fs,Uw,CH,BH,xf,Ic,Q0,SY,RY,QY,P0,cn,x1,lc,M0,Vw,A0,z0,y0,x0,jK,Ww,_k,Ww,Vw,D0,$G,C0,B0,Rw,H0,G0,F0,E0,fs,Uw,CH,BH,jK,Ww,Rw,K0,$G,J0,I0,es,Sw,wH,vH,yF,WY,Us,AF,cZ,bZ,aZ,$Y,_Y,BF,ZY,YY,XY,FF,vZ,uZ,tZ,sZ,rZ,lc,qZ,pZ,MF,BZ,AZ,zZ,yZ,xZ,wZ,NF,FZ,ND,UV,EZ,DZ,CZ,xf,Ic,Ic,nZ,mZ,lZ,kZ,jZ,iZ,hZ,gZ,BF,fZ,eZ,dZ,Ic,CF,CF,ip,He,He,oZ,He,Ic,IF,HF,ip,lc,lc,GF,Mn,Ic,IF,HF,ip,lc,lc,GF,Mn,Ic,LF,KF,ip,lc,lc,JF,Mn,Ic,LF,KF,ip,lc,lc,JF,Mn,xf,Ic,s0,r0,q0,xf,Ic,p0,o0,n0,Ic,m0,h0,f0,e0,xG,xG,d0,c0,b0,a0,$$,Ic,_$,Z$,Y$,X$,oG,oG,W$,V$,U$,T$,S$,Ic,R$,Q$,O$,N$,M$,L$,J$,I$,Ic,H$,G$,E$,D$,C$,B$,z$,y$,xf,Ic,Ee,x$,w$,v$,u$,t$,s$,TZ,SZ,RZ,QZ,OZ,MZ,KZ,xf,Ic,Ee,r$,q$,p$,o$,n$,m$,f_,e_,d_,c_,a_,_Z,YZ,rw,OF,l$,rw,OF,k$,Ic,Nr,Nr,Lh,Lh,Lh,eG,lc,Sk,Sk,Ic,Nr,Nr,Lh,Lh,Lh,eG,lc,Sk,Sk,Ic,Mr,Mr,Lh,Lh,Lh,dG,lc,Sk,Sk,Ic,Mr,Mr,Lh,Lh,Lh,dG,lc,Sk,Sk,Ic,j$,e$,Ic,c$,__,Ic,X_,U_,Ic,T_,Q_,Ic,UF,P_,Je,Ic,UF,O_,Je,xf,Tg,Ic,PY,vF,Ic,OY,NY,vF,cn,Tg,Ic,LY,xa,xf,Ic,tf,tf,JY,BY,DY,EY,Ic,wY,Ic,vY,kn,cn,kn,kn,kn,kn,cn,Ic,uY,Ic,AY,CY,FY,Ic,IY,HY,GY,Ic,xY]);function ob(){return s.byteLength/65536|0}function tb(ub){ub=ub|0;var pb=ob()|0;var qb=pb+ub|0;if(pb<qb&&qb<65536){var rb=new ArrayBuffer(B(qb,65536));var sb=new Int8Array(rb);sb.set(t);t=new Int8Array(rb);u=new Int16Array(rb);v=new Int32Array(rb);w=new Uint8Array(rb);x=new Uint16Array(rb);y=new Uint32Array(rb);z=new Float32Array(rb);A=new Float64Array(rb);s=rb;r.buffer=s;e=w}return pb}return{"ya":GV,"za":S6,"Aa":T6,"Ba":Ic,"Ca":Mb,"Da":R6,"Ea":O6,"Fa":L6,"Ga":Ns,"Ha":Je,"Ia":V6,"Ja":U6,"Ka":Y6,"La":Px,"Ma":W6,"Na":rK,"Oa":X6,"Pa":xf,"Qa":uK,"Ra":tK,"Sa":uK,"Ta":$3,"Ua":tY,"Va":sY,"Wa":rY,"Xa":K6,"Ya":oK,"Za":G6,"_a":nK,"$a":q6,"ab":i4,"bb":j4,"cb":o6,"db":n6,"eb":m6,"fb":p6,"gb":k4,"hb":M4,"ib":c4,"jb":P4,"kb":m5,"lb":f4,"mb":S4,"nb":h4,"ob":R4,"pb":d4,"qb":q4,"rb":m4,"sb":o4,"tb":E4,"ub":A4,"vb":C4,"wb":s4,"xb":u4,"yb":w4,"zb":y4,"Ab":g5,"Bb":i5,"Cb":u5,"Db":p5,"Eb":o5,"Fb":n5,"Gb":t5,"Hb":s5,"Ib":q5,"Jb":r5,"Kb":y5,"Lb":z5,"Mb":v5,"Nb":x5,"Ob":w5,"Pb":$4,"Qb":e5,"Rb":c5,"Sb":b5,"Tb":d5,"Ub":a5,"Vb":L4,"Wb":D5,"Xb":Z4,"Yb":W4,"Zb":k5,"_b":O4,"$b":X4,"ac":U4,"bc":T4,"cc":F5,"dc":H4,"ec":H5,"fc":J4,"gc":B5,"hc":E6,"ic":C6,"jc":qY,"kc":A6,"lc":x6,"mc":v6,"nc":t6,"oc":pY,"pc":s6,"qc":r6,"rc":l6,"sc":j6,"tc":h6,"uc":I5,"vc":g6,"wc":Od,"xc":nb,"yc":Paa,"zc":Tba,"Ac":qba,"Bc":zY,"Cc":yY,"Dc":oY,"Ec":mY,"Fc":hY,"Gc":nY,"Hc":mY,"Ic":lY,"Jc":iY,"Kc":kY,"Lc":jY,"Mc":iY,"Nc":hY,"Oc":hY}}return vb(xb)}
// EMSCRIPTEN_END_ASM




)(asmLibraryArg);
  },

  instantiate: /** @suppress{checkTypes} */ function(binary, info) {
    return {
      then: function(ok) {
        var module = new WebAssembly.Module(binary);
        ok({
          'instance': new WebAssembly.Instance(module)
        });
        // Emulate a simple WebAssembly.instantiate(..).then(()=>{}).catch(()=>{}) syntax.
        return { catch: function() {} };
      }
    };
  },

  RuntimeError: Error
};

// We don't need to actually download a wasm binary, mark it as present but empty.
wasmBinary = [];


